# automatically generated file, don't edit



# Copyright 2011 David Cantrell, derived from data from libphonenumber
# http://code.google.com/p/libphonenumber/
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
package Number::Phone::StubCountry::AM;
use base qw(Number::Phone::StubCountry);

use strict;
use warnings;
use utf8;
our $VERSION = 1.20220307120108;

my $formatters = [
                {
                  'format' => '$1 $2 $3',
                  'leading_digits' => '[89]0',
                  'national_rule' => '0 $1',
                  'pattern' => '(\\d{3})(\\d{2})(\\d{3})'
                },
                {
                  'format' => '$1 $2',
                  'leading_digits' => '
            2|
            3[12]
          ',
                  'national_rule' => '(0$1)',
                  'pattern' => '(\\d{3})(\\d{5})'
                },
                {
                  'format' => '$1 $2',
                  'leading_digits' => '
            1|
            47
          ',
                  'national_rule' => '(0$1)',
                  'pattern' => '(\\d{2})(\\d{6})'
                },
                {
                  'format' => '$1 $2',
                  'leading_digits' => '[3-9]',
                  'national_rule' => '0$1',
                  'pattern' => '(\\d{2})(\\d{6})'
                }
              ];

my $validators = {
                'fixed_line' => '
          (?:
            (?:
              1[0-25]|
              47
            )\\d|
            2(?:
              2[2-46]|
              3[1-8]|
              4[2-69]|
              5[2-7]|
              6[1-9]|
              8[1-7]
            )|
            3[12]2
          )\\d{5}
        ',
                'geographic' => '
          (?:
            (?:
              1[0-25]|
              47
            )\\d|
            2(?:
              2[2-46]|
              3[1-8]|
              4[2-69]|
              5[2-7]|
              6[1-9]|
              8[1-7]
            )|
            3[12]2
          )\\d{5}
        ',
                'mobile' => '
          (?:
            33|
            4[1349]|
            55|
            77|
            88|
            9[13-9]
          )\\d{6}
        ',
                'pager' => '',
                'personal_number' => '',
                'specialrate' => '(80[1-4]\\d{5})|(90[016]\\d{5})',
                'toll_free' => '800\\d{5}',
                'voip' => '
          60(?:
            2[78]|
            3[5-9]|
            4[02-9]|
            5[0-46-9]|
            [6-8]\\d|
            9[01]
          )\\d{4}
        '
              };
my %areanames = ();
$areanames{ru} = {"37428781", "Джермук\/Гндеваз\,\ ВАЙОЦДЗОРСКИЙ",
"3742682", "Дилижан\,\ Тавушский",
"3742360", "Айнтап\/Масис\/Нор\ Харберд\/Норабац\,\ Арарат",
"3742313", "Звартноц\,\ Армавир",
"3742672", "Берд\,\ Тавушский",
"37423190", "Баграмян\,\ Армавир",
"3742316", "Эчмиадзин\,\ Армавир",
"374470", "Нагорный\ Карабах",
"3742440", "Артик\/Пемзашен\,\ Ширакский",
"37424995", "Арагац\,\ Арагацо́тн",
"37410", "Ереван\/Джрвеж",
"3742241", "Канакераван\/Нор\ Гехи\/Нор\ Ачн\/Егвард\,\ Котайк",
"37426797", "Норашен\,\ Тавушский",
"3742355", "Арташат\,\ Арарат",
"37426897", "Техут\,\ Тавушский",
"3742566", "Степанаван\,\ Лори",
"3742563", "Степанаван\,\ Лори",
"3742538", "Алаверди\/Одзун\/Цахкашат\/Туманян\,\ Лори",
"374224811", "Егвард\,\ Котайк",
"37428499", "Корнидзор\,\ Сюника",
"374224819", "Нор\ Ачн\,\ Котайк",
"37423376", "Даларик\,\ Армавир",
"3742322", "Аштарак\,\ Арагацо́тн",
"37423492", "Мартиросян\,\ Арарат",
"374285813", "Капан\,\ Сюника",
"3742335", "Баграмян\/Лернагог\,\ Армавир",
"37422378", "Цахкадзор\,\ Котайк",
"37428546", "Каджаран\,\ Сюника",
"37422391", "Лернанист\,\ Котайк",
"3742328", "Ахцк\/Аштарак\/Карби\/Ошакан\,\ Арагацо́тн",
"374231819", "Звартноц\,\ Армавир",
"3742337", "Баграмян\,\ Армавир",
"374286817", "Агарак\/Мегри\,\ Сюника",
"3742848", "Горис\/Веришен\,\ Сюника",
"3742494", "Талин\/Арагац\/Катнахбюр\/Мастара\,\ Арагацо́тн",
"37424481", "Артик\/Паник\,\ Ширакский",
"37424973", "Катнахбюр\,\ Арагацо́тн",
"374238", "Арарат\/Авшар\/Суренаван\/Ерасх",
"37422370", "Раздан\,\ Котайк",
"37426692", "Арчис\,\ Тавушский",
"37423681", "Масис\,\ Арарат",
"37423474", "Веди\,\ Арарат",
"374476", "Аскеран",
"3742357", "Арташат\,\ Арарат",
"3742243", "Егвард\,\ Котайк",
"37431289", "Гюмри\/Ахурян\,\ Ширакский",
"3742246", "Егвард\,\ Котайк",
"37426696", "Воскепар\,\ Тавушский",
"374234513", "Веди\,\ Арарат",
"37415", "Ереван",
"3743221", "Ванадзор\/Гугарк\,\ Лори",
"374262", "Мартуни\,\ Гегаркуникский",
"37431287", "Гюмри\/Ахурян\,\ Ширакский",
"3742561", "Бовадзор\/Степанаван\,\ Лори",
"37423198", "Джрарат\,\ Армавир",
"37431283", "Ахурян\,\ Ширакский",
"3742640", "Гавар\/Сарухан\,\ Гегаркуникский",
"3742532", "Алаверди\,\ Лори",
"374223817", "Цахкадзор\,\ Котайк",
"37432298", "Лермонтово\,\ Лори",
"374224816", "Нор\ Ачн\,\ Котайк",
"3742311", "Эчмиадзин\/Мусалер\/Паракяр\/Звартноц\,\ Армавир",
"37428542", "Капан\,\ Сюника",
"3742678", "Айгепар\/Берд\,\ Тавушский",
"37431281", "Ахурян\,\ Ширакский",
"37428351", "Сисиан\,\ Сюника",
"37424293", "Ширакскийаван\,\ Ширакский",
"3742637", "Иджеван\,\ Тавушский",
"374234516", "Арарат\/Урцадзор\,\ Арарат",
"37424297", "Ани\ Каяран\,\ Ширакский",
"374285819", "Каджаран\,\ Сюника",
"37428194", "Арени\,\ ВАЙОЦДЗОРСКИЙ",
"374224813", "Егвард\,\ Котайк",
"3742422", "Маралик\,\ Ширакский",
"3742244", "Нор\ Ачн\,\ Котайк",
"3742862", "Агарак\,\ Сюника",
"37424492", "Паник\,\ Ширакский",
"37426681", "Ноемберян\/Воскепар\/Кочи\/Кохб\,\ Тавушский",
"37422399", "Раздан\,\ Котайк",
"37432295", "Ехегнут\,\ Лори",
"37422397", "Солак\,\ Котайк",
"37424496", "Мец\ Манташ\,\ Ширакский",
"3742340", "Арарат\/Веди\/Воскетап\,\ Арарат",
"37425695", "Лежан\,\ Лори",
"374284", "Горис\,\ Сюника",
"37422393", "Мехрадзор\,\ Котайк",
"3742817", "Гетап\/Салли\/Ехегнадзор\,\ ВАЙОЦДЗОРСКИЙ",
"3742851", "Давит\ Бек\/Каджаран\/Капан\,\ Сюника",
"3742543", "Ташир\/Мецаван\,\ Лори",
"3742225", "Абовян\/Арзни\/Ариндж\/Гехашен\,\ Котайк",
"37412", "Ереван",
"374285811", "Капан\,\ Сюника",
"3742378", "Аракс\/Армавир\/Октембер\/Ленухи\/Мецамор\/Зартонк\,\ Армавир",
"3742232", "Раздан\,\ Котайк",
"37423195", "Норакерт\,\ Армавир",
"3742856", "Капан\,\ Сюника",
"3742660", "Бердаван\/Кохб\/Ноемберян\,\ Тавушский",
"3742853", "Каджаран\,\ Сюника",
"37428491", "Аржис\,\ Сюника",
"374286814", "Мегри\,\ Сюника",
"3742372", "Армавир",
"374474", "Мартакерт",
"3742227", "Гарни\/Абовян\,\ Котайк",
"3742238", "Анкаван\/Раздан\/Цахкадзор\,\ Котайк",
"3742369", "Масис\,\ Арарат",
"374285816", "Каджаран\,\ Сюника",
"3742815", "Ехегнадзор\,\ ВАЙОЦДЗОРСКИЙ",
"3743120", "Гюмри\/Ахурян\,\ Ширакский",
"3742449", "Артик\,\ Ширакский",
"374255", "Спитак\,\ Лори",
"374234519", "Арарат\/Урцадзор\,\ Арарат",
"374223814", "Раздан\,\ Котайк",
"3742836", "Сисиан\,\ Сюника",
"3742833", "Сисиан\,\ Сюника",
"3742428", "Маралик\/Сарнахбюр\,\ Ширакский",
"3742868", "Мегри\/Агарак\,\ Сюника",
"374234511", "Веди\,\ Арарат",
"37422375", "Цахкадзор\,\ Котайк",
"37422453", "Прошян\,\ Котайк",
"3742564", "Степанаван\,\ Лори",
"37422294", "Арзни\,\ Котайк",
"37426299", "Еранос\,\ Гегаркуникский",
"37426791", "Навур\,\ Тавушский",
"37423481", "Айгаван\,\ Арарат",
"3742635", "Азатамут\/Гетаховит\/Иджеван\/Енокаван\,\ Тавушский",
"3742314", "Эчмиадзин\,\ Армавир",
"3742861", "Мегри\/Агарак\,\ Сюника",
"37425691", "Куртан\,\ Лори",
"3742421", "Маралик\/Сарнахбюр\,\ Ширакский",
"3742832", "Сисиан\,\ Сюника",
"37425353", "Шнох\,\ Лори",
"3742345", "Арарат\/Веди\/Воскетап\,\ Арарат",
"374286811", "Мегри\,\ Сюника",
"37426381", "Иджеван\/Айгеховит\/Ачаджур\,\ Тавушский",
"3743127", "Ахурян\,\ Ширакский",
"37423476", "Арарат\/Урцадзор\,\ Арарат",
"37425357", "Туманян\,\ Лори",
"37428544", "Капан\,\ Сюника",
"3742667", "Бердаван\/Ноемберян\,\ Тавушский",
"3742684", "Дилижан\/Агарцин\/Техут\,\ Тавушский",
"37423191", "Ваче\,\ Армавир",
"374223819", "Цахкадзор\,\ Котайк",
"3742623", "Мартуни\/Варденик\,\ Гегаркуникский",
"3742220", "Абовян\/Акунк\/Бюрегаван\/Нор\ Гюх\/Верин\ Птхни\,\ Котайк",
"3742674", "Айгепар\/Берд\,\ Тавушский",
"374223811", "Раздан\,\ Котайк",
"37428181", "Ехегнадзор\/Малишка\/Шатин\,\ ВАЙОЦДЗОРСКИЙ",
"37426652", "Кохб\,\ Тавушский",
"3742852", "Капан\,\ Сюника",
"3742324", "Аштарак\/Бюракан\/Оганаван\,\ Арагацо́тн",
"37426581", "Чамбарак\/Ваан\,\ Гегаркуникский",
"3742231", "Анкаван\/Раздан\/Цахкадзор\,\ Котайк",
"374234514", "Веди\,\ Арарат",
"3742373", "Мецамор\,\ Армавир",
"3742376", "Армавир",
"37423472", "Веди\,\ Арарат",
"3742570", "Цахкаховит\,\ Арагацо́тн",
"37426694", "Ноемберян\,\ Тавушский",
"37423771", "Армавир",
"374231817", "Звартноц\,\ Армавир",
"37422398", "Бжни\,\ Котайк",
"374286819", "Агарак\/Мегри\,\ Сюника",
"3742339", "Баграмян\,\ Армавир",
"37422281", "Абовян\/Арзни\/Ариндж\/Гехашен\,\ Котайк",
"37422371", "Раздан\,\ Котайк",
"37423798", "Шенаван\,\ Армавир",
"374223816", "Цахкадзор\,\ Котайк",
"37428375", "Тасик\,\ Сюника",
"374224817", "Нор\ Ачн\,\ Котайк",
"3742630", "Азатамут\/Гетаховит\/Иджеван\/Енокаван\,\ Тавушский",
"37426895", "Агарцин\,\ Тавушский",
"3742858", "Давит\ Бек\/Каджаран\/Капан\,\ Сюника",
"37422390", "Раздан\,\ Котайк",
"3742236", "Раздан\,\ Котайк",
"37424997", "Мастара\,\ Арагацо́тн",
"3742233", "Раздан\,\ Котайк",
"3742371", "Аракс\/Армавир\/Октембер\/Ленухи\/Мецамор\/Зартонк\,\ Армавир",
"37423374", "Мясникян\,\ Армавир",
"374322", "Ванадзор\,\ Лори",
"374286816", "Агарак\/Мегри\,\ Сюника",
"37425781", "Цахкаховит\,\ Арагацо́тн",
"37428495", "Шинуайр\,\ Сюника",
"3742665", "Кохб\/Ноемберян\,\ Тавушский",
"3742866", "Мегри\,\ Сюника",
"3742426", "Маралик\,\ Ширакский",
"3742423", "Маралик\,\ Ширакский",
"3742863", "Мегри\,\ Сюника",
"3742838", "Сисиан\,\ Сюника",
"374285814", "Капан\,\ Сюника",
"37422675", "Алапарс\/Варданаванк\,\ Котайк",
"3742810", "Гетап\/Салли\/Ехегнадзор\,\ ВАЙОЦДЗОРСКИЙ",
"3742534", "Алаверди\,\ Лори",
"37422292", "Зовк\/Абовян\,\ Котайк",
"3743228", "Ванадзор\/Гугарк\,\ Лори",
"3742424", "Маралик\,\ Ширакский",
"3742864", "Мегри\,\ Сюника",
"3742242", "Егвард\,\ Котайк",
"374286813", "Мегри\,\ Сюника",
"3742639", "Иджеван\,\ Тавушский",
"3742536", "Алаверди\,\ Лори",
"3742533", "Алаверди\,\ Лори",
"3742568", "Бовадзор\/Степанаван\,\ Лори",
"37425281", "Апаран\/Артаван\/Кучак\,\ Арагацо́тн",
"3742330", "Баграмян\/Лернагог\,\ Армавир",
"3742671", "Айгепар\/Берд\,\ Тавушский",
"37431280", "Ахурян\,\ Ширакский",
"3742318", "Эчмиадзин\/Мусалер\/Паракяр\/Звартноц\,\ Армавир",
"37426253", "Варденик\,\ Гегаркуникский",
"3742445", "Артик\,\ Ширакский",
"3742321", "Ахцк\/Аштарак\/Карби\/Ошакан\,\ Арагацо́тн",
"37422377", "Цахкадзор\,\ Котайк",
"374234517", "Арарат\/Урцадзор\,\ Арарат",
"37422379", "Цахкадзор\,\ Котайк",
"37426374", "Айгеховит\,\ Тавушский",
"3742365", "Масис\,\ Арарат",
"3742234", "Раздан\,\ Котайк",
"37428794", "Гндеваз\,\ ВАЙОЦДЗОРСКИЙ",
"374223813", "Раздан\,\ Котайк",
"37422373", "Раздан\,\ Котайк",
"3742841", "Горис\/Веришен\,\ Сюника",
"374269", "Варденис\,\ Гегаркуникский",
"3742350", "Арташат\/Айгезард\/Далар\/Кахцрашен\/Мхчян\/Шаумян\,\ Арарат",
"3742647", "Гавар\/Сарухан\,\ Гегаркуникский",
"374226", "Чаренцаван\,\ Котайк",
"374261", "Севан\,\ Гегаркуникский",
"37422296", "Птхни\,\ Котайк",
"374254", "Ташир\,\ Лори",
"37428695", "Шванидзор\,\ Сюника",
"37426392", "Ачаджур\,\ Тавушский",
"37423381", "Баграмян\/Мясникян\,\ Армавир",
"37423779", "Бамбакашат\,\ Армавир",
"3742323", "Аштарак\,\ Арагацо́тн",
"374475", "Гадрут",
"3742367", "Айнтап\/Масис\/Нор\ Харберд\/Норабац\,\ Арарат",
"37426596", "Ваан\,\ Гегаркуникский",
"37423290", "Оганаван\,\ Арагацо́тн",
"374249", "Талин\,\ Арагацо́тн",
"3742326", "Аштарак\,\ Арагацо́тн",
"3742447", "Артик\/Пемзашен\,\ Ширакский",
"3742374", "Армавир",
"374224814", "Егвард\,\ Котайк",
"37428196", "Ехегнадзор\,\ ВАЙОЦДЗОРСКИЙ",
"37428192", "Ехегнадзор\,\ ВАЙОЦДЗОРСКИЙ",
"3742683", "Дилижан\,\ Тавушский",
"37432293", "Памбак\,\ Лори",
"3742686", "Дилижан\,\ Тавушский",
"37432297", "Дзорагет\,\ Лори",
"3742312", "Эчмиадзин\,\ Армавир",
"3742676", "Берд\,\ Тавушский",
"37432299", "Ваагни\,\ Лори",
"37422395", "Раздан\,\ Котайк",
"3742673", "Берд\/Мосесгех\/Навур\/Норашен\,\ Тавушский",
"37423581", "Арташат\/Норашен\,\ Арарат",
"37423199", "Хоронк\,\ Армавир",
"3742248", "Канакераван\/Нор\ Гехи\/Нор\ Ачн\/Егвард\,\ Котайк",
"37423197", "Эчмиадзин\,\ Армавир",
"374473", "Нагорный\ Карабах",
"374285817", "Каджаран\,\ Сюника",
"37423193", "Эчмиадзин\,\ Армавир",
"3742531", "Алаверди\/Одзун\/Цахкашат\/Туманян\,\ Лори",
"3742562", "Степанаван\,\ Лори",
"37431288", "Гюмри\/Ахурян\,\ Ширакский",
"3742429", "Маралик\,\ Ширакский",
"374286810", "Мегри\,\ Сюника",
"3742869", "Мегри\,\ Сюника",
"3742634", "Иджеван\,\ Тавушский",
"3742315", "Эчмиадзин\,\ Армавир",
"374312", "Гюмри\,\ Ширакский",
"374224815", "Нор\ Ачн\,\ Котайк",
"37422374", "Раздан\,\ Котайк",
"37423470", "Веди\,\ Арарат",
"37422295", "Зовк\/Абовян\,\ Котайк",
"3742356", "Арташат\,\ Арарат",
"37423792", "Налбандяна\,\ Армавир",
"3742565", "Бовадзор\/Степанаван\,\ Лори",
"37426781", "Берд\/Мосесгех\/Навур\/Норашен\,\ Тавушский",
"374472", "Нагорный\ Карабах",
"3742247", "Егвард\/Нор\ Ачн\,\ Котайк",
"3742353", "Арташат\/Норашен\,\ Арарат",
"37426881", "Дилижан\/Агарцин\/Техут\,\ Тавушский",
"37422452", "Зовуни\,\ Котайк",
"3742654", "Чамбарак\/Ваан\,\ Гегаркуникский",
"37423281", "Аштарак\/Бюракан\/Оганаван\,\ Арагацо́тн",
"374223810", "Раздан\,\ Котайк",
"3742814", "Гетап\/Салли\/Ехегнадзор\,\ ВАЙОЦДЗОРСКИЙ",
"37423796", "Тандзут\,\ Армавир",
"3742530", "Алаверди\/Одзун\/Цахкашат\/Туманян\,\ Лори",
"3742336", "Баграмян\,\ Армавир",
"3742368", "Айнтап\/Масис\/Нор\ Харберд\/Норабац\,\ Арарат",
"3742333", "Баграмян\/Мясникян\,\ Армавир",
"374285818", "Каджаран\,\ Сюника",
"3742448", "Артик\/Пемзашен\,\ Ширакский",
"3742680", "Дилижан\,\ Тавушский",
"37424300", "Ахурян\/Арапи\/Камо\/Мусаелян\,\ Ширакский",
"3742331", "Баграмян\/Лернагог\,\ Армавир",
"37432294", "Лернапат\,\ Лори",
"3742362", "Масис\,\ Арарат",
"37425694", "Агарак\,\ Лори",
"3742224", "Абовян\,\ Котайк",
"3742442", "Артик\,\ Ширакский",
"3742670", "Айгепар\/Берд\,\ Тавушский",
"37428541", "Капан\,\ Сюника",
"37422396", "Раздан\,\ Котайк",
"3742648", "Гавар\/Сарухан\,\ Гегаркуникский",
"3742379", "Армавир\/Налбандяна",
"37423194", "Эчмиадзин\,\ Армавир",
"37423699", "Даштаван\,\ Арарат",
"3742351", "Арташат\/Айгезард\/Далар\/Кахцрашен\/Мхчян\/Шаумян\,\ Арарат",
"37422392", "Раздан\,\ Котайк",
"37423478", "Арарат\/Урцадзор\,\ Арарат",
"3742567", "Бовадзор\/Степанаван\,\ Лори",
"374234518", "Арарат\/Урцадзор\,\ Арарат",
"37428195", "Малишка\,\ ВАЙОЦДЗОРСКИЙ",
"3742245", "Егвард\,\ Котайк",
"374282", "Вайк\,\ ВАЙОЦДЗОРСКИЙ",
"374246", "Амасия\,\ Ширакский",
"3742320", "Ахцк\/Аштарак\/Карби\/Ошакан\,\ Арагацо́тн",
"37425381", "Алаверди\/Ахтала\/Туманян\,\ Лори",
"3742840", "Горис\/Веришен\,\ Сюника",
"374224812", "Егвард\,\ Котайк",
"374234", "Арарат\/Веди\,\ Арарат",
"37426691", "Ноемберян\,\ Тавушский",
"3742317", "Звартноц\,\ Армавир",
"3742662", "Ноемберян\,\ Тавушский",
"3742631", "Азатамут\/Гетаховит\/Иджеван\/Енокаван\,\ Тавушский",
"374287", "Джермук\,\ ВАЙОЦДЗОРСКИЙ",
"3742370", "Аракс\/Армавир\/Октембер\/Ленухи\/Мецамор\/Зартонк\,\ Армавир",
"374234512", "Веди\,\ Арарат",
"37426693", "Баганис\,\ Тавушский",
"3742573", "Цахкаховит\,\ Арагацо́тн",
"3742837", "Сисиан\,\ Сюника",
"3742689", "Дилижан\,\ Тавушский",
"3742576", "Цахкаховит\,\ Арагацо́тн",
"37431286", "Гюмри\/Ахурян\,\ Ширакский",
"374312859", "Ахурян\,\ Ширакский",
"37426699", "Кочи\,\ Тавушский",
"37426697", "Ноемберян\,\ Тавушский",
"3742679", "Берд\,\ Тавушский",
"3742524", "Апаран\/Артаван\/Кучак\,\ Арагацо́тн",
"374224818", "Нор\ Ачн\,\ Котайк",
"37431282", "Ахурян\,\ Ширакский",
"3742329", "Аштарак\,\ Арагацо́тн",
"374285815", "Каджаран\,\ Сюника",
"3742811", "Гетап\/Салли\/Ехегнадзор\,\ ВАЙОЦДЗОРСКИЙ",
"3742857", "Давит\ Бек\/Каджаран\/Капан\,\ Сюника",
"37428543", "Капан\,\ Сюника",
"37428427", "Веришен\,\ Сюника",
"37428198", "Ринд\,\ ВАЙОЦДЗОРСКИЙ",
"3742223", "Абовян\,\ Котайк",
"37428549", "Каджаран\,\ Сюника",
"37423475", "Арарат\/Урцадзор\,\ Арарат",
"37422290", "Маяковский\,\ Котайк",
"3742226", "Абовян\,\ Котайк",
"37428151", "Хачик\,\ ВАЙОЦДЗОРСКИЙ",
"37428547", "Каджаран\,\ Сюника",
"374264", "Гавар\,\ Гегаркуникский",
"3742334", "Баграмян\/Лернагог\,\ Армавир",
"37423748", "Аракс\/Армавир\/Октембер\/Ленухи\/Мецамор\/Зартонк\,\ Армавир",
"3742855", "Капан\,\ Сюника",
"3742221", "Абовян\/Акунк\/Бюрегаван\/Нор\ Гюх\/Верин\ Птхни\,\ Котайк",
"37423781", "Армавир",
"3742420", "Маралик\/Сарнахбюр\,\ Ширакский",
"3742860", "Мегри\/Агарак\,\ Сюника",
"37422298", "Ариндж\,\ Котайк",
"3742813", "Ехегнадзор\/Малишка\/Шатин\,\ ВАЙОЦДЗОРСКИЙ",
"37428190", "Ехегнадзор\,\ ВАЙОЦДЗОРСКИЙ",
"3742816", "Ехегнадзор\,\ ВАЙОЦДЗОРСКИЙ",
"37425295", "Артаван\,\ Арагацо́тн",
"374285812", "Капан\,\ Сюника",
"374478", "Мартуни",
"3742354", "Арташат\/Айгезард\/Далар\/Кахцрашен\/Мхчян\/Шаумян\,\ Арарат",
"37425494", "Мецаван\,\ Лори",
"37426796", "Мосесгех\,\ Тавушский",
"37423486", "Урцадзор\,\ Арарат",
"374477", "Шуши",
"37426281", "Мартуни\/Варденик\,\ Гегаркуникский",
"3742633", "Иджеван\,\ Тавушский",
"37423497", "Покр\ Веди\,\ Арарат",
"3742668", "Бердаван\/Кохб\/Ноемберян\,\ Тавушский",
"37422672", "Арзакан\,\ Котайк",
"3742636", "Иджеван\,\ Тавушский",
"374231818", "Звартноц\,\ Армавир",
"3742539", "Алаверди\/Одзун\/Цахкашат\/Туманян\,\ Лори",
"374234515", "Арарат\/Урцадзор\,\ Арарат",
"3742230", "Анкаван\/Раздан\/Цахкадзор\,\ Котайк",
"3742867", "Мегри\/Агарак\,\ Сюника",
"3742427", "Маралик\/Сарнахбюр\,\ Ширакский",
"37426698", "Ноемберян\,\ Тавушский",
"37422394", "Пюник\,\ Котайк",
"37426397", "Азатамут\,\ Тавушский",
"3743121", "Гюмри\/Ахурян\,\ Ширакский",
"37423196", "Эчмиадзин\,\ Армавир",
"3742632", "Иджеван\/Айгеховит\/Ачаджур\,\ Тавушский",
"37423772", "Мргашат\,\ Армавир",
"3742661", "Бердаван\/Кохб\/Ноемберян\,\ Тавушский",
"374224810", "Егвард\,\ Котайк",
"3742249", "Егвард\,\ Котайк",
"37432296", "Маргаовит\,\ Лори",
"37423471", "Веди\,\ Арарат",
"37424495", "Аревшат\,\ Ширакский",
"374252", "Апаран\,\ Арагацо́тн",
"374286815", "Агарак\/Мегри\,\ Сюника",
"37424231", "Сарнахбюр\,\ Ширакский",
"37428197", "Елпин\,\ ВАЙОЦДЗОРСКИЙ",
"37428199", "Шатин\,\ ВАЙОЦДЗОРСКИЙ",
"3742375", "Армавир",
"37428548", "Каджаран\,\ Сюника",
"3742228", "Абовян\/Акунк\/Бюрегаван\/Нор\ Гюх\/Верин\ Птхни\,\ Котайк",
"37428193", "Агавнадзор\,\ ВАЙОЦДЗОРСКИЙ",
"37426272", "Личк\,\ Гегаркуникский",
"37423192", "Эчмиадзин\,\ Армавир",
"374223815", "Цахкадзор\,\ Котайк",
"3742812", "Ехегнадзор\,\ ВАЙОЦДЗОРСКИЙ",
"37422297", "Гехашен\,\ Котайк",
"37428540", "Капан\,\ Сюника",
"37422299", "Котайк",
"3742830", "Сисиан\,\ Сюника",
"374223812", "Раздан\,\ Котайк",
"3742818", "Гетап\/Салли\/Ехегнадзор\,\ ВАЙОЦДЗОРСКИЙ",
"37425481", "Ташир\/Мецаван\,\ Лори",
"37422293", "Арамус\,\ Котайк",
"37422454", "Аргел\,\ Котайк",
"37423747", "Аракс\/Армавир\/Октембер\/Ленухи\/Мецамор\/Зартонк\,\ Армавир",
"3742364", "Масис\,\ Арарат",
"37423749", "Аракс\/Армавир\/Октембер\/Ленухи\/Мецамор\/Зартонк\,\ Армавир",
"3742235", "Цахкадзор\,\ Котайк",
"37426252", "Варденик\,\ Гегаркуникский",
"3742222", "Абовян\,\ Котайк",
"37422376", "Цахкадзор\,\ Котайк",
"3742444", "Артик\/Паник\,\ Ширакский",
"37424981", "Талин\/Арагац\/Катнахбюр\/Мастара\,\ Арагацо́тн",
"3742377", "Армавир\/Мргашат",
"3742663", "Ноемберян\/Воскепар\/Кочи\/Кохб\,\ Тавушский",
"3742638", "Азатамут\/Гетаховит\/Иджеван\/Енокаван\,\ Тавушский",
"37422372", "Раздан\,\ Котайк",
"37426690", "Ноемберян\,\ Тавушский",
"3742666", "Ноемберян\,\ Тавушский",
"3742850", "Давит\ Бек\/Каджаран\/Капан\,\ Сюника",
"3742569", "Степанаван\,\ Лори",
"37423498", "Таперакан\,\ Арарат",
"374286812", "Мегри\,\ Сюника",
"3742572", "Цахкаховит\,\ Арагацо́тн",
"37425291", "Кучак\,\ Арагацо́тн",
"3742425", "Маралик\/Сарнахбюр\,\ Ширакский",
"3742865", "Агарак\/Шванидзор\,\ Сюника",
"3742341", "Арарат\/Веди\/Воскетап\,\ Арарат",
"37423794", "Маргара\,\ Армавир",
"3742535", "Алаверди\,\ Лори",
"37423375", "Каракерт\,\ Армавир",
"37423294", "Бюракан\,\ Арагацо́тн",
"3742358", "Арташат\/Айгезард\/Далар\/Кахцрашен\/Мхчян\/Шаумян\,\ Арарат",
"374286818", "Агарак\/Мегри\,\ Сюника",
"37428494", "Хндзореск\,\ Сюника",
"3742839", "Сисиан\,\ Сюника",
"3742664", "Бердаван\/Кохб\/Ноемберян\,\ Тавушский",
"3742677", "Берд\,\ Тавушский",
"3742366", "Масис\,\ Арарат",
"374265", "Чамбарак\,\ Гегаркуникский",
"374223818", "Цахкадзор\,\ Котайк",
"3742338", "Баграмян\/Лернагог\,\ Армавир",
"3742327", "Ахцк\/Аштарак\/Карби\/Ошакан\,\ Арагацо́тн",
"3742363", "Айнтап\/Масис\,\ Арарат",
"37422291", "Балаовит\/Камарис\,\ Котайк",
"3742446", "Артик\,\ Ширакский",
"3742310", "Эчмиадзин\/Мусалер\/Паракяр\/Звартноц\,\ Армавир",
"3742443", "Артик\,\ Ширакский",
"3742847", "Горис\/Веришен\,\ Сюника",
"3743220", "Ванадзор\/Гугарк\,\ Лори",
"374285810", "Капан\,\ Сюника",
"3742859", "Капан\,\ Сюника",
"37426794", "Товуз\,\ Тавушский",
"3742641", "Гавар\/Сарухан\,\ Гегаркуникский",
"3742560", "Бовадзор\/Степанаван\,\ Лори",
"3742240", "Канакераван\/Нор\ Гехи\/Нор\ Ачн\/Егвард\,\ Котайк",
"374245", "Ашоцк\,\ Ширакский",
"3742549", "Ташир\/Мецаван\,\ Лори",
"37428191", "Арпи\,\ ВАЙОЦДЗОРСКИЙ",
"374479", "Степанакерт",
"37431284", "Ахурян\,\ Ширакский",
"374471", "Степанакерт",
"37425352", "Ахтала\,\ Лори",
"3742499", "Арагацаван\/Талин\,\ Арагацо́тн",
"3742361", "Айнтап\/Масис\/Нор\ Харберд\/Норабац\,\ Арарат",
"37447732", "Бердзор\/Кашатах",
"3742332", "Баграмян\,\ Армавир",
"37426695", "Зоракан\,\ Тавушский",
"3742441", "Артик\/Пемзашен\,\ Ширакский",
"37411", "Ереван",
"3742325", "Ахцк\/Аштарак\/Карби\/Ошакан\,\ Арагацо́тн",
"374257", "Арагац\,\ Арагацо́тн",
"37428396", "Ангехакот\,\ Сюника",
"374234510", "Веди\,\ Арарат",
"3742675", "Арцваберд\/Берд\,\ Тавушский",
"37425681", "Степанаван\,\ Лори",
"37426653", "Кохб\,\ Тавушский",
"37425356", "Чочкан\,\ Лори",
"37423477", "Арарат\/Урцадзор\,\ Арарат",
"37423181", "Эчмиадзин\,\ Армавир",
"37423479", "Арарат\/Урцадзор\,\ Арарат",
"37428545", "Каджаран\,\ Сюника",
"3742352", "Арташат\,\ Арарат",
"3742537", "Алаверди\/Ахтала\/Туманян\,\ Лори",
"3742873", "Джермук\/Гндеваз\,\ ВАЙОЦДЗОРСКИЙ",
"37423473", "Веди\,\ Арарат",};
$areanames{hy} = {"3742812", "Եղեգնաձոր\,\ Վայոց\ Ձոր",
"37423192", "Էջմիածին\,\ Արմավիր",
"374223815", "Ծաղկաձոր\,\ Կոտայք",
"37428193", "Աղավնաձոր\,\ Վայոց\ Ձոր",
"3742228", "Աբովյան\/Ակունք\/Բյուրեղավան\/Նոր\ Գյուղ\/Վերին\ Պտղնի\,\ Կոտայք",
"37426272", "Լիճք\,\ Գեղարքունիք",
"37428199", "Շատին\,\ Վայոց\ Ձոր",
"37428197", "Ելփին\,\ Վայոց\ Ձոր",
"37428548", "Քաջարան\,\ Սյունիք",
"3742375", "Արմավիր",
"37424495", "Արևշատ\,\ Շիրակ",
"374252", "Ապարան\,\ Արագածոտն",
"37424231", "Սառնաղբյուր\,\ Շիրակ",
"374286815", "Ագարակ\/Մեղրի\,\ Սյունիք",
"37423772", "Մրգաշատ\,\ Արմավիր",
"3742632", "Իջեւան\/Այգեհովիտ\/Աչաջուր\,\ Տավուշ",
"37432296", "Մարգահովիտ\,\ Լոռի",
"37423471", "Վեդի\,\ Արարատ",
"3742661", "Բերդավան\/Կողբ\/Նոյեմբերյան\,\ Տավուշ",
"374224810", "Եղվարդ\,\ Կոտայք",
"3742249", "Եղվարդ\,\ Կոտայք",
"37426397", "Ազատամուտ\,\ Տավուշ",
"37422394", "Փյունիք\,\ Կոտայք",
"3743121", "Գյումրի\/Ախուրյան\,\ Շիրակ",
"37423196", "Էջմիածին\,\ Արմավիր",
"37426698", "Նոյեմբերյան\,\ Տավուշ",
"3742867", "Մեղրի\/Ագարակ\,\ Սյունիք",
"3742427", "Մարալիկ\/Սառնաղբյուր\,\ Շիրակ",
"3742425", "Մարալիկ\/Սառնաղբյուր\,\ Շիրակ",
"3742865", "Ագարակ\/Շվանիձոր\,\ Սյունիք",
"37423794", "Մարգարա\,\ Արմավիր",
"3742341", "Արարատ\/Վեդի\/Ոսկետափ\,\ Արարատ",
"3742572", "Ծաղկահովիտ\,\ Արագածոտն",
"37425291", "Քուչակ\,\ Արագածոտն",
"3742569", "Ստեփանավան\,\ Լոռի",
"37423498", "Տափերական\,\ Արարատ",
"374286812", "Մեղրի\,\ Սյունիք",
"3742638", "Ազատամուտ\/Գետահովիտ\/Իջեւան\/Ենոքավան\,\ Տավուշ",
"3742663", "Նոյեմբերյան\/Ոսկեպար\/Կոթի\/Կողբ\,\ Տավուշ",
"37426690", "Նոյեմբերյան\,\ Տավուշ",
"3742666", "Նոյեմբերյան\,\ Տավուշ",
"3742850", "Դավիթ\ Բեկ\/Քաջարան\/Կապան\,\ Սյունիք",
"37422372", "Հրազդան\,\ Կոտայք",
"3742222", "Աբովյան\,\ Կոտայք",
"37422376", "Ծաղկաձոր\,\ Կոտայք",
"3742444", "Արթիկ\/Փանիկ\,\ Շիրակ",
"3742377", "Արմավիր\/Մրգաշատ",
"37424981", "Թալին\/Արագած\/Կաթնաղբյուր\/Մաստարա\,\ Արագածոտն",
"37423749", "Արաքս\/Արմավիր\/Հոկտեմբեր\/Լենուղի\/Մեծամոր\/Զարթոնք\,\ Արմավիր",
"3742235", "Ծաղկաձոր\,\ Կոտայք",
"37423747", "Արաքս\/Արմավիր\/Հոկտեմբեր\/Լենուղի\/Մեծամոր\/Զարթոնք\,\ Արմավիր",
"3742364", "Մասիս\,\ Արարատ",
"37426252", "Վարդենիկ\,\ Գեղարքունիք",
"37425481", "Տաշիր\/Մեծավան\,\ Լոռի",
"37422293", "Արամուս\,\ Կոտայք",
"3742818", "Գետափ\/Սալլի\/Եղեգնաձոր\,\ Վայոց\ Ձոր",
"37422454", "Արգել\,\ Կոտայք",
"37428540", "Կապան\,\ Սյունիք",
"37422299", "Կոտայք",
"37422297", "Գեղաշեն\,\ Կոտայք",
"3742830", "Սիսիան\,\ Սյունիք",
"374223812", "Հրազդան\,\ Կոտայք",
"3742641", "Գավառ\/Սարուխան\,\ Գեղարքունիք",
"37426794", "Թովուզ\,\ Տավուշ",
"3742560", "Բովաձոր\/Ստեփանավան\,\ Լոռի",
"3742859", "Կապան\,\ Սյունիք",
"374285810", "Կապան\,\ Սյունիք",
"3743220", "Վանաձոր\/Գուգարք\,\ Լոռի",
"3742446", "Արթիկ\,\ Շիրակ",
"3742310", "Էջմիածին\/Մուսալեռ\/Փարաքար\/Զվարթնոց\,\ Արմավիր",
"3742847", "Գորիս\/Վերիշեն\,\ Սյունիք",
"3742443", "Արթիկ\,\ Շիրակ",
"374223818", "Ծաղկաձոր\,\ Կոտայք",
"374265", "Ճամբարակ\,\ Գեղարքունիք",
"3742366", "Մասիս\,\ Արարատ",
"3742363", "Այնթապ\/Մասիս\,\ Արարատ",
"37422291", "Բալահովիտ\/Կամարիս\,\ Կոտայք",
"3742338", "Բաղրամյան\/Լեռնագոգ\,\ Արմավիր",
"3742327", "Աղձք\/Աշտարակ\/Կարբի\/Օշական\,\ Արագածոտն",
"3742677", "Բերդ\,\ Տավուշ",
"3742839", "Սիսիան\,\ Սյունիք",
"3742664", "Բերդավան\/Կողբ\/Նոյեմբերյան\,\ Տավուշ",
"374286818", "Ագարակ\/Մեղրի\,\ Սյունիք",
"37428494", "Խնձորեսկ\,\ Սյունիք",
"3742535", "Ալավերդի\,\ Լոռի",
"37423375", "Քարակերտ\,\ Արմավիր",
"3742358", "Արտաշատ\/Այգեզարդ\/Դալար\/Քաղցրաշեն\/Մխչյան\/Շահումյան\,\ Արարատ",
"37423294", "Բյուրական\,\ Արագածոտն",
"37423473", "Վեդի\,\ Արարատ",
"3742537", "Ալավերդի\/Ախթալա\/Թումանյան\,\ Լոռի",
"3742873", "Ջերմուկ\/Գնդեվազ\,\ Վայոց\ Ձոր",
"37423479", "Արարատ\/Ուրցաձոր\,\ Արարատ",
"37428545", "Քաջարան\,\ Սյունիք",
"37425356", "Ճոճկան\,\ Լոռի",
"37423477", "Արարատ\/Ուրցաձոր\,\ Արարատ",
"37423181", "Էջմիածին\,\ Արմավիր",
"3742352", "Արտաշատ\,\ Արարատ",
"37426653", "Կողբ\,\ Տավուշ",
"374234510", "Վեդի\,\ Արարատ",
"3742675", "Արծվաբերդ\/Բերդ\,\ Տավուշ",
"37428396", "Անգեղակոթ\,\ Սյունիք",
"374257", "Արագած\,\ Արագածոտն",
"37425681", "Ստեփանավան\,\ Լոռի",
"3742441", "Արթիկ\/Պեմզաշեն\,\ Շիրակ",
"37411", "Երևան",
"3742325", "Աղձք\/Աշտարակ\/Կարբի\/Օշական\,\ Արագածոտն",
"3742361", "Այնթապ\/Մասիս\/Նոր\ Խարբերդ\/Նորաբաց\,\ Արարատ",
"37447732", "Բերձոր\/Քաշաթաղ",
"3742499", "Արագածավան\/Թալին\,\ Արագածոտն",
"3742332", "Բաղրամյան\,\ Արմավիր",
"37426695", "Զորական\,\ Տավուշ",
"37431284", "Ախուրյան\,\ Շիրակ",
"37425352", "Ախթալա\,\ Լոռի",
"374471", "Ստեփանակերտ",
"374245", "Աշոցք\,\ Շիրակ",
"3742240", "Քանաքեռավան\/Նոր\ Գեղի\/Նոր\ Հաճն\/Եղվարդ\,\ Կոտայք",
"37428191", "Արփի\,\ Վայոց\ Ձոր",
"374479", "Ստեփանակերտ",
"3742549", "Տաշիր\/Մեծավան\,\ Լոռի",
"374285818", "Քաջարան\,\ Սյունիք",
"3742448", "Արթիկ\/Պեմզաշեն\,\ Շիրակ",
"3742336", "Բաղրամյան\,\ Արմավիր",
"3742333", "Բաղրամյան\/Մյասնիկյան\,\ Արմավիր",
"3742368", "Այնթապ\/Մասիս\/Նոր\ Խարբերդ\/Նորաբաց\,\ Արարատ",
"374223810", "Հրազդան\,\ Կոտայք",
"37423281", "Աշտարակ\/Բյուրական\/Օհանավան\,\ Արագածոտն",
"37423796", "Տանձուտ\,\ Արմավիր",
"3742530", "Ալավերդի\/Օձուն\/Ծաղկաշատ\/Թումանյան\,\ Լոռի",
"3742814", "Գետափ\/Սալլի\/Եղեգնաձոր\,\ Վայոց\ Ձոր",
"37422452", "Զովունի\,\ Կոտայք",
"3742654", "Ճամբարակ\/Վահան\,\ Գեղարքունիք",
"37426881", "Դիլիջան\/Հաղարծին\/Թեղուտ\,\ Տավուշ",
"3742565", "Բովաձոր\/Ստեփանավան\,\ Լոռի",
"3742356", "Արտաշատ\,\ Արարատ",
"37423792", "Նալբանդյան\,\ Արմավիր",
"3742247", "Եղվարդ\/Նոր\ Հաճն\,\ Կոտայք",
"3742353", "Արտաշատ\/Նորաշեն\,\ Արարատ",
"37426781", "Բերդ\/Մոսեսգեղ\/Նավուր\/Նորաշեն\,\ Տավուշ",
"374472", "Լեռնային\ Ղարաբաղ",
"37422374", "Հրազդան\,\ Կոտայք",
"374224815", "Նոր\ Հաճն\,\ Կոտայք",
"374312", "Գյումրի\,\ Շիրակ",
"37422295", "Զովք\/Աբովյան\,\ Կոտայք",
"37423470", "Վեդի\,\ Արարատ",
"3742429", "Մարալիկ\,\ Շիրակ",
"374286810", "Մեղրի\,\ Սյունիք",
"3742869", "Մեղրի\,\ Սյունիք",
"3742634", "Իջեւան\,\ Տավուշ",
"3742315", "Էջմիածին\,\ Արմավիր",
"3742840", "Գորիս\/Վերիշեն\,\ Սյունիք",
"374224812", "Եղվարդ\,\ Կոտայք",
"374234", "Արարատ\/Վեդի\,\ Արարատ",
"37426691", "Նոյեմբերյան\,\ Տավուշ",
"3742317", "Զվարթնոց\,\ Արմավիր",
"374282", "Վայք\,\ Վայոց\ Ձոր",
"3742320", "Աղձք\/Աշտարակ\/Կարբի\/Օշական\,\ Արագածոտն",
"374246", "Ամասիա\,\ Շիրակ",
"37425381", "Ալավերդի\/Ախթալա\/Թումանյան\,\ Լոռի",
"374234518", "Արարատ\/Ուրցաձոր\,\ Արարատ",
"37423478", "Արարատ\/Ուրցաձոր\,\ Արարատ",
"3742567", "Բովաձոր\/Ստեփանավան\,\ Լոռի",
"37428195", "Մալիշկա\,\ Վայոց\ Ձոր",
"3742245", "Եղվարդ\,\ Կոտայք",
"3742351", "Արտաշատ\/Այգեզարդ\/Դալար\/Քաղցրաշեն\/Մխչյան\/Շահումյան\,\ Արարատ",
"37422392", "Հրազդան\,\ Կոտայք",
"37428541", "Կապան\,\ Սյունիք",
"37422396", "Հրազդան\,\ Կոտայք",
"37423699", "Դաշտավան\,\ Արարատ",
"3742648", "Գավառ\/Սարուխան\,\ Գեղարքունիք",
"3742379", "Արմավիր\/Նալբանդյան",
"37423194", "Էջմիածին\,\ Արմավիր",
"37425694", "Ագարակ\,\ Լոռի",
"3742670", "Այգեպար\/Բերդ\,\ Տավուշ",
"3742224", "Աբովյան\,\ Կոտայք",
"3742442", "Արթիկ\,\ Շիրակ",
"3742331", "Բաղրամյան\/Լեռնագոգ\,\ Արմավիր",
"3742680", "Դիլիջան\,\ Տավուշ",
"37424300", "Ախուրյան\/Առափի\/Կամո\/Մուսայելյան\,\ Շիրակ",
"3742362", "Մասիս\,\ Արարատ",
"37432294", "Լեռնապատ\,\ Լոռի",
"3742223", "Աբովյան\,\ Կոտայք",
"37428198", "Ռինդ\,\ Վայոց\ Ձոր",
"37428151", "Խաչիկ\,\ Վայոց\ Ձոր",
"37428547", "Քաջարան\,\ Սյունիք",
"374264", "Գավառ\,\ Գեղարքունիք",
"37428549", "Քաջարան\,\ Սյունիք",
"37423475", "Արարատ\/Ուրցաձոր\,\ Արարատ",
"37422290", "Մայակովսկի\,\ Կոտայք",
"3742226", "Աբովյան\,\ Կոտայք",
"3742857", "Դավիթ\ Բեկ\/Քաջարան\/Կապան\,\ Սյունիք",
"37428427", "Վերիշեն\,\ Սյունիք",
"37428543", "Կապան\,\ Սյունիք",
"3742811", "Գետափ\/Սալլի\/Եղեգնաձոր\,\ Վայոց\ Ձոր",
"374285815", "Քաջարան\,\ Սյունիք",
"37431282", "Ախուրյան\,\ Շիրակ",
"3742329", "Աշտարակ\,\ Արագածոտն",
"37426697", "Նոյեմբերյան\,\ Տավուշ",
"3742679", "Բերդ\,\ Տավուշ",
"37431286", "Գյումրի\/Ախուրյան\,\ Շիրակ",
"374312859", "Ախուրյան\,\ Շիրակ",
"37426699", "Կոթի\,\ Տավուշ",
"3742524", "Ապարան\/Արտավան\/Քուչակ\,\ Արագածոտն",
"374224818", "Նոր\ Հաճն\,\ Կոտայք",
"3742573", "Ծաղկահովիտ\,\ Արագածոտն",
"37426693", "Բաղանիս\,\ Տավուշ",
"3742837", "Սիսիան\,\ Սյունիք",
"3742576", "Ծաղկահովիտ\,\ Արագածոտն",
"3742689", "Դիլիջան\,\ Տավուշ",
"374287", "Ջերմուկ\,\ Վայոց\ Ձոր",
"3742370", "Արաքս\/Արմավիր\/Հոկտեմբեր\/Լենուղի\/Մեծամոր\/Զարթոնք\,\ Արմավիր",
"374234512", "Վեդի\,\ Արարատ",
"3742662", "Նոյեմբերյան\,\ Տավուշ",
"3742631", "Ազատամուտ\/Գետահովիտ\/Իջեւան\/Ենոքավան\,\ Տավուշ",
"3742539", "Ալավերդի\/Օձուն\/Ծաղկաշատ\/Թումանյան\,\ Լոռի",
"3742230", "Հանքավան\/Հրազդան\/Ծաղկաձոր\,\ Կոտայք",
"374234515", "Արարատ\/Ուրցաձոր\,\ Արարատ",
"3742668", "Բերդավան\/Կողբ\/Նոյեմբերյան\,\ Տավուշ",
"37423497", "Փոքր\ Վեդի\,\ Արարատ",
"3742633", "Իջեւան\,\ Տավուշ",
"3742636", "Իջեւան\,\ Տավուշ",
"374231818", "Զվարթնոց\,\ Արմավիր",
"37422672", "Արզական\,\ Կոտայք",
"37426796", "Մոսեսգեղ\,\ Տավուշ",
"37423486", "Ուրցաձոր\,\ Արարատ",
"374477", "Շուշի",
"37426281", "Մարտունի\/Վարդենիկ\,\ Գեղարքունիք",
"3742354", "Արտաշատ\/Այգեզարդ\/Դալար\/Քաղցրաշեն\/Մխչյան\/Շահումյան\,\ Արարատ",
"374478", "Մարտունի",
"37425494", "Մեծավան\,\ Լոռի",
"3742813", "Եղեգնաձոր\/Մալիշկա\/Շատին\,\ Վայոց\ Ձոր",
"37422298", "Առինջ\,\ Կոտայք",
"374285812", "Կապան\,\ Սյունիք",
"3742816", "Եղեգնաձոր\,\ Վայոց\ Ձոր",
"37428190", "Եղեգնաձոր\,\ Վայոց\ Ձոր",
"37425295", "Արտավան\,\ Արագածոտն",
"37423781", "Արմավիր",
"3742420", "Մարալիկ\/Սառնաղբյուր\,\ Շիրակ",
"3742860", "Մեղրի\/Ագարակ\,\ Սյունիք",
"3742855", "Կապան\,\ Սյունիք",
"37423748", "Արաքս\/Արմավիր\/Հոկտեմբեր\/Լենուղի\/Մեծամոր\/Զարթոնք\,\ Արմավիր",
"3742221", "Աբովյան\/Ակունք\/Բյուրեղավան\/Նոր\ Գյուղ\/Վերին\ Պտղնի\,\ Կոտայք",
"3742334", "Բաղրամյան\/Լեռնագոգ\,\ Արմավիր",
"374231817", "Զվարթնոց\,\ Արմավիր",
"37422398", "Բջնի\,\ Կոտայք",
"374286819", "Ագարակ\/Մեղրի\,\ Սյունիք",
"3742570", "Ծաղկահովիտ\,\ Արագածոտն",
"37423472", "Վեդի\,\ Արարատ",
"37426694", "Նոյեմբերյան\,\ Տավուշ",
"37423771", "Արմավիր",
"3742373", "Մեծամոր\,\ Արմավիր",
"37426581", "Ճամբարակ\/Վահան\,\ Գեղարքունիք",
"3742231", "Հանքավան\/Հրազդան\/Ծաղկաձոր\,\ Կոտայք",
"374234514", "Վեդի\,\ Արարատ",
"3742376", "Արմավիր",
"37428181", "Եղեգնաձոր\/Մալիշկա\/Շատին\,\ Վայոց\ Ձոր",
"37426652", "Կողբ\,\ Տավուշ",
"374223811", "Հրազդան\,\ Կոտայք",
"3742324", "Աշտարակ\/Բյուրական\/Օհանավան\,\ Արագածոտն",
"3742852", "Կապան\,\ Սյունիք",
"3742674", "Այգեպար\/Բերդ\,\ Տավուշ",
"3742220", "Աբովյան\/Ակունք\/Բյուրեղավան\/Նոր\ Գյուղ\/Վերին\ Պտղնի\,\ Կոտայք",
"37428544", "Կապան\,\ Սյունիք",
"374223819", "Ծաղկաձոր\,\ Կոտայք",
"3742623", "Մարտունի\/Վարդենիկ\,\ Գեղարքունիք",
"3742667", "Բերդավան\/Նոյեմբերյան\,\ Տավուշ",
"3742684", "Դիլիջան\/Հաղարծին\/Թեղուտ\,\ Տավուշ",
"37423191", "Վաչե\,\ Արմավիր",
"37426381", "Իջեւան\/Այգեհովիտ\/Աչաջուր\,\ Տավուշ",
"374286811", "Մեղրի\,\ Սյունիք",
"37423476", "Արարատ\/Ուրցաձոր\,\ Արարատ",
"37425357", "Թումանյան\,\ Լոռի",
"3743127", "Ախուրյան\,\ Շիրակ",
"3742861", "Մեղրի\/Ագարակ\,\ Սյունիք",
"37425691", "Կուրթան\,\ Լոռի",
"3742421", "Մարալիկ\/Սառնաղբյուր\,\ Շիրակ",
"3742345", "Արարատ\/Վեդի\/Ոսկետափ\,\ Արարատ",
"37425353", "Շնող\,\ Լոռի",
"3742832", "Սիսիան\,\ Սյունիք",
"3742534", "Ալավերդի\,\ Լոռի",
"374285814", "Կապան\,\ Սյունիք",
"3742810", "Գետափ\/Սալլի\/Եղեգնաձոր\,\ Վայոց\ Ձոր",
"37422675", "Ալապարս\/Վարդանավանք\,\ Կոտայք",
"3742866", "Մեղրի\,\ Սյունիք",
"3742426", "Մարալիկ\,\ Շիրակ",
"3742838", "Սիսիան\,\ Սյունիք",
"3742423", "Մարալիկ\,\ Շիրակ",
"3742863", "Մեղրի\,\ Սյունիք",
"37425781", "Ծաղկահովիտ\,\ Արագածոտն",
"3742665", "Կողբ\/Նոյեմբերյան\,\ Տավուշ",
"37428495", "Շինուհայր\,\ Սյունիք",
"374322", "Վանաձոր\,\ Լոռի",
"3742359", "Արտաշատ\/Նորաշեն\,\ Արարատ",
"37423374", "Մյասնիկյան\,\ Արմավիր",
"374286816", "Ագարակ\/Մեղրի\,\ Սյունիք",
"3742236", "Հրազդան\,\ Կոտայք",
"37422390", "Հրազդան\,\ Կոտայք",
"3742371", "Արաքս\/Արմավիր\/Հոկտեմբեր\/Լենուղի\/Մեծամոր\/Զարթոնք\,\ Արմավիր",
"37424997", "Մաստարա\,\ Արագածոտն",
"3742233", "Հրազդան\,\ Կոտայք",
"3742630", "Ազատամուտ\/Գետահովիտ\/Իջեւան\/Ենոքավան\,\ Տավուշ",
"374224817", "Նոր\ Հաճն\,\ Կոտայք",
"37428375", "Թասիկ\,\ Սյունիք",
"3742858", "Դավիթ\ Բեկ\/Քաջարան\/Կապան\,\ Սյունիք",
"37426895", "Հաղարծին\,\ Տավուշ",
"37423798", "Շենավան\,\ Արմավիր",
"374223816", "Ծաղկաձոր\,\ Կոտայք",
"37422371", "Հրազդան\,\ Կոտայք",
"37422281", "Աբովյան\/Արզնի\/Առինջ\/Գեղաշեն\,\ Կոտայք",
"3742339", "Բաղրամյան\,\ Արմավիր",
"3742647", "Գավառ\/Սարուխան\,\ Գեղարքունիք",
"374261", "Սևան\,\ Գեղարքունիք",
"37422296", "Պտղնի\,\ Կոտայք",
"374226", "Չարենցավան\,\ Կոտայք",
"374269", "Վարդենիս\,\ Գեղարքունիք",
"3742350", "Արտաշատ\/Այգեզարդ\/Դալար\/Քաղցրաշեն\/Մխչյան\/Շահումյան\,\ Արարատ",
"3742234", "Հրազդան\,\ Կոտայք",
"3742365", "Մասիս\,\ Արարատ",
"37422373", "Հրազդան\,\ Կոտայք",
"3742841", "Գորիս\/Վերիշեն\,\ Սյունիք",
"37428794", "Գնդեվազ\,\ Վայոց\ Ձոր",
"374223813", "Հրազդան\,\ Կոտայք",
"3742445", "Արթիկ\,\ Շիրակ",
"374234517", "Արարատ\/Ուրցաձոր\,\ Արարատ",
"37422379", "Ծաղկաձոր\,\ Կոտայք",
"37426374", "Այգեհովիտ\,\ Տավուշ",
"3742321", "Աղձք\/Աշտարակ\/Կարբի\/Օշական\,\ Արագածոտն",
"37422377", "Ծաղկաձոր\,\ Կոտայք",
"37431280", "Ախուրյան\,\ Շիրակ",
"3742318", "Էջմիածին\/Մուսալեռ\/Փարաքար\/Զվարթնոց\,\ Արմավիր",
"3742671", "Այգեպար\/Բերդ\,\ Տավուշ",
"37426253", "Վարդենիկ\,\ Գեղարքունիք",
"37425281", "Ապարան\/Արտավան\/Քուչակ\,\ Արագածոտն",
"3742330", "Բաղրամյան\/Լեռնագոգ\,\ Արմավիր",
"3742536", "Ալավերդի\,\ Լոռի",
"3742568", "Բովաձոր\/Ստեփանավան\,\ Լոռի",
"3742533", "Ալավերդի\,\ Լոռի",
"3742424", "Մարալիկ\,\ Շիրակ",
"3742864", "Մեղրի\,\ Սյունիք",
"3742242", "Եղվարդ\,\ Կոտայք",
"37422292", "Զովք\/Աբովյան\,\ Կոտայք",
"3743228", "Վանաձոր\/Գուգարք\,\ Լոռի",
"3742639", "Իջեւան\,\ Տավուշ",
"374286813", "Մեղրի\,\ Սյունիք",
"37423193", "Էջմիածին\,\ Արմավիր",
"3742531", "Ալավերդի\/Օձուն\/Ծաղկաշատ\/Թումանյան\,\ Լոռի",
"37431288", "Գյումրի\/Ախուրյան\,\ Շիրակ",
"3742562", "Ստեփանավան\,\ Լոռի",
"37423197", "Էջմիածին\,\ Արմավիր",
"374473", "Լեռնային\ Ղարաբաղ",
"37423199", "Խորոնք\,\ Արմավիր",
"3742248", "Քանաքեռավան\/Նոր\ Գեղի\/Նոր\ Հաճն\/Եղվարդ\,\ Կոտայք",
"374285817", "Քաջարան\,\ Սյունիք",
"3742676", "Բերդ\,\ Տավուշ",
"37432299", "Վահագնի\,\ Լոռի",
"37422395", "Հրազդան\,\ Կոտայք",
"37432297", "Ձորագետ\,\ Լոռի",
"3742312", "Էջմիածին\,\ Արմավիր",
"37423581", "Արտաշատ\/Նորաշեն\,\ Արարատ",
"3742673", "Բերդ\/Մոսեսգեղ\/Նավուր\/Նորաշեն\,\ Տավուշ",
"37432293", "Փամբակ\,\ Լոռի",
"3742683", "Դիլիջան\,\ Տավուշ",
"37428192", "Եղեգնաձոր\,\ Վայոց\ Ձոր",
"3742686", "Դիլիջան\,\ Տավուշ",
"3742447", "Արթիկ\/Պեմզաշեն\,\ Շիրակ",
"374224814", "Եղվարդ\,\ Կոտայք",
"37428196", "Եղեգնաձոր\,\ Վայոց\ Ձոր",
"3742374", "Արմավիր",
"374475", "Հադրութ",
"3742367", "Այնթապ\/Մասիս\/Նոր\ Խարբերդ\/Նորաբաց\,\ Արարատ",
"37423779", "Բամբակաշատ\,\ Արմավիր",
"3742323", "Աշտարակ\,\ Արագածոտն",
"37423290", "Օհանավան\,\ Արագածոտն",
"3742326", "Աշտարակ\,\ Արագածոտն",
"374249", "Թալին\,\ Արագածոտն",
"37426596", "Վահան\,\ Գեղարքունիք",
"37426392", "Աչաջուր\,\ Տավուշ",
"37423381", "Բաղրամյան\/Մյասնիկյան\,\ Արմավիր",
"374254", "Տաշիր\,\ Լոռի",
"37428695", "Շվանիձոր\,\ Սյունիք",
"3742335", "Բաղրամյան\/Լեռնագոգ\,\ Արմավիր",
"37422378", "Ծաղկաձոր\,\ Կոտայք",
"37423492", "Մարտիրոսյան\,\ Արարատ",
"37423376", "Դալարիկ\,\ Արմավիր",
"3742322", "Աշտարակ\,\ Արագածոտն",
"374285813", "Կապան\,\ Սյունիք",
"374224819", "Նոր\ Հաճն\,\ Կոտայք",
"37428499", "Կոռնիձոր\,\ Սյունիք",
"3742566", "Ստեփանավան\,\ Լոռի",
"37426897", "Թեղուտ\,\ Տավուշ",
"3742355", "Արտաշատ\,\ Արարատ",
"3742538", "Ալավերդի\/Օձուն\/Ծաղկաշատ\/Թումանյան\,\ Լոռի",
"374224811", "Եղվարդ\,\ Կոտայք",
"3742563", "Ստեփանավան\,\ Լոռի",
"37424995", "Արագած\,\ Արագածոտն",
"3742241", "Քանաքեռավան\/Նոր\ Գեղի\/Նոր\ Հաճն\/Եղվարդ\,\ Կոտայք",
"37426797", "Նորաշեն\,\ Տավուշ",
"37410", "Երևան\/Ջրվեժ",
"3742313", "Զվարթնոց\,\ Արմավիր",
"3742316", "Էջմիածին\,\ Արմավիր",
"37423190", "Բաղրամյան\,\ Արմավիր",
"374470", "Լեռնային\ Ղարաբաղ",
"3742440", "Արթիկ\/Պեմզաշեն\,\ Շիրակ",
"3742672", "Բերդ\,\ Տավուշ",
"3742682", "Դիլիջան\,\ Տավուշ",
"37428781", "Ջերմուկ\/Գնդեվազ\,\ Վայոց\ Ձոր",
"3742360", "Այնթապ\/Մասիս\/Նոր\ Խարբերդ\/Նորաբաց\,\ Արարատ",
"37428542", "Կապան\,\ Սյունիք",
"3742678", "Այգեպար\/Բերդ\,\ Տավուշ",
"3742311", "Էջմիածին\/Մուսալեռ\/Փարաքար\/Զվարթնոց\,\ Արմավիր",
"374224816", "Նոր\ Հաճն\,\ Կոտայք",
"37432298", "Լերմոնտովո\,\ Լոռի",
"37423198", "Ջրառատ\,\ Արմավիր",
"3742561", "Բովաձոր\/Ստեփանավան\,\ Լոռի",
"374223817", "Ծաղկաձոր\,\ Կոտայք",
"37431283", "Ախուրյան\,\ Շիրակ",
"3742640", "Գավառ\/Սարուխան\,\ Գեղարքունիք",
"3742532", "Ալավերդի\,\ Լոռի",
"3742357", "Արտաշատ\,\ Արարատ",
"374476", "Ասկերան",
"3742243", "Եղվարդ\,\ Կոտայք",
"3743221", "Վանաձոր\/Գուգարք\,\ Լոռի",
"374262", "Մարտունի\,\ Գեղարքունիք",
"37431287", "Գյումրի\/Ախուրյան\,\ Շիրակ",
"37431289", "Գյումրի\/Ախուրյան\,\ Շիրակ",
"37426696", "Ոսկեպար\,\ Տավուշ",
"374234513", "Վեդի\,\ Արարատ",
"3742246", "Եղվարդ\,\ Կոտայք",
"37415", "Երևան",
"37426692", "Արճիս\,\ Տավուշ",
"37422370", "Հրազդան\,\ Կոտայք",
"37423681", "Մասիս\,\ Արարատ",
"37423474", "Վեդի\,\ Արարատ",
"3742494", "Թալին\/Արագած\/Կաթնաղբյուր\/Մաստարա\,\ Արագածոտն",
"37424481", "Արթիկ\/Փանիկ\,\ Շիրակ",
"37424973", "Կաթնաղբյուր\,\ Արագածոտն",
"374238", "Արարատ\/Ավշար\/Սուրենավան\/Երասխ",
"3742848", "Գորիս\/Վերիշեն\,\ Սյունիք",
"374231819", "Զվարթնոց\,\ Արմավիր",
"3742328", "Աղձք\/Աշտարակ\/Կարբի\/Օշական\,\ Արագածոտն",
"3742337", "Բաղրամյան\,\ Արմավիր",
"37428546", "Քաջարան\,\ Սյունիք",
"37422391", "Լեռնանիստ\,\ Կոտայք",
"374286817", "Ագարակ\/Մեղրի\,\ Սյունիք",
"3742378", "Արաքս\/Արմավիր\/Հոկտեմբեր\/Լենուղի\/Մեծամոր\/Զարթոնք\,\ Արմավիր",
"374285811", "Կապան\,\ Սյունիք",
"37423195", "Նորակերտ\,\ Արմավիր",
"3742232", "Հրազդան\,\ Կոտայք",
"3742543", "Տաշիր\/Մեծավան\,\ Լոռի",
"3742851", "Դավիթ\ Բեկ\/Քաջարան\/Կապան\,\ Սյունիք",
"3742225", "Աբովյան\/Արզնի\/Առինջ\/Գեղաշեն\,\ Կոտայք",
"37412", "Երևան",
"37425695", "Լեջան\,\ Լոռի",
"3742340", "Արարատ\/Վեդի\/Ոսկետափ\,\ Արարատ",
"374284", "Գորիս\,\ Սյունիք",
"37424496", "Մեծ\ Մանթաշ\,\ Շիրակ",
"3742817", "Գետափ\/Սալլի\/Եղեգնաձոր\,\ Վայոց\ Ձոր",
"37422393", "Մեղրաձոր\,\ Կոտայք",
"37422397", "Սոլակ\,\ Կոտայք",
"37422399", "Հրազդան\,\ Կոտայք",
"37432295", "Եղեգնուտ\,\ Լոռի",
"37426681", "Նոյեմբերյան\/Ոսկեպար\/Կոթի\/Կողբ\,\ Տավուշ",
"374224813", "Եղվարդ\,\ Կոտայք",
"37424492", "Փանիկ\,\ Շիրակ",
"3742422", "Մարալիկ\,\ Շիրակ",
"3742862", "Ագարակ\,\ Սյունիք",
"3742244", "Նոր\ Հաճն\,\ Կոտայք",
"374285819", "Քաջարան\,\ Սյունիք",
"37428194", "Արենի\,\ Վայոց\ Ձոր",
"37424297", "Անի\ Կայարան\,\ Շիրակ",
"37431281", "Ախուրյան\,\ Շիրակ",
"37428351", "Սիսիան\,\ Սյունիք",
"37424293", "Շիրակավան\,\ Շիրակ",
"374234516", "Արարատ\/Ուրցաձոր\,\ Արարատ",
"3742637", "Իջեւան\,\ Տավուշ",
"3742635", "Ազատամուտ\/Գետահովիտ\/Իջեւան\/Ենոքավան\,\ Տավուշ",
"3742314", "Էջմիածին\,\ Արմավիր",
"37426791", "Նավուր\,\ Տավուշ",
"37423481", "Այգավան\,\ Արարատ",
"3742564", "Ստեփանավան\,\ Լոռի",
"37422453", "Պռոշյան\,\ Կոտայք",
"37422375", "Ծաղկաձոր\,\ Կոտայք",
"374234511", "Վեդի\,\ Արարատ",
"37426299", "Երանոս\,\ Գեղարքունիք",
"37422294", "Արզնի\,\ Կոտայք",
"3742836", "Սիսիան\,\ Սյունիք",
"374223814", "Հրազդան\,\ Կոտայք",
"3742428", "Մարալիկ\/Սառնաղբյուր\,\ Շիրակ",
"3742868", "Մեղրի\/Ագարակ\,\ Սյունիք",
"3742833", "Սիսիան\,\ Սյունիք",
"3743120", "Գյումրի\/Ախուրյան\,\ Շիրակ",
"3742449", "Արթիկ\,\ Շիրակ",
"374234519", "Արարատ\/Ուրցաձոր\,\ Արարատ",
"374255", "Սպիտակ\,\ Լոռի",
"3742369", "Մասիս\,\ Արարատ",
"374285816", "Քաջարան\,\ Սյունիք",
"3742815", "Եղեգնաձոր\,\ Վայոց\ Ձոր",
"3742372", "Արմավիր",
"374286814", "Մեղրի\,\ Սյունիք",
"3742238", "Հանքավան\/Հրազդան\/Ծաղկաձոր\,\ Կոտայք",
"3742227", "Գառնի\/Աբովյան\,\ Կոտայք",
"374474", "Մարտակերտ",
"3742856", "Կապան\,\ Սյունիք",
"3742660", "Բերդավան\/Կողբ\/Նոյեմբերյան\,\ Տավուշ",
"37428491", "Հարժիս\,\ Սյունիք",
"3742853", "Քաջարան\,\ Սյունիք",};
$areanames{en} = {"3742368", "Ayntap\/Masis\/Nor\ Kharberd\/Norabats\,\ Ararat",
"3742333", "Baghramyan\/Myasnikyan\,\ Armavir",
"3742336", "Baghramyan\,\ Armavir",
"3742448", "Artik\/Pemzashen\,\ Shirak",
"374285818", "Kajaran\,\ Syunik",
"3742654", "Tchambarak\/Vahan\,\ Gegharkunik",
"37422452", "Zovuni\,\ Kotayk",
"3742814", "Getap\/Salli\/Yeghegnadzor\,\ Vayots\ dzor",
"3742530", "Alaverdi\/Odzun\/Tsaghkashat\/Tumanyan\,\ Lori",
"37423796", "Tandzut\,\ Armavir",
"37423281", "Ashtarak\/Byurakan\/Ohanavan\,\ Aragatsotn",
"374223810", "Hrazdan\,\ Kotayk",
"374472", "Nagorno\-Karabakh",
"37426781", "Berd\/Mosesgegh\/Navur\/Norashen\,\ Tavush",
"3742353", "Artashat\/Norashen\,\ Ararat",
"3742247", "Yeghvard\/Nor\ Hajn\,\ Kotayk",
"37423792", "Nalbandian\,\ Armavir",
"3742356", "Artashat\,\ Ararat",
"3742565", "Bovadzor\/Stepanavan\,\ Lori",
"37426881", "Dilijan\/Haghartsin\/Teghut\,\ Tavush",
"3742315", "Echmiadzin\,\ Armavir",
"3742634", "Ijevan\,\ Tavush",
"3742869", "Meghri\,\ Syunik",
"374286810", "Meghri\,\ Syunik",
"3742429", "Maralik\,\ Shirak",
"37423470", "Vedi\,\ Ararat",
"37422295", "Zovk\/Abovyan\,\ Kotayk",
"374312", "Gyumri\,\ Shirak",
"374224815", "Nor\ Hajn\,\ Kotayk",
"37422374", "Hrazdan\,\ Kotayk",
"37425381", "Alaverdi\/Akhtala\/Tumanyan\,\ Lori",
"3742320", "Aghdzq\/Ashtarak\/Karbi\/Oshakan\,\ Aragatsotn",
"374246", "Amasia\,\ Shirak",
"374282", "Vayk\,\ Vayots\ dzor",
"37426691", "Noyemberyan\,\ Tavush",
"3742317", "Zvartnots\,\ Armavir",
"374234", "Ararat\/Vedi\,\ Ararat",
"374224812", "Yeghvard\,\ Kotayk",
"3742840", "Goris\/Verishen\,\ Syunik",
"37422392", "Hrazdan\,\ Kotayk",
"3742351", "Artashat\/Aygezard\/Dalar\/Kaghtsrashen\/Mkhchyan\/Shahumyan\,\ Ararat",
"37428195", "Malishka\,\ Vayots\ dzor",
"3742245", "Yeghvard\,\ Kotayk",
"3742567", "Bovadzor\/Stepanavan\,\ Lori",
"37423478", "Ararat\/Urtsadzor\,\ Ararat",
"374234518", "Ararat\/Urtsadzor\,\ Ararat",
"3742379", "Armavir\/Nalbandian",
"37423194", "Echmiadzin\,\ Armavir",
"3742648", "Gavar\/Sarukhan\,\ Gegharkunik",
"37423699", "Dashtavan\,\ Ararat",
"37422396", "Hrazdan\,\ Kotayk",
"37428541", "Kapan\,\ Syunik",
"37432294", "Lernapat\,\ Lori",
"3742362", "Masis\,\ Ararat",
"37424300", "Akhuryan\/Arapi\/Kamo\/Musayelyan\,\ Shirak",
"3742680", "Dilijan\,\ Tavush",
"3742331", "Baghramyan\/Lernagog\,\ Armavir",
"3742442", "Artik\,\ Shirak",
"3742224", "Abovyan\,\ Kotayk",
"3742670", "Aygepar\/Berd\,\ Tavush",
"37425694", "Agarak\,\ Lori",
"37428543", "Kapan\,\ Syunik",
"37428427", "Verishen\,\ Syunik",
"3742857", "Davit\ Bek\/Kajaran\/Kapan\,\ Syunik",
"37423475", "Ararat\/Urtsadzor\,\ Ararat",
"3742226", "Abovyan\,\ Kotayk",
"37422290", "Mayakovsky\,\ Kotayk",
"37428549", "Kajaran\,\ Syunik",
"374264", "Gavar\,\ Gegharkunik",
"37428151", "Khachik\,\ Vayots\ dzor",
"37428547", "Kajaran\,\ Syunik",
"37428198", "Rind\,\ Vayots\ dzor",
"3742223", "Abovyan\,\ Kotayk",
"37431282", "Akhuryan\,\ Shirak",
"3742329", "Ashtarak\,\ Aragatsotn",
"374285815", "Kajaran\,\ Syunik",
"3742811", "Getap\/Salli\/Yeghegnadzor\,\ Vayots\ dzor",
"3742689", "Dilijan\,\ Tavush",
"3742576", "Tsakhkahovit\,\ Aragatsotn",
"3742837", "Sisian\,\ Syunik",
"3742573", "Tsakhkahovit\,\ Aragatsotn",
"37426693", "Baghanis\,\ Tavush",
"374224818", "Nor\ Hajn\,\ Kotayk",
"3742524", "Aparan\/Artavan\/Kuchak\,\ Aragatsotn",
"37431286", "Gyumri\/Akhuryan\,\ Shirak",
"374312859", "Akhuryan\,\ Shirak",
"37426699", "Koti\,\ Tavush",
"3742679", "Berd\,\ Tavush",
"37426697", "Noyemberyan\,\ Tavush",
"3742631", "Azatamut\/Getahovit\/Ijevan\/Yenokavan\,\ Tavush",
"3742662", "Noyemberyan\,\ Tavush",
"374234512", "Vedi\,\ Ararat",
"3742370", "Araks\/Armavir\/Hoktember\/Lenughi\/Metsamor\/Zartonk\,\ Armavir",
"374287", "Jermuk\,\ Vayots\ dzor",
"37422672", "Arzakan\,\ Kotayk",
"3742636", "Ijevan\,\ Tavush",
"374231818", "Zvartnots\,\ Armavir",
"3742633", "Ijevan\,\ Tavush",
"37423497", "Pokr\ Vedi\,\ Ararat",
"3742668", "Berdavan\/Koghb\/Noyemberyan\,\ Tavush",
"374234515", "Ararat\/Urtsadzor\,\ Ararat",
"3742230", "Hankavan\/Hrazdan\/Tsaghkadzor\,\ Kotayk",
"3742539", "Alaverdi\/Odzun\/Tsaghkashat\/Tumanyan\,\ Lori",
"37425494", "Metsavan\,\ Lori",
"3742354", "Artashat\/Aygezard\/Dalar\/Kaghtsrashen\/Mkhchyan\/Shahumyan\,\ Ararat",
"374478", "Martuni",
"37426281", "Martuni\/Vardenik\,\ Gegharkunik",
"374477", "Shushi",
"37423486", "Urtsadzor\,\ Ararat",
"37426796", "Mosesgegh\,\ Tavush",
"3742860", "Meghri\/Agarak\,\ Syunik",
"3742420", "Maralik\/Sarnaghbyur\,\ Shirak",
"37423781", "Armavir",
"3742816", "Yeghegnadzor\,\ Vayots\ dzor",
"37428190", "Yeghegnadzor\,\ Vayots\ dzor",
"37425295", "Artavan\,\ Aragatsotn",
"374285812", "Kapan\,\ Syunik",
"37422298", "Arinj\,\ Kotayk",
"3742813", "Yeghegnadzor\/Malishka\/Shatin\,\ Vayots\ dzor",
"3742334", "Baghramyan\/Lernagog\,\ Armavir",
"3742221", "Abovyan\/Akunk\/Byureghavan\/Nor\ Gyugh\/Verin\ Ptghni\,\ Kotayk",
"37423748", "Araks\/Armavir\/Hoktember\/Lenughi\/Metsamor\/Zartonk\,\ Armavir",
"3742855", "Kapan\,\ Syunik",
"374223815", "Tsaghkadzor\,\ Kotayk",
"37423192", "Echmiadzin\,\ Armavir",
"3742812", "Yeghegnadzor\,\ Vayots\ dzor",
"3742375", "Armavir",
"37428548", "Kajaran\,\ Syunik",
"37428197", "Yelpin\,\ Vayots\ dzor",
"37428199", "Shatin\,\ Vayots\ dzor",
"37426272", "Lichk\,\ Gegharkunik",
"3742228", "Abovyan\/Akunk\/Byureghavan\/Nor\ Gyugh\/Verin\ Ptghni\,\ Kotayk",
"37428193", "Aghavnadzor\,\ Vayots\ dzor",
"374224810", "Yeghvard\,\ Kotayk",
"3742249", "Yeghvard\,\ Kotayk",
"3742661", "Berdavan\/Koghb\/Noyemberyan\,\ Tavush",
"37423471", "Vedi\,\ Ararat",
"37432296", "Margahovit\,\ Lori",
"3742632", "Ijevan\/Aygehovit\/Achajur\,\ Tavush",
"37423772", "Mrgashat\,\ Armavir",
"374286815", "Agarak\/Meghri\,\ Syunik",
"37424231", "Sarnaghbyur\,\ Shirak",
"37424495", "Arevshat\,\ Shirak",
"374252", "Aparan\,\ Aragatsotn",
"3742427", "Maralik\/Sarnaghbyur\,\ Shirak",
"3742867", "Meghri\/Agarak\,\ Syunik",
"37426698", "Noyemberyan\,\ Tavush",
"3743121", "Gyumri\/Akhuryan\,\ Shirak",
"37423196", "Echmiadzin\,\ Armavir",
"37422394", "Pyunik\,\ Kotayk",
"37426397", "Azatamut\,\ Tavush",
"37425291", "Kuchak\,\ Aragatsotn",
"3742572", "Tsakhkahovit\,\ Aragatsotn",
"3742341", "Ararat\/Vedi\/Vosketap\,\ Ararat",
"37423794", "Margara\,\ Armavir",
"3742865", "Agarak\/Shvanidzor\,\ Syunik",
"3742425", "Maralik\/Sarnaghbyur\,\ Shirak",
"37422372", "Hrazdan\,\ Kotayk",
"3742850", "Davit\ Bek\/Kajaran\/Kapan\,\ Syunik",
"3742666", "Noyemberyan\,\ Tavush",
"37426690", "Noyemberyan\,\ Tavush",
"3742663", "Noyemberyan\/Voskepar\/Koti\/Koghb\,\ Tavush",
"3742638", "Azatamut\/Getahovit\/Ijevan\/Yenokavan\,\ Tavush",
"374286812", "Meghri\,\ Syunik",
"37423498", "Taperakan\,\ Ararat",
"3742569", "Stepanavan\,\ Lori",
"37426252", "Vardenik\,\ Gegharkunik",
"3742364", "Masis\,\ Ararat",
"37423747", "Araks\/Armavir\/Hoktember\/Lenughi\/Metsamor\/Zartonk\,\ Armavir",
"3742235", "Tsaghkadzor\,\ Kotayk",
"37423749", "Araks\/Armavir\/Hoktember\/Lenughi\/Metsamor\/Zartonk\,\ Armavir",
"37424981", "Talin\/Aragats\/Katnaghbyur\/Mastara\,\ Aragatsotn",
"3742377", "Armavir\/Mrgashat",
"37422376", "Tsaghkadzor\,\ Kotayk",
"3742444", "Artik\/Panik\,\ Shirak",
"3742222", "Abovyan\,\ Kotayk",
"374223812", "Hrazdan\,\ Kotayk",
"3742830", "Sisian\,\ Syunik",
"37422297", "Geghashen\,\ Kotayk",
"37422299", "Kotayk",
"37428540", "Kapan\,\ Syunik",
"37422454", "Argel\,\ Kotayk",
"3742818", "Getap\/Salli\/Yeghegnadzor\,\ Vayots\ dzor",
"37422293", "Aramus\,\ Kotayk",
"37425481", "Tashir\/Metsavan\,\ Lori",
"3743220", "Vanadzor\/Gugark\,\ Lori",
"374285810", "Kapan\,\ Syunik",
"3742859", "Kapan\,\ Syunik",
"3742560", "Bovadzor\/Stepanavan\,\ Lori",
"37426794", "Tovuz\,\ Tavush",
"3742641", "Gavar\/Sarukhan\,\ Gegharkunik",
"3742327", "Aghdzq\/Ashtarak\/Karbi\/Oshakan\,\ Aragatsotn",
"3742338", "Baghramyan\/Lernagog\,\ Armavir",
"3742363", "Ayntap\/Masis\,\ Ararat",
"37422291", "Balahovit\/Kamaris\,\ Kotayk",
"374265", "Tchambarak\,\ Gegharkunik",
"3742366", "Masis\,\ Ararat",
"374223818", "Tsaghkadzor\,\ Kotayk",
"3742443", "Artik\,\ Shirak",
"3742847", "Goris\/Verishen\,\ Syunik",
"3742310", "Echmiadzin\/Musaler\/Parakar\/Zvartnots\,\ Armavir",
"3742446", "Artik\,\ Shirak",
"3742664", "Berdavan\/Koghb\/Noyemberyan\,\ Tavush",
"3742839", "Sisian\,\ Syunik",
"3742677", "Berd\,\ Tavush",
"37423294", "Byurakan\,\ Aragatsotn",
"3742358", "Artashat\/Aygezard\/Dalar\/Kaghtsrashen\/Mkhchyan\/Shahumyan\,\ Ararat",
"37423375", "Karakert\,\ Armavir",
"3742535", "Alaverdi\,\ Lori",
"37428494", "Khndzoresk\,\ Syunik",
"374286818", "Agarak\/Meghri\,\ Syunik",
"3742352", "Artashat\,\ Ararat",
"37425356", "Chochkan\,\ Lori",
"37423477", "Ararat\/Urtsadzor\,\ Ararat",
"37423181", "Echmiadzin\,\ Armavir",
"37428545", "Kajaran\,\ Syunik",
"37423479", "Ararat\/Urtsadzor\,\ Ararat",
"3742873", "Jermuk\/Gndevaz\,\ Vayots\ dzor",
"3742537", "Alaverdi\/Akhtala\/Tumanyan\,\ Lori",
"37423473", "Vedi\,\ Ararat",
"37425681", "Stepanavan\,\ Lori",
"37428396", "Angehakot\,\ Syunik",
"374257", "Aragats\,\ Aragatsotn",
"3742675", "Artsvaberd\/Berd\,\ Tavush",
"374234510", "Vedi\,\ Ararat",
"37426653", "Koghb\,\ Tavush",
"37426695", "Zorakan\,\ Tavush",
"3742332", "Baghramyan\,\ Armavir",
"3742499", "Aragatsavan\/Talin\,\ Aragatsotn",
"37447732", "Berdzor\/Kashatagh",
"3742361", "Ayntap\/Masis\/Nor\ Kharberd\/Norabats\,\ Ararat",
"3742325", "Aghdzq\/Ashtarak\/Karbi\/Oshakan\,\ Aragatsotn",
"37411", "Yerevan",
"3742441", "Artik\/Pemzashen\,\ Shirak",
"3742549", "Tashir\/Metsavan\,\ Lori",
"374479", "Stepanakert",
"37428191", "Arpi\,\ Vayots\ dzor",
"3742240", "Kanakeravan\/Nor\ Geghi\/Nor\ Hajn\/Yeghvard\,\ Kotayk",
"374245", "Ashotsk\,\ Shirak",
"374471", "Stepanakert",
"37425352", "Akhtala\,\ Lori",
"37431284", "Akhuryan\,\ Shirak",
"374285813", "Kapan\,\ Syunik",
"3742322", "Ashtarak\,\ Aragatsotn",
"37423376", "Dalarik\,\ Armavir",
"37423492", "Martirosyan\,\ Ararat",
"37422378", "Tsaghkadzor\,\ Kotayk",
"3742335", "Baghramyan\/Lernagog\,\ Armavir",
"37428499", "Kornidzor\,\ Syunik",
"374224819", "Nor\ Hajn\,\ Kotayk",
"37410", "Yerevan\/Jrvezh",
"3742241", "Kanakeravan\/Nor\ Geghi\/Nor\ Hajn\/Yeghvard\,\ Kotayk",
"37426797", "Norashen\,\ Tavush",
"37424995", "Aragats\,\ Aragatsotn",
"3742563", "Stepanavan\,\ Lori",
"3742538", "Alaverdi\/Odzun\/Tsaghkashat\/Tumanyan\,\ Lori",
"374224811", "Yeghvard\,\ Kotayk",
"3742355", "Artashat\,\ Ararat",
"37426897", "Teghut\,\ Tavush",
"3742566", "Stepanavan\,\ Lori",
"3742360", "Ayntap\/Masis\/Nor\ Kharberd\/Norabats\,\ Ararat",
"37428781", "Jermuk\/Gndevaz\,\ Vayots\ dzor",
"3742682", "Dilijan\,\ Tavush",
"3742672", "Berd\,\ Tavush",
"3742440", "Artik\/Pemzashen\,\ Shirak",
"374470", "Nagorno\-Karabakh",
"3742316", "Echmiadzin\,\ Armavir",
"37423190", "Baghramyan\,\ Armavir",
"3742313", "Zvartnots\,\ Armavir",
"37432298", "Lermontovo\,\ Lori",
"374224816", "Nor\ Hajn\,\ Kotayk",
"3742311", "Echmiadzin\/Musaler\/Parakar\/Zvartnots\,\ Armavir",
"37428542", "Kapan\,\ Syunik",
"3742678", "Aygepar\/Berd\,\ Tavush",
"37415", "Yerevan",
"37431289", "Gyumri\/Akhuryan\,\ Shirak",
"37426696", "Voskepar\,\ Tavush",
"374234513", "Vedi\,\ Ararat",
"3742246", "Yeghvard\,\ Kotayk",
"37431287", "Gyumri\/Akhuryan\,\ Shirak",
"3743221", "Vanadzor\/Gugark\,\ Lori",
"374262", "Martuni\,\ Gegharkunik",
"3742243", "Yeghvard\,\ Kotayk",
"3742357", "Artashat\,\ Ararat",
"374476", "Askeran",
"3742532", "Alaverdi\,\ Lori",
"37431283", "Akhuryan\,\ Shirak",
"3742640", "Gavar\/Sarukhan\,\ Gegharkunik",
"374223817", "Tsaghkadzor\,\ Kotayk",
"3742561", "Bovadzor\/Stepanavan\,\ Lori",
"37423198", "Jrarat\,\ Armavir",
"37424973", "Katnaghbyur\,\ Aragatsotn",
"374238", "Ararat\/Avshar\/Surenavan\/Yeraskh",
"37424481", "Artik\/Panik\,\ Shirak",
"3742494", "Talin\/Aragats\/Katnaghbyur\/Mastara\,\ Aragatsotn",
"37423474", "Vedi\,\ Ararat",
"37423681", "Masis\,\ Ararat",
"37422370", "Hrazdan\,\ Kotayk",
"37426692", "Archis\,\ Tavush",
"374286817", "Agarak\/Meghri\,\ Syunik",
"37422391", "Lernanist\,\ Kotayk",
"37428546", "Kajaran\,\ Syunik",
"374231819", "Zvartnots\,\ Armavir",
"3742328", "Aghdzq\/Ashtarak\/Karbi\/Oshakan\,\ Aragatsotn",
"3742337", "Baghramyan\,\ Armavir",
"3742848", "Goris\/Verishen\,\ Syunik",
"37412", "Yerevan",
"3742225", "Abovyan\/Arzni\/Arinj\/Geghashen\,\ Kotayk",
"3742851", "Davit\ Bek\/Kajaran\/Kapan\,\ Syunik",
"3742543", "Tashir\/Metsavan\,\ Lori",
"3742232", "Hrazdan\,\ Kotayk",
"37423195", "Norakert\,\ Armavir",
"374285811", "Kapan\,\ Syunik",
"3742378", "Araks\/Armavir\/Hoktember\/Lenughi\/Metsamor\/Zartonk\,\ Armavir",
"37432295", "Yeghegnut\,\ Lori",
"37422399", "Hrazdan\,\ Kotayk",
"37422397", "Solak\,\ Kotayk",
"37422393", "Meghradzor\,\ Kotayk",
"3742817", "Getap\/Salli\/Yeghegnadzor\,\ Vayots\ dzor",
"37424496", "Mets\ Mantash\,\ Shirak",
"374284", "Goris\,\ Syunik",
"37425695", "Lejan\,\ Lori",
"3742340", "Ararat\/Vedi\/Vosketap\,\ Ararat",
"3742862", "Agarak\,\ Syunik",
"3742244", "Nor\ Hajn\,\ Kotayk",
"3742422", "Maralik\,\ Shirak",
"37424492", "Panik\,\ Shirak",
"374224813", "Yeghvard\,\ Kotayk",
"37426681", "Noyemberyan\/Voskepar\/Koti\/Koghb\,\ Tavush",
"3742637", "Ijevan\,\ Tavush",
"37424293", "Shirakavan\,\ Shirak",
"374234516", "Ararat\/Urtsadzor\,\ Ararat",
"37428351", "Sisian\,\ Syunik",
"37431281", "Akhuryan\,\ Shirak",
"37428194", "Areni\,\ Vayots\ dzor",
"374285819", "Kajaran\,\ Syunik",
"37424297", "Ani\ Kayaran\,\ Shirak",
"37423481", "Aygavan\,\ Ararat",
"37426791", "Navur\,\ Tavush",
"3742314", "Echmiadzin\,\ Armavir",
"3742635", "Azatamut\/Getahovit\/Ijevan\/Yenokavan\,\ Tavush",
"3742833", "Sisian\,\ Syunik",
"3742868", "Meghri\/Agarak\,\ Syunik",
"3742428", "Maralik\/Sarnaghbyur\,\ Shirak",
"374223814", "Hrazdan\,\ Kotayk",
"3742836", "Sisian\,\ Syunik",
"37426299", "Eranos\,\ Gegharkunik",
"37422294", "Arzni\,\ Kotayk",
"37422375", "Tsaghkadzor\,\ Kotayk",
"374234511", "Vedi\,\ Ararat",
"3742564", "Stepanavan\,\ Lori",
"37422453", "Proshyan\,\ Kotayk",
"3742815", "Yeghegnadzor\,\ Vayots\ dzor",
"374285816", "Kajaran\,\ Syunik",
"3742369", "Masis\,\ Ararat",
"374255", "Spitak\,\ Lori",
"374234519", "Ararat\/Urtsadzor\,\ Ararat",
"3743120", "Gyumri\/Akhuryan\,\ Shirak",
"3742449", "Artik\,\ Shirak",
"3742853", "Kajaran\,\ Syunik",
"37428491", "Harzhis\,\ Syunik",
"3742660", "Berdavan\/Koghb\/Noyemberyan\,\ Tavush",
"3742856", "Kapan\,\ Syunik",
"374474", "Martakert",
"3742238", "Hankavan\/Hrazdan\/Tsaghkadzor\,\ Kotayk",
"3742227", "Garni\/Abovyan\,\ Kotayk",
"374286814", "Meghri\,\ Syunik",
"3742372", "Armavir",
"37426694", "Noyemberyan\,\ Tavush",
"37423771", "Armavir",
"37423472", "Vedi\,\ Ararat",
"3742570", "Tsakhkahovit\,\ Aragatsotn",
"374286819", "Agarak\/Meghri\,\ Syunik",
"37422398", "Bjni\,\ Kotayk",
"374231817", "Zvartnots\,\ Armavir",
"3742852", "Kapan\,\ Syunik",
"3742324", "Ashtarak\/Byurakan\/Ohanavan\,\ Aragatsotn",
"374223811", "Hrazdan\,\ Kotayk",
"37426652", "Koghb\,\ Tavush",
"37428181", "Yeghegnadzor\/Malishka\/Shatin\,\ Vayots\ dzor",
"3742376", "Armavir",
"374234514", "Vedi\,\ Ararat",
"3742231", "Hankavan\/Hrazdan\/Tsaghkadzor\,\ Kotayk",
"37426581", "Tchambarak\/Vahan\,\ Gegharkunik",
"3742373", "Metsamor\,\ Armavir",
"3742667", "Berdavan\/Noyemberyan\,\ Tavush",
"3742684", "Dilijan\/Haghartsin\/Teghut\,\ Tavush",
"37423191", "Vache\,\ Armavir",
"374223819", "Tsaghkadzor\,\ Kotayk",
"3742623", "Martuni\/Vardenik\,\ Gegharkunik",
"37428544", "Kapan\,\ Syunik",
"3742220", "Abovyan\/Akunk\/Byureghavan\/Nor\ Gyugh\/Verin\ Ptghni\,\ Kotayk",
"3742674", "Aygepar\/Berd\,\ Tavush",
"3742832", "Sisian\,\ Syunik",
"37425353", "Shnogh\,\ Lori",
"3742345", "Ararat\/Vedi\/Vosketap\,\ Ararat",
"3742421", "Maralik\/Sarnaghbyur\,\ Shirak",
"37425691", "Kurtan\,\ Lori",
"3742861", "Meghri\/Agarak\,\ Syunik",
"3743127", "Akhuryan\,\ Shirak",
"37423476", "Ararat\/Urtsadzor\,\ Ararat",
"37425357", "Tumanyan\,\ Lori",
"37426381", "Ijevan\/Aygehovit\/Achajur\,\ Tavush",
"374286811", "Meghri\,\ Syunik",
"3742863", "Meghri\,\ Syunik",
"3742423", "Maralik\,\ Shirak",
"3742838", "Sisian\,\ Syunik",
"3742426", "Maralik\,\ Shirak",
"3742866", "Meghri\,\ Syunik",
"3742810", "Getap\/Salli\/Yeghegnadzor\,\ Vayots\ dzor",
"37422675", "Alapars\/Vardanavank\,\ Kotayk",
"374285814", "Kapan\,\ Syunik",
"3742534", "Alaverdi\,\ Lori",
"374286816", "Agarak\/Meghri\,\ Syunik",
"37423374", "Myasnikyan\,\ Armavir",
"3742359", "Artashat\/Norashen\,\ Ararat",
"374322", "Vanadzor\,\ Lori",
"37428495", "Shinuhayr\,\ Syunik",
"3742665", "Koghb\/Noyemberyan\,\ Tavush",
"37425781", "Tsakhkahovit\,\ Aragatsotn",
"37426895", "Haghartsin\,\ Tavush",
"3742858", "Davit\ Bek\/Kajaran\/Kapan\,\ Syunik",
"374224817", "Nor\ Hajn\,\ Kotayk",
"37428375", "Tasik\,\ Syunik",
"3742630", "Azatamut\/Getahovit\/Ijevan\/Yenokavan\,\ Tavush",
"3742233", "Hrazdan\,\ Kotayk",
"37424997", "Mastara\,\ Aragatsotn",
"3742371", "Araks\/Armavir\/Hoktember\/Lenughi\/Metsamor\/Zartonk\,\ Armavir",
"3742236", "Hrazdan\,\ Kotayk",
"37422390", "Hrazdan\,\ Kotayk",
"3742339", "Baghramyan\,\ Armavir",
"37422371", "Hrazdan\,\ Kotayk",
"37422281", "Abovyan\/Arzni\/Arinj\/Geghashen\,\ Kotayk",
"374223816", "Tsaghkadzor\,\ Kotayk",
"37423798", "Shenavan\,\ Armavir",
"3742350", "Artashat\/Aygezard\/Dalar\/Kaghtsrashen\/Mkhchyan\/Shahumyan\,\ Ararat",
"374269", "Vardenis\,\ Gegharkunik",
"374226", "Charentsavan\,\ Kotayk",
"37422296", "Ptghni\,\ Kotayk",
"374261", "Sevan\,\ Gegharkunik",
"3742647", "Gavar\/Sarukhan\,\ Gegharkunik",
"37422377", "Tsaghkadzor\,\ Kotayk",
"3742321", "Aghdzq\/Ashtarak\/Karbi\/Oshakan\,\ Aragatsotn",
"37422379", "Tsaghkadzor\,\ Kotayk",
"37426374", "Aygehovit\,\ Tavush",
"374234517", "Ararat\/Urtsadzor\,\ Ararat",
"3742445", "Artik\,\ Shirak",
"37428794", "Gndevaz\,\ Vayots\ dzor",
"374223813", "Hrazdan\,\ Kotayk",
"37422373", "Hrazdan\,\ Kotayk",
"3742841", "Goris\/Verishen\,\ Syunik",
"3742365", "Masis\,\ Ararat",
"3742234", "Hrazdan\,\ Kotayk",
"3742330", "Baghramyan\/Lernagog\,\ Armavir",
"37425281", "Aparan\/Artavan\/Kuchak\,\ Aragatsotn",
"37426253", "Vardenik\,\ Gegharkunik",
"3742671", "Aygepar\/Berd\,\ Tavush",
"3742318", "Echmiadzin\/Musaler\/Parakar\/Zvartnots\,\ Armavir",
"37431280", "Akhuryan\,\ Shirak",
"374286813", "Meghri\,\ Syunik",
"3742639", "Ijevan\,\ Tavush",
"3743228", "Vanadzor\/Gugark\,\ Lori",
"37422292", "Zovk\/Abovyan\,\ Kotayk",
"3742864", "Meghri\,\ Syunik",
"3742242", "Yeghvard\,\ Kotayk",
"3742424", "Maralik\,\ Shirak",
"3742533", "Alaverdi\,\ Lori",
"3742568", "Bovadzor\/Stepanavan\,\ Lori",
"3742536", "Alaverdi\,\ Lori",
"374285817", "Kajaran\,\ Syunik",
"3742248", "Kanakeravan\/Nor\ Geghi\/Nor\ Hajn\/Yeghvard\,\ Kotayk",
"37423199", "Khoronk\,\ Armavir",
"374473", "Nagorno\-Karabakh",
"37423197", "Echmiadzin\,\ Armavir",
"3742562", "Stepanavan\,\ Lori",
"37431288", "Gyumri\/Akhuryan\,\ Shirak",
"3742531", "Alaverdi\/Odzun\/Tsaghkashat\/Tumanyan\,\ Lori",
"37423193", "Echmiadzin\,\ Armavir",
"3742686", "Dilijan\,\ Tavush",
"37428192", "Yeghegnadzor\,\ Vayots\ dzor",
"3742683", "Dilijan\,\ Tavush",
"37432293", "Pambak\,\ Lori",
"3742673", "Berd\/Mosesgegh\/Navur\/Norashen\,\ Tavush",
"37423581", "Artashat\/Norashen\,\ Ararat",
"3742312", "Echmiadzin\,\ Armavir",
"37432297", "Dzoraget\,\ Lori",
"37422395", "Hrazdan\,\ Kotayk",
"3742676", "Berd\,\ Tavush",
"37432299", "Vahagni\,\ Lori",
"37426596", "Vahan\,\ Gegharkunik",
"3742326", "Ashtarak\,\ Aragatsotn",
"37423290", "Ohanavan\,\ Aragatsotn",
"374249", "Talin\,\ Aragatsotn",
"37423779", "Bambakashat\,\ Armavir",
"3742323", "Ashtarak\,\ Aragatsotn",
"3742367", "Ayntap\/Masis\/Nor\ Kharberd\/Norabats\,\ Ararat",
"374475", "Hadrut",
"3742374", "Armavir",
"374224814", "Yeghvard\,\ Kotayk",
"37428196", "Yeghegnadzor\,\ Vayots\ dzor",
"3742447", "Artik\/Pemzashen\,\ Shirak",
"37428695", "Shvanidzor\,\ Syunik",
"374254", "Tashir\,\ Lori",
"37423381", "Baghramyan\/Myasnikyan\,\ Armavir",
"37426392", "Achajur\,\ Tavush",};

    sub new {
      my $class = shift;
      my $number = shift;
      $number =~ s/(^\+374|\D)//g;
      my $self = bless({ number => $number, formatters => $formatters, validators => $validators, areanames => \%areanames}, $class);
      return $self if ($self->is_valid());
      $number =~ s/^(?:0)//;
      $self = bless({ number => $number, formatters => $formatters, validators => $validators, areanames => \%areanames}, $class);
      return $self->is_valid() ? $self : undef;
    }
1;