# automatically generated file, don't edit
package Number::Phone::Data;
*Number::Phone::libphonenumber_tag = sub { "v8.12.44" };
*Number::Phone::UK::data_source = sub { "OFCOM at ".gmtime(1646209800)." UTC" };
*Number::Phone::NANP::CA::data_source = sub { "CNAC at ".gmtime(1646600430)." UTC" };
*Number::Phone::NANP::US::data_source = sub { "National Pooling Administrator at ".gmtime(1646637178)." UTC" };
*Number::Phone::NANP::data_source = sub { "localcallingguide.com at ".gmtime(1646654440)." UTC" };
1;

=head1 NAME

Number::Phone::Data

=head1 DATA SOURCES

Canadian operator data derived from CNAC at Sun Mar 6 21:00:30 2022 UTC

US operator data derived from National Pooling Administrator at Mon Mar 7 07:12:58 2022 UTC

Other NANP operator data derived from localcallingguide.com at Mon Mar 7 12:00:40 2022 UTC

UK data derived from OFCOM at Wed Mar 2 08:30:00 2022 UTC

Most other data derived from libphonenumber v8.12.44

=cut
