
        # automatically generated file, don't edit
        #
        # Copyright 2016 David Cantrell, derived from data from libphonenumber
        # http://code.google.com/p/libphonenumber/
        #
        # Licensed under the Apache License, Version 2.0 (the "License");
        # you may not use this file except in compliance with the License.
        # You may obtain a copy of the License at
        #
        #     http://www.apache.org/licenses/LICENSE-2.0
        #
        # Unless required by applicable law or agreed to in writing, software
        # distributed under the License is distributed on an "AS IS" BASIS,
        # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
        # See the License for the specific language governing permissions and
        # limitations under the License.
        
        use strict;
        use warnings;
        use lib 't/inc';
        use nptestutils;

        use Scalar::Util qw(blessed);
        use Test::More;

        use Number::Phone;
        use Number::Phone::Lib;
    foreach my $test ({ class => 'Number::Phone::Lib', args => ['AC','+24762889'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['AC','62889'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+24762889'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['AC','+24740123'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['AC','40123'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+24740123'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['AC','+247542011'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AC','542011'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+247542011'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AD','+376712345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['AD','712345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+376712345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['AD','+376312345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['AD','312345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+376312345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['AD','+37618001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['AD','18001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+37618001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['AD','+376912345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AD','912345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+376912345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AE','+97122345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['AE','22345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+97122345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['AE','+971501234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['AE','501234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+971501234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['AE','+971800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['AE','800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+971800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['AE','+971900234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AE','900234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+971900234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AE','+971700012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AE','700012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+971700012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AE','+971600212345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AE','600212345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+971600212345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AF','+93234567890'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['AF','234567890'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+93234567890'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['AF','+93701234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['AF','701234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+93701234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone', args => ['AG','+12684601234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['AG','+12684601234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['AG','2684601234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['AG','2684601234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['+12684601234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+12684601234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['AG','+12684641234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['AG','+12684641234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['AG','2684641234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['AG','2684641234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['+12684641234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+12684641234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['AG','+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['AG','+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['AG','8002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['AG','8002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['AG','+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AG','+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['AG','9002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AG','9002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['AG','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['AG','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['AG','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['AG','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['AI','+12644612345'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['AI','+12644612345'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['AI','2644612345'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['AI','2644612345'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['+12644612345'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+12644612345'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['AI','+12642351234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['AI','+12642351234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['AI','2642351234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['AI','2642351234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['+12642351234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+12642351234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['AI','+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['AI','+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['AI','8002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['AI','8002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['AI','+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AI','+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['AI','9002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AI','9002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['AI','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['AI','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['AI','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['AI','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['AL','+35522345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['AL','22345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+35522345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['AL','+355672123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['AL','672123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+355672123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['AL','+3558001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['AL','8001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+3558001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['AL','+355900123'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AL','900123'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+355900123'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AL','+355808123'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AL','808123'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+355808123'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AL','+35570021234'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['AL','70021234'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+35570021234'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['AM','+37410123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['AM','10123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+37410123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['AM','+37477123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['AM','77123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+37477123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['AM','+37480012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['AM','80012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+37480012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['AM','+37490012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AM','90012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+37490012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AM','+37480112345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AM','80112345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+37480112345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AM','+37460271234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['AM','60271234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+37460271234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['AO','+244222123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['AO','222123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+244222123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['AO','+244923123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['AO','923123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+244923123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['AR','+541123456789'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['AR','1123456789'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+541123456789'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['AR','+5491123456789'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['AR','91123456789'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+5491123456789'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['AR','+548001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['AR','8001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+548001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['AR','+546001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AR','6001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+546001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AR','+548101234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AR','8101234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+548101234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['AS','+16846221234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['AS','+16846221234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['AS','6846221234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['AS','6846221234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['+16846221234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+16846221234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['AS','+16847331234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['AS','+16847331234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['AS','6847331234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['AS','6847331234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['+16847331234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+16847331234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['AS','+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['AS','+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['AS','8002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['AS','8002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['AS','+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AS','+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['AS','9002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AS','9002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['AS','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['AS','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['AS','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['AS','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['AT','+431234567890'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['AT','1234567890'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+431234567890'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['AT','+43664123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['AT','664123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+43664123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['AT','+43800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['AT','800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+43800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['AT','+43900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AT','900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+43900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AT','+43810123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AT','810123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+43810123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AT','+43780123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['AT','780123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+43780123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['AU','+61212345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['AU','212345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+61212345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['AU','+61412345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['AU','412345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+61412345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['AU','+611631234'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['AU','1631234'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['+611631234'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['AU','+611800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['AU','1800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+611800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['AU','+611900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AU','1900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+611900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AU','+611300123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AU','1300123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+611300123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AU','+61147101234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['AU','147101234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+61147101234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['AW','+2975212345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['AW','5212345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+2975212345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['AW','+2975601234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['AW','5601234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+2975601234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['AW','+2978001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['AW','8001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+2978001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['AW','+2979001234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AW','9001234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+2979001234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AW','+2975011234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['AW','5011234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+2975011234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['AX','+358181234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['AX','181234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+358181234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['AX','+358412345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['AX','412345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+358412345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['AX','+358800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['AX','800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+358800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['AX','+358600123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AX','600123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+358600123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AX','+35810112345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AX','10112345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+35810112345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AZ','+994123123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['AZ','123123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+994123123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['AZ','+994401234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['AZ','401234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+994401234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['AZ','+994881234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['AZ','881234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+994881234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['AZ','+994900200123'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['AZ','900200123'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+994900200123'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BA','+38730212345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['BA','30212345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+38730212345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['BA','+38761123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['BA','61123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+38761123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['BA','+38780123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['BA','80123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+38780123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['BA','+38790123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BA','90123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+38790123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BA','+38782123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BA','82123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+38782123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BA','+38770341234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BA','70341234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+38770341234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['BB','+12464123456'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['BB','+12464123456'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['BB','2464123456'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['BB','2464123456'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['+12464123456'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+12464123456'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['BB','+12462501234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['BB','+12462501234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['BB','2462501234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['BB','2462501234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['+12462501234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+12462501234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['BB','+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['BB','+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['BB','8002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['BB','8002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['BB','+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BB','+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['BB','9002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BB','9002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['BB','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['BB','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['BB','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['BB','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['BB','+12464301234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BB','+12464301234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['BB','2464301234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BB','2464301234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['+12464301234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+12464301234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BD','+88027111234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['BD','27111234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+88027111234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['BD','+8801812345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['BD','1812345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+8801812345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['BD','+8808001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['BD','8001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+8808001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['BD','+8809604123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['BD','9604123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+8809604123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['BE','+3212345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['BE','12345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+3212345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['BE','+32470123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['BE','470123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+32470123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['BE','+3280012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['BE','80012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+3280012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['BE','+3290012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BE','90012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+3290012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BE','+3278791234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BE','78791234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+3278791234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BE','+3278102345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BE','78102345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+3278102345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BF','+22620491234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['BF','20491234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+22620491234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['BF','+22670123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['BF','70123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+22670123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['BG','+3592123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['BG','2123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+3592123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['BG','+35943012345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['BG','43012345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+35943012345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['BG','+35980012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['BG','80012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+35980012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['BG','+35990123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BG','90123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+35990123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BG','+35970012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BG','70012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+35970012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BH','+97317001234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['BH','17001234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+97317001234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['BH','+97336001234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['BH','36001234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+97336001234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['BH','+97380123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['BH','80123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+97380123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['BH','+97390123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BH','90123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+97390123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BH','+97384123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BH','84123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+97384123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BI','+25722201234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['BI','22201234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+25722201234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['BI','+25779561234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['BI','79561234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+25779561234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['BJ','+22920211234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['BJ','20211234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+22920211234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['BJ','+22990011234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['BJ','90011234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+22990011234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['BJ','+22985751234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['BJ','85751234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+22985751234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['BJ','+22981123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BJ','81123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+22981123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BL','+590590271234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['BL','590271234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+590590271234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['BL','+590690001234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['BL','690001234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+590690001234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['BL','+590800012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['BL','800012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+590800012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['BL','+590976012345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['BL','976012345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+590976012345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone', args => ['BM','+14414123456'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['BM','+14414123456'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['BM','4414123456'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['BM','4414123456'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['+14414123456'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+14414123456'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['BM','+14413701234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['BM','+14413701234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['BM','4413701234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['BM','4413701234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['+14413701234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+14413701234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['BM','+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['BM','+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['BM','8002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['BM','8002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['BM','+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BM','+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['BM','9002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BM','9002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['BM','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['BM','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['BM','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['BM','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['BN','+6732345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['BN','2345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+6732345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['BN','+6737123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['BN','7123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+6737123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['BN','+6735345678'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['BN','5345678'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+6735345678'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['BO','+59122123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['BO','22123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+59122123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['BO','+59171234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['BO','71234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+59171234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['BO','+591800171234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['BO','800171234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+591800171234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['BQ','+5997151234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['BQ','7151234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+5997151234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['BQ','+5993181234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['BQ','3181234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+5993181234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['BR','+551123456789'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['BR','1123456789'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+551123456789'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['BR','+5511961234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['BR','11961234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+5511961234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['BR','+55800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['BR','800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+55800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['BR','+55300123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BR','300123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+55300123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BR','+5540041234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BR','40041234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+5540041234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['BS','+12423456789'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['BS','+12423456789'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['BS','2423456789'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['BS','2423456789'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['+12423456789'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+12423456789'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['BS','+12423591234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['BS','+12423591234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['BS','2423591234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['BS','2423591234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['+12423591234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+12423591234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['BS','+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['BS','+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['BS','8002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['BS','8002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['BS','+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BS','+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['BS','9002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BS','9002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['BS','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['BS','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['BS','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['BS','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['BS','+12422250123'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BS','+12422250123'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['BS','2422250123'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BS','2422250123'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['+12422250123'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+12422250123'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BT','+9752345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['BT','2345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+9752345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['BT','+97517123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['BT','17123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+97517123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['BW','+2672401234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['BW','2401234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+2672401234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['BW','+26771123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['BW','71123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+26771123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['BW','+2670800012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['BW','0800012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+2670800012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['BW','+2679012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BW','9012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+2679012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BW','+26779101234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['BW','79101234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+26779101234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['BY','+375152450911'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['BY','152450911'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+375152450911'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['BY','+375294911911'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['BY','294911911'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+375294911911'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['BY','+3758011234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['BY','8011234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+3758011234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['BY','+3759021234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BY','9021234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+3759021234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['BY','+375249123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['BY','249123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+375249123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['BZ','+5012221234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['BZ','2221234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+5012221234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['BZ','+5016221234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['BZ','6221234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+5016221234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['BZ','+50108001234123'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['BZ','08001234123'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+50108001234123'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['CA','+15062345678'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['CA','+15062345678'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['CA','5062345678'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['CA','5062345678'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['+15062345678'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+15062345678'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['CA','+15062345678'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['CA','+15062345678'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['CA','5062345678'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['CA','5062345678'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['+15062345678'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+15062345678'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['CA','+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['CA','+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['CA','8002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['CA','8002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['CA','+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CA','+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['CA','9002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CA','9002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['CA','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['CA','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['CA','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['CA','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['CC','+61891621234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['CC','891621234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+61891621234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['CC','+61412345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['CC','412345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+61412345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['CC','+611800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['CC','1800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+611800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['CC','+611900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CC','1900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+611900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CC','+611300123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CC','1300123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+611300123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CC','+61147101234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['CC','147101234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+61147101234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['CD','+2431234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['CD','1234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+2431234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['CD','+243991234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['CD','991234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+243991234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['CF','+23621612345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['CF','21612345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+23621612345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['CF','+23670012345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['CF','70012345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+23670012345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['CF','+23687761234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CF','87761234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+23687761234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CG','+242222123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['CG','222123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+242222123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['CG','+242061234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['CG','061234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+242061234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['CG','+242800123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CG','800123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+242800123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CH','+41212345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['CH','212345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+41212345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['CH','+41781234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['CH','781234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+41781234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['CH','+41740123456'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['CH','740123456'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['+41740123456'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['CH','+41800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['CH','800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+41800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['CH','+41900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CH','900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+41900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CH','+41840123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CH','840123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+41840123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CH','+41878123456'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['CH','878123456'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+41878123456'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['CH','+41581234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CH','581234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+41581234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CI','+2252123456789'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['CI','2123456789'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+2252123456789'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['CI','+2250123456789'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['CI','0123456789'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+2250123456789'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['CK','+68221234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['CK','21234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+68221234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['CK','+68271234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['CK','71234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+68271234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['CL','+56221234567'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['CL','221234567'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+56221234567'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['CL','+56221234567'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['CL','221234567'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+56221234567'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['CL','+56800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['CL','800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+56800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['CL','+566001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CL','6001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+566001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CL','+56441234567'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['CL','441234567'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+56441234567'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['CM','+237222123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['CM','222123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+237222123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['CM','+237671234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['CM','671234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+237671234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['CM','+23788012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['CM','88012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+23788012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['CN','+861012345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['CN','1012345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+861012345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['CN','+8613123456789'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['CN','13123456789'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+8613123456789'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['CN','+868001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['CN','8001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+868001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['CN','+8616812345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CN','16812345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+8616812345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CN','+864001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CN','4001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+864001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CO','+5712345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['CO','12345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+5712345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['CO','+573211234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['CO','3211234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+573211234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['CO','+5718001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['CO','18001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+5718001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['CO','+5719001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CO','19001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+5719001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CR','+50622123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['CR','22123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+50622123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['CR','+50683123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['CR','83123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+50683123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['CR','+5068001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['CR','8001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+5068001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['CR','+5069001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CR','9001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+5069001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CR','+50640001234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['CR','40001234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+50640001234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['CU','+5371234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['CU','71234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+5371234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['CU','+5351234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['CU','51234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+5351234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['CU','+538001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['CU','8001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+538001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['CU','+538071234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CU','8071234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+538071234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CV','+2382211234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['CV','2211234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+2382211234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['CV','+2389911234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['CV','9911234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+2389911234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['CV','+2388001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['CV','8001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+2388001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['CV','+2383401234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['CV','3401234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+2383401234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['CW','+59994351234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['CW','94351234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+59994351234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['CW','+59995181234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['CW','95181234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+59995181234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['CW','+59995581234'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['CW','95581234'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['+59995581234'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['CW','+5996001234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CW','6001234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+5996001234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CX','+61891641234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['CX','891641234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+61891641234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['CX','+61412345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['CX','412345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+61412345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['CX','+611800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['CX','1800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+611800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['CX','+611900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CX','1900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+611900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CX','+611300123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CX','1300123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+611300123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CX','+61147101234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['CX','147101234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+61147101234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['CY','+35722345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['CY','22345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+35722345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['CY','+35796123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['CY','96123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+35796123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['CY','+35780001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['CY','80001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+35780001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['CY','+35790012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CY','90012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+35790012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CY','+35780112345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CY','80112345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+35780112345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CY','+35770012345'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['CY','70012345'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+35770012345'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['CY','+35777123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CY','77123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+35777123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CZ','+420212345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['CZ','212345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+420212345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['CZ','+420601123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['CZ','601123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+420601123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['CZ','+420800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['CZ','800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+420800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['CZ','+420900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CZ','900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+420900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CZ','+420811234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CZ','811234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+420811234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CZ','+420700123456'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['CZ','700123456'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+420700123456'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['CZ','+420910123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['CZ','910123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+420910123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['CZ','+420972123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['CZ','972123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+420972123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['DE','+4930123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['DE','30123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+4930123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['DE','+4915123456789'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['DE','15123456789'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+4915123456789'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['DE','+4916412345'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['DE','16412345'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['+4916412345'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['DE','+498001234567890'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['DE','8001234567890'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+498001234567890'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['DE','+499001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['DE','9001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+499001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['DE','+4918012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['DE','18012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+4918012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['DE','+4970012345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['DE','70012345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+4970012345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['DE','+4918500123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['DE','18500123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+4918500123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['DJ','+25321360003'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['DJ','21360003'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+25321360003'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['DJ','+25377831001'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['DJ','77831001'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+25377831001'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['DK','+4532123456'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['DK','32123456'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+4532123456'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['DK','+4532123456'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['DK','32123456'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+4532123456'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['DK','+4580123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['DK','80123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+4580123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['DK','+4590123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['DK','90123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+4590123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['DM','+17674201234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['DM','+17674201234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['DM','7674201234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['DM','7674201234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['+17674201234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+17674201234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['DM','+17672251234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['DM','+17672251234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['DM','7672251234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['DM','7672251234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['+17672251234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+17672251234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['DM','+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['DM','+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['DM','8002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['DM','8002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['DM','+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['DM','+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['DM','9002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['DM','9002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['DM','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['DM','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['DM','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['DM','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['DO','+18092345678'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['DO','+18092345678'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['DO','8092345678'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['DO','8092345678'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['+18092345678'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+18092345678'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['DO','+18092345678'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['DO','+18092345678'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['DO','8092345678'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['DO','8092345678'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['+18092345678'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+18092345678'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['DO','+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['DO','+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['DO','8002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['DO','8002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['DO','+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['DO','+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['DO','9002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['DO','9002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['DO','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['DO','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['DO','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['DO','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['DZ','+21312345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['DZ','12345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+21312345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['DZ','+213551234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['DZ','551234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+213551234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['DZ','+213800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['DZ','800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+213800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['DZ','+213808123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['DZ','808123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+213808123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['DZ','+213801123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['DZ','801123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+213801123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['DZ','+213983123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['DZ','983123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+213983123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['EC','+59322123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['EC','22123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+59322123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['EC','+593991234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['EC','991234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+593991234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['EC','+59318001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['EC','18001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+59318001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['EC','+59328901234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['EC','28901234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+59328901234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['EE','+3723212345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['EE','3212345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+3723212345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['EE','+37251234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['EE','51234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+37251234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['EE','+37280012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['EE','80012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+37280012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['EE','+3729001234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['EE','9001234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+3729001234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['EE','+37270012345'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['EE','70012345'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+37270012345'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['EG','+20234567890'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['EG','234567890'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+20234567890'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['EG','+201001234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['EG','1001234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+201001234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['EG','+208001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['EG','8001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+208001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['EG','+209001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['EG','9001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+209001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['EH','+212528812345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['EH','528812345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+212528812345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['EH','+212650123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['EH','650123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+212650123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['EH','+212801234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['EH','801234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+212801234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['EH','+212891234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['EH','891234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+212891234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['EH','+212592401234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['EH','592401234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+212592401234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['ER','+2918370362'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['ER','8370362'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+2918370362'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['ER','+2917123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['ER','7123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+2917123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['ES','+34810123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['ES','810123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+34810123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['ES','+34612345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['ES','612345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+34612345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['ES','+34800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['ES','800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+34800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['ES','+34803123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['ES','803123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+34803123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['ES','+34901123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['ES','901123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+34901123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['ES','+34701234567'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['ES','701234567'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+34701234567'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['ES','+34511234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['ES','511234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+34511234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['ET','+251111112345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['ET','111112345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+251111112345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['ET','+251911234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['ET','911234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+251911234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['FI','+358131234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['FI','131234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+358131234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['FI','+358412345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['FI','412345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+358412345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['FI','+358800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['FI','800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+358800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['FI','+358600123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['FI','600123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+358600123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['FI','+35810112345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['FI','10112345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+35810112345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['FJ','+6793212345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['FJ','3212345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+6793212345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['FJ','+6797012345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['FJ','7012345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+6797012345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['FJ','+67908001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['FJ','08001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+67908001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['FK','+50031234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['FK','31234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+50031234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['FK','+50051234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['FK','51234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+50051234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['FM','+6913201234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['FM','3201234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+6913201234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['FM','+6913501234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['FM','3501234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+6913501234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['FO','+298201234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['FO','201234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+298201234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['FO','+298211234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['FO','211234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+298211234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['FO','+298802123'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['FO','802123'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+298802123'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['FO','+298901123'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['FO','901123'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+298901123'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['FO','+298601234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['FO','601234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+298601234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['FR','+33123456789'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['FR','123456789'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+33123456789'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['FR','+33612345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['FR','612345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+33612345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['FR','+33801234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['FR','801234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+33801234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['FR','+33891123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['FR','891123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+33891123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['FR','+33884012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['FR','884012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+33884012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['FR','+33912345678'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['FR','912345678'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+33912345678'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['FR','+33806123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['FR','806123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+33806123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['GA','+24101441234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['GA','01441234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+24101441234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['GA','+24106031234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['GA','06031234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+24106031234'], methods => ['is_mobile'] },
{ class => 'Number::Phone', args => ['GB','+441212345678'], methods => ['is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['GB','+441212345678'], methods => ['is_geographic'] },
{ class => 'Number::Phone', args => ['UK','+441212345678'], methods => ['is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['UK','+441212345678'], methods => ['is_geographic'] },
{ class => 'Number::Phone', args => ['GB','1212345678'], methods => ['is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['GB','1212345678'], methods => ['is_geographic'] },
{ class => 'Number::Phone', args => ['UK','1212345678'], methods => ['is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['UK','1212345678'], methods => ['is_geographic'] },
{ class => 'Number::Phone', args => ['+441212345678'], methods => ['is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+441212345678'], methods => ['is_geographic'] },
{ class => 'Number::Phone', args => ['GB','+447400123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['GB','+447400123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone', args => ['UK','+447400123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['UK','+447400123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone', args => ['GB','7400123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['GB','7400123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone', args => ['UK','7400123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['UK','7400123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone', args => ['+447400123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+447400123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone', args => ['GB','+447640123456'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['GB','+447640123456'], methods => ['is_pager'] },
{ class => 'Number::Phone', args => ['UK','+447640123456'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['UK','+447640123456'], methods => ['is_pager'] },
{ class => 'Number::Phone', args => ['GB','7640123456'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['GB','7640123456'], methods => ['is_pager'] },
{ class => 'Number::Phone', args => ['UK','7640123456'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['UK','7640123456'], methods => ['is_pager'] },
{ class => 'Number::Phone', args => ['+447640123456'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['+447640123456'], methods => ['is_pager'] },
{ class => 'Number::Phone', args => ['GB','+449012345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['GB','+449012345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['UK','+449012345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['UK','+449012345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['GB','9012345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['GB','9012345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['UK','9012345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['UK','9012345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['+449012345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+449012345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['GB','+447012345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['GB','+447012345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['UK','+447012345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['UK','+447012345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['GB','7012345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['GB','7012345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['UK','7012345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['UK','7012345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['+447012345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+447012345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['GD','+14732691234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['GD','+14732691234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['GD','4732691234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['GD','4732691234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['+14732691234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+14732691234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['GD','+14734031234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['GD','+14734031234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['GD','4734031234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['GD','4734031234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['+14734031234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+14734031234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['GD','+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['GD','+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['GD','8002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['GD','8002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['GD','+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['GD','+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['GD','9002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['GD','9002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['GD','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['GD','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['GD','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['GD','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['GE','+995322123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['GE','322123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+995322123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['GE','+995555123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['GE','555123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+995555123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['GE','+995800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['GE','800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+995800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['GE','+995706123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['GE','706123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+995706123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['GF','+594594101234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['GF','594101234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+594594101234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['GF','+594694201234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['GF','694201234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+594694201234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['GF','+594800012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['GF','800012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+594800012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['GF','+594976012345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['GF','976012345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+594976012345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone', args => ['GG','+441481256789'], methods => ['is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['GG','+441481256789'], methods => ['is_geographic'] },
{ class => 'Number::Phone', args => ['GG','1481256789'], methods => ['is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['GG','1481256789'], methods => ['is_geographic'] },
{ class => 'Number::Phone', args => ['+441481256789'], methods => ['is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+441481256789'], methods => ['is_geographic'] },
{ class => 'Number::Phone', args => ['GG','+447781123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['GG','+447781123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone', args => ['GG','7781123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['GG','7781123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone', args => ['+447781123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+447781123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone', args => ['GG','+447640123456'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['GG','+447640123456'], methods => ['is_pager'] },
{ class => 'Number::Phone', args => ['GG','7640123456'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['GG','7640123456'], methods => ['is_pager'] },
{ class => 'Number::Phone', args => ['+447640123456'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['+447640123456'], methods => ['is_pager'] },
{ class => 'Number::Phone', args => ['GG','+449012345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['GG','+449012345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['GG','9012345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['GG','9012345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['+449012345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+449012345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['GG','+447012345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['GG','+447012345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['GG','7012345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['GG','7012345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['+447012345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+447012345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['GH','+233302345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['GH','302345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+233302345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['GH','+233231234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['GH','231234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+233231234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['GH','+23380012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['GH','80012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+23380012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['GI','+35020012345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['GI','20012345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+35020012345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['GI','+35057123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['GI','57123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+35057123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['GL','+299321000'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['GL','321000'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+299321000'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['GL','+299221234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['GL','221234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+299221234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['GL','+299801234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['GL','801234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+299801234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['GL','+299381234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['GL','381234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+299381234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['GM','+2205661234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['GM','5661234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+2205661234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['GM','+2203012345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['GM','3012345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+2203012345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['GN','+22430241234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['GN','30241234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+22430241234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['GN','+224601123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['GN','601123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+224601123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['GN','+224722123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['GN','722123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+224722123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['GP','+590590201234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['GP','590201234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+590590201234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['GP','+590690001234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['GP','690001234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+590690001234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['GP','+590800012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['GP','800012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+590800012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['GP','+590976012345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['GP','976012345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+590976012345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['GQ','+240333091234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['GQ','333091234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+240333091234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['GQ','+240222123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['GQ','222123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+240222123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['GQ','+240800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['GQ','800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+240800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['GQ','+240900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['GQ','900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+240900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['GR','+302123456789'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['GR','2123456789'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+302123456789'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['GR','+306912345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['GR','6912345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+306912345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['GR','+308001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['GR','8001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+308001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['GR','+309091234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['GR','9091234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+309091234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['GR','+308011234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['GR','8011234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+308011234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['GR','+307012345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['GR','7012345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+307012345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['GR','+305005000123'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['GR','5005000123'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+305005000123'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['GT','+50222456789'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['GT','22456789'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+50222456789'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['GT','+50251234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['GT','51234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+50251234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['GT','+50218001112222'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['GT','18001112222'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+50218001112222'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['GT','+50219001112222'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['GT','19001112222'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+50219001112222'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['GU','+16713001234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['GU','+16713001234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['GU','6713001234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['GU','6713001234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['+16713001234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+16713001234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['GU','+16713001234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['GU','+16713001234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['GU','6713001234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['GU','6713001234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['+16713001234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+16713001234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['GU','+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['GU','+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['GU','8002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['GU','8002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['GU','+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['GU','+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['GU','9002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['GU','9002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['GU','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['GU','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['GU','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['GU','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['GW','+245443201234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['GW','443201234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+245443201234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['GW','+245955012345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['GW','955012345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+245955012345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['GW','+2454012345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['GW','4012345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+2454012345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['GY','+5922201234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['GY','2201234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+5922201234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['GY','+5926091234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['GY','6091234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+5926091234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['GY','+5922891234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['GY','2891234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+5922891234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['GY','+5929008123'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['GY','9008123'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+5929008123'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['HK','+85221234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['HK','21234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+85221234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['HK','+85251234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['HK','51234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+85251234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['HK','+85271123456'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['HK','71123456'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['+85271123456'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['HK','+852800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['HK','800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+852800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['HK','+85290012345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['HK','90012345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+85290012345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['HK','+85281123456'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['HK','81123456'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+85281123456'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['HK','+85230161234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['HK','30161234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+85230161234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['HN','+50422123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['HN','22123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+50422123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['HN','+50491234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['HN','91234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+50491234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['HN','+50480021234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['HN','80021234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+50480021234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['HR','+38512345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['HR','12345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+38512345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['HR','+385921234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['HR','921234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+385921234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['HR','+385800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['HR','800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+385800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['HR','+385611234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['HR','611234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+385611234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['HR','+38574123456'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['HR','74123456'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+38574123456'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['HR','+38562123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['HR','62123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+38562123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['HT','+50922453300'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['HT','22453300'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+50922453300'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['HT','+50934101234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['HT','34101234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+50934101234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['HT','+50980012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['HT','80012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+50980012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['HT','+50998901234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['HT','98901234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+50998901234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['HU','+3612345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['HU','12345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+3612345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['HU','+36201234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['HU','201234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+36201234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['HU','+3680123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['HU','80123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+3680123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['HU','+3690123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['HU','90123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+3690123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['HU','+36211234567'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['HU','211234567'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+36211234567'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['HU','+36381234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['HU','381234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+36381234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['ID','+62218350123'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['ID','218350123'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+62218350123'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['ID','+62812345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['ID','812345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+62812345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['ID','+628001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['ID','8001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+628001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['ID','+628091234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['ID','8091234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+628091234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['ID','+628041234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['ID','8041234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+628041234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['ID','+628071123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['ID','8071123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+628071123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['IE','+3532212345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['IE','2212345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+3532212345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['IE','+353850123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['IE','850123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+353850123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['IE','+3531800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['IE','1800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+3531800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['IE','+3531520123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['IE','1520123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+3531520123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['IE','+3531850123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['IE','1850123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+3531850123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['IE','+353700123456'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['IE','700123456'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+353700123456'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['IE','+353761234567'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['IE','761234567'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+353761234567'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['IE','+353818123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['IE','818123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+353818123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['IL','+97221234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['IL','21234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+97221234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['IL','+972502345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['IL','502345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+972502345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['IL','+9721800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['IL','1800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+9721800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['IL','+9721919123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['IL','1919123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+9721919123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['IL','+9721700123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['IL','1700123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+9721700123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['IL','+972771234567'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['IL','771234567'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+972771234567'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['IL','+9721599123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['IL','1599123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+9721599123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['IM','+441624756789'], methods => ['is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['IM','+441624756789'], methods => ['is_geographic'] },
{ class => 'Number::Phone', args => ['IM','1624756789'], methods => ['is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['IM','1624756789'], methods => ['is_geographic'] },
{ class => 'Number::Phone', args => ['+441624756789'], methods => ['is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+441624756789'], methods => ['is_geographic'] },
{ class => 'Number::Phone', args => ['IM','+447924123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['IM','+447924123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone', args => ['IM','7924123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['IM','7924123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone', args => ['+447924123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+447924123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone', args => ['IM','+448081624567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['IM','+448081624567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['IM','8081624567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['IM','8081624567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['+448081624567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+448081624567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['IM','+449016247890'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['IM','+449016247890'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['IM','9016247890'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['IM','9016247890'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['+449016247890'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+449016247890'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['IM','+447012345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['IM','+447012345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['IM','7012345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['IM','7012345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['+447012345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+447012345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['IN','+917410410123'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['IN','7410410123'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+917410410123'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['IN','+918123456789'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['IN','8123456789'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+918123456789'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['IN','+911800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['IN','1800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+911800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['IN','+911861123456789'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['IN','1861123456789'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+911861123456789'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['IN','+9118603451234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['IN','18603451234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+9118603451234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['IN','+911409305260'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['IN','1409305260'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+911409305260'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['IO','+2463709100'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['IO','3709100'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+2463709100'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['IO','+2463801234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['IO','3801234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+2463801234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['IQ','+96412345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['IQ','12345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+96412345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['IQ','+9647912345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['IQ','7912345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+9647912345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['IR','+982123456789'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['IR','2123456789'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+982123456789'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['IR','+989123456789'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['IR','9123456789'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+989123456789'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['IR','+989601'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['IR','9601'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+989601'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['IS','+3544101234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['IS','4101234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+3544101234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['IS','+3546111234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['IS','6111234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+3546111234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['IS','+3548001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['IS','8001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+3548001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['IS','+3549001234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['IS','9001234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+3549001234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['IS','+3544921234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['IS','4921234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+3544921234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['IS','+3548091234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['IS','8091234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+3548091234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['IT','+390212345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['IT','0212345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+390212345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['IT','+393123456789'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['IT','3123456789'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+393123456789'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['IT','+39800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['IT','800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+39800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['IT','+39899123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['IT','899123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+39899123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['IT','+39848123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['IT','848123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+39848123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['IT','+391781234567'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['IT','1781234567'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+391781234567'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['IT','+395512345678'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['IT','5512345678'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+395512345678'], methods => ['is_ipphone'] },
{ class => 'Number::Phone', args => ['JE','+447797712345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['JE','+447797712345'], methods => ['is_mobile'] },
{ class => 'Number::Phone', args => ['JE','7797712345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['JE','7797712345'], methods => ['is_mobile'] },
{ class => 'Number::Phone', args => ['+447797712345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+447797712345'], methods => ['is_mobile'] },
{ class => 'Number::Phone', args => ['JE','+447640123456'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['JE','+447640123456'], methods => ['is_pager'] },
{ class => 'Number::Phone', args => ['JE','7640123456'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['JE','7640123456'], methods => ['is_pager'] },
{ class => 'Number::Phone', args => ['+447640123456'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['+447640123456'], methods => ['is_pager'] },
{ class => 'Number::Phone', args => ['JE','+448007354567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['JE','+448007354567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['JE','8007354567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['JE','8007354567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['+448007354567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+448007354567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['JE','+449018105678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['JE','+449018105678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['JE','9018105678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['JE','9018105678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['+449018105678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+449018105678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['JE','+447015115678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['JE','+447015115678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['JE','7015115678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['JE','7015115678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['+447015115678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+447015115678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['JM','+18765230123'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['JM','+18765230123'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['JM','8765230123'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['JM','8765230123'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['+18765230123'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+18765230123'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['JM','+18762101234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['JM','+18762101234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['JM','8762101234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['JM','8762101234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['+18762101234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+18762101234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['JM','+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['JM','+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['JM','8002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['JM','8002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['JM','+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['JM','+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['JM','9002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['JM','9002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['JM','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['JM','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['JM','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['JM','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['JO','+96262001234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['JO','62001234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+96262001234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['JO','+962790123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['JO','790123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+962790123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['JO','+962746612345'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['JO','746612345'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['+962746612345'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['JO','+96280012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['JO','80012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+96280012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['JO','+96290012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['JO','90012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+96290012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['JO','+96285012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['JO','85012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+96285012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['JO','+962700123456'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['JO','700123456'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+962700123456'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['JO','+96288101234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['JO','88101234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+96288101234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['JP','+81312345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['JP','312345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+81312345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['JP','+819012345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['JP','9012345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+819012345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['JP','+812012345678'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['JP','2012345678'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['+812012345678'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['JP','+81120123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['JP','120123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+81120123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['JP','+81990123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['JP','990123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+81990123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['JP','+81601234567'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['JP','601234567'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+81601234567'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['JP','+815012345678'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['JP','5012345678'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+815012345678'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['JP','+81570123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['JP','570123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+81570123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['KE','+254202012345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['KE','202012345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+254202012345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['KE','+254712123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['KE','712123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+254712123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['KE','+254800223456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['KE','800223456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+254800223456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['KE','+254900223456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['KE','900223456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+254900223456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['KG','+996312123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['KG','312123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+996312123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['KG','+996700123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['KG','700123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+996700123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['KG','+996800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['KG','800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+996800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['KH','+85523756789'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['KH','23756789'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+85523756789'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['KH','+85591234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['KH','91234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+85591234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['KH','+8551800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['KH','1800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+8551800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['KH','+8551900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['KH','1900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+8551900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['KI','+68631234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['KI','31234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+68631234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['KI','+68672001234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['KI','72001234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+68672001234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['KI','+68630010000'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['KI','30010000'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+68630010000'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['KM','+2697712345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['KM','7712345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+2697712345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['KM','+2693212345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['KM','3212345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+2693212345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['KM','+2698001234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['KM','8001234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+2698001234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['KN','+18692361234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['KN','+18692361234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['KN','8692361234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['KN','8692361234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['+18692361234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+18692361234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['KN','+18697652917'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['KN','+18697652917'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['KN','8697652917'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['KN','8697652917'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['+18697652917'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+18697652917'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['KN','+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['KN','+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['KN','8002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['KN','8002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['KN','+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['KN','+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['KN','9002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['KN','9002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['KN','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['KN','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['KN','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['KN','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['KP','+85021234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['KP','21234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+85021234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['KP','+8501921234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['KP','1921234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+8501921234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['KR','+8222123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['KR','22123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+8222123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['KR','+821020000000'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['KR','1020000000'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+821020000000'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['KR','+821523456789'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['KR','1523456789'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['+821523456789'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['KR','+82801234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['KR','801234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+82801234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['KR','+82602345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['KR','602345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+82602345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['KR','+825012345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['KR','5012345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+825012345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['KR','+827012345678'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['KR','7012345678'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+827012345678'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['KR','+8215441234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['KR','15441234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+8215441234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['KW','+96522345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['KW','22345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+96522345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['KW','+96550012345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['KW','50012345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+96550012345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['KW','+9651801234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['KW','1801234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+9651801234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['KY','+13452221234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['KY','+13452221234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['KY','3452221234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['KY','3452221234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['+13452221234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+13452221234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['KY','+13453231234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['KY','+13453231234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['KY','3453231234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['KY','3453231234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['+13453231234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+13453231234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['KY','+18002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['KY','+18002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['KY','8002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['KY','8002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['+18002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+18002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['KY','+19002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['KY','+19002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['KY','9002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['KY','9002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['+19002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+19002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['KY','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['KY','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['KY','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['KY','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['KZ','+77123456789'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['KZ','7123456789'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+77123456789'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['KZ','+77710009998'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['KZ','7710009998'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+77710009998'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['KZ','+78001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['KZ','8001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+78001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['KZ','+78091234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['KZ','8091234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+78091234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['KZ','+78081234567'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['KZ','8081234567'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+78081234567'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['KZ','+77511234567'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['KZ','7511234567'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+77511234567'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['LA','+85621212862'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['LA','21212862'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+85621212862'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['LA','+8562023123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['LA','2023123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+8562023123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['LA','+856301234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['LA','301234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+856301234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['LB','+9611123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['LB','1123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+9611123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['LB','+96171123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['LB','71123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+96171123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['LB','+96190123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['LB','90123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+96190123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['LB','+96180123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['LB','80123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+96180123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['LC','+17584305678'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['LC','+17584305678'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['LC','7584305678'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['LC','7584305678'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['+17584305678'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+17584305678'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['LC','+17582845678'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['LC','+17582845678'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['LC','7582845678'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['LC','7582845678'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['+17582845678'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+17582845678'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['LC','+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['LC','+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['LC','8002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['LC','8002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['LC','+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['LC','+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['LC','9002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['LC','9002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['LC','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['LC','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['LC','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['LC','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['LI','+4232345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['LI','2345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+4232345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['LI','+423660234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['LI','660234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+423660234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['LI','+4238002222'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['LI','8002222'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+4238002222'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['LI','+4239002222'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['LI','9002222'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+4239002222'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['LI','+4238702812'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['LI','8702812'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+4238702812'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['LK','+94112345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['LK','112345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+94112345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['LK','+94712345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['LK','712345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+94712345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['LK','+94197312345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['LK','197312345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+94197312345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['LR','+23121234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['LR','21234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+23121234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['LR','+231770123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['LR','770123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+231770123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['LR','+231332021234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['LR','332021234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+231332021234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['LS','+26622123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['LS','22123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+26622123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['LS','+26650123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['LS','50123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+26650123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['LS','+26680021234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['LS','80021234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+26680021234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['LT','+37031234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['LT','31234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+37031234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['LT','+37061234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['LT','61234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+37061234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['LT','+37080012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['LT','80012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+37080012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['LT','+37090012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['LT','90012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+37090012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['LT','+37080812345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['LT','80812345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+37080812345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['LT','+37070012345'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['LT','70012345'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+37070012345'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['LT','+37080123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['LT','80123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+37080123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['LT','+37070712345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['LT','70712345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+37070712345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['LU','+35227123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['LU','27123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+35227123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['LU','+352628123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['LU','628123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+352628123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['LU','+35280012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['LU','80012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+35280012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['LU','+35290012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['LU','90012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+35290012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['LU','+35280112345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['LU','80112345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+35280112345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['LU','+35220201234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['LU','20201234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+35220201234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['LV','+37163123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['LV','63123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+37163123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['LV','+37121234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['LV','21234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+37121234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['LV','+37180123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['LV','80123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+37180123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['LV','+37190123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['LV','90123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+37190123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['LV','+37181123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['LV','81123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+37181123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['LY','+218212345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['LY','212345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+218212345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['LY','+218912345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['LY','912345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+218912345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['MA','+212520123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['MA','520123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+212520123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['MA','+212650123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['MA','650123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+212650123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['MA','+212801234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['MA','801234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+212801234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['MA','+212891234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['MA','891234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+212891234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['MA','+212592401234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['MA','592401234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+212592401234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['MC','+37799123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['MC','99123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+37799123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['MC','+377612345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['MC','612345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+377612345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['MC','+37790123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['MC','90123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+37790123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['MD','+37322212345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['MD','22212345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+37322212345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['MD','+37362112345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['MD','62112345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+37362112345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['MD','+37380012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['MD','80012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+37380012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['MD','+37390012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['MD','90012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+37390012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['MD','+37380812345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['MD','80812345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+37380812345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['MD','+37330123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['MD','30123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+37330123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['MD','+37380312345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['MD','80312345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+37380312345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['ME','+38230234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['ME','30234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+38230234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['ME','+38267622901'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['ME','67622901'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+38267622901'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['ME','+38280080002'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['ME','80080002'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+38280080002'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['ME','+38294515151'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['ME','94515151'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+38294515151'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['ME','+38278108780'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['ME','78108780'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+38278108780'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['ME','+38277273012'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['ME','77273012'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+38277273012'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['MF','+590590271234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['MF','590271234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+590590271234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['MF','+590690001234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['MF','690001234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+590690001234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['MF','+590800012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['MF','800012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+590800012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['MF','+590976012345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['MF','976012345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+590976012345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['MG','+261202123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['MG','202123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+261202123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['MG','+261321234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['MG','321234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+261321234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['MG','+261221234567'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['MG','221234567'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+261221234567'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['MH','+6922471234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['MH','2471234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+6922471234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['MH','+6922351234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['MH','2351234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+6922351234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['MH','+6926351234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['MH','6351234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+6926351234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['MK','+38922012345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['MK','22012345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+38922012345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['MK','+38972345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['MK','72345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+38972345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['MK','+38980012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['MK','80012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+38980012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['MK','+38950012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['MK','50012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+38950012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['MK','+38980123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['MK','80123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+38980123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['ML','+22320212345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['ML','20212345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+22320212345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['ML','+22365012345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['ML','65012345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+22365012345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['ML','+22380012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['ML','80012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+22380012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['MM','+951234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['MM','1234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+951234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['MM','+9592123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['MM','92123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+9592123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['MM','+958008001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['MM','8008001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+958008001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['MM','+9513331234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['MM','13331234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+9513331234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['MN','+97653123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['MN','53123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+97653123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['MN','+97688123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['MN','88123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+97688123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['MN','+97675123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['MN','75123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+97675123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['MO','+85328212345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['MO','28212345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+85328212345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['MO','+85366123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['MO','66123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+85366123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['MO','+8530800501'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['MO','0800501'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+8530800501'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['MP','+16702345678'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['MP','+16702345678'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['MP','6702345678'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['MP','6702345678'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['+16702345678'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+16702345678'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['MP','+16702345678'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['MP','+16702345678'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['MP','6702345678'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['MP','6702345678'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['+16702345678'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+16702345678'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['MP','+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['MP','+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['MP','8002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['MP','8002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['MP','+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['MP','+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['MP','9002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['MP','9002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['MP','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['MP','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['MP','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['MP','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['MQ','+596596301234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['MQ','596301234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+596596301234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['MQ','+596696201234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['MQ','696201234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+596696201234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['MQ','+596800012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['MQ','800012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+596800012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['MQ','+596976612345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['MQ','976612345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+596976612345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['MR','+22235123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['MR','35123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+22235123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['MR','+22222123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['MR','22123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+22222123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['MR','+22280012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['MR','80012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+22280012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['MS','+16644912345'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['MS','+16644912345'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['MS','6644912345'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['MS','6644912345'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['+16644912345'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+16644912345'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['MS','+16644923456'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['MS','+16644923456'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['MS','6644923456'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['MS','6644923456'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['+16644923456'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+16644923456'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['MS','+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['MS','+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['MS','8002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['MS','8002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['MS','+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['MS','+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['MS','9002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['MS','9002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['MS','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['MS','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['MS','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['MS','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['MT','+35621001234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['MT','21001234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+35621001234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['MT','+35696961234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['MT','96961234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+35696961234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['MT','+35671171234'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['MT','71171234'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['+35671171234'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['MT','+35680071234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['MT','80071234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+35680071234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['MT','+35650037123'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['MT','50037123'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+35650037123'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['MT','+35635501234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['MT','35501234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+35635501234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['MT','+35650112345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['MT','50112345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+35650112345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['MU','+23054480123'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['MU','54480123'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+23054480123'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['MU','+23052512345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['MU','52512345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+23052512345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['MU','+2308001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['MU','8001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+2308001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['MU','+2303012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['MU','3012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+2303012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['MU','+2303201234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['MU','3201234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+2303201234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['MV','+9606701234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['MV','6701234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+9606701234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['MV','+9607712345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['MV','7712345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+9607712345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['MV','+9608001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['MV','8001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+9608001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['MV','+9609001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['MV','9001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+9609001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['MV','+9604001234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['MV','4001234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+9604001234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['MW','+2651234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['MW','1234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+2651234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['MW','+265991234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['MW','991234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+265991234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['MX','+522001234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['MX','2001234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+522001234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['MX','+5212221234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['MX','12221234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+5212221234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['MX','+528001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['MX','8001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+528001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['MX','+529001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['MX','9001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+529001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['MX','+523001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['MX','3001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+523001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['MX','+525001234567'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['MX','5001234567'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+525001234567'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['MY','+60323856789'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['MY','323856789'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+60323856789'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['MY','+60123456789'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['MY','123456789'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+60123456789'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['MY','+601300123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['MY','1300123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+601300123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['MY','+601600123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['MY','1600123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+601600123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['MY','+601546012345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['MY','1546012345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+601546012345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['MZ','+25821123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['MZ','21123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+25821123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['MZ','+258821234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['MZ','821234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+258821234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['MZ','+258800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['MZ','800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+258800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['NA','+26461221234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['NA','61221234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+26461221234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['NA','+264811234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['NA','811234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+264811234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['NA','+264800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['NA','800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+264800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['NA','+264870123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['NA','870123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+264870123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['NA','+26488612345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['NA','88612345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+26488612345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['NC','+687201234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['NC','201234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+687201234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['NC','+687751234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['NC','751234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+687751234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['NC','+687366711'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['NC','366711'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+687366711'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['NE','+22720201234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['NE','20201234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+22720201234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['NE','+22793123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['NE','93123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+22793123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['NE','+22708123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['NE','08123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+22708123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['NE','+22709123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['NE','09123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+22709123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['NF','+672381234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['NF','381234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+672381234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['NG','+23418040123'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['NG','18040123'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+23418040123'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['NG','+2348021234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['NG','8021234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+2348021234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['NG','+23480017591759'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['NG','80017591759'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+23480017591759'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['NG','+2347001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['NG','7001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+2347001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['NI','+50521234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['NI','21234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+50521234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['NI','+50581234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['NI','81234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+50581234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['NI','+50518001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['NI','18001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+50518001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['NL','+31101234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['NL','101234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+31101234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['NL','+31612345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['NL','612345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+31612345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['NL','+31662345678'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['NL','662345678'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['+31662345678'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['NL','+318001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['NL','8001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+318001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['NL','+319061234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['NL','9061234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+319061234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['NL','+31851234567'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['NL','851234567'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+31851234567'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['NL','+3114020'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['NL','14020'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+3114020'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['NO','+4721234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['NO','21234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+4721234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['NO','+4740612345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['NO','40612345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+4740612345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['NO','+4780012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['NO','80012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+4780012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['NO','+4782012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['NO','82012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+4782012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['NO','+4781021234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['NO','81021234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+4781021234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['NO','+4788012345'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['NO','88012345'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+4788012345'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['NO','+4785012345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['NO','85012345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+4785012345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['NO','+4702000'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['NO','02000'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+4702000'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['NP','+97714567890'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['NP','14567890'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+97714567890'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['NP','+9779841234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['NP','9841234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+9779841234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['NP','+97716600101234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['NP','16600101234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+97716600101234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['NR','+6744441234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['NR','4441234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+6744441234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['NR','+6745551234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['NR','5551234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+6745551234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['NU','+6837012'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['NU','7012'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+6837012'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['NU','+6838884012'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['NU','8884012'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+6838884012'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['NZ','+6432345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['NZ','32345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+6432345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['NZ','+64211234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['NZ','211234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+64211234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['NZ','+6426123456'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['NZ','26123456'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['+6426123456'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['NZ','+64800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['NZ','800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+64800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['NZ','+64900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['NZ','900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+64900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['NZ','+64701234567'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['NZ','701234567'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+64701234567'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['NZ','+6483012378'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['NZ','83012378'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+6483012378'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['OM','+96823123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['OM','23123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+96823123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['OM','+96892123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['OM','92123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+96892123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['OM','+96880071234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['OM','80071234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+96880071234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['OM','+96890012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['OM','90012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+96890012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['PA','+5072001234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['PA','2001234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+5072001234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['PA','+50761234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['PA','61234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+50761234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['PA','+5078001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['PA','8001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+5078001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['PA','+5078601234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['PA','8601234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+5078601234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['PE','+5111234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['PE','11234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+5111234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['PE','+51912345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['PE','912345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+51912345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['PE','+5180012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['PE','80012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+5180012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['PE','+5180512345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['PE','80512345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+5180512345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['PE','+5180112345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['PE','80112345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+5180112345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['PE','+5180212345'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['PE','80212345'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+5180212345'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['PF','+68940412345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['PF','40412345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+68940412345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['PF','+68987123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['PF','87123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+68987123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['PF','+689800012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['PF','800012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+689800012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['PF','+68949901234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['PF','49901234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+68949901234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['PF','+689440123'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['PF','440123'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+689440123'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['PG','+6753123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['PG','3123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+6753123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['PG','+67570123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['PG','70123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+67570123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['PG','+6752700123'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['PG','2700123'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['+6752700123'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['PG','+6751801234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['PG','1801234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+6751801234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['PG','+6752751234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['PG','2751234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+6752751234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['PH','+63232345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['PH','232345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+63232345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['PH','+639051234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['PH','9051234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+639051234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['PH','+63180012345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['PH','180012345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+63180012345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['PK','+922123456789'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['PK','2123456789'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+922123456789'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['PK','+923012345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['PK','3012345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+923012345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['PK','+9280012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['PK','80012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+9280012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['PK','+9290012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['PK','90012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+9290012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['PK','+92122044444'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['PK','122044444'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+92122044444'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['PK','+9221111825888'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['PK','21111825888'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+9221111825888'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['PL','+48123456789'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['PL','123456789'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+48123456789'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['PL','+48512345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['PL','512345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+48512345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['PL','+48641234567'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['PL','641234567'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['+48641234567'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['PL','+48800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['PL','800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+48800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['PL','+48701234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['PL','701234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+48701234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['PL','+48801234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['PL','801234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+48801234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['PL','+48391234567'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['PL','391234567'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+48391234567'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['PL','+48804123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['PL','804123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+48804123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['PM','+508430123'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['PM','430123'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+508430123'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['PM','+508551234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['PM','551234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+508551234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['PM','+508800012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['PM','800012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+508800012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['PR','+17872345678'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['PR','+17872345678'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['PR','7872345678'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['PR','7872345678'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['+17872345678'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+17872345678'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['PR','+17872345678'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['PR','+17872345678'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['PR','7872345678'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['PR','7872345678'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['+17872345678'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+17872345678'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['PR','+18002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['PR','+18002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['PR','8002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['PR','8002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['+18002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+18002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['PR','+19002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['PR','+19002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['PR','9002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['PR','9002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['+19002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+19002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['PR','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['PR','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['PR','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['PR','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['PS','+97022234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['PS','22234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+97022234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['PS','+970599123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['PS','599123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+970599123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['PS','+9701800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['PS','1800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+9701800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['PS','+9701700123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['PS','1700123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+9701700123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['PT','+351212345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['PT','212345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+351212345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['PT','+351912345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['PT','912345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+351912345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['PT','+351800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['PT','800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+351800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['PT','+351760123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['PT','760123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+351760123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['PT','+351808123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['PT','808123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+351808123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['PT','+351884123456'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['PT','884123456'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+351884123456'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['PT','+351301234567'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['PT','301234567'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+351301234567'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['PT','+351707123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['PT','707123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+351707123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['PW','+6802771234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['PW','2771234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+6802771234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['PW','+6806201234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['PW','6201234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+6806201234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['PY','+595212345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['PY','212345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+595212345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['PY','+595961456789'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['PY','961456789'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+595961456789'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['PY','+59598000123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['PY','98000123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+59598000123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['PY','+595870012345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['PY','870012345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+595870012345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['PY','+595201234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['PY','201234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+595201234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['QA','+97444123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['QA','44123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+97444123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['QA','+97433123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['QA','33123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+97433123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['QA','+9742123456'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['QA','2123456'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['+9742123456'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['QA','+9748001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['QA','8001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+9748001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['RE','+262262161234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['RE','262161234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+262262161234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['RE','+262692123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['RE','692123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+262692123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['RE','+262801234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['RE','801234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+262801234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['RE','+262891123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['RE','891123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+262891123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['RE','+262810123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['RE','810123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+262810123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['RO','+40211234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['RO','211234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+40211234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['RO','+40712034567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['RO','712034567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+40712034567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['RO','+40800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['RO','800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+40800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['RO','+40900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['RO','900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+40900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['RO','+40801123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['RO','801123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+40801123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['RO','+40372123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['RO','372123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+40372123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['RS','+38110234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['RS','10234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+38110234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['RS','+381601234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['RS','601234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+381601234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['RS','+38180012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['RS','80012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+38180012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['RS','+38190012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['RS','90012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+38190012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['RS','+381700123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['RS','700123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+381700123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['RU','+73011234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['RU','3011234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+73011234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['RU','+79123456789'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['RU','9123456789'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+79123456789'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['RU','+78001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['RU','8001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+78001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['RU','+78091234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['RU','8091234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+78091234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['RU','+78081234567'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['RU','8081234567'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+78081234567'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['RW','+250250123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['RW','250123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+250250123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['RW','+250720123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['RW','720123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+250720123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['RW','+250800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['RW','800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+250800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['RW','+250900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['RW','900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+250900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SA','+966112345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['SA','112345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+966112345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['SA','+966512345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['SA','512345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+966512345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['SA','+9668001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['SA','8001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+9668001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['SA','+966925012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SA','925012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+966925012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SA','+966920012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SA','920012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+966920012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SA','+9668110123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SA','8110123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+9668110123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SB','+67740123'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['SB','40123'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+67740123'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['SB','+6777421234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['SB','7421234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+6777421234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['SB','+67718123'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['SB','18123'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+67718123'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['SB','+67751123'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['SB','51123'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+67751123'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['SC','+2484217123'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['SC','4217123'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+2484217123'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['SC','+2482510123'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['SC','2510123'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+2482510123'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['SC','+2488000000'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['SC','8000000'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+2488000000'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['SC','+2486412345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['SC','6412345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+2486412345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['SD','+249153123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['SD','153123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+249153123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['SD','+249911231234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['SD','911231234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+249911231234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['SE','+468123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['SE','8123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+468123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['SE','+46701234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['SE','701234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+46701234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['SE','+46740123456'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['SE','740123456'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['+46740123456'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['SE','+4620123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['SE','20123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+4620123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['SE','+469001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SE','9001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+469001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SE','+46771234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SE','771234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+46771234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SE','+46751234567'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['SE','751234567'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+46751234567'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['SE','+46102345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SE','102345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+46102345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SG','+6561234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['SG','61234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+6561234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['SG','+6581234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['SG','81234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+6581234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['SG','+6518001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['SG','18001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+6518001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['SG','+6519001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SG','19001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+6519001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SG','+6531234567'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['SG','31234567'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+6531234567'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['SG','+6570001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SG','70001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+6570001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SH','+29022158'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['SH','22158'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+29022158'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['SH','+29051234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['SH','51234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+29051234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['SH','+29026212'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['SH','26212'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+29026212'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['SI','+38612345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['SI','12345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+38612345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['SI','+38631234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['SI','31234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+38631234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['SI','+38680123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['SI','80123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+38680123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['SI','+38690123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SI','90123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+38690123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SI','+38659012345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['SI','59012345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+38659012345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['SJ','+4779123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['SJ','79123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+4779123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['SJ','+4741234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['SJ','41234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+4741234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['SJ','+4780012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['SJ','80012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+4780012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['SJ','+4782012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SJ','82012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+4782012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SJ','+4781021234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SJ','81021234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+4781021234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SJ','+4788012345'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['SJ','88012345'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+4788012345'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['SJ','+4785012345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['SJ','85012345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+4785012345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['SJ','+4702000'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SJ','02000'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+4702000'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SK','+421221234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['SK','221234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+421221234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['SK','+421912123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['SK','912123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+421912123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['SK','+4219090123'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['SK','9090123'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['+4219090123'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['SK','+421800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['SK','800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+421800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['SK','+421900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SK','900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+421900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SK','+421850123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SK','850123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+421850123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SK','+421690123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['SK','690123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+421690123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['SK','+421961234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SK','961234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+421961234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SL','+23222221234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['SL','22221234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+23222221234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['SL','+23225123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['SL','25123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+23225123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['SM','+3780549886377'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['SM','0549886377'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+3780549886377'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['SM','+37866661212'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['SM','66661212'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+37866661212'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['SM','+37871123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SM','71123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+37871123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SM','+37858001110'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['SM','58001110'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+37858001110'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['SN','+221301012345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['SN','301012345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+221301012345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['SN','+221701234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['SN','701234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+221701234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['SN','+221800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['SN','800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+221800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['SN','+221884123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SN','884123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+221884123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SN','+221810123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SN','810123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+221810123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SN','+221933301234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['SN','933301234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+221933301234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['SO','+2524012345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['SO','4012345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+2524012345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['SO','+25271123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['SO','71123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+25271123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['SR','+597211234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['SR','211234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+597211234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['SR','+5977412345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['SR','7412345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+5977412345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['SR','+597561234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['SR','561234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+597561234'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['SS','+211181234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['SS','181234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+211181234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['SS','+211977123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['SS','977123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+211977123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['ST','+2392221234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['ST','2221234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+2392221234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['ST','+2399812345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['ST','9812345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+2399812345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['SV','+50321234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['SV','21234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+50321234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['SV','+50370123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['SV','70123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+50370123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['SV','+5038001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['SV','8001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+5038001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['SV','+5039001234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SV','9001234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+5039001234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['SX','+17215425678'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['SX','+17215425678'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['SX','7215425678'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['SX','7215425678'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['+17215425678'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+17215425678'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['SX','+17215205678'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['SX','+17215205678'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['SX','7215205678'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['SX','7215205678'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['+17215205678'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+17215205678'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['SX','+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['SX','+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['SX','8002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['SX','8002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+18002123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['SX','+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SX','+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['SX','9002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SX','9002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+19002123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['SX','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['SX','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['SX','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['SX','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['SY','+963112345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['SY','112345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+963112345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['SY','+963944567890'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['SY','944567890'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+963944567890'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['SZ','+26822171234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['SZ','22171234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+26822171234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['SZ','+26876123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['SZ','76123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+26876123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['SZ','+26808001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['SZ','08001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+26808001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['SZ','+268900012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SZ','900012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+268900012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['SZ','+26870012345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['SZ','70012345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+26870012345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['TA','+2908999'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['TA','8999'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+2908999'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone', args => ['TC','+16497121234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['TC','+16497121234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['TC','6497121234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['TC','6497121234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['+16497121234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+16497121234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['TC','+16492311234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['TC','+16492311234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['TC','6492311234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['TC','6492311234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['+16492311234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+16492311234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['TC','+18002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['TC','+18002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['TC','8002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['TC','8002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['+18002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+18002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['TC','+19002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['TC','+19002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['TC','9002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['TC','9002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['+19002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+19002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['TC','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['TC','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['TC','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['TC','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['TD','+23522501234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['TD','22501234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+23522501234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['TD','+23563012345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['TD','63012345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+23563012345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['TG','+22822212345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['TG','22212345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+22822212345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['TG','+22890112345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['TG','90112345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+22890112345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['TH','+6621234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['TH','21234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+6621234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['TH','+66812345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['TH','812345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+66812345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['TH','+661800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['TH','1800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+661800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['TH','+661900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['TH','1900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+661900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['TH','+66601234567'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['TH','601234567'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+66601234567'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['TJ','+992372123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['TJ','372123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+992372123456'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['TJ','+992917123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['TJ','917123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+992917123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['TK','+6903101'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['TK','3101'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+6903101'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['TK','+6907290'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['TK','7290'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+6907290'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['TL','+6702112345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['TL','2112345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+6702112345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['TL','+67077212345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['TL','77212345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+67077212345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['TL','+6708012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['TL','8012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+6708012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['TL','+6709012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['TL','9012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+6709012345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['TL','+6707012345'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['TL','7012345'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+6707012345'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['TM','+99312345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['TM','12345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+99312345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['TM','+99366123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['TM','66123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+99366123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['TN','+21630010123'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['TN','30010123'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+21630010123'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['TN','+21620123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['TN','20123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+21620123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['TN','+21680101234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['TN','80101234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+21680101234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['TN','+21688123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['TN','88123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+21688123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['TN','+21681101234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['TN','81101234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+21681101234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['TO','+67620123'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['TO','20123'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+67620123'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['TO','+6767715123'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['TO','7715123'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+6767715123'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['TO','+6760800222'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['TO','0800222'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+6760800222'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['TO','+6765510123'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['TO','5510123'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+6765510123'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['TR','+902123456789'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['TR','2123456789'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+902123456789'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['TR','+905012345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['TR','5012345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+905012345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['TR','+905123456789'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['TR','5123456789'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['+905123456789'], methods => ['is_pager'] },
{ class => 'Number::Phone::Lib', args => ['TR','+908001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['TR','8001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+908001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['TR','+909001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['TR','9001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+909001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['TR','+905922121234'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['TR','5922121234'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+905922121234'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['TR','+908500123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['TR','8500123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+908500123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['TR','+904441444'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['TR','4441444'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+904441444'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['TT','+18682211234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['TT','+18682211234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['TT','8682211234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['TT','8682211234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['+18682211234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+18682211234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['TT','+18682911234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['TT','+18682911234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['TT','8682911234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['TT','8682911234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['+18682911234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+18682911234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['TT','+18002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['TT','+18002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['TT','8002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['TT','8002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['+18002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+18002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['TT','+19002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['TT','+19002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['TT','9002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['TT','9002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['+19002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+19002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['TT','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['TT','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['TT','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['TT','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['TV','+68820123'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['TV','20123'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+68820123'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['TV','+688901234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['TV','901234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+688901234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['TW','+886221234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['TW','221234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+886221234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['TW','+886912345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['TW','912345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+886912345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['TW','+886800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['TW','800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+886800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['TW','+886203123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['TW','203123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+886203123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['TW','+886990123456'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['TW','990123456'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+886990123456'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['TW','+8867012345678'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['TW','7012345678'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+8867012345678'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['TW','+886500123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['TW','500123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+886500123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['TZ','+255222345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['TZ','222345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+255222345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['TZ','+255621234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['TZ','621234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+255621234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['TZ','+255800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['TZ','800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+255800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['TZ','+255900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['TZ','900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+255900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['TZ','+255840123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['TZ','840123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+255840123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['TZ','+255412345678'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['TZ','412345678'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+255412345678'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['UA','+380311234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['UA','311234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+380311234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['UA','+380501234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['UA','501234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+380501234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['UA','+380800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['UA','800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+380800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['UA','+380900212345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['UA','900212345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+380900212345'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['UA','+380891234567'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['UA','891234567'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+380891234567'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['UG','+256312345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['UG','312345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+256312345678'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['UG','+256712345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['UG','712345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+256712345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['UG','+256800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['UG','800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+256800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['UG','+256901123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['UG','901123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+256901123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['US','+12015550123'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['US','+12015550123'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['US','2015550123'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['US','2015550123'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['+12015550123'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+12015550123'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['US','+12015550123'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['US','+12015550123'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['US','2015550123'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['US','2015550123'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['+12015550123'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+12015550123'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['US','+18002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['US','+18002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['US','8002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['US','8002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['+18002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+18002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['US','+19002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['US','+19002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['US','9002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['US','9002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['+19002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+19002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['US','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['US','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['US','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['US','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['UY','+59821231234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['UY','21231234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+59821231234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['UY','+59894231234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['UY','94231234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+59894231234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['UY','+5988001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['UY','8001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+5988001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['UY','+5989001234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['UY','9001234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+5989001234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['UZ','+998669050123'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['UZ','669050123'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+998669050123'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['UZ','+998912345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['UZ','912345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+998912345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['IT','+390669812345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['IT','0669812345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+390669812345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['IT','+393123456789'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['IT','3123456789'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+393123456789'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['IT','+39800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['IT','800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+39800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['IT','+39899123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['IT','899123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+39899123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['IT','+39848123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['IT','848123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+39848123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['IT','+391781234567'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['IT','1781234567'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+391781234567'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['IT','+395512345678'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['IT','5512345678'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+395512345678'], methods => ['is_ipphone'] },
{ class => 'Number::Phone', args => ['VC','+17842661234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['VC','+17842661234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['VC','7842661234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['VC','7842661234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['+17842661234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+17842661234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['VC','+17844301234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['VC','+17844301234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['VC','7844301234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['VC','7844301234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['+17844301234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+17844301234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['VC','+18002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['VC','+18002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['VC','8002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['VC','8002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['+18002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+18002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['VC','+19002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['VC','+19002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['VC','9002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['VC','9002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['+19002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+19002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['VC','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['VC','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['VC','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['VC','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['VE','+582121234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['VE','2121234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+582121234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['VE','+584121234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['VE','4121234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+584121234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['VE','+588001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['VE','8001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+588001234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['VE','+589001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['VE','9001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+589001234567'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['VE','+585010123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['VE','5010123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+585010123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['VG','+12842291234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['VG','+12842291234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['VG','2842291234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['VG','2842291234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['+12842291234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+12842291234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['VG','+12843001234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['VG','+12843001234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['VG','2843001234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['VG','2843001234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['+12843001234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+12843001234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['VG','+18002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['VG','+18002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['VG','8002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['VG','8002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['+18002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+18002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['VG','+19002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['VG','+19002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['VG','9002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['VG','9002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['+19002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+19002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['VG','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['VG','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['VG','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['VG','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['VI','+13406421234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['VI','+13406421234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['VI','3406421234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['VI','3406421234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['+13406421234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+13406421234'], methods => ['is_fixed_line','is_geographic'] },
{ class => 'Number::Phone', args => ['VI','+13406421234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['VI','+13406421234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['VI','3406421234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['VI','3406421234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['+13406421234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone::Lib', args => ['+13406421234'], methods => ['is_mobile','is_geographic'] },
{ class => 'Number::Phone', args => ['VI','+18002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['VI','+18002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['VI','8002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['VI','8002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['+18002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+18002345678'], methods => ['is_tollfree'] },
{ class => 'Number::Phone', args => ['VI','+19002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['VI','+19002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['VI','9002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['VI','9002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['+19002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+19002345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone', args => ['VI','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['VI','+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['VI','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['VI','5002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['+15002345678'], methods => ['is_personal'] },
{ class => 'Number::Phone::Lib', args => ['VN','+842101234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['VN','2101234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+842101234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['VN','+84912345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['VN','912345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+84912345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['VN','+841800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['VN','1800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+841800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['VN','+841900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['VN','1900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+841900123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['VN','+84672012345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['VN','672012345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+84672012345'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['VN','+841992000'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['VN','1992000'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+841992000'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['VU','+67822123'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['VU','22123'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+67822123'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['VU','+6785912345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['VU','5912345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+6785912345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['VU','+67881123'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['VU','81123'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+67881123'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['VU','+6789010123'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['VU','9010123'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+6789010123'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['VU','+67830123'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['VU','30123'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+67830123'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['WF','+681721234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['WF','721234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+681721234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['WF','+681821234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['WF','821234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+681821234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['WF','+681800012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['WF','800012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+681800012345'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['WS','+68522123'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['WS','22123'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+68522123'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['WS','+6857212345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['WS','7212345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+6857212345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['WS','+685800123'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['WS','800123'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+685800123'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['XK','+38328012345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['XK','28012345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+38328012345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['XK','+38343201234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['XK','43201234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+38343201234'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['XK','+38380001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['XK','80001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+38380001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['XK','+38390001234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['XK','90001234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+38390001234'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['YE','+9671234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['YE','1234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+9671234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['YE','+967712345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['YE','712345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+967712345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['YT','+262269601234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['YT','269601234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+262269601234'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['YT','+262639012345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['YT','639012345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+262639012345'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['YT','+262801234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['YT','801234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+262801234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['ZA','+27101234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['ZA','101234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+27101234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['ZA','+27711234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['ZA','711234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+27711234567'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['ZA','+27801234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['ZA','801234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+27801234567'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['ZA','+27862345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['ZA','862345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+27862345678'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['ZA','+27860123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['ZA','860123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+27860123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['ZA','+27871234567'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['ZA','871234567'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+27871234567'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['ZA','+27861123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['ZA','861123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['+27861123456'], methods => ['is_specialrate'] },
{ class => 'Number::Phone::Lib', args => ['ZM','+260211234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['ZM','211234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+260211234567'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['ZM','+260955123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['ZM','955123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+260955123456'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['ZM','+260800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['ZM','800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+260800123456'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['ZM','+260630123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['ZM','630123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+260630123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['ZW','+2631312345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['ZW','1312345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['+2631312345'], methods => ['is_fixed_line'] },
{ class => 'Number::Phone::Lib', args => ['ZW','+263712345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['ZW','712345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['+263712345678'], methods => ['is_mobile'] },
{ class => 'Number::Phone::Lib', args => ['ZW','+2638001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['ZW','8001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['+2638001234'], methods => ['is_tollfree'] },
{ class => 'Number::Phone::Lib', args => ['ZW','+2638686123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['ZW','8686123456'], methods => ['is_ipphone'] },
{ class => 'Number::Phone::Lib', args => ['+2638686123456'], methods => ['is_ipphone'] },
) {
    my($class, $args, $methods) = map { $test->{$_} } qw(class args methods);
    SKIP: {
        skip("built --without_uk so not testing that full-fat implementation today", 1)
            if(
                $class eq "Number::Phone" && building_without_uk() &&
                ($args->[-1] =~ /^\+44/ || $args->[0]  =~ /^(GB|UK|GG|JE|IM)$/)
            );
        my $object = $class->new(@{$args});
        my $obj_class = $object ? blessed($object) : "[undef]";
        ok(defined($object), "$class->new(".join(", ", @{$args}).") returns an object: $obj_class") && 
        ok(
            # grep is because a number might need to be checked as is_geographic *or* is_fixed_line
            (grep { $class->new(@{$args})->$_() } @{$methods}),
            "$class->new(".join(", ", @{$args}).")->".join(", ", @{$methods})."() does the right thing"
        );
    }
}
done_testing();
