# automatically generated file, don't edit



# Copyright 2011 David Cantrell, derived from data from libphonenumber
# http://code.google.com/p/libphonenumber/
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
package Number::Phone::StubCountry::IN;
use base qw(Number::Phone::StubCountry);

use strict;
use warnings;
use utf8;
our $VERSION = 1.20220307120119;

my $formatters = [
                {
                  'format' => '$1',
                  'intl_format' => 'NA',
                  'leading_digits' => '575',
                  'pattern' => '(\\d{7})'
                },
                {
                  'format' => '$1',
                  'leading_digits' => '
            5(?:
              0|
              2(?:
                21|
                3
              )|
              3(?:
                0|
                3[23]
              )|
              616|
              717|
              8888
            )
          ',
                  'pattern' => '(\\d{8})'
                },
                {
                  'format' => '$1 $2',
                  'leading_digits' => '1800',
                  'pattern' => '(\\d{4})(\\d{4,5})'
                },
                {
                  'format' => '$1 $2 $3',
                  'leading_digits' => '140',
                  'pattern' => '(\\d{3})(\\d{3})(\\d{4})'
                },
                {
                  'format' => '$1 $2 $3',
                  'leading_digits' => '
            11|
            2[02]|
            33|
            4[04]|
            79(?:
              [124-6]|
              3(?:
                [02-9]|
                1[0-24-9]
              )|
              7(?:
                1|
                9[1-6]
              )
            )|
            80(?:
              [2-4]|
              6[0-589]
            )
          ',
                  'national_rule' => '0$1',
                  'pattern' => '(\\d{2})(\\d{4})(\\d{4})'
                },
                {
                  'format' => '$1 $2 $3',
                  'leading_digits' => '
            1(?:
              2[0-24]|
              3[0-25]|
              4[145]|
              [59][14]|
              6[1-9]|
              7[1257]|
              8[1-57-9]
            )|
            2(?:
              1[257]|
              3[013]|
              4[01]|
              5[0137]|
              6[058]|
              78|
              8[1568]|
              9[14]
            )|
            3(?:
              26|
              4[1-3]|
              5[34]|
              6[01489]|
              7[02-46]|
              8[159]
            )|
            4(?:
              1[36]|
              2[1-47]|
              3[15]|
              5[12]|
              6[0-26-9]|
              7[0-24-9]|
              8[013-57]|
              9[014-7]
            )|
            5(?:
              1[025]|
              22|
              [36][25]|
              4[28]|
              [578]1|
              9[15]
            )|
            6(?:
              12(?:
                [2-6]|
                7[0-8]
              )|
              74[2-7]
            )|
            7(?:
              (?:
                2[14]|
                5[15]
              )[2-6]|
              3171|
              61[346]|
              88(?:
                [2-7]|
                82
              )
            )|
            8(?:
              70[2-6]|
              84(?:
                [2356]|
                7[19]
              )|
              91(?:
                [3-6]|
                7[19]
              )
            )|
            73[134][2-6]|
            (?:
              74[47]|
              8(?:
                16|
                2[014]|
                3[126]|
                6[136]|
                7[78]|
                83
              )
            )(?:
              [2-6]|
              7[19]
            )|
            (?:
              1(?:
                29|
                60|
                8[06]
              )|
              261|
              552|
              6(?:
                [2-4]1|
                5[17]|
                6[13]|
                7(?:
                  1|
                  4[0189]
                )|
                80
              )|
              7(?:
                12|
                88[01]
              )
            )[2-7]
          ',
                  'national_rule' => '0$1',
                  'pattern' => '(\\d{3})(\\d{3})(\\d{4})'
                },
                {
                  'format' => '$1 $2 $3',
                  'leading_digits' => '
            1(?:
              [2-479]|
              5(?:
                [0236-9]|
                5[013-9]
              )
            )|
            [2-5]|
            6(?:
              2(?:
                84|
                95
              )|
              355|
              83
            )|
            73179|
            807(?:
              1|
              9[1-3]
            )|
            (?:
              1552|
              6(?:
                1[1358]|
                2[2457]|
                3[2-4]|
                4[235-7]|
                5[2-689]|
                6[24578]|
                7[235689]|
                8[124-6]
              )\\d|
              7(?:
                1(?:
                  [013-8]\\d|
                  9[6-9]
                )|
                28[6-8]|
                3(?:
                  2[0-49]|
                  9[2-57]
                )|
                4(?:
                  1[2-4]|
                  [29][0-7]|
                  3[0-8]|
                  [56]\\d|
                  8[0-24-7]
                )|
                5(?:
                  2[1-3]|
                  9[0-6]
                )|
                6(?:
                  0[5689]|
                  2[5-9]|
                  3[02-8]|
                  4\\d|
                  5[0-367]
                )|
                70[13-7]
              )
            )[2-7]
          ',
                  'national_rule' => '0$1',
                  'pattern' => '(\\d{4})(\\d{3})(\\d{3})'
                },
                {
                  'format' => '$1 $2',
                  'leading_digits' => '[6-9]',
                  'national_rule' => '0$1',
                  'pattern' => '(\\d{5})(\\d{5})'
                },
                {
                  'format' => '$1 $2 $3',
                  'leading_digits' => '
            1(?:
              6|
              8[06]0
            )
          ',
                  'pattern' => '(\\d{4})(\\d{2,4})(\\d{4})'
                },
                {
                  'format' => '$1 $2 $3 $4',
                  'intl_format' => 'NA',
                  'pattern' => '(\\d{3})(\\d{3})(\\d{3})(\\d{4})'
                },
                {
                  'format' => '$1 $2 $3 $4',
                  'leading_digits' => '18',
                  'pattern' => '(\\d{4})(\\d{3})(\\d{3})(\\d{3})'
                }
              ];

my $validators = {
                'fixed_line' => '
          2717(?:
            [2-7]\\d|
            95
          )\\d{4}|
          (?:
            271[0-689]|
            782[0-6]
          )[2-7]\\d{5}|
          (?:
            170[24]|
            2(?:
              (?:
                [02][2-79]|
                90
              )\\d|
              80[13468]
            )|
            (?:
              3(?:
                23|
                80
              )|
              683|
              79[1-7]
            )\\d|
            4(?:
              20[24]|
              72[2-8]
            )|
            552[1-7]
          )\\d{6}|
          (?:
            11|
            33|
            4[04]|
            80
          )[2-7]\\d{7}|
          (?:
            342|
            674|
            788
          )(?:
            [0189][2-7]|
            [2-7]\\d
          )\\d{5}|
          (?:
            1(?:
              2[0-249]|
              3[0-25]|
              4[145]|
              [59][14]|
              6[014]|
              7[1257]|
              8[01346]
            )|
            2(?:
              1[257]|
              3[013]|
              4[01]|
              5[0137]|
              6[0158]|
              78|
              8[1568]|
              9[14]
            )|
            3(?:
              26|
              4[13]|
              5[34]|
              6[01489]|
              7[02-46]|
              8[159]
            )|
            4(?:
              1[36]|
              2[1-47]|
              3[15]|
              5[12]|
              6[0-26-9]|
              7[014-9]|
              8[013-57]|
              9[014-7]
            )|
            5(?:
              1[025]|
              22|
              [36][25]|
              4[28]|
              [578]1|
              9[15]
            )|
            6(?:
              12|
              [2-47]1|
              5[17]|
              6[13]|
              80
            )|
            7(?:
              12|
              2[14]|
              3[134]|
              4[47]|
              5[15]|
              [67]1
            )|
            8(?:
              16|
              2[014]|
              3[126]|
              6[136]|
              7[078]|
              8[34]|
              91
            )
          )[2-7]\\d{6}|
          (?:
            1(?:
              2[35-8]|
              3[346-9]|
              4[236-9]|
              [59][0235-9]|
              6[235-9]|
              7[34689]|
              8[257-9]
            )|
            2(?:
              1[134689]|
              3[24-8]|
              4[2-8]|
              5[25689]|
              6[2-4679]|
              7[3-79]|
              8[2-479]|
              9[235-9]
            )|
            3(?:
              01|
              1[79]|
              2[1245]|
              4[5-8]|
              5[125689]|
              6[235-7]|
              7[157-9]|
              8[2-46-8]
            )|
            4(?:
              1[14578]|
              2[5689]|
              3[2-467]|
              5[4-7]|
              6[35]|
              73|
              8[2689]|
              9[2389]
            )|
            5(?:
              [16][146-9]|
              2[14-8]|
              3[1346]|
              4[14-69]|
              5[46]|
              7[2-4]|
              8[2-8]|
              9[246]
            )|
            6(?:
              1[1358]|
              2[2457]|
              3[2-4]|
              4[235-7]|
              5[2-689]|
              6[24578]|
              7[235689]|
              8[124-6]
            )|
            7(?:
              1[013-9]|
              2[0235-9]|
              3[2679]|
              4[1-35689]|
              5[2-46-9]|
              [67][02-9]|
              8[013-7]|
              9[089]
            )|
            8(?:
              1[1357-9]|
              2[235-8]|
              3[03-57-9]|
              4[0-24-9]|
              5\\d|
              6[2457-9]|
              7[1-6]|
              8[1256]|
              9[2-4]
            )
          )\\d[2-7]\\d{5}
        ',
                'geographic' => '
          2717(?:
            [2-7]\\d|
            95
          )\\d{4}|
          (?:
            271[0-689]|
            782[0-6]
          )[2-7]\\d{5}|
          (?:
            170[24]|
            2(?:
              (?:
                [02][2-79]|
                90
              )\\d|
              80[13468]
            )|
            (?:
              3(?:
                23|
                80
              )|
              683|
              79[1-7]
            )\\d|
            4(?:
              20[24]|
              72[2-8]
            )|
            552[1-7]
          )\\d{6}|
          (?:
            11|
            33|
            4[04]|
            80
          )[2-7]\\d{7}|
          (?:
            342|
            674|
            788
          )(?:
            [0189][2-7]|
            [2-7]\\d
          )\\d{5}|
          (?:
            1(?:
              2[0-249]|
              3[0-25]|
              4[145]|
              [59][14]|
              6[014]|
              7[1257]|
              8[01346]
            )|
            2(?:
              1[257]|
              3[013]|
              4[01]|
              5[0137]|
              6[0158]|
              78|
              8[1568]|
              9[14]
            )|
            3(?:
              26|
              4[13]|
              5[34]|
              6[01489]|
              7[02-46]|
              8[159]
            )|
            4(?:
              1[36]|
              2[1-47]|
              3[15]|
              5[12]|
              6[0-26-9]|
              7[014-9]|
              8[013-57]|
              9[014-7]
            )|
            5(?:
              1[025]|
              22|
              [36][25]|
              4[28]|
              [578]1|
              9[15]
            )|
            6(?:
              12|
              [2-47]1|
              5[17]|
              6[13]|
              80
            )|
            7(?:
              12|
              2[14]|
              3[134]|
              4[47]|
              5[15]|
              [67]1
            )|
            8(?:
              16|
              2[014]|
              3[126]|
              6[136]|
              7[078]|
              8[34]|
              91
            )
          )[2-7]\\d{6}|
          (?:
            1(?:
              2[35-8]|
              3[346-9]|
              4[236-9]|
              [59][0235-9]|
              6[235-9]|
              7[34689]|
              8[257-9]
            )|
            2(?:
              1[134689]|
              3[24-8]|
              4[2-8]|
              5[25689]|
              6[2-4679]|
              7[3-79]|
              8[2-479]|
              9[235-9]
            )|
            3(?:
              01|
              1[79]|
              2[1245]|
              4[5-8]|
              5[125689]|
              6[235-7]|
              7[157-9]|
              8[2-46-8]
            )|
            4(?:
              1[14578]|
              2[5689]|
              3[2-467]|
              5[4-7]|
              6[35]|
              73|
              8[2689]|
              9[2389]
            )|
            5(?:
              [16][146-9]|
              2[14-8]|
              3[1346]|
              4[14-69]|
              5[46]|
              7[2-4]|
              8[2-8]|
              9[246]
            )|
            6(?:
              1[1358]|
              2[2457]|
              3[2-4]|
              4[235-7]|
              5[2-689]|
              6[24578]|
              7[235689]|
              8[124-6]
            )|
            7(?:
              1[013-9]|
              2[0235-9]|
              3[2679]|
              4[1-35689]|
              5[2-46-9]|
              [67][02-9]|
              8[013-7]|
              9[089]
            )|
            8(?:
              1[1357-9]|
              2[235-8]|
              3[03-57-9]|
              4[0-24-9]|
              5\\d|
              6[2457-9]|
              7[1-6]|
              8[1256]|
              9[2-4]
            )
          )\\d[2-7]\\d{5}
        ',
                'mobile' => '
          (?:
            61279|
            7(?:
              887[02-9]|
              9(?:
                313|
                79[07-9]
              )
            )|
            8(?:
              079[04-9]|
              (?:
                84|
                91
              )7[02-8]
            )
          )\\d{5}|
          (?:
            6(?:
              12|
              [2-47]1|
              5[17]|
              6[13]|
              80
            )[0189]|
            7(?:
              1(?:
                2[0189]|
                9[0-5]
              )|
              2(?:
                [14][017-9]|
                8[0-59]
              )|
              3(?:
                2[5-8]|
                [34][017-9]|
                9[016-9]
              )|
              4(?:
                1[015-9]|
                [29][89]|
                39|
                8[389]
              )|
              5(?:
                [15][017-9]|
                2[04-9]|
                9[7-9]
              )|
              6(?:
                0[0-47]|
                1[0-257-9]|
                2[0-4]|
                3[19]|
                5[4589]
              )|
              70[0289]|
              88[089]|
              97[02-8]
            )|
            8(?:
              0(?:
                6[67]|
                7[02-8]
              )|
              70[017-9]|
              84[01489]|
              91[0-289]
            )
          )\\d{6}|
          (?:
            7(?:
              31|
              4[47]
            )|
            8(?:
              16|
              2[014]|
              3[126]|
              6[136]|
              7[78]|
              83
            )
          )(?:
            [0189]\\d|
            7[02-8]
          )\\d{5}|
          (?:
            6(?:
              [09]\\d|
              1[04679]|
              2[03689]|
              3[05-9]|
              4[0489]|
              50|
              6[069]|
              7[07]|
              8[7-9]
            )|
            7(?:
              0\\d|
              2[0235-79]|
              3[05-8]|
              40|
              5[0346-8]|
              6[6-9]|
              7[1-9]|
              8[0-79]|
              9[089]
            )|
            8(?:
              0[01589]|
              1[0-57-9]|
              2[235-9]|
              3[03-57-9]|
              [45]\\d|
              6[02457-9]|
              7[1-69]|
              8[0-25-9]|
              9[02-9]
            )|
            9\\d\\d
          )\\d{7}|
          (?:
            6(?:
              (?:
                1[1358]|
                2[2457]|
                3[2-4]|
                4[235-7]|
                5[2-689]|
                6[24578]|
                8[124-6]
              )\\d|
              7(?:
                [235689]\\d|
                4[0189]
              )
            )|
            7(?:
              1(?:
                [013-8]\\d|
                9[6-9]
              )|
              28[6-8]|
              3(?:
                2[0-49]|
                9[2-5]
              )|
              4(?:
                1[2-4]|
                [29][0-7]|
                3[0-8]|
                [56]\\d|
                8[0-24-7]
              )|
              5(?:
                2[1-3]|
                9[0-6]
              )|
              6(?:
                0[5689]|
                2[5-9]|
                3[02-8]|
                4\\d|
                5[0-367]
              )|
              70[13-7]|
              881
            )
          )[0189]\\d{5}
        ',
                'pager' => '',
                'personal_number' => '',
                'specialrate' => '(1860\\d{7})|(186[12]\\d{9})|(140\\d{7})',
                'toll_free' => '
          000800\\d{7}|
          1(?:
            600\\d{6}|
            80(?:
              0\\d{4,9}|
              3\\d{9}
            )
          )
        ',
                'voip' => ''
              };
my %areanames = ();
$areanames{en} = {"9174640", "Karauli\,\ Rajasthan",
"918592", "Ongole\,\ Andhra\ Pradesh",
"9167666", "Keonjhar\,\ Odisha",
"9162455", "Gogri\,\ Bihar",
"9167865", "Chandbali\,\ Odisha",
"912136", "Urlikanchan\,\ Maharashtra",
"9166482", "Patnagarh\,\ Odisha",
"917686", "Khajuraho\,\ Madhya\ Pradesh",
"9181722", "Hassan\,\ Karnataka",
"9161115", "Hilsa\,\ Bihar",
"918399", "Huvinahadagali\,\ Karnataka",
"912344", "Jath\,\ Maharashtra",
"9165604", "Patan\,\ Bihar",
"9166414", "Deodgarh\,\ Odisha",
"9165477", "Chavparan\,\ Bihar",
"917253", "Mangrulpur\,\ Maharashtra",
"911604", "Kharar\,\ Punjab",
"911685", "Guruharsahai\,\ Punjab",
"915144", "Safipur\,\ Uttar\ Pradesh",
"913451", "Seharabazar\,\ West\ Bengal",
"9164264", "Rajmahal\,\ Bihar",
"911345", "Bijnor\/Chandpur\,\ Uttar\ Pradesh",
"918702", "Warangal\,\ Andhra\ Pradesh",
"9167957", "Udala\,\ Odisha",
"9167237", "Athgarh\,\ Odisha",
"914632", "Kovilpatti\,\ Tamil\ Nadu",
"91374", "Tinsukhia\,\ Assam",
"913659", "Resubelpara\/Mendipathar\,\ Meghalaya",
"917391", "Petlawad\,\ Madhya\ Pradesh",
"918255", "Bantwal\,\ Karnataka",
"912937", "Raipur\,\ Rajasthan",
"913472", "Krishna\ Nagar\,\ West\ Bengal",
"9166702", "Bhawanipatna\,\ Odisha",
"9174854", "Udaipura\,\ Madhya\ Pradesh",
"9165847", "Bishrampur\,\ Bihar",
"9173939", "Jobat\,\ Madhya\ Pradesh",
"9171005", "Kuhi\,\ Maharashtra",
"911483", "Hurda\/Gulabpura\,\ Rajasthan",
"912903", "Chohtan\/Gangasar\,\ Rajasthan",
"9168212", "Bhanjanagar\,\ Odisha",
"918515", "Banaganapalle\,\ Andhra\ Pradesh",
"9171714", "Gond\ Pipri\,\ Maharashtra",
"91477", "Alappuzha\,\ Kerala",
"912437", "Khultabad\,\ Maharashtra",
"913561", "Jalpaiguri\,\ West\ Bengal",
"9165916", "Chandil\,\ Bihar",
"915255", "Kaisarganh\/Mahasi\,\ Uttar\ Pradesh",
"9161545", "Siwan\,\ Bihar",
"911983", "Zanaskar\,\ Jammu\ And\ Kashmir",
"9173930", "Jobat\,\ Madhya\ Pradesh",
"914899", "Chetlat\,\ Lakshadweep",
"9163226", "Wazirganj\,\ Bihar",
"916412", "Bhagalpur\,\ Bihar",
"9173207", "Pandhana\,\ Madhya\ Pradesh",
"9162756", "Rosera\,\ Bihar",
"918187", "Shikaripura\,\ Karnataka",
"9171782", "Sinderwahi\,\ Maharashtra",
"9168453", "Phiringia\,\ Odisha",
"9165296", "Itki\,\ Bihar",
"9173223", "Depalpur\,\ Madhya\ Pradesh",
"9166543", "Sonapur\,\ Odisha",
"9168695", "Papadhandi\,\ Odisha",
"9177013", "Pingeshwar\,\ Madhya\ Pradesh",
"9164382", "Madhupur\,\ Bihar",
"9174649", "Karauli\,\ Rajasthan",
"9175293", "Laher\,\ Madhya\ Pradesh",
"913678", "Morigaon\,\ Assam",
"9165884", "Jagarnathpur\,\ Bihar",
"91212", "Chinchwad\,\ Maharashtra",
"9165466", "Hazaribagh\,\ Bihar",
"9162472", "Singhwara\,\ Bihar",
"9168154", "Parlakhemundi\,\ Odisha",
"9167522", "Puri\,\ Odisha",
"9165812", "Bhandaria\,\ Bihar",
"9171524", "Wardha\,\ Maharashtra",
"916217", "Muzaffarpur\,\ Bihar",
"9174628", "Sawaimadhopur\,\ Rajasthan",
"91532", "Allahabad\,\ Uttar\ Pradesh",
"9167404", "Bhubaneshwar\,\ Odisha",
"9167677", "Barbil\,\ Odisha",
"9164314", "Jharmundi\,\ Bihar",
"918336", "Khanapur\,\ Karnataka",
"917513", "Gwalior\,\ Madhya\ Pradesh",
"9175913", "Sironj\,\ Madhya\ Pradesh",
"9174215", "Manasa\,\ Madhya\ Pradesh",
"9167567", "Balugaon\,\ Odisha",
"918777", "Tirupathi\,\ Andhra\ Pradesh",
"915192", "Banda\,\ Uttar\ Pradesh",
"917510", "Gwalior\,\ Madhya\ Pradesh",
"9168143", "Digapahandi\,\ Odisha",
"9171432", "Bhainsdehi\,\ Madhya\ Pradesh",
"9162515", "Bagaha\,\ Bihar",
"9176465", "Nainpur\,\ Madhya\ Pradesh",
"912521", "Talasari\,\ Maharashtra",
"9164297", "Kahalgaon\,\ Bihar",
"916746", "Bhubaneshwar\,\ Odisha",
"9161884", "Rohtas\,\ Bihar",
"9164775", "Triveniganj\,\ Bihar",
"9166554", "Titlagarh\,\ Odisha",
"9161812", "Piro\,\ Bihar",
"9171164", "Umrer\,\ Maharashtra",
"914181", "Polur\,\ Tamil\ Nadu",
"91135", "Dehradun\,\ Uttarakhand",
"9176373", "Birsa\,\ Madhya\ Pradesh",
"912599", "Bhudargad\/Gargoti\,\ Maharashtra",
"9174858", "Udaipura\,\ Madhya\ Pradesh",
"9174692", "Hindaun\,\ Rajasthan",
"9173957", "Sondhwa\,\ Madhya\ Pradesh",
"911372", "Chamoli\,\ Uttarakhand",
"9173237", "Punasa\,\ Madhya\ Pradesh",
"9168444", "Kantamal\,\ Odisha",
"9171375", "Desaiganj\,\ Maharashtra",
"911980", "Nobra\,\ Jammu\ And\ Kashmir",
"9162725", "Darbhanga\,\ Bihar",
"9165545", "Rajdhanwar\,\ Bihar",
"9163255", "Pakribarwan\,\ Bihar",
"917226", "Dharani\,\ Maharashtra",
"918587", "Venkatgirikota\,\ Andhra\ Pradesh",
"9165274", "Kolebira\,\ Bihar",
"9166217", "Hemgiri\,\ Odisha",
"915863", "Biswan\,\ Uttar\ Pradesh",
"9164534", "Araria\,\ Bihar",
"91288", "Jamnagar\,\ Gujarat",
"9176295", "Pushprajgarh\,\ Madhya\ Pradesh",
"914994", "Kasaragod\,\ Kerala",
"911468", "Ramgarh\,\ Rajasthan",
"9171463", "Ghorandogri\,\ Madhya\ Pradesh",
"912900", "Siwana\/Samdari\,\ Rajasthan",
"911480", "Asind\,\ Rajasthan",
"9167354", "Telkoi\,\ Odisha",
"9171035", "Butibori\,\ Maharashtra",
"915115", "Ghatampur\,\ Uttar\ Pradesh",
"9174624", "Sawaimadhopur\,\ Rajasthan",
"9171352", "Chamorshi\,\ Maharashtra",
"915241", "Ramsanehi\ Ghat\,\ Uttar\ Pradesh",
"9166732", "Jayapatna\,\ Odisha",
"917231", "Umarkhed\,\ Maharashtra",
"917122", "Nagpur\,\ Maharashtra",
"9161847", "Sasaram\,\ Bihar",
"914327", "Thuraiyur\,\ Tamil\ Nadu",
"9174843", "Silwani\,\ Madhya\ Pradesh",
"9163272", "Rafiganj\,\ Bihar",
"918863", "Chavitidibbalu\,\ Andhra\ Pradesh",
"9162426", "Benipur\,\ Bihar",
"9174365", "Hindoli\,\ Rajasthan",
"917865", "Gogunda\,\ Madhya\ Pradesh",
"917534", "Bhind\,\ Madhya\ Pradesh",
"918192", "Davangere\,\ Karnataka",
"9166763", "M\.Rampur\,\ Odisha",
"9167223", "Pardip\,\ Odisha",
"9165634", "Bhawanathpur\,\ Bihar",
"9189465", "Pathapatnam\/Hiramandalam\,\ Andhra\ Pradesh",
"9164752", "S\.Bakhtiarpur\,\ Bihar",
"915544", "Naugarh\/Tetribazar\,\ Uttar\ Pradesh",
"9168487", "Kotagarh\,\ Odisha",
"9166242", "Rajgangpur\,\ Odisha",
"9181767", "Cannarayapatna\,\ Karnataka",
"9167576", "Daspalla\,\ Odisha",
"912328", "Panhala\,\ Maharashtra",
"911662", "Hissar\,\ Haryana",
"916634", "Sambalpur\,\ Odisha",
"917862", "Bastanar\,\ Madhya\ Pradesh",
"9167665", "Keonjhar\,\ Odisha",
"9162456", "Gogri\,\ Bihar",
"918195", "Challakere\,\ Karnataka",
"9161834", "Buxar\,\ Bihar",
"9161116", "Hilsa\,\ Bihar",
"914368", "Karaikal\,\ Tamil\ Nadu",
"9167933", "Betanati\,\ Odisha",
"9174840", "Silwani\,\ Madhya\ Pradesh",
"9167253", "Dhanmandal\,\ Odisha",
"9171482", "Prabha\ Pattan\,\ Madhya\ Pradesh",
"9167866", "Chandbali\,\ Odisha",
"9167484", "Bhubaneshwar\,\ Odisha",
"912664", "Pavijetpur\,\ Gujarat",
"918466", "Banswada\,\ Andhra\ Pradesh",
"91474", "Kollam\,\ Kerala",
"9171414", "Betul\,\ Madhya\ Pradesh",
"9167412", "Bhubaneshwar\,\ Odisha",
"9175398", "Ambah\,\ Madhya\ Pradesh",
"913836", "Saiha\/Tuipang\,\ Mizoram",
"918520", "Pattikonda\,\ Andhra\ Pradesh",
"915966", "Ranikhet\,\ Uttar\ Pradesh",
"913670", "Maibong\,\ Assam",
"917817", "Janjgir\,\ Madhya\ Pradesh",
"9176379", "Birsa\,\ Madhya\ Pradesh",
"9171322", "Gadchiroli\,\ Maharashtra",
"9174654", "Sapotra\,\ Rajasthan",
"9167324", "Hindol\,\ Odisha",
"915112", "Bilhaur\,\ Uttar\ Pradesh",
"9164512", "Barsoi\,\ Bihar",
"912367", "Kankavali\,\ Maharashtra",
"9171702", "Chumur\,\ Maharashtra",
"918216", "Mysore\,\ Karnataka",
"9171964", "Arjuni\ Morgaon\,\ Maharashtra",
"9165647", "Nagarutari\,\ Bihar",
"9167962", "Karanjia\,\ Odisha",
"911463", "Kishangarh\,\ Rajasthan",
"9127174", "Sanand\,\ Gujarat",
"917125", "Nagpur\,\ Maharashtra",
"9162772", "Phulparas\,\ Bihar",
"9171006", "Kuhi\,\ Maharashtra",
"91495", "Kozhikode\,\ Kerala",
"9166714", "Rajkhariar\,\ Odisha",
"913581", "Dinhata\,\ West\ Bengal",
"913752", "Lakhimpur\,\ Assam",
"911697", "Ratia\,\ Haryana",
"9171394", "Kurkheda\,\ Maharashtra",
"918556", "Hindupur\,\ Andhra\ Pradesh",
"9173927", "Jhabua\,\ Madhya\ Pradesh",
"911375", "Rajgarhi\,\ Uttarakhand",
"9176370", "Birsa\,\ Madhya\ Pradesh",
"9165915", "Chandil\,\ Bihar",
"915880", "Puranpur\,\ Uttar\ Pradesh",
"915174", "Jhansi\,\ Uttar\ Pradesh",
"9162755", "Rosera\,\ Bihar",
"9161546", "Siwan\,\ Bihar",
"918868", "Yeleswaram\,\ Andhra\ Pradesh",
"9176274", "Manpur\,\ Madhya\ Pradesh",
"9175217", "Seondha\,\ Madhya\ Pradesh",
"9163225", "Wazirganj\,\ Bihar",
"917601", "Patharia\,\ Madhya\ Pradesh",
"9166782", "Nowparatan\,\ Odisha",
"9172878", "Gogaon\,\ Madhya\ Pradesh",
"9165295", "Itki\,\ Bihar",
"9175968", "Gyraspur\,\ Madhya\ Pradesh",
"9174849", "Silwani\,\ Madhya\ Pradesh",
"9168696", "Papadhandi\,\ Odisha",
"915195", "Mau\/Rajapur\,\ Uttar\ Pradesh",
"9165684", "Balumath\,\ Bihar",
"9164547", "Purnea\,\ Bihar",
"9165465", "Hazaribagh\,\ Bihar",
"911427", "Dausa\,\ Rajasthan",
"9166524", "Balangir\,\ Odisha",
"9168437", "Puruna\ Katak\,\ Odisha",
"913771", "Mariani\,\ Assam",
"915466", "Sagri\,\ Uttar\ Pradesh",
"913821", "R\.K\.Pur\,\ Tripura",
"9168564", "Rayagada\,\ Odisha",
"9173244", "Mhow\,\ Madhya\ Pradesh",
"912323", "Ajara\,\ Maharashtra",
"9177068", "Gariaband\,\ Madhya\ Pradesh",
"9164794", "Udakishanganj\,\ Bihar",
"9166402", "Bagdihi\,\ Odisha",
"912677", "Limkheda\,\ Gujarat",
"9165612", "Garhwa\,\ Bihar",
"9174974", "Khaniadhana\,\ Madhya\ Pradesh",
"914561", "Devakottai\,\ Tamil\ Nadu",
"918966", "Srungavarapukota\/Kothavalasa\,\ Andhra\ Pradesh",
"9174828", "Raisen\,\ Madhya\ Pradesh",
"9173933", "Jobat\,\ Madhya\ Pradesh",
"915523", "Maharajganj\,\ Uttar\ Pradesh",
"9162516", "Bagaha\,\ Bihar",
"9174216", "Manasa\,\ Madhya\ Pradesh",
"9166432", "Barkot\,\ Odisha",
"914933", "Perinthalmanna\,\ Kerala",
"91731", "Indore\,\ Madhya\ Pradesh",
"912320", "Chandgad\,\ Maharashtra",
"9176466", "Nainpur\,\ Madhya\ Pradesh",
"9168674", "Jharigan\,\ Odisha",
"9168407", "Tumudibandha\,\ Odisha",
"9171554", "Seloo\,\ Maharashtra",
"9176812", "Jatara\,\ Madhya\ Pradesh",
"9167552", "Khurda\,\ Odisha",
"911234", "Baghpat\/Baraut\,\ Uttar\ Pradesh",
"9164776", "Triveniganj\,\ Bihar",
"9174658", "Sapotra\,\ Rajasthan",
"9174377", "Nainwa\,\ Rajasthan",
"915271", "Akbarpur\,\ Uttar\ Pradesh",
"91416", "Vellore\,\ Tamil\ Nadu",
"917258", "Akot\,\ Maharashtra",
"916613", "Rourkela\,\ Odisha",
"911531", "Nokha\,\ Rajasthan",
"918512", "Adoni\,\ Andhra\ Pradesh",
"914202", "Mulanur\,\ Tamil\ Nadu",
"9171997", "Deori\,\ Maharashtra",
"918156", "Chikkaballapur\,\ Karnataka",
"911960", "Nowshera\,\ Jammu\ And\ Kashmir",
"9167287", "Jajapur\ Town\,\ Odisha",
"918319", "Belgaum\,\ Karnataka",
"9171376", "Desaiganj\,\ Maharashtra",
"915252", "Bahraich\/Bahrailh\,\ Uttar\ Pradesh",
"913014", "Jaisalmer\/Khuri\,\ Rajasthan",
"9175910", "Sironj\,\ Madhya\ Pradesh",
"9163256", "Pakribarwan\,\ Bihar",
"9173220", "Depalpur\,\ Madhya\ Pradesh",
"9162726", "Darbhanga\,\ Bihar",
"9164213", "Naugachia\,\ Bihar",
"9165546", "Rajdhanwar\,\ Bihar",
"91286", "Porbander\,\ Gujarat",
"916415", "Bhagalpur\,\ Bihar",
"9177010", "Pingeshwar\,\ Madhya\ Pradesh",
"911488", "Kotri\,\ Rajasthan",
"9176296", "Pushprajgarh\,\ Madhya\ Pradesh",
"9168423", "Phulbani\,\ Odisha",
"9175290", "Laher\,\ Madhya\ Pradesh",
"9166463", "Bargarh\,\ Odisha",
"918567", "Lakkireddipalli\,\ Andhra\ Pradesh",
"9171036", "Butibori\,\ Maharashtra",
"914635", "Nanguneri\,\ Tamil\ Nadu",
"911526", "Lunkaransar\/Mahajan\,\ Rajasthan",
"9167927", "Baripada\,\ Odisha",
"9175919", "Sironj\,\ Madhya\ Pradesh",
"9173248", "Mhow\,\ Madhya\ Pradesh",
"913624", "Nalbari\,\ Assam",
"912908", "Amet\,\ Rajasthan",
"9177064", "Gariaband\,\ Madhya\ Pradesh",
"911460", "Kishangarhbas\/Khairthal\,\ Rajasthan",
"9174824", "Raisen\,\ Madhya\ Pradesh",
"9174978", "Khaniadhana\,\ Madhya\ Pradesh",
"9171732", "Rajura\,\ Maharashtra",
"9175299", "Laher\,\ Madhya\ Pradesh",
"9174643", "Karauli\,\ Rajasthan",
"9175964", "Gyraspur\,\ Madhya\ Pradesh",
"917279", "Nandnva\,\ Maharashtra",
"9171367", "Etapalli\,\ Maharashtra",
"912356", "Khed\,\ Maharashtra",
"9164363", "Sahibganj\,\ Bihar",
"918747", "Nuguru\/Cherla\,\ Andhra\ Pradesh",
"917525", "Bhitarwar\,\ Madhya\ Pradesh",
"9173229", "Depalpur\,\ Madhya\ Pradesh",
"912119", "Kedgaon\,\ Maharashtra",
"915567", "Captanganj\,\ Uttar\ Pradesh",
"9177019", "Pingeshwar\,\ Madhya\ Pradesh",
"9175111", "Gwalior\,\ Madhya\ Pradesh",
"912806", "Gogodar\,\ Gujarat",
"9162425", "Benipur\,\ Bihar",
"9165834", "Kharsawa\,\ Bihar",
"913673", "Haflong\,\ Assam",
"9168597", "Motu\,\ Odisha",
"9174366", "Hindoli\,\ Rajasthan",
"918523", "Alur\,\ Andhra\ Pradesh",
"9176278", "Manpur\,\ Madhya\ Pradesh",
"9171763", "Warora\,\ Maharashtra",
"918457", "Siddipet\,\ Andhra\ Pradesh",
"9164767", "Madhepura\,\ Bihar",
"917804", "Kusmi\,\ Madhya\ Pradesh",
"9172874", "Gogaon\,\ Madhya\ Pradesh",
"9181752", "Holenarasipur\,\ Karnataka",
"9164332", "Jamtara\,\ Bihar",
"9168192", "Surada\,\ Odisha",
"911886", "Tanda\ Urmar\,\ Punjab",
"9176477", "Ghughari\,\ Madhya\ Pradesh",
"917518", "Gwalior\,\ Madhya\ Pradesh",
"9189466", "Pathapatnam\/Hiramandalam\,\ Andhra\ Pradesh",
"911682", "Zira\,\ Punjab",
"9161804", "Adhaura\,\ Bihar",
"9167575", "Daspalla\,\ Odisha",
"918784", "Karimnagar\,\ Andhra\ Pradesh",
"918705", "Warangal\,\ Andhra\ Pradesh",
"911342", "Bijnor\,\ Uttar\ Pradesh",
"9167244", "Jagatsinghpur\,\ Odisha",
"9176299", "Pushprajgarh\,\ Madhya\ Pradesh",
"913783", "Along\,\ Arunachal\ Pradesh",
"9167663", "Keonjhar\,\ Odisha",
"917912", "Ahmedabad\ Local\,\ Gujarat",
"917693", "Ghansour\,\ Madhya\ Pradesh",
"9167255", "Dhanmandal\,\ Odisha",
"917474", "Bundi\,\ Rajasthan",
"9167935", "Betanati\,\ Odisha",
"914864", "Adimaly\,\ Kerala",
"915612", "Ferozabad\,\ Uttar\ Pradesh",
"915280", "Rath\,\ Uttar\ Pradesh",
"911822", "Kapurthala\,\ Punjab",
"9176322", "Balaghat\,\ Madhya\ Pradesh",
"9182897", "Athani\,\ Karnataka",
"9165352", "Chainpur\,\ Bihar",
"9168642", "Mathili\,\ Odisha",
"913524", "Harirampur\,\ West\ Bengal",
"918674", "Gudivada\,\ Andhra\ Pradesh",
"918493", "Madakasira\,\ Andhra\ Pradesh",
"91144", "Alwar\,\ Rajasthan",
"918425", "Biligi\,\ Karnataka",
"91175", "Patiala\,\ Punjab",
"9161592", "Masrakh\,\ Bihar",
"9176414", "Niwas\,\ Madhya\ Pradesh",
"911582", "Nagaur\,\ Rajasthan",
"9189460", "Pathapatnam\/Hiramandalam\,\ Andhra\ Pradesh",
"915364", "Kadipur\,\ Uttar\ Pradesh",
"9162437", "Begusarai\,\ Bihar",
"9174264", "Sitamau\,\ Madhya\ Pradesh",
"913805", "Hayuliang\,\ Arunachal\ Pradesh",
"912792", "Amreli\,\ Gujarat",
"9162564", "Ramnagar\,\ Bihar",
"911389", "Joshimath\,\ Uttarakhand",
"913221", "Jhargram\,\ West\ Bengal",
"9172691", "Deolgaonraja\,\ Maharashtra",
"918418", "Medchal\,\ Andhra\ Pradesh",
"9174360", "Hindoli\,\ Rajasthan",
"9176469", "Nainpur\,\ Madhya\ Pradesh",
"9166834", "Padmapur\,\ Odisha",
"918623", "Sullurpet\,\ Andhra\ Pradesh",
"9174538", "Baran\,\ Rajasthan",
"918377", "Nargund\,\ Karnataka",
"911496", "Sarwar\,\ Rajasthan",
"912164", "Karad\,\ Maharashtra",
"9174219", "Manasa\,\ Madhya\ Pradesh",
"9167632", "Athmallik\,\ Odisha",
"9176482", "Mawai\,\ Madhya\ Pradesh",
"912878", "Mangrol\,\ Gujarat",
"9161524", "Chapra\,\ Bihar",
"9174314", "Aklera\,\ Rajasthan",
"9165913", "Chandil\,\ Bihar",
"918364", "Hubli\,\ Karnataka",
"916513", "Ranchi\,\ Bihar",
"9163223", "Wazirganj\,\ Bihar",
"914543", "Batlagundu\,\ Tamil\ Nadu",
"9174382", "Keshoraipatan\/Patan\,\ Rajasthan",
"911996", "Doda\,\ Jammu\ And\ Kashmir",
"9162753", "Rosera\,\ Bihar",
"9165432", "Barhi\,\ Bihar",
"9174210", "Manasa\,\ Madhya\ Pradesh",
"9165293", "Itki\,\ Bihar",
"917262", "Buldhana\,\ Maharashtra",
"9168456", "Phiringia\,\ Odisha",
"918918", "Visakhapatnam\,\ Andhra\ Pradesh",
"9168617", "Malkangiri\,\ Odisha",
"9174369", "Hindoli\,\ Rajasthan",
"9176460", "Nainpur\,\ Madhya\ Pradesh",
"9173226", "Depalpur\,\ Madhya\ Pradesh",
"9111", "New\ Delhi",
"9167272", "Kendrapara\,\ Odisha",
"9177016", "Pingeshwar\,\ Madhya\ Pradesh",
"9166546", "Sonapur\,\ Odisha",
"9175296", "Laher\,\ Madhya\ Pradesh",
"912976", "Sheoganj\/Posaliyan\,\ Rajasthan",
"9176290", "Pushprajgarh\,\ Madhya\ Pradesh",
"912715", "Viramgam\,\ Gujarat",
"9165463", "Hazaribagh\,\ Bihar",
"918667", "Vijayawada\,\ Andhra\ Pradesh",
"918612", "Nellore\,\ Andhra\ Pradesh",
"91194", "Srinagar\,\ Jammu\ And\ Kashmir",
"9174504", "Sangod\,\ Rajasthan",
"918816", "Bhimavaram\,\ Andhra\ Pradesh",
"915493", "Mohamdabad\,\ Uttar\ Pradesh",
"9175916", "Sironj\,\ Madhya\ Pradesh",
"9173935", "Jobat\,\ Madhya\ Pradesh",
"9168146", "Digapahandi\,\ Odisha",
"912454", "Basmatnagar\,\ Maharashtra",
"9174534", "Baran\,\ Rajasthan",
"917729", "Bhilaigarh\,\ Madhya\ Pradesh",
"9162234", "Motipur\,\ Bihar",
"918283", "Salkani\,\ Karnataka",
"91368", "Passighat\,\ Arunachal\ Pradesh",
"918852", "Peddapuram\,\ Andhra\ Pradesh",
"9176418", "Niwas\,\ Madhya\ Pradesh",
"9166777", "Narlaroad\,\ Odisha",
"918656", "Nuzvidu\,\ Andhra\ Pradesh",
"9176376", "Birsa\,\ Madhya\ Pradesh",
"9163237", "Dumraon\,\ Bihar",
"9174268", "Sitamau\,\ Madhya\ Pradesh",
"912843", "Gariadhar\,\ Gujarat",
"917791", "Gadarwara\,\ Madhya\ Pradesh",
"9171812", "Lakhandur\,\ Maharashtra",
"9162744", "Samastipur\,\ Bihar",
"918721", "Husnabad\,\ Andhra\ Pradesh",
"9167814", "Basta\,\ Odisha",
"911745", "Nilokheri\,\ Haryana",
"915736", "Siyana\,\ Uttar\ Pradesh",
"9165402", "Govindpur\,\ Bihar",
"9174917", "Narwar\,\ Madhya\ Pradesh",
"914143", "Virudhachalam\,\ Tamil\ Nadu",
"917285", "Kasrawad\,\ Madhya\ Pradesh",
"9164215", "Naugachia\,\ Bihar",
"912744", "Deesa\,\ Gujarat",
"9166465", "Bargarh\,\ Odisha",
"9168425", "Phulbani\,\ Odisha",
"917746", "Manpur\,\ Madhya\ Pradesh",
"9171466", "Ghorandogri\,\ Madhya\ Pradesh",
"91291", "Jodhpur\,\ Rajasthan",
"9167882", "Soro\,\ Odisha",
"9162597", "Pakridayal\,\ Bihar",
"9165592", "Simaria\,\ Bihar",
"9171477", "Multai\,\ Madhya\ Pradesh",
"9171604", "Jamai\,\ Madhya\ Pradesh",
"915871", "Nighasan\/Palia\ Kalan\,\ Uttar\ Pradesh",
"918736", "Mancherial\,\ Andhra\ Pradesh",
"9167602", "Talcher\,\ Odisha",
"915721", "Sikandra\ Rao\,\ Uttar\ Pradesh",
"917858", "Kuakunda\,\ Madhya\ Pradesh",
"9174508", "Sangod\,\ Rajasthan",
"918620", "Udaygiri\,\ Andhra\ Pradesh",
"911565", "Sri\ Dungargarh\,\ Rajasthan",
"9164365", "Sahibganj\,\ Bihar",
"91241", "Ahmednagar\,\ Maharashtra",
"9174645", "Karauli\,\ Rajasthan",
"9174846", "Silwani\,\ Madhya\ Pradesh",
"912835", "Nakhatrana\,\ Gujarat",
"912564", "Nandurbar\,\ Maharashtra",
"918490", "Pamuru\,\ Andhra\ Pradesh",
"9162423", "Benipur\,\ Bihar",
"9174942", "Kolaras\,\ Madhya\ Pradesh",
"911733", "Kalka\,\ Haryana",
"9176367", "Baihar\,\ Madhya\ Pradesh",
"912954", "Kumbalgarh\/Charbhujaji\,\ Rajasthan",
"9171057", "Narkhed\,\ Maharashtra",
"9167226", "Pardip\,\ Odisha",
"916122", "Patna\,\ Bihar",
"9171847", "Bhandara\,\ Maharashtra",
"9166766", "M\.Rampur\,\ Odisha",
"915283", "Charkhari\,\ Uttar\ Pradesh",
"9171765", "Warora\,\ Maharashtra",
"91226", "Mumbai",
"9164624", "Dhamdaha\,\ Bihar",
"9161352", "Bikram\,\ Bihar",
"911955", "Kupwara\,\ Jammu\ And\ Kashmir",
"915852", "Hardoi\,\ Uttar\ Pradesh",
"9162787", "Dalsinghsarai\,\ Bihar",
"917690", "Lakhnadon\,\ Madhya\ Pradesh",
"914371", "Arantangi\,\ Tamil\ Nadu",
"9174318", "Aklera\,\ Rajasthan",
"913780", "Dirang\,\ Arunachal\ Pradesh",
"9167573", "Daspalla\,\ Odisha",
"9162453", "Gogri\,\ Bihar",
"9174584", "Pipalda\/Sumerganj\ Mandi\,\ Rajasthan",
"9162284", "Pupri\,\ Bihar",
"9165367", "Palkot\,\ Bihar",
"914573", "Rameshwaram\,\ Tamil\ Nadu",
"918288", "Bailhongal\,\ Karnataka",
"916125", "Patna\,\ Bihar",
"9167256", "Dhanmandal\,\ Odisha",
"9167936", "Betanati\,\ Odisha",
"912929", "Shergarh\/Balesar\,\ Rajasthan",
"9161113", "Hilsa\,\ Bihar",
"9171027", "Parseoni\,\ Maharashtra",
"9167863", "Chandbali\,\ Odisha",
"9163287", "Daudnagar\,\ Bihar",
"918719", "Mahabubbad\,\ Andhra\ Pradesh",
"912848", "Palitana\,\ Gujarat",
"9161322", "Barh\,\ Bihar",
"915855", "Bilgram\/Sandi\,\ Uttar\ Pradesh",
"911952", "Baramulla\,\ Jammu\ And\ Kashmir",
"91422", "Coimbatore\,\ Tamil\ Nadu",
"914884", "Vadakkanchery\,\ Kerala",
"912147", "Shrivardhan\,\ Maharashtra",
"912991", "Jaisalmer\/Ramgarh\,\ Rajasthan",
"915260", "Tarabganj\,\ Uttar\ Pradesh",
"9174512", "Atru\,\ Rajasthan",
"9174302", "Khanpur\,\ Rajasthan",
"915644", "Bharatpur\,\ Rajasthan",
"918910", "Visakhapatnam\,\ Andhra\ Pradesh",
"9165242", "Gumla\,\ Bihar",
"911562", "Churu\,\ Rajasthan",
"9171834", "Tumsar\,\ Maharashtra",
"912184", "Barsi\,\ Maharashtra",
"912870", "Malia\ Hatina\,\ Gujarat",
"9168472", "G\.Udayagiri\,\ Odisha",
"9171003", "Kuhi\,\ Maharashtra",
"912832", "Bhuj\,\ Gujarat",
"91771", "Raipur\,\ Madhya\ Pradesh",
"9176524", "Shahdol\,\ Madhya\ Pradesh",
"9174142", "Jaora\,\ Madhya\ Pradesh",
"918384", "Sirsi\,\ Karnataka",
"9163244", "Nawada\,\ Bihar",
"9176402", "Shahpur\,\ Madhya\ Pradesh",
"918934", "Chodavaram\,\ Andhra\ Pradesh",
"912699", "Thasra\,\ Gujarat",
"917853", "Bijapur\,\ Madhya\ Pradesh",
"918644", "Tenali\,\ Andhra\ Pradesh",
"911471", "Rashmi\,\ Rajasthan",
"912446", "Ambejogai\,\ Maharashtra",
"917282", "Khargone\,\ Madhya\ Pradesh",
"9162247", "Hajipur\,\ Bihar",
"9174547", "Chhipaborad\,\ Rajasthan",
"9161543", "Siwan\,\ Bihar",
"913877", "Tamenglong\,\ Manipur",
"912621", "Sayan\,\ Gujarat",
"917444", "Ladpura\/Kota\,\ Rajasthan",
"911257", "Meham\,\ Haryana",
"9168455", "Phiringia\,\ Odisha",
"9177015", "Pingeshwar\,\ Madhya\ Pradesh",
"9166545", "Sonapur\,\ Odisha",
"9168693", "Papadhandi\,\ Odisha",
"9173225", "Depalpur\,\ Madhya\ Pradesh",
"912429", "Shevgaon\,\ Maharashtra",
"917754", "Pandaria\,\ Madhya\ Pradesh",
"9175295", "Laher\,\ Madhya\ Pradesh",
"912756", "Muli\,\ Gujarat",
"911679", "Barnala\,\ Punjab",
"918855", "Mandapeta\/Ravulapalem\,\ Andhra\ Pradesh",
"9175915", "Sironj\,\ Madhya\ Pradesh",
"9162737", "Jhajharpur\,\ Bihar",
"9162513", "Bagaha\,\ Bihar",
"9168145", "Digapahandi\,\ Odisha",
"9173936", "Jobat\,\ Madhya\ Pradesh",
"918263", "Mudigere\,\ Karnataka",
"9174213", "Manasa\,\ Madhya\ Pradesh",
"912712", "Gandhi\ Nagar\,\ Gujarat",
"913788", "Kolaring\,\ Arunachal\ Pradesh",
"917831", "Balrampur\,\ Madhya\ Pradesh",
"9176463", "Nainpur\,\ Madhya\ Pradesh",
"918615", "Nellore\,\ Andhra\ Pradesh",
"918922", "Vizayanagaram\,\ Andhra\ Pradesh",
"9171777", "Brahmapuri\,\ Maharashtra",
"9165394", "Bolwa\,\ Bihar",
"9164773", "Triveniganj\,\ Bihar",
"915841", "Tilhar\,\ Uttar\ Pradesh",
"912767", "Sidhpur\,\ Gujarat",
"918498", "Nallacheruvu\/Tanakallu\,\ Andhra\ Pradesh",
"9176375", "Birsa\,\ Madhya\ Pradesh",
"9163324", "Nabinagar\,\ Bihar",
"913661", "Kokrajhar\,\ Assam",
"9166812", "Jujumura\,\ Odisha",
"9161554", "Ekma\,\ Bihar",
"918839", "Rajahmundri\,\ Andhra\ Pradesh",
"9167614", "Chhendipada\,\ Odisha",
"9171373", "Desaiganj\,\ Maharashtra",
"9171612", "Parasia\,\ Madhya\ Pradesh",
"9163412", "Seikhpura\,\ Bihar",
"9164377", "Mahagama\,\ Bihar",
"914341", "Uthangarai\,\ Tamil\ Nadu",
"9174588", "Pipalda\/Sumerganj\ Mandi\,\ Rajasthan",
"915692", "Farrukhabad\/Fategarh\,\ Uttar\ Pradesh",
"917850", "Bhanupratappur\,\ Madhya\ Pradesh",
"9163253", "Pakribarwan\,\ Bihar",
"9167682", "Parajang\,\ Odisha",
"9165543", "Rajdhanwar\,\ Bihar",
"9164216", "Naugachia\,\ Bihar",
"9162723", "Darbhanga\,\ Bihar",
"9163484", "Mallehpur\,\ Bihar",
"9171684", "Harrai\,\ Madhya\ Pradesh",
"9176432", "Bijadandi\,\ Madhya\ Pradesh",
"9168426", "Phulbani\,\ Odisha",
"918413", "Hyderabad\ West\/Shamshabad\,\ Andhra\ Pradesh",
"9176293", "Pushprajgarh\,\ Madhya\ Pradesh",
"9171465", "Ghorandogri\,\ Madhya\ Pradesh",
"917265", "Nandura\,\ Maharashtra",
"918628", "Chejerla\,\ Andhra\ Pradesh",
"9166466", "Bargarh\,\ Odisha",
"9166477", "Naktideul\,\ Odisha",
"9165414", "Chatra\,\ Bihar",
"9171033", "Butibori\,\ Maharashtra",
"911504", "Bhadra\,\ Rajasthan",
"911585", "Nagaur\/Khinwsar\,\ Rajasthan",
"913802", "Roing\/Arda\,\ Arunachal\ Pradesh",
"912873", "Visavadar\,\ Gujarat",
"9171804", "Salekasa\,\ Maharashtra",
"9189461", "Pathapatnam\/Hiramandalam\,\ Andhra\ Pradesh",
"912795", "Kodinar\,\ Gujarat",
"9174646", "Karauli\,\ Rajasthan",
"912584", "Raver\,\ Maharashtra",
"9164366", "Sahibganj\,\ Bihar",
"918913", "Visakhapatnam\,\ Andhra\ Pradesh",
"918692", "Nampalle\,\ Andhra\ Pradesh",
"916804", "Berhampur\,\ Odisha",
"917849", "Baderajpur\,\ Madhya\ Pradesh",
"917586", "Deori\,\ Madhya\ Pradesh",
"9165482", "Ichak\,\ Bihar",
"9174845", "Silwani\,\ Madhya\ Pradesh",
"918227", "T\.Narsipur\,\ Karnataka",
"9174332", "Pachpahar\/Bhawanimandi\,\ Rajasthan",
"915413", "Chakia\,\ Uttar\ Pradesh",
"9165964", "Noamundi\,\ Bihar",
"9171647", "Pandhurna\,\ Madhya\ Pradesh",
"9163447", "Monghyr\,\ Bihar",
"915263", "Balarampur\/Balrampur\,\ Uttar\ Pradesh",
"917297", "Kukshi\,\ Madhya\ Pradesh",
"912774", "Modasa\,\ Gujarat",
"912824", "Dhoraji\,\ Gujarat",
"914173", "Arni\,\ Tamil\ Nadu",
"9174363", "Hindoli\,\ Rajasthan",
"917915", "Ahmedabad\ Local\,\ Gujarat",
"917622", "Katni\,\ Madhya\ Pradesh",
"9166847", "Paikamal\,\ Odisha",
"917776", "Premnagar\,\ Madhya\ Pradesh",
"9171766", "Warora\,\ Maharashtra",
"917826", "Patan\,\ Madhya\ Pradesh",
"9166765", "M\.Rampur\,\ Odisha",
"9167225", "Pardip\,\ Odisha",
"915498", "Ballia\,\ Uttar\ Pradesh",
"9176528", "Shahdol\,\ Madhya\ Pradesh",
"91120", "Ghaziabad\/Dadri\,\ Uttar\ Pradesh",
"9162444", "Khagaria\,\ Bihar",
"9165322", "Giridih\,\ Bihar",
"9176352", "Lanji\,\ Madhya\ Pradesh",
"915922", "Amroha\,\ Uttar\ Pradesh",
"9189463", "Pathapatnam\/Hiramandalam\,\ Andhra\ Pradesh",
"911893", "Nurpur\,\ Himachal\ Pradesh",
"9171062", "Bhiwapur\,\ Maharashtra",
"914339", "Keeranur\,\ Tamil\ Nadu",
"918422", "Chadchan\,\ Karnataka",
"9164313", "Jharmundi\,\ Bihar",
"9166797", "Komana\,\ Odisha",
"912351", "Langa\,\ Maharashtra",
"9167403", "Bhubaneshwar\,\ Odisha",
"9164672", "Banmankhi\,\ Bihar",
"9171317", "Sironcha\,\ Maharashtra",
"9175914", "Sironj\,\ Madhya\ Pradesh",
"911392", "Budhana\,\ Uttar\ Pradesh",
"9171523", "Wardha\,\ Maharashtra",
"9177069", "Gariaband\,\ Madhya\ Pradesh",
"9164527", "Katihar\,\ Bihar",
"9168153", "Parlakhemundi\,\ Odisha",
"9174829", "Raisen\,\ Madhya\ Pradesh",
"9174506", "Sangod\,\ Rajasthan",
"9175390", "Ambah\,\ Madhya\ Pradesh",
"918545", "Amangallu\,\ Andhra\ Pradesh",
"9175294", "Laher\,\ Madhya\ Pradesh",
"9175969", "Gyraspur\,\ Madhya\ Pradesh",
"9174848", "Silwani\,\ Madhya\ Pradesh",
"91515", "Unnao\,\ Uttar\ Pradesh",
"911521", "Bikaner\/Jaimalsar\,\ Rajasthan",
"9165883", "Jagarnathpur\,\ Bihar",
"9173224", "Depalpur\,\ Madhya\ Pradesh",
"9177014", "Pingeshwar\,\ Madhya\ Pradesh",
"9166544", "Sonapur\,\ Odisha",
"917727", "Balodabazar\,\ Madhya\ Pradesh",
"912468", "Hadgaon\,\ Maharashtra",
"915172", "Mehraun\,\ Uttar\ Pradesh",
"9168454", "Phiringia\,\ Odisha",
"911900", "Lahul\/Keylong\,\ Himachal\ Pradesh",
"914262", "Gudalur\,\ Tamil\ Nadu",
"9173947", "Alirajpur\,\ Madhya\ Pradesh",
"911881", "Ropar\,\ Punjab",
"918276", "Somwarpet\,\ Karnataka",
"913754", "Moranhat\,\ Assam",
"9162577", "Barachakia\,\ Bihar",
"9172879", "Gogaon\,\ Madhya\ Pradesh",
"9174277", "Bhanpura\,\ Madhya\ Pradesh",
"917543", "Ashoknagar\,\ Madhya\ Pradesh",
"9174316", "Aklera\,\ Rajasthan",
"912980", "Pachpadra\/Korna\,\ Rajasthan",
"914923", "Koduvayur\,\ Kerala",
"912801", "Ranavav\,\ Gujarat",
"912372", "Patan\,\ Maharashtra",
"9161526", "Chapra\,\ Bihar",
"9163245", "Nawada\,\ Bihar",
"9176525", "Shahdol\,\ Madhya\ Pradesh",
"9164717", "Birpur\,\ Bihar",
"9171713", "Gond\ Pipri\,\ Maharashtra",
"9172870", "Gogaon\,\ Madhya\ Pradesh",
"917763", "Jashpurnagar\,\ Madhya\ Pradesh",
"9171342", "Bhamregadh\,\ Maharashtra",
"9171835", "Tumsar\,\ Maharashtra",
"915114", "Derapur\/Jhinjak\,\ Uttar\ Pradesh",
"9166836", "Padmapur\,\ Odisha",
"912968", "Bagidora\,\ Rajasthan",
"918533", "Gangavathi\,\ Karnataka",
"9176378", "Birsa\,\ Madhya\ Pradesh",
"9174266", "Sitamau\,\ Madhya\ Pradesh",
"9165572", "Bagodar\,\ Bihar",
"9162566", "Ramnagar\,\ Bihar",
"9174853", "Udaipura\,\ Madhya\ Pradesh",
"9171497", "Tamia\,\ Madhya\ Pradesh",
"9161857", "Bikramganj\,\ Bihar",
"9164232", "Maheshpur\ Raj\,\ Bihar",
"9176416", "Niwas\,\ Madhya\ Pradesh",
"9165627", "Daltonganj\,\ Bihar",
"9177060", "Gariaband\,\ Madhya\ Pradesh",
"912662", "Padra\,\ Gujarat",
"9164263", "Rajmahal\,\ Bihar",
"9174820", "Raisen\,\ Madhya\ Pradesh",
"9165603", "Patan\,\ Bihar",
"9166413", "Deodgarh\,\ Odisha",
"916632", "Sambalpur\,\ Odisha",
"917535", "Raghunathpur\,\ Madhya\ Pradesh",
"917864", "Sukma\,\ Madhya\ Pradesh",
"9166252", "Lahunipara\,\ Odisha",
"918151", "Malur\,\ Karnataka",
"9175222", "Datia\,\ Madhya\ Pradesh",
"9174637", "Gangapur\,\ Rajasthan",
"913711", "Udalguri\,\ Assam",
"915545", "Bansi\,\ Uttar\ Pradesh",
"912558", "Peint\,\ Maharashtra",
"911536", "Kolayat\/Daitra\,\ Rajasthan",
"9175960", "Gyraspur\,\ Madhya\ Pradesh",
"9162285", "Pupri\,\ Bihar",
"9173292", "Khakner\,\ Madhya\ Pradesh",
"9174585", "Pipalda\/Sumerganj\ Mandi\,\ Rajasthan",
"917606", "Jabera\,\ Madhya\ Pradesh",
"912345", "Shirala\,\ Maharashtra",
"9175267", "Ghatigaon\,\ Madhya\ Pradesh",
"917371", "Sarangpur\,\ Madhya\ Pradesh",
"917802", "Churhat\,\ Madhya\ Pradesh",
"9162445", "Khagaria\,\ Bihar",
"9174607", "Sahabad\,\ Rajasthan",
"9164626", "Dhamdaha\,\ Bihar",
"9174650", "Sapotra\,\ Rajasthan",
"918551", "Garladinne\,\ Andhra\ Pradesh",
"918782", "Karimnagar\,\ Andhra\ Pradesh",
"9166764", "M\.Rampur\,\ Odisha",
"9167224", "Pardip\,\ Odisha",
"911344", "Dhampur\,\ Uttar\ Pradesh",
"9165633", "Bhawanathpur\,\ Bihar",
"9176279", "Manpur\,\ Madhya\ Pradesh",
"918406", "Cumbum\,\ Andhra\ Pradesh",
"911684", "Narwana\,\ Haryana",
"911605", "Kharar\,\ Punjab",
"9165965", "Noamundi\,\ Bihar",
"9174844", "Silwani\,\ Madhya\ Pradesh",
"915461", "Ghosi\,\ Uttar\ Pradesh",
"912483", "Ambad\,\ Maharashtra",
"913826", "Ambasa\,\ Tripura",
"9175298", "Laher\,\ Madhya\ Pradesh",
"9164202", "Amarpur\,\ Bihar",
"913776", "Bokakhat\,\ Assam",
"918254", "Kundapur\,\ Karnataka",
"918572", "Chittoor\,\ Andhra\ Pradesh",
"9168187", "Buguda\,\ Odisha",
"914566", "Aruppukottai\,\ Tamil\ Nadu",
"9173228", "Depalpur\,\ Madhya\ Pradesh",
"9165662", "Japla\,\ Bihar",
"918379", "Hangal\,\ Karnataka",
"9177018", "Pingeshwar\,\ Madhya\ Pradesh",
"9167947", "Rairangpur\,\ Odisha",
"918133", "Chikkanayakanahalli\,\ Karnataka",
"9165857", "Ghatsila\,\ Bihar",
"9173249", "Mhow\,\ Madhya\ Pradesh",
"9161572", "Mairwa\,\ Bihar",
"9175918", "Sironj\,\ Madhya\ Pradesh",
"9171805", "Salekasa\,\ Maharashtra",
"9171606", "Jamai\,\ Madhya\ Pradesh",
"9174979", "Khaniadhana\,\ Madhya\ Pradesh",
"9165415", "Chatra\,\ Bihar",
"9174623", "Sawaimadhopur\,\ Rajasthan",
"9167353", "Telkoi\,\ Odisha",
"9168582", "Nowrangapur\,\ Odisha",
"915254", "Nanparah\/Mihinpurwa\,\ Uttar\ Pradesh",
"913012", "Jaisalmer\/Mehsana\,\ Rajasthan",
"9171537", "Hinganghat\,\ Maharashtra",
"913831", "Champa\,\ Mizoram",
"9164533", "Araria\,\ Bihar",
"917788", "Luckwada\,\ Madhya\ Pradesh",
"918461", "Dichpalli\,\ Andhra\ Pradesh",
"9171464", "Ghorandogri\,\ Madhya\ Pradesh",
"9163485", "Mallehpur\,\ Bihar",
"9171685", "Harrai\,\ Madhya\ Pradesh",
"912983", "Barmer\/Gudda\,\ Rajasthan",
"915961", "Munsiari\,\ Uttar\ Pradesh",
"9165273", "Kolebira\,\ Bihar",
"914285", "Gobichettipalayam\,\ Tamil\ Nadu",
"918514", "Nandyal\,\ Andhra\ Pradesh",
"914204", "Kodumudi\,\ Tamil\ Nadu",
"917540", "Bamori\,\ Madhya\ Pradesh",
"917661", "Teonthar\,\ Madhya\ Pradesh",
"9167615", "Chhendipada\,\ Odisha",
"9168443", "Kantamal\,\ Odisha",
"9174970", "Khaniadhana\,\ Madhya\ Pradesh",
"9171132", "Saoner\,\ Maharashtra",
"911437", "Malpura\,\ Rajasthan",
"9162746", "Samastipur\,\ Bihar",
"9167816", "Basta\,\ Odisha",
"911903", "Banjar\,\ Himachal\ Pradesh",
"916716", "Cuttack\,\ Odisha",
"9161555", "Ekma\,\ Bihar",
"9173240", "Mhow\,\ Madhya\ Pradesh",
"9176374", "Birsa\,\ Madhya\ Pradesh",
"9163325", "Nabinagar\,\ Bihar",
"9174659", "Sapotra\,\ Rajasthan",
"9167912", "Bangiriposi\,\ Odisha",
"91479", "Mavelikkara\,\ Kerala",
"918358", "Basavanabagewadi\,\ Karnataka",
"9165395", "Bolwa\,\ Bihar",
"9166553", "Titlagarh\,\ Odisha",
"9171163", "Umrer\,\ Maharashtra",
"9167292", "Pattamundai\,\ Odisha",
"9174536", "Baran\,\ Rajasthan",
"917578", "Pachmarhi\,\ Madhya\ Pradesh",
"9162236", "Motipur\,\ Bihar",
"9161883", "Rohtas\,\ Bihar",
"911232", "Modinagar\,\ Uttar\ Pradesh",
"9171982", "Tirora\,\ Maharashtra",
"918669", "Vijayawada\,\ Andhra\ Pradesh",
"9168144", "Digapahandi\,\ Odisha",
"9176270", "Manpur\,\ Madhya\ Pradesh",
"9171797", "Nagbhir\,\ Maharashtra",
"917236", "Maregaon\,\ Maharashtra",
"912550", "Niphad\,\ Maharashtra",
"9164793", "Udakishanganj\,\ Bihar",
"9174629", "Sawaimadhopur\,\ Rajasthan",
"9174973", "Khaniadhana\,\ Madhya\ Pradesh",
"9174505", "Sangod\,\ Rajasthan",
"913217", "Basirhat\,\ West\ Bengal",
"9166523", "Balangir\,\ Odisha",
"9168563", "Rayagada\,\ Odisha",
"9173243", "Mhow\,\ Madhya\ Pradesh",
"9174648", "Karauli\,\ Rajasthan",
"9165683", "Balumath\,\ Bihar",
"913015", "Jaisalmer\/Myajlar\,\ Rajasthan",
"912488", "Parner\,\ Maharashtra",
"91186", "Pathankot\,\ Punjab",
"9182207", "Gundlupet\,\ Karnataka",
"914282", "Attur\,\ Tamil\ Nadu",
"9176273", "Manpur\,\ Madhya\ Pradesh",
"918837", "Rajahmundri\,\ Andhra\ Pradesh",
"9174315", "Aklera\,\ Rajasthan",
"9168532", "Sunabeda\,\ Odisha",
"9176526", "Shahdol\,\ Madhya\ Pradesh",
"912960", "Sojat\,\ Rajasthan",
"916414", "Bhagalpur\,\ Bihar",
"91253", "Nasik\ City\,\ Maharashtra",
"918138", "Koratageri\,\ Karnataka",
"9161525", "Chapra\,\ Bihar",
"9171393", "Kurkheda\,\ Maharashtra",
"9166713", "Rajkhariar\,\ Odisha",
"9163246", "Nawada\,\ Bihar",
"913474", "Bethuadahari\,\ West\ Bengal",
"91471", "Thiruvananthapuram\,\ Kerala",
"9161862", "Aurangabad\,\ Bihar",
"912988", "Pachpadra\/Balotra\,\ Rajasthan",
"918229", "Gundlupet\,\ Karnataka",
"9171587", "Deoli\,\ Maharashtra",
"9166835", "Padmapur\,\ Odisha",
"9173938", "Jobat\,\ Madhya\ Pradesh",
"9171963", "Arjuni\ Morgaon\,\ Maharashtra",
"917783", "Padamkot\,\ Madhya\ Pradesh",
"9171836", "Tumsar\,\ Maharashtra",
"917847", "Antagarh\,\ Madhya\ Pradesh",
"9127173", "Sanand\,\ Gujarat",
"914634", "Ambasamudram\,\ Tamil\ Nadu",
"9162565", "Ramnagar\,\ Bihar",
"911908", "Jogindernagar\,\ Himachal\ Pradesh",
"9166497", "Jamankira\,\ Odisha",
"917524", "Dabra\,\ Madhya\ Pradesh",
"912460", "Delhi\ Tanda\,\ Maharashtra",
"9165827", "Chaibasa\,\ Bihar",
"9174265", "Sitamau\,\ Madhya\ Pradesh",
"9167323", "Hindol\,\ Odisha",
"9171182", "Kalmeshwar\,\ Maharashtra",
"9174653", "Sapotra\,\ Rajasthan",
"912526", "Wada\,\ Maharashtra",
"9176415", "Niwas\,\ Madhya\ Pradesh",
"9181742", "Arsikere\,\ Karnataka",
"9166267", "Banaigarh\,\ Odisha",
"917221", "Nandgaon\,\ Maharashtra",
"912342", "Islampur\,\ Maharashtra",
"917805", "Singrauli\,\ Madhya\ Pradesh",
"9168227", "Aska\,\ Odisha",
"9163372", "Arwal\,\ Bihar",
"918594", "Chirala\,\ Andhra\ Pradesh",
"9171413", "Betul\,\ Madhya\ Pradesh",
"9174620", "Sawaimadhopur\,\ Rajasthan",
"918353", "Jamkhandi\,\ Karnataka",
"9175902", "Lateri\,\ Madhya\ Pradesh",
"9167254", "Dhanmandal\,\ Odisha",
"9167934", "Betanati\,\ Odisha",
"918704", "Warangal\,\ Andhra\ Pradesh",
"918785", "Karimnagar\,\ Andhra\ Pradesh",
"915142", "Purwa\/Bighapur\,\ Uttar\ Pradesh",
"9167483", "Bhubaneshwar\,\ Odisha",
"9177002", "Nagri\,\ Madhya\ Pradesh",
"911602", "Kharar\,\ Punjab",
"917573", "Timarani\,\ Madhya\ Pradesh",
"9174586", "Pipalda\/Sumerganj\ Mandi\,\ Rajasthan",
"9161833", "Buxar\,\ Bihar",
"9162286", "Pupri\,\ Bihar",
"918246", "Mangalore\,\ Karnataka",
"911806", "Panipat\,\ Haryana",
"9174807", "Goharganj\,\ Madhya\ Pradesh",
"912665", "Sankheda\,\ Gujarat",
"9161803", "Adhaura\,\ Bihar",
"9167243", "Jagatsinghpur\,\ Odisha",
"917570", "Seonimalwa\,\ Madhya\ Pradesh",
"9174850", "Udaipura\,\ Madhya\ Pradesh",
"918717", "Eturnagaram\,\ Andhra\ Pradesh",
"9164625", "Dhamdaha\,\ Bihar",
"912149", "Mahasala\,\ Maharashtra",
"9177032", "Manpur\,\ Madhya\ Pradesh",
"918194", "Chitradurga\,\ Karnataka",
"9162446", "Khagaria\,\ Bihar",
"917532", "Morena\,\ Madhya\ Pradesh",
"916635", "Sambalpur\,\ Odisha",
"918350", "Mudhol\,\ Karnataka",
"9166222", "Sundargarh\,\ Odisha",
"9175932", "Kurwai\,\ Madhya\ Pradesh",
"9171764", "Warora\,\ Maharashtra",
"911664", "Bhiwani\,\ Haryana",
"9167337", "Ghatgaon\,\ Odisha",
"915542", "Basti\,\ Uttar\ Pradesh",
"9172873", "Gogaon\,\ Madhya\ Pradesh",
"9165966", "Noamundi\,\ Bihar",
"913566", "Kalchini\,\ West\ Bengal",
"9165833", "Kharsawa\,\ Bihar",
"912927", "Osian\/Dhanwara\,\ Rajasthan",
"9168492", "Daringbadi\,\ Odisha",
"917548", "Mungaoli\,\ Madhya\ Pradesh",
"9165862", "Chainpur\,\ Bihar",
"9175963", "Gyraspur\,\ Madhya\ Pradesh",
"912463", "Degloor\,\ Maharashtra",
"9174644", "Karauli\,\ Rajasthan",
"9164364", "Sahibganj\,\ Bihar",
"918331", "Raibag\/Kudchi\,\ Karnataka",
"91548", "Ghazipur\,\ Uttar\ Pradesh",
"9177063", "Gariaband\,\ Madhya\ Pradesh",
"9171806", "Salekasa\,\ Maharashtra",
"9161827", "Arrah\,\ Bihar",
"917124", "Nagpur\,\ Maharashtra",
"9176572", "Jaitpur\,\ Madhya\ Pradesh",
"9174823", "Raisen\,\ Madhya\ Pradesh",
"9165416", "Chatra\,\ Bihar",
"9171605", "Jamai\,\ Madhya\ Pradesh",
"9165657", "Latehar\,\ Bihar",
"9166537", "Dunguripali\,\ Odisha",
"9168424", "Phulbani\,\ Odisha",
"915175", "Lalitpur\/Talbehat\,\ Uttar\ Pradesh",
"913879", "Bishenpur\,\ Manipur",
"911374", "Bhatwari\/Uttarkashi\,\ Uttarakhand",
"912963", "Gerhi\/Partapur\,\ Rajasthan",
"9166464", "Bargarh\,\ Odisha",
"9168502", "Kalimela\,\ Odisha",
"915331", "Bharwari\,\ Uttar\ Pradesh",
"918481", "Basavakalyan\,\ Karnataka",
"911259", "Kosli\,\ Haryana",
"917768", "Saranggarh\,\ Madhya\ Pradesh",
"9163486", "Mallehpur\,\ Bihar",
"9171686", "Harrai\,\ Madhya\ Pradesh",
"918326", "Goa",
"9164214", "Naugachia\,\ Bihar",
"913791", "Taliha\,\ Arunachal\ Pradesh",
"9167616", "Chhendipada\,\ Odisha",
"9164282", "Nala\,\ Bihar",
"912375", "Pusegaon\,\ Maharashtra",
"91734", "Ujjain\,\ Madhya\ Pradesh",
"912697", "Retlad\,\ Gujarat",
"9161556", "Ekma\,\ Bihar",
"918538", "Manvi\,\ Karnataka",
"9162745", "Samastipur\,\ Bihar",
"9167815", "Basta\,\ Odisha",
"9168107", "Khalikote\,\ Odisha",
"9163326", "Nabinagar\,\ Bihar",
"9165977", "Saraikela\/Adstyapur\,\ Bihar",
"9164557", "Forbesganj\,\ Bihar",
"9171553", "Seloo\,\ Maharashtra",
"915194", "Karvi\/Manikpur\,\ Uttar\ Pradesh",
"9165396", "Bolwa\,\ Bihar",
"9174859", "Udaipura\,\ Madhya\ Pradesh",
"9162235", "Motipur\,\ Bihar",
"912427", "Newasa\,\ Maharashtra",
"918689", "Miryalguda\,\ Andhra\ Pradesh",
"918542", "Mahabubnagar\,\ Andhra\ Pradesh",
"9168673", "Jharigan\,\ Odisha",
"91483", "Manjeri\,\ Kerala",
"9174535", "Baran\,\ Rajasthan",
"9173934", "Jobat\,\ Madhya\ Pradesh",
"9174687", "Khandar\,\ Rajasthan",
"912553", "Igatpuri\,\ Maharashtra",
"9174975", "Khaniadhana\,\ Madhya\ Pradesh",
"917360", "Shujalpur\,\ Madhya\ Pradesh",
"9167406", "Bhubaneshwar\,\ Odisha",
"918203", "Udupi\,\ Karnataka",
"9164316", "Jharmundi\,\ Bihar",
"9164795", "Udakishanganj\,\ Bihar",
"912455", "Kalamnuri\,\ Maharashtra",
"9168156", "Parlakhemundi\,\ Odisha",
"912597", "Parola\,\ Maharashtra",
"9168565", "Rayagada\,\ Odisha",
"9173245", "Mhow\,\ Madhya\ Pradesh",
"9171526", "Wardha\,\ Maharashtra",
"917752", "Bilaspur\,\ Madhya\ Pradesh",
"917581", "Khurai\,\ Madhya\ Pradesh",
"918638", "Guntur\,\ Andhra\ Pradesh",
"9161507", "Hathua\,\ Bihar",
"9174503", "Sangod\,\ Rajasthan",
"9166525", "Balangir\,\ Odisha",
"9165537", "Ramgarh\,\ Bihar",
"918829", "Bhimadole\,\ Andhra\ Pradesh",
"9165886", "Jagarnathpur\,\ Bihar",
"9165464", "Hazaribagh\,\ Bihar",
"918779", "Tirupathi\,\ Andhra\ Pradesh",
"9165685", "Balumath\,\ Bihar",
"91360", "Itanagar\/Ziro\,\ Arunachal\ Pradesh",
"9164277", "Kathikund\,\ Bihar",
"918589", "Siddavattam\,\ Andhra\ Pradesh",
"918642", "Guntur\ Palnad\/Macherala\,\ Andhra\ Pradesh",
"9165294", "Itki\,\ Bihar",
"91191", "Jammu\,\ Jammu\ And\ Kashmir",
"918846", "Kakinada\,\ Andhra\ Pradesh",
"918932", "Narsipatnam\,\ Andhra\ Pradesh",
"9176275", "Manpur\,\ Madhya\ Pradesh",
"918382", "Karwar\,\ Karnataka",
"9163224", "Wazirganj\,\ Bihar",
"911744", "Kurukshetra\,\ Haryana",
"9162754", "Rosera\,\ Bihar",
"9174122", "Ratlam\,\ Madhya\ Pradesh",
"9174672", "Bamanwas\,\ Rajasthan",
"9174313", "Aklera\,\ Rajasthan",
"917442", "Ladpura\/Kota\,\ Rajasthan",
"911577", "Dantaramgarh\,\ Rajasthan",
"9165914", "Chandil\,\ Bihar",
"9166715", "Rajkhariar\,\ Odisha",
"9174527", "Chhabra\,\ Rajasthan",
"9171395", "Kurkheda\,\ Maharashtra",
"917821", "Dhamda\,\ Madhya\ Pradesh",
"9161523", "Chapra\,\ Bihar",
"917771", "Manendragarh\,\ Madhya\ Pradesh",
"9171716", "Gond\ Pipri\,\ Maharashtra",
"917284", "Rajpur\,\ Madhya\ Pradesh",
"9162227", "Sheohar\,\ Bihar",
"91207", "Pune\,\ Maharashtra",
"9176252", "Umariapan\,\ Madhya\ Pradesh",
"9165222", "Muri\,\ Bihar",
"911564", "Sardarshahar\,\ Rajasthan",
"918470", "Afzalpur\,\ Karnataka",
"915642", "Dholpur\,\ Rajasthan",
"913666", "Barpeta\ Road\,\ Assam",
"9127175", "Sanand\,\ Gujarat",
"9171965", "Arjuni\ Morgaon\,\ Maharashtra",
"91141", "Jaipur\,\ Rajasthan",
"913862", "Dimapur\,\ Nagaland",
"9166833", "Padmapur\,\ Odisha",
"914329", "Ariyalur\,\ Tamil\ Nadu",
"9174263", "Sitamau\,\ Madhya\ Pradesh",
"912565", "Shahada\,\ Maharashtra",
"912834", "Kutchmandvi\,\ Gujarat",
"917670", "Majhagwan\,\ Madhya\ Pradesh",
"9174856", "Udaipura\,\ Madhya\ Pradesh",
"9162563", "Ramnagar\,\ Bihar",
"9176413", "Niwas\,\ Madhya\ Pradesh",
"9174655", "Sapotra\,\ Rajasthan",
"917836", "Baikunthpur\,\ Madhya\ Pradesh",
"9167325", "Hindol\,\ Odisha",
"912182", "Karmala\,\ Maharashtra",
"9164266", "Rajmahal\,\ Bihar",
"9171857", "Pauni\,\ Maharashtra",
"916316", "Gaya\,\ Bihar",
"9171047", "Hingua\,\ Maharashtra",
"9174232", "Neemuch\,\ Madhya\ Pradesh",
"912955", "Malvi\/Fatehnagar\,\ Rajasthan",
"9166416", "Deodgarh\,\ Odisha",
"914253", "Anamalai\,\ Tamil\ Nadu",
"9165606", "Patan\,\ Bihar",
"9174952", "Badarwas\,\ Madhya\ Pradesh",
"915948", "Khatima\/Sitarganj\,\ Uttar\ Pradesh",
"9171415", "Betul\,\ Madhya\ Pradesh",
"9162532", "Narkatiaganj\,\ Bihar",
"9167485", "Bhubaneshwar\,\ Odisha",
"913193", "Andaman\ \&\ Nicobar\,\ Nicobar\ Islands",
"911954", "Sopore\,\ Jammu\ And\ Kashmir",
"914346", "Harur\,\ Tamil\ Nadu",
"912733", "Harij\,\ Gujarat",
"9161835", "Buxar\,\ Bihar",
"9163462", "Lakhisarai\,\ Bihar",
"9171662", "Chaurai\,\ Madhya\ Pradesh",
"9167664", "Keonjhar\,\ Odisha",
"9176529", "Shahdol\,\ Madhya\ Pradesh",
"917475", "Bundi\,\ Rajasthan",
"9167245", "Jagatsinghpur\,\ Odisha",
"9171572", "Arvi\,\ Maharashtra",
"9165497", "Bermo\,\ Bihar",
"9161805", "Adhaura\,\ Bihar",
"9167574", "Daspalla\,\ Odisha",
"912441", "Ashti\,\ Maharashtra",
"917624", "Sihora\,\ Madhya\ Pradesh",
"9166827", "Attabira\,\ Odisha",
"912822", "Morvi\,\ Gujarat",
"9171627", "Chhindwara\,\ Madhya\ Pradesh",
"9163427", "H\.Kharagpur\,\ Bihar",
"9164623", "Dhamdaha\,\ Bihar",
"912626", "Vyara\,\ Gujarat",
"912772", "Himatnagar\,\ Gujarat",
"9172875", "Gogaon\,\ Madhya\ Pradesh",
"918424", "Devarahippargi\,\ Karnataka",
"9162502", "Dhaka\,\ Bihar",
"911859", "Goindwal\,\ Punjab",
"9174202", "Jawad\,\ Madhya\ Pradesh",
"9165636", "Bhawanathpur\,\ Bihar",
"913525", "Dalkhola\,\ West\ Bengal",
"9165342", "Jhumaritalaiya\,\ Bihar",
"911476", "Kapasan\,\ Rajasthan",
"9168652", "Kashipur\,\ Odisha",
"9162424", "Benipur\,\ Bihar",
"918397", "H\.B\.Halli\,\ Karnataka",
"9165835", "Kharsawa\,\ Bihar",
"915924", "Hasanpur\,\ Uttar\ Pradesh",
"914865", "Munnar\,\ Kerala",
"913804", "Tezu\,\ Arunachal\ Pradesh",
"917327", "Harsud\,\ Madhya\ Pradesh",
"9174580", "Pipalda\/Sumerganj\ Mandi\,\ Rajasthan",
"911502", "Nohar\/Jedasar\,\ Rajasthan",
"917673", "Nagod\,\ Madhya\ Pradesh",
"9175965", "Gyraspur\,\ Madhya\ Pradesh",
"91423", "Udhagamandalam\,\ Tamil\ Nadu",
"9174825", "Raisen\,\ Madhya\ Pradesh",
"9165267", "Lohardaga\,\ Bihar",
"913657", "Mairang\,\ Meghalaya",
"911792", "Solan\,\ Himachal\ Pradesh",
"912165", "Dhiwadi\,\ Maharashtra",
"916802", "Berhampur\,\ Odisha",
"9177065", "Gariaband\,\ Madhya\ Pradesh",
"912582", "Bhusawal\,\ Maharashtra",
"918694", "Ramannapet\,\ Andhra\ Pradesh",
"912751", "Chotila\,\ Gujarat",
"912649", "Dediapada\,\ Gujarat",
"9171603", "Jamai\,\ Madhya\ Pradesh",
"918473", "Yadgiri\,\ Karnataka",
"9167356", "Telkoi\,\ Odisha",
"9174626", "Sawaimadhopur\,\ Rajasthan",
"912939", "Jaitaran\,\ Rajasthan",
"918365", "Hubli\,\ Karnataka",
"9164536", "Araria\,\ Bihar",
"9174589", "Pipalda\/Sumerganj\ Mandi\,\ Rajasthan",
"918189", "Channagiri\,\ Karnataka",
"914897", "Kadamath\,\ Lakshadweep",
"9174562", "Kishanganj\/Bhanwargarh\,\ Rajasthan",
"912996", "Pokhran\/Loharki\,\ Rajasthan",
"9162262", "Sitamarhi\,\ Bihar",
"9165276", "Kolebira\,\ Bihar",
"912439", "Golegaon\,\ Maharashtra",
"9165317", "Mandar\,\ Bihar",
"9168446", "Kantamal\,\ Odisha",
"9167813", "Basta\,\ Odisha",
"9162743", "Samastipur\,\ Bihar",
"915694", "Kannauj\,\ Uttar\ Pradesh",
"912898", "Jamjodhpur\,\ Gujarat",
"912714", "Dholka\,\ Gujarat",
"9166556", "Titlagarh\,\ Odisha",
"9176520", "Shahdol\,\ Madhya\ Pradesh",
"91294", "Udaipur\ Girwa\/Udaipur\,\ Rajasthan",
"9171166", "Umrer\,\ Maharashtra",
"9167697", "Kamakhyanagar\,\ Odisha",
"912631", "Ahwa\,\ Gujarat",
"9171555", "Seloo\,\ Maharashtra",
"9165507", "Hunterganj\,\ Bihar",
"9174533", "Baran\,\ Rajasthan",
"9168675", "Jharigan\,\ Odisha",
"9161537", "Maharajganj\,\ Bihar",
"9161886", "Rohtas\,\ Bihar",
"911976", "Amb\,\ Himachal\ Pradesh",
"9162233", "Motipur\,\ Bihar",
"918200", "Udupi\,\ Karnataka",
"918924", "Anakapalle\,\ Andhra\ Pradesh",
"917363", "Berchha\,\ Madhya\ Pradesh",
"9164796", "Udakishanganj\,\ Bihar",
"917561", "Ichhawar\,\ Madhya\ Pradesh",
"9174976", "Khaniadhana\,\ Madhya\ Pradesh",
"9167405", "Bhubaneshwar\,\ Odisha",
"9164315", "Jharmundi\,\ Bihar",
"9166526", "Balangir\,\ Odisha",
"9176507", "Beohari\,\ Madhya\ Pradesh",
"9168155", "Parlakhemundi\,\ Odisha",
"9168566", "Rayagada\,\ Odisha",
"9173246", "Mhow\,\ Madhya\ Pradesh",
"9171525", "Wardha\,\ Maharashtra",
"9165885", "Jagarnathpur\,\ Bihar",
"915672", "Mainpuri\,\ Uttar\ Pradesh",
"918731", "Utnor\,\ Andhra\ Pradesh",
"915876", "Mohammadi\,\ Uttar\ Pradesh",
"918440", "Nimburga\,\ Karnataka",
"9168694", "Papadhandi\,\ Odisha",
"918614", "Nellore\,\ Andhra\ Pradesh",
"9165686", "Balumath\,\ Bihar",
"9174530", "Baran\,\ Rajasthan",
"91565", "Mathura\,\ Uttar\ Pradesh",
"918362", "Hubli\,\ Karnataka",
"918569", "Badvel\,\ Andhra\ Pradesh",
"9161544", "Siwan\,\ Bihar",
"9174368", "Hindoli\,\ Rajasthan",
"9176276", "Manpur\,\ Madhya\ Pradesh",
"91460", "Taliparamba\,\ Kerala",
"913513", "Harishchandrapur\,\ West\ Bengal",
"917264", "Chikhali\,\ Maharashtra",
"918478", "Kamalapur\,\ Karnataka",
"9171977", "Mohadi\,\ Maharashtra",
"9171715", "Gond\ Pipri\,\ Maharashtra",
"9174872", "Begamganj\,\ Madhya\ Pradesh",
"9176523", "Shahdol\,\ Madhya\ Pradesh",
"91795", "Ahmedabad\ Local\,\ Gujarat",
"9163243", "Nawada\,\ Bihar",
"9166716", "Rajkhariar\,\ Odisha",
"918317", "Belgaum\,\ Karnataka",
"9171396", "Kurkheda\,\ Maharashtra",
"912794", "Rajula\,\ Gujarat",
"918749", "Madhira\,\ Andhra\ Pradesh",
"915362", "Sultanpur\,\ Uttar\ Pradesh",
"9176468", "Nainpur\,\ Madhya\ Pradesh",
"9171004", "Kuhi\,\ Maharashtra",
"9171966", "Arjuni\ Morgaon\,\ Maharashtra",
"916573", "Jamshedpur\,\ Bihar",
"911584", "Nagaur\/Mundwa\ Marwar\,\ Rajasthan",
"911505", "Padampur\,\ Rajasthan",
"9174539", "Baran\,\ Rajasthan",
"9187597", "Outsarangapalle\,\ Andhra\ Pradesh",
"912117", "Daund\,\ Maharashtra",
"9127176", "Sanand\,\ Gujarat",
"9174218", "Manasa\,\ Madhya\ Pradesh",
"9171833", "Tumsar\,\ Maharashtra",
"912162", "Satara\,\ Maharashtra",
"9176267", "Vijayraghogarh\,\ Madhya\ Pradesh",
"911795", "Nalagarh\,\ Himachal\ Pradesh",
"9174855", "Udaipura\,\ Madhya\ Pradesh",
"916805", "Berhampur\,\ Odisha",
"915317", "Dalmau\,\ Uttar\ Pradesh",
"913253", "Manbazar\,\ West\ Bengal",
"912585", "Yawal\,\ Maharashtra",
"9174656", "Sapotra\,\ Rajasthan",
"9167326", "Hindol\,\ Odisha",
"917472", "Bundi\,\ Rajasthan",
"9166857", "Sohela\,\ Odisha",
"9164265", "Rajmahal\,\ Bihar",
"9168172", "R\.Udayigiri\,\ Odisha",
"917914", "Ahmedabad\ Local\,\ Gujarat",
"9176497", "Kakaiya\,\ Madhya\ Pradesh",
"9171416", "Betul\,\ Madhya\ Pradesh",
"917741", "Kawardha\,\ Madhya\ Pradesh",
"914118", "Tiruttani\,\ Tamil\ Nadu",
"91204", "Pune\,\ Maharashtra",
"912893", "Jodia\,\ Gujarat",
"917659", "Jaithari\,\ Madhya\ Pradesh",
"912825", "Gondal\,\ Gujarat",
"912775", "Khedbrahma\,\ Gujarat",
"9165605", "Patan\,\ Bihar",
"9166415", "Deodgarh\,\ Odisha",
"9171657", "Saunsar\,\ Madhya\ Pradesh",
"9163457", "Jamui\,\ Bihar",
"915731", "Garhmukteshwar\,\ Uttar\ Pradesh",
"9161114", "Hilsa\,\ Bihar",
"9168577", "Gunupur\,\ Odisha",
"915440", "Mirzapur\/Hallia\,\ Uttar\ Pradesh",
"9176298", "Pushprajgarh\,\ Madhya\ Pradesh",
"9167864", "Chandbali\,\ Odisha",
"913522", "Balurghat\,\ West\ Bengal",
"918672", "Bandar\/Machilipatnam\,\ Andhra\ Pradesh",
"9171862", "Sakoli\,\ Maharashtra",
"9167486", "Bhubaneshwar\,\ Odisha",
"917368", "Ghatia\,\ Madhya\ Pradesh",
"915614", "Jarar\,\ Uttar\ Pradesh",
"9174583", "Pipalda\/Sumerganj\ Mandi\,\ Rajasthan",
"911824", "Phagwara\,\ Punjab",
"9176342", "Lamta\,\ Madhya\ Pradesh",
"9174967", "Pichhore\,\ Madhya\ Pradesh",
"9168622", "Gudari\,\ Odisha",
"9161587", "Sonepur\,\ Bihar",
"9162454", "Gogri\,\ Bihar",
"911281", "Jatusana\,\ Haryana",
"918630", "Guntur\,\ Andhra\ Pradesh",
"914862", "Thodupuzha\,\ Kerala",
"9162283", "Pupri\,\ Bihar",
"9161836", "Buxar\,\ Bihar",
"9161806", "Adhaura\,\ Bihar",
"9174260", "Sitamau\,\ Madhya\ Pradesh",
"918633", "Guntur\,\ Andhra\ Pradesh",
"911991", "Reasi\,\ Jammu\ And\ Kashmir",
"9166572", "Kantabhanji\,\ Odisha",
"916124", "Patna\,\ Bihar",
"9167246", "Jagatsinghpur\,\ Odisha",
"9171827", "Gondia\,\ Maharashtra",
"9174319", "Aklera\,\ Rajasthan",
"9176410", "Niwas\,\ Madhya\ Pradesh",
"9168667", "Umerkote\,\ Odisha",
"9174922", "Shivpuri\,\ Madhya\ Pradesh",
"912952", "Rajsamand\/Kankorli\,\ Rajasthan",
"918208", "Udupi\,\ Karnataka",
"917819", "Pandishankar\,\ Madhya\ Pradesh",
"9189464", "Pathapatnam\/Hiramandalam\,\ Andhra\ Pradesh",
"915443", "Chunur\,\ Uttar\ Pradesh",
"9162443", "Khagaria\,\ Bihar",
"9165635", "Bhawanathpur\,\ Bihar",
"914885", "Kunnamkulam\,\ Kerala",
"9172876", "Gogaon\,\ Madhya\ Pradesh",
"9165587", "Dumri\(Isribazar\)\,\ Bihar",
"915854", "Sandila\,\ Uttar\ Pradesh",
"9165963", "Noamundi\,\ Bihar",
"9165836", "Kharsawa\,\ Bihar",
"9174364", "Hindoli\,\ Rajasthan",
"918811", "Polavaram\,\ Andhra\ Pradesh",
"9165252", "Simdega\,\ Bihar",
"9165932", "Manoharpur\,\ Bihar",
"915645", "Rupbas\,\ Rajasthan",
"911636", "Moga\,\ Punjab",
"9175966", "Gyraspur\,\ Madhya\ Pradesh",
"911870", "Jugial\,\ Punjab",
"913865", "Phek\,\ Nagaland",
"9162792", "Barauni\,\ Bihar",
"9171803", "Salekasa\,\ Maharashtra",
"912562", "Dhule\,\ Maharashtra",
"9177066", "Gariaband\,\ Madhya\ Pradesh",
"9174826", "Raisen\,\ Madhya\ Pradesh",
"9174509", "Sangod\,\ Rajasthan",
"9167355", "Telkoi\,\ Odisha",
"912185", "Malsuras\,\ Maharashtra",
"9171034", "Butibori\,\ Maharashtra",
"9174625", "Sawaimadhopur\,\ Rajasthan",
"9165413", "Chatra\,\ Bihar",
"912971", "Pindwara\,\ Rajasthan",
"91581", "Bareilly\,\ Uttar\ Pradesh",
"918645", "Mangalagiri\,\ Andhra\ Pradesh",
"9176294", "Pushprajgarh\,\ Madhya\ Pradesh",
"918935", "Paderu\,\ Andhra\ Pradesh",
"9164535", "Araria\,\ Bihar",
"9163254", "Pakribarwan\,\ Bihar",
"918304", "Kundgol\,\ Karnataka",
"918385", "Bhatkal\,\ Karnataka",
"9165275", "Kolebira\,\ Bihar",
"9162724", "Darbhanga\,\ Bihar",
"9177077", "Bagbahera\,\ Madhya\ Pradesh",
"9163483", "Mallehpur\,\ Bihar",
"9171683", "Harrai\,\ Madhya\ Pradesh",
"9165544", "Rajdhanwar\,\ Bihar",
"9168445", "Kantamal\,\ Odisha",
"9167613", "Chhendipada\,\ Odisha",
"9171374", "Desaiganj\,\ Maharashtra",
"912471", "Tuljapur\,\ Maharashtra",
"918753", "Outsarangapalle\,\ Andhra\ Pradesh",
"917445", "Ladpura\/Kota\,\ Rajasthan",
"9161553", "Ekma\,\ Bihar",
"9174557", "Digod\/Sultanpur\,\ Rajasthan",
"912742", "Palanpur\,\ Gujarat",
"917202", "Ralegaon\,\ Maharashtra",
"9174500", "Sangod\,\ Rajasthan",
"914258", "Dharampuram\,\ Tamil\ Nadu",
"915943", "Khatima\,\ Uttar\ Pradesh",
"9174310", "Aklera\,\ Rajasthan",
"9176419", "Niwas\,\ Madhya\ Pradesh",
"912452", "Parbhani\,\ Maharashtra",
"9184537", "Medak\,\ Andhra\ Pradesh",
"9163323", "Nabinagar\,\ Bihar",
"9162582", "Areraj\,\ Bihar",
"918443", "Shorapur\,\ Karnataka",
"9171165", "Umrer\,\ Maharashtra",
"9171556", "Seloo\,\ Maharashtra",
"917755", "Mungeli\,\ Madhya\ Pradesh",
"9172867", "Khetia\,\ Madhya\ Pradesh",
"9174269", "Sitamau\,\ Madhya\ Pradesh",
"911491", "Nasirabad\,\ Rajasthan",
"9165393", "Bolwa\,\ Bihar",
"9164774", "Triveniganj\,\ Bihar",
"9166555", "Titlagarh\,\ Odisha",
"912679", "Jhalod\,\ Gujarat",
"912738", "Santalpur\,\ Gujarat",
"9176537", "Bandhavgarh\,\ Madhya\ Pradesh",
"9161885", "Rohtas\,\ Bihar",
"9176464", "Nainpur\,\ Madhya\ Pradesh",
"9168676", "Jharigan\,\ Odisha",
"911429", "Bassi\,\ Rajasthan",
"91431", "Tiruchchirappalli\,\ Tamil\ Nadu",
"9162514", "Bagaha\,\ Bihar",
"918854", "Tuni\,\ Andhra\ Pradesh",
"9174214", "Manasa\,\ Madhya\ Pradesh",
"9162546", "Bettiah\,\ Bihar",
"9174246", "Malhargarh\,\ Madhya\ Pradesh",
"913848", "Thonbal\,\ Manipur",
"9167922", "Baripada\,\ Odisha",
"918267", "Kadur\,\ Karnataka",
"9165306", "Bundu\,\ Bihar",
"9163315", "Imamganj\,\ Bihar",
"9176335", "Waraseoni\,\ Madhya\ Pradesh",
"918212", "Mysore\,\ Karnataka",
"918680", "Nidamanur\/Hillcolony\,\ Andhra\ Pradesh",
"912763", "Vijapur\,\ Gujarat",
"9164733", "Supaul\,\ Bihar",
"9171737", "Rajura\,\ Maharashtra",
"915274", "Tanda\/Baskhari\,\ Uttar\ Pradesh",
"9171362", "Etapalli\,\ Maharashtra",
"911534", "Kolayat\,\ Rajasthan",
"9164762", "Madhepura\,\ Bihar",
"915962", "Almora\,\ Uttar\ Pradesh",
"9181700", "Alur\,\ Karnataka",
"9164337", "Jamtara\,\ Bihar",
"9181757", "Holenarasipur\,\ Karnataka",
"913870", "Ukhrursouth\/Kassemkhulen\,\ Manipur",
"9171333", "Aheri\,\ Maharashtra",
"911250", "Charkhidadri\,\ Haryana",
"918462", "Nizamabad\,\ Andhra\ Pradesh",
"913011", "Jaisalmer\/Pasewar\,\ Rajasthan",
"9168592", "Motu\,\ Odisha",
"9175940", "Ganjbasoda\,\ Madhya\ Pradesh",
"9166753", "T\.Rampur\,\ Odisha",
"918417", "Chevella\,\ Andhra\ Pradesh",
"9164243", "Banka\,\ Bihar",
"9165516", "Barkagaon\,\ Bihar",
"9177040", "Deobhog\,\ Madhya\ Pradesh",
"9167826", "Balasore\,\ Odisha",
"9167625", "Dhenkanal\,\ Odisha",
"9176472", "Ghughari\,\ Madhya\ Pradesh",
"9174355", "Gangdhar\,\ Rajasthan",
"917866", "Konta\,\ Madhya\ Pradesh",
"9168197", "Surada\,\ Odisha",
"918378", "Savanur\,\ Karnataka",
"917662", "Rewa\,\ Madhya\ Pradesh",
"9174868", "Bareli\,\ Madhya\ Pradesh",
"9175949", "Ganjbasoda\,\ Madhya\ Pradesh",
"9168402", "Tumudibandha\,\ Odisha",
"9173218", "Sanwer\,\ Madhya\ Pradesh",
"912877", "Talala\,\ Gujarat",
"913621", "Boko\,\ Assam",
"9181709", "Alur\,\ Karnataka",
"918571", "Madanapalli\,\ Andhra\ Pradesh",
"9171154", "Mouda\,\ Maharashtra",
"9168524", "Koraput\,\ Odisha",
"915462", "Azamgarh\,\ Uttar\ Pradesh",
"9166437", "Barkot\,\ Odisha",
"9176455", "Karanjia\,\ Madhya\ Pradesh",
"9174613", "Mahuwa\,\ Rajasthan",
"9165425", "Bokaro\,\ Bihar",
"918223", "K\.R\.Nagar\,\ Karnataka",
"9174372", "Nainwa\,\ Rajasthan",
"916745", "Bhubaneshwar\,\ Odisha",
"917789", "Bhairongarh\,\ Madhya\ Pradesh",
"9171896", "Amagaon\,\ Maharashtra",
"9167557", "Khurda\,\ Odisha",
"9163495", "Jhajha\,\ Bihar",
"9171695", "Batkakhapa\,\ Madhya\ Pradesh",
"9176817", "Jatara\,\ Madhya\ Pradesh",
"9175928", "Vidisha\,\ Madhya\ Pradesh",
"918917", "Visakhapatnam\,\ Andhra\ Pradesh",
"9177049", "Deobhog\,\ Madhya\ Pradesh",
"9164616", "Raniganj\,\ Bihar",
"9167282", "Jajapur\ Town\,\ Odisha",
"914728", "Nedumangad\,\ Kerala",
"9171453", "Chicholi\,\ Madhya\ Pradesh",
"9161893", "Bhabhua\,\ Bihar",
"917372", "Rajgarh\,\ Madhya\ Pradesh",
"918668", "Vijayawada\,\ Andhra\ Pradesh",
"9171992", "Deori\,\ Maharashtra",
"914177", "Arkonam\,\ Tamil\ Nadu",
"917801", "Deosar\,\ Madhya\ Pradesh",
"9180", "Bangalore\,\ Karnataka",
"9163265", "Sherghati\,\ Bihar",
"912140", "Mangaon\,\ Maharashtra",
"917225", "Tiwasa\,\ Maharashtra",
"915680", "Bharthana\,\ Uttar\ Pradesh",
"915212", "Malihabad\,\ Uttar\ Pradesh",
"918359", "Indi\,\ Karnataka",
"9165385", "Torpa\,\ Bihar",
"911897", "Pangi\/Killar\,\ Himachal\ Pradesh",
"918552", "Gooty\/Guntakal\,\ Andhra\ Pradesh",
"913756", "Sadiya\,\ Assam",
"9178081", "\`",
"918274", "Virajpet\,\ Karnataka",
"9167214", "Narsinghpur\,\ Odisha",
"9168463", "Baliguda\,\ Odisha",
"9173922", "Jhabua\,\ Madhya\ Pradesh",
"9165893", "Jhinkpani\,\ Bihar",
"915343", "Patti\,\ Uttar\ Pradesh",
"9166423", "Kuchinda\,\ Odisha",
"9167976", "Jashipur\,\ Odisha",
"914577", "Tirupathur\,\ Tamil\ Nadu",
"9161146", "Jahanabad\,\ Bihar",
"916714", "Cuttack\,\ Odisha",
"9174810", "Gairatganj\,\ Madhya\ Pradesh",
"915683", "Auraiya\,\ Uttar\ Pradesh",
"9162766", "Madhubani\,\ Bihar",
"912661", "Naswadi\,\ Gujarat",
"9171444", "Atner\,\ Madhya\ Pradesh",
"917290", "Badwani\,\ Madhya\ Pradesh",
"912143", "Pen\,\ Maharashtra",
"9166787", "Nowparatan\,\ Odisha",
"913712", "Tezpur\,\ Assam",
"918516", "Dronachalam\,\ Andhra\ Pradesh",
"91491", "Palakkad\,\ Kerala",
"918152", "Kolar\,\ Karnataka",
"9176386", "Damoh\,\ Madhya\ Pradesh",
"9175212", "Seondha\,\ Madhya\ Pradesh",
"918335", "Ramdurg\,\ Karnataka",
"9168164", "Mohana\,\ Odisha",
"9164542", "Purnea\,\ Bihar",
"9165617", "Garhwa\,\ Bihar",
"9166407", "Bagdihi\,\ Odisha",
"912469", "Kinwat\,\ Maharashtra",
"9181739", "Sakleshpur\,\ Karnataka",
"9165456", "Mandu\,\ Bihar",
"9176426", "Mandla\,\ Madhya\ Pradesh",
"9171143", "Ramtek\,\ Maharashtra",
"9168432", "Puruna\ Katak\,\ Odisha",
"9171874", "Goregaon\,\ Maharashtra",
"918404", "Marturu\,\ Andhra\ Pradesh",
"9164254", "Katoria\,\ Bihar",
"917857", "Bacheli\,\ Madhya\ Pradesh",
"918485", "Aurad\,\ Karnataka",
"911346", "Pauri\/Bubakhal\,\ Uttarakhand",
"913584", "Mekhliganj\,\ West\ Bengal",
"9171487", "Prabha\ Pattan\,\ Madhya\ Pradesh",
"915335", "Soraon\,\ Uttar\ Pradesh",
"911882", "Hoshiarpur\,\ Punjab",
"9165945", "Baharagora\,\ Bihar",
"915171", "Garauth\,\ Uttar\ Pradesh",
"911686", "Safidon\,\ Haryana",
"9176515", "Jaisinghnagar\,\ Madhya\ Pradesh",
"912135", "Rajgurunagar\,\ Maharashtra",
"9171723", "Chandrapur\,\ Maharashtra",
"9161516", "Sidhawalia\,\ Bihar",
"917685", "Nowgaon\,\ Madhya\ Pradesh",
"9174706", "Bundi\,\ Rajasthan",
"911253", "Tohsham\,\ Haryana",
"917604", "Hatta\,\ Madhya\ Pradesh",
"9167417", "Bhubaneshwar\,\ Odisha",
"913873", "Thinghat\,\ Manipur",
"912371", "Wathar\,\ Maharashtra",
"912969", "Bhinmal\,\ Rajasthan",
"9174326", "Jhalawar\,\ Rajasthan",
"9181730", "Sakleshpur\,\ Karnataka",
"9167656", "Palla\ Hara\,\ Odisha",
"913795", "Basar\,\ Arunachal\ Pradesh",
"9162465", "Jainagar\,\ Bihar",
"9174819", "Gairatganj\,\ Madhya\ Pradesh",
"9171707", "Chumur\,\ Maharashtra",
"912559", "Yeola\,\ Maharashtra",
"9171513", "Samudrapur\,\ Maharashtra",
"9164517", "Barsoi\,\ Bihar",
"9175924", "Vidisha\,\ Madhya\ Pradesh",
"9162295", "Bidupur\,\ Bihar",
"918683", "Hazurnagar\,\ Andhra\ Pradesh",
"9164323", "Deoghar\,\ Bihar",
"9176305", "Katangi\,\ Madhya\ Pradesh",
"9174595", "Ramganj\ Mandi\,\ Rajasthan",
"912352", "Ratnagiri\,\ Maharashtra",
"9171327", "Gadchiroli\,\ Maharashtra",
"9162777", "Phulparas\,\ Bihar",
"918256", "Belthangady\,\ Karnataka",
"913774", "Golaghat\,\ Assam",
"913824", "Kailsahar\,\ Tripura",
"9165336", "Basia\,\ Bihar",
"9173214", "Sanwer\,\ Madhya\ Pradesh",
"9174864", "Bareli\,\ Madhya\ Pradesh",
"9167967", "Karanjia\,\ Odisha",
"911522", "Bikaner\/Jamsar\,\ Rajasthan",
"9167583", "Nimapara\,\ Odisha",
"9165642", "Nagarutari\,\ Bihar",
"914564", "Paramakudi\,\ Tamil\ Nadu",
"9174245", "Malhargarh\,\ Madhya\ Pradesh",
"9162274", "Mahua\,\ Bihar",
"9168113", "Chhatrapur\,\ Odisha",
"9174574", "Mangrol\,\ Rajasthan",
"9162545", "Bettiah\,\ Bihar",
"915688", "Etawah\,\ Uttar\ Pradesh",
"912524", "Murbad\,\ Maharashtra",
"9163316", "Imamganj\,\ Bihar",
"9175954", "Nateran\,\ Madhya\ Pradesh",
"9171357", "Chamorshi\,\ Maharashtra",
"9165305", "Bundu\,\ Bihar",
"912355", "Chiplun\,\ Maharashtra",
"9164353", "Pakur\,\ Bihar",
"9181733", "Sakleshpur\,\ Karnataka",
"912847", "Gadhada\,\ Gujarat",
"9177054", "Kurud\,\ Madhya\ Pradesh",
"9161842", "Sasaram\,\ Bihar",
"9176336", "Waraseoni\,\ Madhya\ Pradesh",
"9163277", "Rafiganj\,\ Bihar",
"914636", "Sankarankovil\,\ Tamil\ Nadu",
"9166737", "Jayapatna\,\ Odisha",
"911593", "Khetri\,\ Rajasthan",
"912148", "Karjat\,\ Maharashtra",
"918541", "Achampet\,\ Andhra\ Pradesh",
"918660", "Vijayawada\,\ Andhra\ Pradesh",
"918482", "Bidar\,\ Karnataka",
"9164224", "Godda\,\ Bihar",
"915332", "Phoolpur\,\ Uttar\ Pradesh",
"918706", "Warangal\,\ Andhra\ Pradesh",
"911804", "Panipat\,\ Haryana",
"911885", "Balachaur\,\ Punjab",
"918244", "Mangalore\,\ Karnataka",
"9168414", "Boudh\,\ Odisha",
"9171753", "Bhadrawati\,\ Maharashtra",
"9168482", "Kotagarh\,\ Odisha",
"9165515", "Barkagaon\,\ Bihar",
"9164757", "S\.Bakhtiarpur\,\ Bihar",
"9167825", "Balasore\,\ Odisha",
"912132", "Junnar\,\ Maharashtra",
"9166247", "Rajgangpur\,\ Odisha",
"9181762", "Cannarayapatna\,\ Karnataka",
"917682", "Chhatarpur\,\ Madhya\ Pradesh",
"91222", "Mumbai",
"913792", "Daporizo\,\ Arunachal\ Pradesh",
"9167626", "Dhenkanal\,\ Odisha",
"918596", "Markapur\,\ Andhra\ Pradesh",
"9174356", "Gangdhar\,\ Rajasthan",
"914147", "Tindivanam\,\ Tamil\ Nadu",
"9164292", "Kahalgaon\,\ Bihar",
"918332", "Gokak\,\ Karnataka",
"91131", "Muzaffarnagar\,\ Uttar\ Pradesh",
"918539", "Koppal\,\ Karnataka",
"9171564", "Talegaokarangal\,\ Maharashtra",
"918370", "Kalghatagi\,\ Karnataka",
"9167562", "Balugaon\,\ Odisha",
"9175383", "Ambah\,\ Madhya\ Pradesh",
"915244", "Haidergarh\,\ Uttar\ Pradesh",
"9174668", "Bonli\,\ Rajasthan",
"9171437", "Bhainsdehi\,\ Madhya\ Pradesh",
"913878", "Chakpikarong\,\ Manipur",
"9171895", "Amagaon\,\ Maharashtra",
"9176456", "Karanjia\,\ Madhya\ Pradesh",
"9165426", "Bokaro\,\ Bihar",
"917234", "Digras\,\ Maharashtra",
"9168543", "Jeypore\,\ Odisha",
"9161817", "Piro\,\ Bihar",
"9174813", "Gairatganj\,\ Madhya\ Pradesh",
"917769", "Bagicha\,\ Madhya\ Pradesh",
"9163496", "Jhajha\,\ Bihar",
"9171696", "Batkakhapa\,\ Madhya\ Pradesh",
"911258", "Kalanaur\,\ Haryana",
"9173952", "Sondhwa\,\ Madhya\ Pradesh",
"9173232", "Punasa\,\ Madhya\ Pradesh",
"917531", "Baroda\,\ Madhya\ Pradesh",
"9164615", "Raniganj\,\ Bihar",
"9181938", "Hiriyur\,\ Karnataka",
"9166453", "Jharsuguda\,\ Odisha",
"9163266", "Sherghati\,\ Bihar",
"9174697", "Hindaun\,\ Rajasthan",
"916416", "Bhagalpur\,\ Bihar",
"9167533", "Nayagarh\,\ Odisha",
"9175381", "Ambah\,\ Madhya\ Pradesh",
"918761", "Sathupalli\,\ Andhra\ Pradesh",
"915541", "Domariyaganj\,\ Uttar\ Pradesh",
"913715", "Gohpur\,\ Assam",
"9165386", "Torpa\,\ Bihar",
"918155", "Gowribidanur\,\ Karnataka",
"9166212", "Hemgiri\,\ Odisha",
"91462", "Tirunelvelli\,\ Tamil\ Nadu",
"9174610", "Mahuwa\,\ Rajasthan",
"91268", "Nadiad\,\ Gujarat",
"9167975", "Jashipur\,\ Odisha",
"9171423", "Bhimpur\,\ Madhya\ Pradesh",
"9162765", "Madhubani\,\ Bihar",
"9168217", "Bhanjanagar\,\ Odisha",
"917375", "Narsingharh\,\ Madhya\ Pradesh",
"913843", "Karimganj\,\ Assam",
"913787", "Seppa\,\ Arunachal\ Pradesh",
"9161145", "Jahanabad\,\ Bihar",
"917222", "Chandurrly\,\ Maharashtra",
"9165693", "Garu\,\ Bihar",
"912341", "Kavathemankal\,\ Maharashtra",
"918497", "Kalyandurg\,\ Andhra\ Pradesh",
"9166444", "Rairakhol\,\ Odisha",
"911376", "Tehri\,\ Uttarakhand",
"9164783", "Saharsa\,\ Bihar",
"9171787", "Sinderwahi\,\ Maharashtra",
"9178080", "\`",
"913454", "Kalna\,\ West\ Bengal",
"918324", "Goa",
"9176385", "Damoh\,\ Madhya\ Pradesh",
"9173202", "Pandhana\,\ Madhya\ Pradesh",
"9177058", "Kurud\,\ Madhya\ Pradesh",
"9162477", "Singhwara\,\ Bihar",
"918965", "Gajapathinagaram\,\ Andhra\ Pradesh",
"918139", "Turuvekere\,\ Karnataka",
"915465", "Phulpur\/Atrawlia\,\ Uttar\ Pradesh",
"9164387", "Madhupur\,\ Bihar",
"9168554", "Laxmipur\,\ Odisha",
"9171383", "Dhanora\,\ Maharashtra",
"9171124", "Katol\,\ Maharashtra",
"9167313", "Anandapur\,\ Odisha",
"9163474", "Chakai\,\ Bihar",
"9171674", "Amarwada\,\ Madhya\ Pradesh",
"9165455", "Mandu\,\ Bihar",
"9167672", "Barbil\,\ Odisha",
"9176425", "Mandla\,\ Madhya\ Pradesh",
"918373", "Ranebennur\,\ Karnataka",
"916742", "Bhubaneshwar\,\ Odisha",
"9174578", "Mangrol\,\ Rajasthan",
"9175958", "Nateran\,\ Madhya\ Pradesh",
"912489", "Karjat\,\ Maharashtra",
"918627", "Atmakur\,\ Andhra\ Pradesh",
"9167527", "Puri\,\ Odisha",
"9165817", "Bhandaria\,\ Bihar",
"91341", "Asansol\,\ West\ Bengal",
"916517", "Ranchi\,\ Bihar",
"914281", "Yercaud\,\ Tamil\ Nadu",
"915965", "Champawat\,\ Uttar\ Pradesh",
"911666", "Sirsa\,\ Haryana",
"9171744", "Mul\,\ Maharashtra",
"9181727", "Hassan\,\ Karnataka",
"9166487", "Patnagarh\,\ Odisha",
"911909", "Udaipur\,\ Himachal\ Pradesh",
"918465", "Yellareddy\,\ Andhra\ Pradesh",
"913564", "Alipurduar\,\ West\ Bengal",
"913835", "Saiha\,\ Mizoram",
"9165946", "Baharagora\,\ Bihar",
"9161515", "Sidhawalia\,\ Bihar",
"9166723", "Dharamgarh\,\ Odisha",
"9167263", "Jajapur\ Road\,\ Odisha",
"9174705", "Bundi\,\ Rajasthan",
"9176516", "Jaisinghnagar\,\ Madhya\ Pradesh",
"912989", "Chohtan\,\ Rajasthan",
"9164593", "Thakurganj\,\ Bihar",
"9174325", "Jhalawar\,\ Rajasthan",
"9167655", "Palla\ Hara\,\ Odisha",
"9165472", "Chavparan\,\ Bihar",
"918228", "H\.D\.Kote\,\ Karnataka",
"9162466", "Jainagar\,\ Bihar",
"918196", "Jagalur\,\ Karnataka",
"918663", "Vijayawada\,\ Andhra\ Pradesh",
"917126", "Nagpur\,\ Maharashtra",
"9166707", "Bhawanipatna\,\ Odisha",
"911590", "Merta\,\ Rajasthan",
"9166513", "Birmaharajpur\,\ Odisha",
"9167493", "Bhubaneshwar\,\ Odisha",
"9177043", "Deobhog\,\ Madhya\ Pradesh",
"9176306", "Katangi\,\ Madhya\ Pradesh",
"9174596", "Ramganj\ Mandi\,\ Rajasthan",
"9174619", "Mahuwa\,\ Rajasthan",
"9167952", "Udala\,\ Odisha",
"9167232", "Athgarh\,\ Odisha",
"9162296", "Bidupur\,\ Bihar",
"9165335", "Basia\,\ Bihar",
"9181703", "Alur\,\ Karnataka",
"9165842", "Bishrampur\,\ Bihar",
"915497", "Zamania\,\ Uttar\ Pradesh",
"918215", "Mysore\,\ Karnataka",
"9164344", "Dumka\,\ Bihar",
"9174664", "Bonli\,\ Rajasthan",
"9178089", "\`",
"9175943", "Ganjbasoda\,\ Madhya\ Pradesh",
"91326", "Dhanbad\,\ Bihar",
"9162543", "Bettiah\,\ Bihar",
"912632", "Valsad\,\ Gujarat",
"915453", "Shahganj\,\ Uttar\ Pradesh",
"9168634", "Bisam\ Cuttack\,\ Odisha",
"9168115", "Chhatrapur\,\ Odisha",
"912836", "Anjar\/Gandhidham\,\ Gujarat",
"9176510", "Jaisinghnagar\,\ Madhya\ Pradesh",
"9174243", "Malhargarh\,\ Madhya\ Pradesh",
"911858", "Ajnala\,\ Punjab",
"9164355", "Pakur\,\ Bihar",
"9181735", "Sakleshpur\,\ Karnataka",
"9165303", "Bundu\,\ Bihar",
"912670", "Shehra\,\ Gujarat",
"9166472", "Naktideul\,\ Odisha",
"9174904", "Pohari\,\ Madhya\ Pradesh",
"917834", "Sitapur\,\ Madhya\ Pradesh",
"917565", "Berasia\,\ Madhya\ Pradesh",
"916617", "Rourkela\,\ Odisha",
"911566", "Sri\ Dungargarh\/Sudsar\,\ Rajasthan",
"915844", "Powayan\,\ Uttar\ Pradesh",
"9165487", "Ichak\,\ Bihar",
"9174337", "Pachpahar\/Bhawanimandi\,\ Rajasthan",
"9164736", "Supaul\,\ Bihar",
"918735", "Bellampalli\,\ Andhra\ Pradesh",
"911420", "Baswa\/Bandikui\,\ Rajasthan",
"913664", "Hajo\,\ Assam",
"9166842", "Paikamal\,\ Odisha",
"9171336", "Aheri\,\ Maharashtra",
"917733", "Pawai\,\ Madhya\ Pradesh",
"9167644", "Anugul\,\ Odisha",
"9163442", "Monghyr\,\ Bihar",
"9171642", "Pandhurna\,\ Madhya\ Pradesh",
"912938", "Bali\,\ Rajasthan",
"911956", "Uri\,\ Jammu\ And\ Kashmir",
"914344", "Hosur\,\ Tamil\ Nadu",
"9171067", "Bhiwapur\,\ Maharashtra",
"918563", "Kamalapuram\/Yerraguntala\,\ Andhra\ Pradesh",
"916314", "Gaya\,\ Bihar",
"9166756", "T\.Rampur\,\ Odisha",
"9167823", "Balasore\,\ Odisha",
"9165513", "Barkagaon\,\ Bihar",
"9164246", "Banka\,\ Bihar",
"9171755", "Bhadrawati\,\ Maharashtra",
"9176300", "Katangi\,\ Madhya\ Pradesh",
"9174590", "Ramganj\ Mandi\,\ Rajasthan",
"9165327", "Giridih\,\ Bihar",
"9176357", "Lanji\,\ Madhya\ Pradesh",
"9174938", "Karera\,\ Madhya\ Pradesh",
"9174258", "Garoth\,\ Madhya\ Pradesh",
"9165444", "Gomia\,\ Bihar",
"912438", "Soyegaon\,\ Maharashtra",
"911501", "Srikaranpur\,\ Rajasthan",
"9175385", "Ambah\,\ Madhya\ Pradesh",
"9176309", "Katangi\,\ Madhya\ Pradesh",
"918188", "Honnali\,\ Karnataka",
"9174599", "Ramganj\ Mandi\,\ Rajasthan",
"9174616", "Mahuwa\,\ Rajasthan",
"915563", "Captanganj\/Khadda\,\ Uttar\ Pradesh",
"9171893", "Amagaon\,\ Maharashtra",
"912752", "Surendranagar\,\ Gujarat",
"918743", "Bhadrachalam\,\ Andhra\ Pradesh",
"9174815", "Gairatganj\,\ Madhya\ Pradesh",
"9168545", "Jeypore\,\ Odisha",
"9171772", "Brahmapuri\,\ Maharashtra",
"9164372", "Mahagama\,\ Bihar",
"9163417", "Seikhpura\,\ Bihar",
"9171617", "Parasia\,\ Madhya\ Pradesh",
"9166455", "Jharsuguda\,\ Odisha",
"9164613", "Raniganj\,\ Bihar",
"912771", "Bhiloda\,\ Gujarat",
"912821", "Jasdan\,\ Gujarat",
"9161896", "Bhabhua\,\ Bihar",
"9171456", "Chicholi\,\ Madhya\ Pradesh",
"917745", "Chhuriakala\,\ Madhya\ Pradesh",
"912442", "Bhir\,\ Maharashtra",
"913677", "Baithalangshu\,\ Assam",
"9166817", "Jujumura\,\ Odisha",
"9165874", "Chakardharpur\,\ Bihar",
"917810", "Uproda\,\ Madhya\ Pradesh",
"918844", "Kakinada\,\ Andhra\ Pradesh",
"911285", "Mohindergarh\,\ Haryana",
"9167535", "Nayagarh\,\ Odisha",
"9176564", "Kannodi\,\ Madhya\ Pradesh",
"911746", "Kaithal\,\ Haryana",
"9176437", "Bijadandi\,\ Madhya\ Pradesh",
"915735", "Sikandrabad\,\ Uttar\ Pradesh",
"9167687", "Parajang\,\ Odisha",
"9161154", "Danapur\,\ Bihar",
"9171425", "Bhimpur\,\ Madhya\ Pradesh",
"9168466", "Baliguda\,\ Odisha",
"9176407", "Shahpur\,\ Madhya\ Pradesh",
"9167973", "Jashipur\,\ Odisha",
"9166426", "Kuchinda\,\ Odisha",
"918778", "Tirupathi\,\ Andhra\ Pradesh",
"9174359", "Gangdhar\,\ Rajasthan",
"9176450", "Karanjia\,\ Madhya\ Pradesh",
"9165896", "Jhinkpani\,\ Bihar",
"9174147", "Jaora\,\ Madhya\ Pradesh",
"9161874", "Mohania\,\ Bihar",
"9165695", "Garu\,\ Bihar",
"9161143", "Jahanabad\,\ Bihar",
"911995", "Kishtwar\,\ Jammu\ And\ Kashmir",
"9162763", "Madhubani\,\ Bihar",
"911923", "Samba\,\ Jammu\ And\ Kashmir",
"917813", "Barpalli\,\ Madhya\ Pradesh",
"9164785", "Saharsa\,\ Bihar",
"9162242", "Hajipur\,\ Bihar",
"918639", "Guntur\,\ Andhra\ Pradesh",
"918450", "Andole\/Jogipet\,\ Andhra\ Pradesh",
"911262", "Rohtak\,\ Haryana",
"9176383", "Damoh\,\ Madhya\ Pradesh",
"912994", "Pokhran\,\ Rajasthan",
"9174542", "Chhipaborad\,\ Rajasthan",
"912363", "Sawantwadi\,\ Maharashtra",
"913861", "Tuengsang\,\ Nagaland",
"9171094", "Kamptee\,\ Maharashtra",
"9163364", "Rajauli\,\ Bihar",
"918740", "Aswaraopet\,\ Andhra\ Pradesh",
"9171385", "Dhanora\,\ Maharashtra",
"915641", "Deeg\,\ Rajasthan",
"9176339", "Waraseoni\,\ Madhya\ Pradesh",
"91452", "Madurai\,\ Tamil\ Nadu",
"9165284", "Khunti\,\ Bihar",
"918588", "Vaimpalli\,\ Andhra\ Pradesh",
"912975", "Reodar\,\ Rajasthan",
"91794", "Ahmedabad\ Local\,\ Gujarat",
"912716", "Dehgam\,\ Gujarat",
"9176423", "Mandla\,\ Madhya\ Pradesh",
"9165453", "Mandu\,\ Bihar",
"9162732", "Jhajharpur\,\ Bihar",
"9167315", "Anandapur\,\ Odisha",
"912181", "Akkalkot\,\ Maharashtra",
"911467", "Kekri\,\ Rajasthan",
"9171146", "Ramtek\,\ Maharashtra",
"9174908", "Pohari\,\ Madhya\ Pradesh",
"9171022", "Parseoni\,\ Maharashtra",
"915740", "Aliganj\/Ganjdundwara\,\ Uttar\ Pradesh",
"9176330", "Waraseoni\,\ Madhya\ Pradesh",
"918381", "Ron\,\ Karnataka",
"918426", "Telgi\,\ Karnataka",
"9176568", "Kannodi\,\ Madhya\ Pradesh",
"918931", "Yelamanchili\,\ Andhra\ Pradesh",
"911693", "Barwala\,\ Haryana",
"918560", "Jammalamadugu\,\ Andhra\ Pradesh",
"9165362", "Palkot\,\ Bihar",
"918641", "Sattenapalli\,\ Andhra\ Pradesh",
"911474", "Begun\,\ Rajasthan",
"917772", "Wadrainagar\,\ Madhya\ Pradesh",
"9171726", "Chandrapur\,\ Maharashtra",
"9166725", "Dharamgarh\,\ Odisha",
"9167265", "Jajapur\ Road\,\ Odisha",
"9174517", "Atru\,\ Rajasthan",
"913243", "Khatra\,\ West\ Bengal",
"917822", "Sidhi\,\ Madhya\ Pradesh",
"9161513", "Sidhawalia\,\ Bihar",
"912624", "Fortsongadh\,\ Gujarat",
"917730", "Ajaigarh\,\ Madhya\ Pradesh",
"9163282", "Daudnagar\,\ Bihar",
"9161327", "Barh\,\ Bihar",
"914328", "Perambalur\,\ Tamil\ Nadu",
"9167653", "Palla\ Hara\,\ Odisha",
"912475", "Omerga\,\ Maharashtra",
"9174323", "Jhalawar\,\ Rajasthan",
"9164595", "Thakurganj\,\ Bihar",
"9167495", "Bhubaneshwar\,\ Odisha",
"9177045", "Deobhog\,\ Madhya\ Pradesh",
"911423", "Amber\/Chomu\,\ Rajasthan",
"9166515", "Birmaharajpur\,\ Odisha",
"911495", "Mandawar\,\ Rajasthan",
"91205", "Pune\,\ Maharashtra",
"9171516", "Samudrapur\,\ Maharashtra",
"917751", "Pendra\,\ Madhya\ Pradesh",
"917582", "Sagar\,\ Madhya\ Pradesh",
"9165247", "Gumla\,\ Bihar",
"9174307", "Khanpur\,\ Rajasthan",
"9174350", "Gangdhar\,\ Rajasthan",
"9176459", "Karanjia\,\ Madhya\ Pradesh",
"9174701", "Bundi\,\ Rajasthan",
"9164326", "Deoghar\,\ Bihar",
"9174934", "Karera\,\ Madhya\ Pradesh",
"913806", "Chowkhem\,\ Arunachal\ Pradesh",
"9174254", "Garoth\,\ Madhya\ Pradesh",
"9162554", "Raxaul\,\ Bihar",
"912673", "Dahod\,\ Gujarat",
"9181705", "Alur\,\ Karnataka",
"9165333", "Basia\,\ Bihar",
"915949", "Kichha\/Bazpur\,\ Uttar\ Pradesh",
"912327", "Gadhinglaj\,\ Maharashtra",
"9167586", "Nimapara\,\ Odisha",
"9175945", "Ganjbasoda\,\ Madhya\ Pradesh",
"915450", "Kerakat\,\ Uttar\ Pradesh",
"9168477", "G\.Udayagiri\,\ Odisha",
"9168604", "Boriguma\,\ Odisha",
"911492", "Laxmangarh\/Kherli\,\ Rajasthan",
"917585", "Rehli\,\ Madhya\ Pradesh",
"9174700", "Bundi\,\ Rajasthan",
"9168116", "Chhatrapur\,\ Odisha",
"912451", "Pathari\,\ Maharashtra",
"9167607", "Talcher\,\ Odisha",
"9163313", "Imamganj\,\ Bihar",
"9165597", "Simaria\,\ Bihar",
"918823", "Chintalapudi\,\ Andhra\ Pradesh",
"9171472", "Multai\,\ Madhya\ Pradesh",
"9181736", "Sakleshpur\,\ Karnataka",
"918773", "Tirupathi\,\ Andhra\ Pradesh",
"9164356", "Pakur\,\ Bihar",
"914367", "Mannargudi\,\ Tamil\ Nadu",
"9174320", "Jhalawar\,\ Rajasthan",
"9176429", "Mandla\,\ Madhya\ Pradesh",
"9174224", "Mandsaur\,\ Madhya\ Pradesh",
"9176448", "Dindori\,\ Madhya\ Pradesh",
"9176333", "Waraseoni\,\ Madhya\ Pradesh",
"912796", "Kunkawav\,\ Gujarat",
"9162524", "Motihari\,\ Bihar",
"917818", "Chandipara\,\ Madhya\ Pradesh",
"918209", "Udupi\,\ Karnataka",
"911586", "Nawa\/Kuchamancity\,\ Rajasthan",
"9164735", "Supaul\,\ Bihar",
"917794", "Gotegaon\,\ Madhya\ Pradesh",
"9171335", "Aheri\,\ Maharashtra",
"9162714", "Benipatti\,\ Bihar",
"918724", "Jagtial\,\ Andhra\ Pradesh",
"9171842", "Bhandara\,\ Maharashtra",
"9171052", "Narkhed\,\ Maharashtra",
"9167844", "Bhadrak\,\ Odisha",
"918180", "Basavapatna\,\ Karnataka",
"9176389", "Damoh\,\ Madhya\ Pradesh",
"9174947", "Kolaras\,\ Madhya\ Pradesh",
"9176362", "Baihar\,\ Madhya\ Pradesh",
"911826", "Phillaur\,\ Punjab",
"917916", "Ahmedabad\ Local\,\ Gujarat",
"9164245", "Banka\,\ Bihar",
"917201", "Kalamb\,\ Maharashtra",
"917775", "Surajpur\,\ Madhya\ Pradesh",
"9171756", "Bhadrawati\,\ Maharashtra",
"917825", "Berla\,\ Madhya\ Pradesh",
"912430", "Sillod\,\ Maharashtra",
"9166755", "T\.Rampur\,\ Odisha",
"9164574", "Korha\,\ Bihar",
"9165234", "Ghaghra\,\ Bihar",
"918583", "Sodam\,\ Andhra\ Pradesh",
"9162782", "Dalsinghsarai\,\ Bihar",
"9174353", "Gangdhar\,\ Rajasthan",
"9167623", "Dhenkanal\,\ Odisha",
"912472", "Osmanabad\,\ Maharashtra",
"9161357", "Bikram\,\ Bihar",
"915168", "Jalaun\,\ Uttar\ Pradesh",
"911698", "Ellenabad\,\ Haryana",
"915180", "Fatehpur\,\ Uttar\ Pradesh",
"915874", "Nighasan\/Dhaurehra\,\ Uttar\ Pradesh",
"915724", "Khair\,\ Uttar\ Pradesh",
"91183", "Amritsar\,\ Punjab",
"918616", "Nellore\,\ Andhra\ Pradesh",
"9176380", "Damoh\,\ Madhya\ Pradesh",
"918812", "Eluru\,\ Andhra\ Pradesh",
"9175386", "Ambah\,\ Madhya\ Pradesh",
"912972", "Sirohi\,\ Rajasthan",
"9176284", "Karpa\,\ Madhya\ Pradesh",
"9163232", "Dumraon\,\ Bihar",
"914323", "Kulithalai\,\ Tamil\ Nadu",
"9165423", "Bokaro\,\ Bihar",
"9174134", "Sailana\,\ Madhya\ Pradesh",
"9174615", "Mahuwa\,\ Rajasthan",
"9176453", "Karanjia\,\ Madhya\ Pradesh",
"9174816", "Gairatganj\,\ Madhya\ Pradesh",
"9172888", "Bhikangaon\,\ Madhya\ Pradesh",
"9168546", "Jeypore\,\ Odisha",
"912930", "Bilara\/Piparcity\,\ Rajasthan",
"9166772", "Narlaroad\,\ Odisha",
"912561", "Pimpalner\,\ Maharashtra",
"9163493", "Jhajha\,\ Bihar",
"912640", "Rajpipla\,\ Gujarat",
"9171693", "Batkakhapa\,\ Madhya\ Pradesh",
"9165407", "Govindpur\,\ Bihar",
"912739", "Vadgam\,\ Gujarat",
"9165674", "Barwadih\,\ Bihar",
"9161895", "Bhabhua\,\ Bihar",
"9171455", "Chicholi\,\ Madhya\ Pradesh",
"917266", "Jalgaonjamod\,\ Maharashtra",
"9174329", "Jhalawar\,\ Rajasthan",
"9176420", "Mandla\,\ Madhya\ Pradesh",
"9166456", "Jharsuguda\,\ Odisha",
"9174912", "Narwar\,\ Madhya\ Pradesh",
"912951", "Bhim\,\ Rajasthan",
"911428", "Dudu\,\ Rajasthan",
"9163263", "Sherghati\,\ Bihar",
"9171817", "Lakhandur\,\ Maharashtra",
"915823", "Aonla\,\ Uttar\ Pradesh",
"9174709", "Bundi\,\ Rajasthan",
"911992", "Udhampur\,\ Jammu\ And\ Kashmir",
"9167536", "Nayagarh\,\ Odisha",
"914259", "Pollachi\,\ Tamil\ Nadu",
"9167887", "Soro\,\ Odisha",
"9162592", "Pakridayal\,\ Bihar",
"914374", "Papanasam\,\ Tamil\ Nadu",
"9174348", "Pirawa\/Raipur\,\ Rajasthan",
"9161564", "Gopalganj\,\ Bihar",
"912678", "Devgadhbaria\,\ Gujarat",
"9165383", "Torpa\,\ Bihar",
"9166425", "Kuchinda\,\ Odisha",
"9185868", "Vayalpad\,\ Andhra\ Pradesh",
"9165895", "Jhinkpani\,\ Bihar",
"9171426", "Bhimpur\,\ Madhya\ Pradesh",
"9168465", "Baliguda\,\ Odisha",
"912445", "Kaij\,\ Maharashtra",
"9168684", "Nandapur\,\ Odisha",
"9165696", "Garu\,\ Bihar",
"911853", "Rayya\,\ Punjab",
"911282", "Narnaul\,\ Haryana",
"9164786", "Saharsa\,\ Bihar",
"9168612", "Malkangiri\,\ Odisha",
"913521", "Gangarampur\,\ West\ Bengal",
"9165564", "Tisri\,\ Bihar",
"918671", "Divi\/Challapalli\,\ Andhra\ Pradesh",
"917257", "Balapur\,\ Maharashtra",
"915732", "Bulandshahr\,\ Uttar\ Pradesh",
"9161124", "Biharsharif\,\ Bihar",
"9174387", "Keshoraipatan\/Patan\,\ Rajasthan",
"9165437", "Barhi\,\ Bihar",
"912643", "Valia\,\ Gujarat",
"9174228", "Mandsaur\,\ Madhya\ Pradesh",
"9176444", "Dindori\,\ Madhya\ Pradesh",
"912933", "Bali\/Sumerpur\,\ Rajasthan",
"918479", "Shahapur\,\ Karnataka",
"915361", "Musafirkhana\,\ Uttar\ Pradesh",
"912383", "Ausa\,\ Maharashtra",
"914320", "Aravakurichi\,\ Tamil\ Nadu",
"918856", "Amalapuram\,\ Andhra\ Pradesh",
"9171386", "Dhanora\,\ Maharashtra",
"913224", "Haldia\,\ West\ Bengal",
"9167277", "Kendrapara\,\ Odisha",
"911487", "Banera\,\ Rajasthan",
"9167316", "Anandapur\,\ Odisha",
"912755", "Sayla\,\ Gujarat",
"918568", "Pulivendla\,\ Andhra\ Pradesh",
"9174249", "Malhargarh\,\ Madhya\ Pradesh",
"915183", "Fatehpur\/Gazipur\,\ Uttar\ Pradesh",
"912161", "Vaduj\,\ Maharashtra",
"9171145", "Ramtek\,\ Maharashtra",
"9174344", "Pirawa\/Raipur\,\ Rajasthan",
"912433", "Gangapur\,\ Maharashtra",
"9165943", "Baharagora\,\ Bihar",
"912907", "Kherwara\,\ Rajasthan",
"9164664", "Kishanganj\,\ Bihar",
"918748", "V\.R\.Puram\,\ Andhra\ Pradesh",
"9167266", "Jajapur\ Road\,\ Odisha",
"916126", "Patna\,\ Bihar",
"9166726", "Dharamgarh\,\ Odisha",
"9171725", "Chandrapur\,\ Maharashtra",
"9174240", "Malhargarh\,\ Madhya\ Pradesh",
"9176513", "Jaisinghnagar\,\ Madhya\ Pradesh",
"9162463", "Jainagar\,\ Bihar",
"918183", "Sagar\,\ Karnataka",
"9164596", "Thakurganj\,\ Bihar",
"9182892", "Athani\,\ Karnataka",
"9176327", "Balaghat\,\ Madhya\ Pradesh",
"9165357", "Chainpur\,\ Bihar",
"915568", "Deoria\,\ Uttar\ Pradesh",
"9168647", "Mathili\,\ Odisha",
"9176288", "Karpa\,\ Madhya\ Pradesh",
"9162432", "Begusarai\,\ Bihar",
"9171515", "Samudrapur\,\ Maharashtra",
"9174138", "Sailana\,\ Madhya\ Pradesh",
"9177046", "Deobhog\,\ Madhya\ Pradesh",
"917369", "Tarana\,\ Madhya\ Pradesh",
"9167496", "Bhubaneshwar\,\ Odisha",
"9166516", "Birmaharajpur\,\ Odisha",
"91797", "Ahmedabad\ Local\,\ Gujarat",
"9161597", "Masrakh\,\ Bihar",
"9174593", "Ramganj\ Mandi\,\ Rajasthan",
"9164325", "Deoghar\,\ Bihar",
"9172884", "Bhikangaon\,\ Madhya\ Pradesh",
"9176303", "Katangi\,\ Madhya\ Pradesh",
"917562", "Sehore\,\ Madhya\ Pradesh",
"9162293", "Bidupur\,\ Bihar",
"918458", "Narsapur\,\ Andhra\ Pradesh",
"911634", "Abohar\,\ Punjab",
"918770", "Tirupathi\,\ Andhra\ Pradesh",
"9181706", "Alur\,\ Karnataka",
"917517", "Gwalior\,\ Madhya\ Pradesh",
"9176487", "Mawai\,\ Madhya\ Pradesh",
"9167637", "Athmallik\,\ Odisha",
"918732", "Adilabad\,\ Andhra\ Pradesh",
"914119", "Ponneri\,\ Tamil\ Nadu",
"917658", "Kotma\,\ Madhya\ Pradesh",
"916213", "Muzaffarpur\,\ Bihar",
"9167585", "Nimapara\,\ Odisha",
"9175946", "Ganjbasoda\,\ Madhya\ Pradesh",
"91171", "Ambala\,\ Haryana",
"915671", "Jasrana\,\ Uttar\ Pradesh",
"9168507", "Kalimela\,\ Odisha",
"9176566", "Kannodi\,\ Madhya\ Pradesh",
"915447", "Dudhi\,\ Uttar\ Pradesh",
"9167213", "Narsinghpur\,\ Odisha",
"9161156", "Danapur\,\ Bihar",
"916715", "Cuttack\,\ Odisha",
"9161565", "Gopalganj\,\ Bihar",
"918947", "Sompeta\,\ Andhra\ Pradesh",
"9166532", "Dunguripali\,\ Odisha",
"918191", "Holalkere\,\ Karnataka",
"918637", "Guntur\,\ Andhra\ Pradesh",
"912598", "Umrane\,\ Maharashtra",
"9165876", "Chakardharpur\,\ Bihar",
"914286", "Namakkal\,\ Tamil\ Nadu",
"9168102", "Khalikote\,\ Odisha",
"9181939", "Hiriyur\,\ Karnataka",
"9164287", "Nala\,\ Bihar",
"9161894", "Bhabhua\,\ Bihar",
"9165675", "Barwadih\,\ Bihar",
"9171454", "Chicholi\,\ Madhya\ Pradesh",
"9164552", "Forbesganj\,\ Bihar",
"9174135", "Sailana\,\ Madhya\ Pradesh",
"9174614", "Mahuwa\,\ Rajasthan",
"918334", "Mudalgi\,\ Karnataka",
"9165972", "Saraikela\/Adstyapur\,\ Bihar",
"9176285", "Karpa\,\ Madhya\ Pradesh",
"911469", "Tijara\,\ Rajasthan",
"917270", "Sonkatch\,\ Madhya\ Pradesh",
"9168523", "Koraput\,\ Odisha",
"9174682", "Khandar\,\ Rajasthan",
"9171153", "Mouda\,\ Maharashtra",
"9165446", "Gomia\,\ Bihar",
"917232", "Yeotmal\,\ Maharashtra",
"9174669", "Bonli\,\ Rajasthan",
"911606", "Kharar\,\ Punjab",
"9177037", "Manpur\,\ Madhya\ Pradesh",
"911802", "Panipat\,\ Haryana",
"9165235", "Ghaghra\,\ Bihar",
"911371", "Dunda\,\ Uttarakhand",
"918242", "Mangalore\,\ Karnataka",
"915334", "Meja\/Sirsa\,\ Uttar\ Pradesh",
"9174802", "Goharganj\,\ Madhya\ Pradesh",
"9166754", "T\.Rampur\,\ Odisha",
"9164575", "Korha\,\ Bihar",
"918484", "Bhalki\,\ Karnataka",
"918310", "Belgaum\,\ Karnataka",
"9164244", "Banka\,\ Bihar",
"918405", "Giddalur\,\ Andhra\ Pradesh",
"913794", "Tawang\,\ Arunachal\ Pradesh",
"9167646", "Anugul\,\ Odisha",
"9174660", "Bonli\,\ Rajasthan",
"914733", "Pathanamthitta\,\ Kerala",
"917605", "Patera\,\ Madhya\ Pradesh",
"912346", "Tasgaon\,\ Maharashtra",
"9166227", "Sundargarh\,\ Odisha",
"9175937", "Kurwai\,\ Madhya\ Pradesh",
"917684", "Baldeogarh\,\ Madhya\ Pradesh",
"9171334", "Aheri\,\ Maharashtra",
"9162715", "Benipatti\,\ Bihar",
"9167332", "Ghatgaon\,\ Odisha",
"9167845", "Bhadrak\,\ Odisha",
"9164734", "Supaul\,\ Bihar",
"912522", "Bhiwandi\,\ Maharashtra",
"9168497", "Daringbadi\,\ Odisha",
"9162525", "Motihari\,\ Bihar",
"912329", "Shahuwadi\/Malakapur\,\ Maharashtra",
"9165867", "Chainpur\,\ Bihar",
"915947", "Kashipur\,\ Uttar\ Pradesh",
"9174225", "Mandsaur\,\ Madhya\ Pradesh",
"915191", "Naraini\/Attarra\,\ Uttar\ Pradesh",
"914565", "Karaikudi\,\ Tamil\ Nadu",
"9174906", "Pohari\,\ Madhya\ Pradesh",
"9165652", "Latehar\,\ Bihar",
"911559", "Rajgarh\,\ Rajasthan",
"914182", "Tiruvettipuram\,\ Tamil\ Nadu",
"9168636", "Bisam\ Cuttack\,\ Odisha",
"913825", "Khowai\,\ Tripura",
"9176577", "Jaitpur\,\ Madhya\ Pradesh",
"913775", "Majuli\,\ Assam",
"9181930", "Hiriyur\,\ Karnataka",
"9161822", "Arrah\,\ Bihar",
"9167584", "Nimapara\,\ Odisha",
"9171582", "Deoli\,\ Maharashtra",
"9168606", "Boriguma\,\ Odisha",
"911763", "Sarhind\,\ Punjab",
"9174936", "Karera\,\ Madhya\ Pradesh",
"9174256", "Garoth\,\ Madhya\ Pradesh",
"9162556", "Raxaul\,\ Bihar",
"9174863", "Bareli\,\ Madhya\ Pradesh",
"91223", "Mumbai",
"9178088", "\`",
"9173213", "Sanwer\,\ Madhya\ Pradesh",
"9161867", "Aurangabad\,\ Bihar",
"9175923", "Vidisha\,\ Madhya\ Pradesh",
"9171187", "Kalmeshwar\,\ Maharashtra",
"915275", "Akbarpur\/Jalalpur\,\ Uttar\ Pradesh",
"9164324", "Deoghar\,\ Bihar",
"9172885", "Bhikangaon\,\ Madhya\ Pradesh",
"9174618", "Mahuwa\,\ Rajasthan",
"9165822", "Chaibasa\,\ Bihar",
"918398", "Harapanahalli\,\ Karnataka",
"91475", "Punalur\,\ Kerala",
"9171514", "Samudrapur\,\ Maharashtra",
"9166492", "Jamankira\,\ Odisha",
"917328", "Khalwa\,\ Madhya\ Pradesh",
"9175950", "Nateran\,\ Madhya\ Pradesh",
"9163377", "Arwal\,\ Bihar",
"913562", "Mal\ Bazar\,\ West\ Bengal",
"9175907", "Lateri\,\ Madhya\ Pradesh",
"9171724", "Chandrapur\,\ Maharashtra",
"9181747", "Arsikere\,\ Karnataka",
"9166262", "Banaigarh\,\ Odisha",
"914822", "Palai\,\ Kerala",
"915546", "Harraiya\,\ Uttar\ Pradesh",
"9168222", "Aska\,\ Odisha",
"911535", "Kolayat\/Bajju\,\ Rajasthan",
"9174570", "Mangrol\,\ Rajasthan",
"9164665", "Kishanganj\,\ Bihar",
"918313", "Belgaum\,\ Karnataka",
"917536", "Sabalgarh\,\ Madhya\ Pradesh",
"9174345", "Pirawa\/Raipur\,\ Rajasthan",
"913658", "Williamnagar\,\ Meghalaya",
"9177050", "Kurud\,\ Madhya\ Pradesh",
"9164253", "Katoria\,\ Bihar",
"9177007", "Nagri\,\ Madhya\ Pradesh",
"914898", "Kiltan\,\ Lakshadweep",
"9171873", "Goregaon\,\ Maharashtra",
"912113", "Bhor\,\ Maharashtra",
"913471", "Karimpur\,\ West\ Bengal",
"9171144", "Ramtek\,\ Maharashtra",
"9174579", "Mangrol\,\ Rajasthan",
"916577", "Jamshedpur\,\ Bihar",
"9165286", "Khunti\,\ Bihar",
"918546", "Gadwal\,\ Andhra\ Pradesh",
"9175959", "Nateran\,\ Madhya\ Pradesh",
"9171792", "Nagbhir\,\ Maharashtra",
"917273", "Kannod\,\ Madhya\ Pradesh",
"91494", "Tirur\,\ Kerala",
"9177059", "Kurud\,\ Madhya\ Pradesh",
"9168163", "Mohana\,\ Odisha",
"915313", "Salon\/Jais\,\ Uttar\ Pradesh",
"9171096", "Kamptee\,\ Maharashtra",
"916744", "Bhubaneshwar\,\ Odisha",
"9163366", "Rajauli\,\ Bihar",
"9176445", "Dindori\,\ Madhya\ Pradesh",
"9161125", "Biharsharif\,\ Bihar",
"917224", "Daryapur\,\ Maharashtra",
"91788", "Durg\,\ Madhya\ Pradesh",
"912897", "Dhrol\,\ Gujarat",
"9182202", "Gundlupet\,\ Karnataka",
"9165565", "Tisri\,\ Bihar",
"9171443", "Atner\,\ Madhya\ Pradesh",
"9161876", "Mohania\,\ Bihar",
"913452", "Guskara\,\ West\ Bengal",
"918322", "Goa",
"9168685", "Nandapur\,\ Odisha",
"9168464", "Baliguda\,\ Odisha",
"9168537", "Sunabeda\,\ Odisha",
"9166424", "Kuchinda\,\ Odisha",
"9165894", "Jhinkpani\,\ Bihar",
"9161155", "Danapur\,\ Bihar",
"9161566", "Gopalganj\,\ Bihar",
"917374", "Biaora\,\ Madhya\ Pradesh",
"9176565", "Kannodi\,\ Madhya\ Pradesh",
"9167534", "Nayagarh\,\ Odisha",
"9171532", "Hinganghat\,\ Maharashtra",
"91260", "Vapi\,\ Gujarat",
"918554", "Anantapur\,\ Andhra\ Pradesh",
"911341", "Najibabad\,\ Uttar\ Pradesh",
"918272", "Madikeri\,\ Karnataka",
"918325", "Goa",
"9165875", "Chakardharpur\,\ Bihar",
"918393", "Kurugodu\,\ Karnataka",
"9165676", "Barwadih\,\ Bihar",
"911681", "Jind\,\ Haryana",
"918230", "Krishnarajapet\,\ Karnataka",
"915176", "Lalitpur\,\ Uttar\ Pradesh",
"9171137", "Saoner\,\ Maharashtra",
"9166454", "Jharsuguda\,\ Odisha",
"914266", "Kotagiri\,\ Tamil\ Nadu",
"9174814", "Gairatganj\,\ Madhya\ Pradesh",
"9168544", "Jeypore\,\ Odisha",
"915464", "Maunathbhanjan\,\ Uttar\ Pradesh",
"911489", "Mandalgarh\,\ Rajasthan",
"918251", "Puttur\,\ Karnataka",
"9175929", "Vidisha\,\ Madhya\ Pradesh",
"918964", "Saluru\,\ Andhra\ Pradesh",
"9176286", "Karpa\,\ Madhya\ Pradesh",
"91551", "Gorakhpur\,\ Uttar\ Pradesh",
"9174136", "Sailana\,\ Madhya\ Pradesh",
"9167917", "Bangiriposi\,\ Odisha",
"9177048", "Deobhog\,\ Madhya\ Pradesh",
"9171987", "Tirora\,\ Maharashtra",
"911396", "Jansath\/Khatauli\,\ Uttar\ Pradesh",
"9171563", "Talegaokarangal\,\ Maharashtra",
"918477", "Aland\,\ Karnataka",
"9173219", "Sanwer\,\ Madhya\ Pradesh",
"9174869", "Bareli\,\ Madhya\ Pradesh",
"9175384", "Ambah\,\ Madhya\ Pradesh",
"9175948", "Ganjbasoda\,\ Madhya\ Pradesh",
"9181708", "Alur\,\ Karnataka",
"918318", "Belgaum\,\ Karnataka",
"9167297", "Pattamundai\,\ Odisha",
"9165445", "Gomia\,\ Bihar",
"913653", "Amlarem\/Dawki\,\ Meghalaya",
"9174602", "Sahabad\,\ Rajasthan",
"915251", "Kaisarganj\/Kaiserganj\,\ Uttar\ Pradesh",
"9165236", "Ghaghra\,\ Bihar",
"913565", "Nagarakata\,\ West\ Bengal",
"913834", "Demagiri\,\ Mizoram",
"9175920", "Vidisha\,\ Madhya\ Pradesh",
"911570", "Laxmangarh\/Nechwa\,\ Rajasthan",
"918464", "Madnur\,\ Andhra\ Pradesh",
"9175262", "Ghatigaon\,\ Madhya\ Pradesh",
"914893", "Androth\,\ Lakshadweep",
"912118", "Walchandnagar\,\ Maharashtra",
"9171754", "Bhadrawati\,\ Maharashtra",
"911532", "Nokha\/Nathusar\,\ Rajasthan",
"915964", "Pithoragarh\,\ Uttar\ Pradesh",
"9164576", "Korha\,\ Bihar",
"917664", "Hanumana\,\ Madhya\ Pradesh",
"9167645", "Anugul\,\ Odisha",
"9168413", "Boudh\,\ Odisha",
"916636", "Sambalpur\,\ Odisha",
"9164223", "Godda\,\ Bihar",
"9162716", "Benipatti\,\ Bihar",
"912666", "Miyagam\,\ Gujarat",
"912909", "Bhim\/Dawer\,\ Rajasthan",
"9167846", "Bhadrak\,\ Odisha",
"9174860", "Bareli\,\ Madhya\ Pradesh",
"9173210", "Sanwer\,\ Madhya\ Pradesh",
"9168182", "Buguda\,\ Odisha",
"9167942", "Rairangpur\,\ Odisha",
"9165667", "Japla\,\ Bihar",
"917519", "Gwalior\,\ Madhya\ Pradesh",
"9174226", "Mandsaur\,\ Madhya\ Pradesh",
"9177053", "Kurud\,\ Madhya\ Pradesh",
"9164207", "Amarpur\,\ Bihar",
"9162526", "Motihari\,\ Bihar",
"9174905", "Pohari\,\ Madhya\ Pradesh",
"917367", "Badnagar\,\ Madhya\ Pradesh",
"9175953", "Nateran\,\ Madhya\ Pradesh",
"9181734", "Sakleshpur\,\ Karnataka",
"9164354", "Pakur\,\ Bihar",
"9168587", "Nowrangapur\,\ Odisha",
"918214", "Mysore\,\ Karnataka",
"9162273", "Mahua\,\ Bihar",
"9161577", "Mairwa\,\ Bihar",
"9174573", "Mangrol\,\ Rajasthan",
"9165852", "Ghatsila\,\ Bihar",
"9168114", "Chhatrapur\,\ Odisha",
"9168635", "Bisam\ Cuttack\,\ Odisha",
"9164343", "Dumka\,\ Bihar",
"912354", "Sanganeshwar\/Deorukh\,\ Maharashtra",
"9168605", "Boriguma\,\ Odisha",
"9171347", "Bhamregadh\,\ Maharashtra",
"9175388", "Ambah\,\ Madhya\ Pradesh",
"9175944", "Ganjbasoda\,\ Madhya\ Pradesh",
"912593", "Surgena\,\ Maharashtra",
"9174663", "Bonli\,\ Rajasthan",
"912525", "Palghar\,\ Maharashtra",
"9162555", "Raxaul\,\ Bihar",
"9181704", "Alur\,\ Karnataka",
"918207", "Udupi\,\ Karnataka",
"9174935", "Karera\,\ Madhya\ Pradesh",
"911783", "Theog\,\ Himachal\ Pradesh",
"9174255", "Garoth\,\ Madhya\ Pradesh",
"9164237", "Maheshpur\ Raj\,\ Bihar",
"914562", "Virudhunagar\,\ Tamil\ Nadu",
"9174818", "Gairatganj\,\ Madhya\ Pradesh",
"9172886", "Bhikangaon\,\ Madhya\ Pradesh",
"9181931", "Hiriyur\,\ Karnataka",
"9165622", "Daltonganj\,\ Bihar",
"913822", "Dharam\ Nagar\,\ Tripura",
"914369", "Thiruthuraipoondi\,\ Tamil\ Nadu",
"91497", "Kannur\,\ Kerala",
"9161852", "Bikramganj\,\ Bihar",
"9167494", "Bhubaneshwar\,\ Odisha",
"9177044", "Deobhog\,\ Madhya\ Pradesh",
"918576", "Satyavedu\,\ Andhra\ Pradesh",
"9166514", "Birmaharajpur\,\ Odisha",
"9165577", "Bagodar\,\ Bihar",
"9171492", "Tamia\,\ Madhya\ Pradesh",
"913772", "Sibsagar\,\ Assam",
"9164594", "Thakurganj\,\ Bihar",
"91122", "Hapur\,\ Uttar\ Pradesh",
"911884", "Garhashanker\,\ Punjab",
"918245", "Mangalore\,\ Karnataka",
"911805", "Panipat\,\ Haryana",
"913582", "Coochbehar\,\ West\ Bengal",
"9166724", "Dharamgarh\,\ Odisha",
"9167264", "Jajapur\ Road\,\ Odisha",
"913751", "Digboi\,\ Assam",
"918786", "Karimnagar\,\ Andhra\ Pradesh",
"918402", "Kanigiri\,\ Andhra\ Pradesh",
"918111", "Hosakote\,\ Karnataka",
"9173297", "Khakner\,\ Madhya\ Pradesh",
"9174346", "Pirawa\/Raipur\,\ Rajasthan",
"912804", "Kutiyana\,\ Gujarat",
"914890", "Bitra\,\ Lakshadweep",
"9164666", "Kishanganj\,\ Bihar",
"9166257", "Lahunipara\,\ Odisha",
"911573", "Laxmangarh\,\ Rajasthan",
"9175227", "Datia\,\ Madhya\ Pradesh",
"917806", "Chitrangi\,\ Madhya\ Pradesh",
"9174632", "Gangapur\,\ Rajasthan",
"9171743", "Mul\,\ Maharashtra",
"913650", "Dadengiri\/Phulbari\,\ Meghalaya",
"9164522", "Katihar\,\ Bihar",
"9181738", "Sakleshpur\,\ Karnataka",
"918869", "Pithapuram\,\ Andhra\ Pradesh",
"9171312", "Sironcha\,\ Maharashtra",
"9164677", "Banmankhi\,\ Bihar",
"9163473", "Chakai\,\ Bihar",
"9171673", "Amarwada\,\ Madhya\ Pradesh",
"9167314", "Anandapur\,\ Odisha",
"915111", "Akbarpur\,\ Uttar\ Pradesh",
"9166792", "Komana\,\ Odisha",
"9165285", "Khunti\,\ Bihar",
"9171123", "Katol\,\ Maharashtra",
"9171384", "Dhanora\,\ Maharashtra",
"9168553", "Laxmipur\,\ Odisha",
"91231", "Kolhapur\,\ Maharashtra",
"917235", "Pandharkawada\,\ Maharashtra",
"9163365", "Rajauli\,\ Bihar",
"9176446", "Dindori\,\ Madhya\ Pradesh",
"9171095", "Kamptee\,\ Maharashtra",
"9162572", "Barachakia\,\ Bihar",
"9165566", "Tisri\,\ Bihar",
"916712", "Cuttack\,\ Odisha",
"9161126", "Biharsharif\,\ Bihar",
"9174272", "Bhanpura\,\ Madhya\ Pradesh",
"914257", "Kangeyam\,\ Tamil\ Nadu",
"9166443", "Rairakhol\,\ Odisha",
"9164784", "Saharsa\,\ Bihar",
"917861", "Netanar\,\ Madhya\ Pradesh",
"9173942", "Alirajpur\,\ Madhya\ Pradesh",
"918154", "Chintamani\,\ Karnataka",
"9168686", "Nandapur\,\ Odisha",
"913714", "Rangapara\,\ Assam",
"9161875", "Mohania\,\ Bihar",
"9165694", "Garu\,\ Bihar",
"912737", "Tharad\,\ Gujarat",
"9164712", "Birpur\,\ Bihar",
"913016", "Jaisalmer\/Jheenjaniyali\,\ Rajasthan",
"9171424", "Bhimpur\,\ Madhya\ Pradesh",
"9176563", "Kannodi\,\ Madhya\ Pradesh",
"9161153", "Danapur\,\ Bihar",
"9167216", "Narsinghpur\,\ Odisha",
"9177072", "Bagbahera\,\ Madhya\ Pradesh",
"9176440", "Dindori\,\ Madhya\ Pradesh",
"9174349", "Pirawa\/Raipur\,\ Rajasthan",
"918713", "Parkal\,\ Andhra\ Pradesh",
"912923", "Phalodi\/Lohawat\,\ Rajasthan",
"9165873", "Chakardharpur\,\ Bihar",
"9174552", "Digod\/Sultanpur\,\ Rajasthan",
"912995", "Pokhran\/Nachna\,\ Rajasthan",
"91480", "Irinjalakuda\,\ Kerala",
"914372", "Orathanad\,\ Tamil\ Nadu",
"9174328", "Jhalawar\,\ Rajasthan",
"9164614", "Raniganj\,\ Bihar",
"917728", "Kasdol\,\ Madhya\ Pradesh",
"918366", "Hubli\,\ Karnataka",
"915851", "Bilgam\/Madhoganj\,\ Uttar\ Pradesh",
"9174708", "Bundi\,\ Rajasthan",
"9172862", "Khetia\,\ Madhya\ Pradesh",
"918814", "Eluru\ Narsapur\/Palakole\,\ Andhra\ Pradesh",
"91435", "Kumbakonam\,\ Tamil\ Nadu",
"912467", "Bhokar\,\ Maharashtra",
"915676", "Shikohabad\,\ Uttar\ Pradesh",
"915722", "Hathras\,\ Uttar\ Pradesh",
"91353", "Siliguri\,\ West\ Bengal",
"9172889", "Bhikangaon\,\ Madhya\ Pradesh",
"9162587", "Areraj\,\ Bihar",
"915872", "Kheri\,\ Uttar\ Pradesh",
"911975", "Una\,\ Himachal\ Pradesh",
"9171894", "Amagaon\,\ Maharashtra",
"9184532", "Medak\,\ Andhra\ Pradesh",
"9171156", "Mouda\,\ Maharashtra",
"9171565", "Talegaokarangal\,\ Maharashtra",
"9168526", "Koraput\,\ Odisha",
"9176532", "Bandhavgarh\,\ Madhya\ Pradesh",
"9165443", "Gomia\,\ Bihar",
"911363", "Karnaprayag\,\ Uttarakhand",
"912974", "Abu\ Road\,\ Rajasthan",
"917840", "Koyelibeda\,\ Madhya\ Pradesh",
"9174927", "Shivpuri\,\ Madhya\ Pradesh",
"911475", "Begun\/Rawatbhata\,\ Rajasthan",
"9168662", "Umerkote\,\ Odisha",
"918830", "Rajahmundri\,\ Andhra\ Pradesh",
"9172880", "Bhikangaon\,\ Madhya\ Pradesh",
"911624", "Jagraon\,\ Punjab",
"912967", "Aspur\,\ Rajasthan",
"918301", "Mundagod\,\ Karnataka",
"9171822", "Gondia\,\ Maharashtra",
"918676", "Vuyyuru\,\ Andhra\ Pradesh",
"9165514", "Barkagaon\,\ Bihar",
"9166577", "Kantabhanji\,\ Odisha",
"9167824", "Balasore\,\ Odisha",
"913526", "Islampur\,\ West\ Bengal",
"9168415", "Boudh\,\ Odisha",
"9167643", "Anugul\,\ Odisha",
"9165582", "Dumri\(Isribazar\)\,\ Bihar",
"9176388", "Damoh\,\ Madhya\ Pradesh",
"917859", "Lohadigundah\,\ Madhya\ Pradesh",
"912625", "Valod\,\ Gujarat",
"917476", "Bundi\,\ Rajasthan",
"9164225", "Godda\,\ Bihar",
"9176449", "Dindori\,\ Madhya\ Pradesh",
"9174340", "Pirawa\/Raipur\,\ Rajasthan",
"9162797", "Barauni\,\ Bihar",
"9165257", "Simdega\,\ Bihar",
"9165937", "Manoharpur\,\ Bihar",
"912166", "Phaltan\,\ Maharashtra",
"911494", "Behror\,\ Rajasthan",
"9177055", "Kurud\,\ Madhya\ Pradesh",
"912557", "Dindori\,\ Maharashtra",
"9165304", "Bundu\,\ Bihar",
"917792", "Narsinghpur\,\ Madhya\ Pradesh",
"9175955", "Nateran\,\ Madhya\ Pradesh",
"9174903", "Pohari\,\ Madhya\ Pradesh",
"9168633", "Bisam\ Cuttack\,\ Odisha",
"913210", "Kakdwip\,\ West\ Bengal",
"9174575", "Mangrol\,\ Rajasthan",
"9162544", "Bettiah\,\ Bihar",
"9174244", "Malhargarh\,\ Madhya\ Pradesh",
"9176428", "Mandla\,\ Madhya\ Pradesh",
"9162275", "Mahua\,\ Bihar",
"912423", "Koparagon\,\ Maharashtra",
"9174665", "Bonli\,\ Rajasthan",
"917835", "Bharathpur\,\ Madhya\ Pradesh",
"917564", "Budhni\,\ Madhya\ Pradesh",
"9187592", "Outsarangapalle\,\ Andhra\ Pradesh",
"9168603", "Boriguma\,\ Odisha",
"9164345", "Dumka\,\ Bihar",
"913213", "Dhaniakhali\,\ West\ Bengal",
"9174253", "Garoth\,\ Madhya\ Pradesh",
"9174933", "Karera\,\ Madhya\ Pradesh",
"912566", "Sindkheda\,\ Maharashtra",
"9165334", "Basia\,\ Bihar",
"9173216", "Sanwer\,\ Madhya\ Pradesh",
"9174866", "Bareli\,\ Madhya\ Pradesh",
"9162553", "Raxaul\,\ Bihar",
"9175926", "Vidisha\,\ Madhya\ Pradesh",
"913665", "Tarabarihat\,\ Assam",
"9176289", "Karpa\,\ Madhya\ Pradesh",
"918734", "Nirmal\,\ Andhra\ Pradesh",
"9174139", "Sailana\,\ Madhya\ Pradesh",
"9176262", "Vijayraghogarh\,\ Madhya\ Pradesh",
"9185860", "Vayalpad\,\ Andhra\ Pradesh",
"911632", "Ferozepur\,\ Punjab",
"918419", "Yellapur\,\ Karnataka",
"9171652", "Saunsar\,\ Madhya\ Pradesh",
"9163452", "Jamui\,\ Bihar",
"9174324", "Jhalawar\,\ Rajasthan",
"9167654", "Palla\ Hara\,\ Odisha",
"912690", "Balasinor\,\ Gujarat",
"9161514", "Sidhawalia\,\ Bihar",
"9176492", "Kakaiya\,\ Madhya\ Pradesh",
"9166852", "Sohela\,\ Odisha",
"9168177", "R\.Udayigiri\,\ Odisha",
"9174704", "Bundi\,\ Rajasthan",
"912956", "Gogunda\,\ Rajasthan",
"9176347", "Lamta\,\ Madhya\ Pradesh",
"9161582", "Sonepur\,\ Bihar",
"9174962", "Pichhore\,\ Madhya\ Pradesh",
"9168627", "Gudari\,\ Odisha",
"917261", "Deolgaonraja\,\ Maharashtra",
"9168572", "Gunupur\,\ Odisha",
"9171745", "Mul\,\ Maharashtra",
"913463", "Bolpur\,\ West\ Bengal",
"9164256", "Katoria\,\ Bihar",
"9174220", "Mandsaur\,\ Madhya\ Pradesh",
"9171867", "Sakoli\,\ Maharashtra",
"918833", "Rajahmundri\,\ Andhra\ Pradesh",
"916315", "Gaya\,\ Bihar",
"912791", "Babra\,\ Gujarat",
"918654", "Jaggayyapet\,\ Andhra\ Pradesh",
"913222", "Kharagpur\,\ West\ Bengal",
"911360", "Dehradun\ Chakrata\/Dakpattar\,\ Uttarakhand",
"9171876", "Goregaon\,\ Maharashtra",
"917787", "Jarwa\,\ Madhya\ Pradesh",
"917843", "Durgakondal\,\ Madhya\ Pradesh",
"9176502", "Beohari\,\ Madhya\ Pradesh",
"911581", "Ladnun\,\ Rajasthan",
"9165283", "Khunti\,\ Bihar",
"9171675", "Amarwada\,\ Madhya\ Pradesh",
"9163475", "Chakai\,\ Bihar",
"9174248", "Malhargarh\,\ Madhya\ Pradesh",
"9165454", "Mandu\,\ Bihar",
"918919", "Visakhapatnam\,\ Andhra\ Pradesh",
"9176424", "Mandla\,\ Madhya\ Pradesh",
"9168166", "Mohana\,\ Odisha",
"9174229", "Mandsaur\,\ Madhya\ Pradesh",
"9168555", "Laxmipur\,\ Odisha",
"9171125", "Katol\,\ Maharashtra",
"9171093", "Kamptee\,\ Maharashtra",
"915833", "Sahaswan\,\ Uttar\ Pradesh",
"91250", "Bassein\,\ Maharashtra",
"9163363", "Rajauli\,\ Bihar",
"911438", "Newai\,\ Rajasthan",
"912456", "Hingoli\,\ Maharashtra",
"918357", "Badami\,\ Karnataka",
"914333", "Ponnamaravathi\,\ Tamil\ Nadu",
"912746", "Radhanpur\,\ Gujarat",
"9176384", "Damoh\,\ Madhya\ Pradesh",
"9171446", "Atner\,\ Madhya\ Pradesh",
"917744", "Rajandgaon\,\ Madhya\ Pradesh",
"9166445", "Rairakhol\,\ Odisha",
"911899", "Chamba\,\ Himachal\ Pradesh",
"914290", "Omalur\,\ Tamil\ Nadu",
"912920", "Bilara\/Bhopalgarh\,\ Rajasthan",
"9185869", "Vayalpad\,\ Andhra\ Pradesh",
"9174877", "Begamganj\,\ Madhya\ Pradesh",
"9161144", "Jahanabad\,\ Bihar",
"915734", "Debai\,\ Uttar\ Pradesh",
"9161873", "Mohania\,\ Bihar",
"917577", "Harda\,\ Madhya\ Pradesh",
"918710", "Cherial\,\ Andhra\ Pradesh",
"9162764", "Madhubani\,\ Bihar",
"9176280", "Karpa\,\ Madhya\ Pradesh",
"911821", "Nakodar\,\ Punjab",
"91177", "Shimla\,\ Himachal\ Pradesh",
"9174130", "Sailana\,\ Madhya\ Pradesh",
"911284", "Bawal\,\ Haryana",
"918845", "Kakinada\,\ Andhra\ Pradesh",
"9171972", "Mohadi\,\ Maharashtra",
"914179", "Tirupattur\,\ Tamil\ Nadu",
"9167974", "Jashipur\,\ Odisha",
"9161563", "Gopalganj\,\ Bihar",
"9174567", "Kishanganj\/Bhanwargarh\,\ Rajasthan",
"9167215", "Narsinghpur\,\ Odisha",
"918499", "Podili\,\ Andhra\ Pradesh",
"9165384", "Torpa\,\ Bihar",
"9162267", "Sitamarhi\,\ Bihar",
"917621", "Patan\,\ Madhya\ Pradesh",
"912444", "Patoda\,\ Maharashtra",
"913218", "Canning\,\ West\ Bengal",
"917446", "Ladpura\/Kota\,\ Rajasthan",
"9163264", "Sherghati\,\ Bihar",
"918386", "Kumta\,\ Karnataka",
"913789", "Huri\,\ Arunachal\ Pradesh",
"9165312", "Mandar\,\ Bihar",
"918646", "Vinukonda\,\ Andhra\ Pradesh",
"915921", "Bilari\,\ Uttar\ Pradesh",
"9165673", "Barwadih\,\ Bihar",
"918936", "Araku\,\ Andhra\ Pradesh",
"918842", "Kakinada\,\ Andhra\ Pradesh",
"913225", "Ghatal\,\ West\ Bengal",
"9176308", "Katangi\,\ Madhya\ Pradesh",
"9174598", "Ramganj\ Mandi\,\ Rajasthan",
"9165502", "Hunterganj\,\ Bihar",
"913801", "Anini\,\ Arunachal\ Pradesh",
"9163494", "Jhajha\,\ Bihar",
"9171694", "Batkakhapa\,\ Madhya\ Pradesh",
"9167692", "Kamakhyanagar\,\ Odisha",
"9176283", "Karpa\,\ Madhya\ Pradesh",
"9176454", "Karanjia\,\ Madhya\ Pradesh",
"918629", "Vinjamuru\,\ Andhra\ Pradesh",
"9165424", "Bokaro\,\ Bihar",
"9174133", "Sailana\,\ Madhya\ Pradesh",
"912487", "Shrigonda\,\ Maharashtra",
"9171155", "Mouda\,\ Maharashtra",
"917756", "Lormi\,\ Madhya\ Pradesh",
"9171566", "Talegaokarangal\,\ Maharashtra",
"9174939", "Karera\,\ Madhya\ Pradesh",
"9168525", "Koraput\,\ Odisha",
"9174259", "Garoth\,\ Madhya\ Pradesh",
"918838", "Rajahmundri\,\ Andhra\ Pradesh",
"9161532", "Maharajganj\,\ Bihar",
"911933", "Pulwama\,\ Jammu\ And\ Kashmir",
"918691", "Devarakonda\,\ Andhra\ Pradesh",
"912754", "Dhrangadhra\,\ Gujarat",
"918137", "Madugiri\,\ Karnataka",
"914153", "Arakandanallur\,\ Tamil\ Nadu",
"914342", "Dharmapuri\,\ Tamil\ Nadu",
"9165233", "Ghaghra\,\ Bihar",
"912987", "Sheo\,\ Rajasthan",
"91799", "Ahmedabad\ Local\,\ Gujarat",
"9167624", "Dhenkanal\,\ Odisha",
"9174354", "Gangdhar\,\ Rajasthan",
"9163422", "H\.Kharagpur\,\ Bihar",
"9171622", "Chhindwara\,\ Madhya\ Pradesh",
"914549", "Thirumanglam\,\ Tamil\ Nadu",
"917848", "Keskal\,\ Madhya\ Pradesh",
"9164573", "Korha\,\ Bihar",
"9166822", "Attabira\,\ Odisha",
"9171577", "Arvi\,\ Maharashtra",
"9165492", "Bermo\,\ Bihar",
"9165347", "Jhumaritalaiya\,\ Bihar",
"9168657", "Kashipur\,\ Odisha",
"911907", "Sundernagar\,\ Himachal\ Pradesh",
"9168416", "Boudh\,\ Odisha",
"911433", "Todaraisingh\,\ Rajasthan",
"9174930", "Karera\,\ Madhya\ Pradesh",
"9167843", "Bhadrak\,\ Odisha",
"9174250", "Garoth\,\ Madhya\ Pradesh",
"9162713", "Benipatti\,\ Bihar",
"9164226", "Godda\,\ Bihar",
"9162507", "Dhaka\,\ Bihar",
"915691", "Chhibramau\,\ Uttar\ Pradesh",
"9174207", "Jawad\,\ Madhya\ Pradesh",
"916312", "Gaya\,\ Bihar",
"912186", "Pandharpur\,\ Maharashtra",
"917832", "Rajpur\,\ Madhya\ Pradesh",
"912711", "Barwala\,\ Gujarat",
"9177056", "Kurud\,\ Madhya\ Pradesh",
"9174223", "Mandsaur\,\ Madhya\ Pradesh",
"9162523", "Motihari\,\ Bihar",
"912634", "Billimora\,\ Gujarat",
"9176334", "Waraseoni\,\ Madhya\ Pradesh",
"917720", "Arang\,\ Madhya\ Pradesh",
"91542", "Varansi\,\ Uttar\ Pradesh",
"9185861", "Vayalpad\,\ Andhra\ Pradesh",
"913662", "Dhubri\,\ Assam",
"9175956", "Nateran\,\ Madhya\ Pradesh",
"9163314", "Imamganj\,\ Bihar",
"9162276", "Mahua\,\ Bihar",
"9165262", "Lohardaga\,\ Bihar",
"915842", "Shahjahanpur\,\ Uttar\ Pradesh",
"9174576", "Mangrol\,\ Rajasthan",
"915646", "Baseri\,\ Rajasthan",
"911635", "Kotkapura\,\ Punjab",
"918718", "Narasampet\,\ Andhra\ Pradesh",
"9164346", "Dumka\,\ Bihar",
"912586", "Chopda\,\ Maharashtra",
"9174666", "Bonli\,\ Rajasthan",
"912849", "Botad\,\ Gujarat",
"9173215", "Sanwer\,\ Madhya\ Pradesh",
"9176257", "Umariapan\,\ Madhya\ Pradesh",
"911796", "Arki\,\ Himachal\ Pradesh",
"9174865", "Bareli\,\ Madhya\ Pradesh",
"917584", "Rahatgarh\,\ Madhya\ Pradesh",
"9165227", "Muri\,\ Bihar",
"916806", "Berhampur\,\ Odisha",
"9176304", "Katangi\,\ Madhya\ Pradesh",
"9172883", "Bhikangaon\,\ Madhya\ Pradesh",
"9174594", "Ramganj\ Mandi\,\ Rajasthan",
"917723", "Mahasamund\,\ Madhya\ Pradesh",
"91145", "Ajmer\,\ Rajasthan",
"911506", "Anupgarh\/Gharsana\,\ Rajasthan",
"9175925", "Vidisha\,\ Madhya\ Pradesh",
"9162294", "Bidupur\,\ Bihar",
"914298", "Metturdam\,\ Tamil\ Nadu",
"912928", "Shergarh\/Deechu\,\ Rajasthan",
"9176458", "Karanjia\,\ Madhya\ Pradesh",
"917547", "Chanderi\,\ Madhya\ Pradesh",
"9174237", "Neemuch\,\ Madhya\ Pradesh",
"911472", "Chittorgarh\,\ Rajasthan",
"9174957", "Badarwas\,\ Madhya\ Pradesh",
"9162464", "Jainagar\,\ Bihar",
"9162537", "Narkatiaganj\,\ Bihar",
"9174900", "Pohari\,\ Madhya\ Pradesh",
"911659", "Sardulgarh\,\ Punjab",
"911430", "Phagi\,\ Rajasthan",
"914149", "Ulundurpet\,\ Tamil\ Nadu",
"911741", "Pehowa\,\ Haryana",
"9176514", "Jaisinghnagar\,\ Madhya\ Pradesh",
"9171042", "Hingua\,\ Maharashtra",
"9171852", "Pauni\,\ Maharashtra",
"918725", "Metpalli\,\ Andhra\ Pradesh",
"9174343", "Pirawa\/Raipur\,\ Rajasthan",
"912826", "Upleta\,\ Gujarat",
"913483", "Murshidabad\/Jiaganj\,\ West\ Bengal",
"912622", "Bardoli\,\ Gujarat",
"9164663", "Kishanganj\,\ Bihar",
"911368", "Pauri\,\ Uttarakhand",
"9171667", "Chaurai\,\ Madhya\ Pradesh",
"9163467", "Lakhisarai\,\ Bihar",
"918503", "Makthal\,\ Andhra\ Pradesh",
"9165944", "Baharagora\,\ Bihar",
"917824", "Bemetara\,\ Madhya\ Pradesh",
"9176569", "Kannodi\,\ Madhya\ Pradesh",
"917774", "Ambikapur\,\ Madhya\ Pradesh",
"9171746", "Mul\,\ Maharashtra",
"9164255", "Katoria\,\ Bihar",
"917281", "Sendhwa\,\ Madhya\ Pradesh",
"911561", "Taranagar\,\ Rajasthan",
"9161502", "Hathua\,\ Bihar",
"9171875", "Goregaon\,\ Maharashtra",
"917767", "Gharghoda\,\ Madhya\ Pradesh",
"9171676", "Amarwada\,\ Madhya\ Pradesh",
"9163476", "Chakai\,\ Bihar",
"915875", "Mohammadi\/Maigalganj\,\ Uttar\ Pradesh",
"911972", "Hamirpur\,\ Himachal\ Pradesh",
"9174909", "Pohari\,\ Madhya\ Pradesh",
"9176560", "Kannodi\,\ Madhya\ Pradesh",
"912831", "Nalia\,\ Gujarat",
"9168165", "Mohana\,\ Odisha",
"9164272", "Kathikund\,\ Bihar",
"9168556", "Laxmipur\,\ Odisha",
"9171126", "Katol\,\ Maharashtra",
"9176443", "Dindori\,\ Madhya\ Pradesh",
"9165532", "Ramgarh\,\ Bihar",
"918537", "Lingsugur\,\ Karnataka",
"9176338", "Waraseoni\,\ Madhya\ Pradesh",
"914553", "Oddanchatram\,\ Tamil\ Nadu",
"912698", "Khambat\,\ Gujarat",
"9165563", "Tisri\,\ Bihar",
"9174127", "Ratlam\,\ Madhya\ Pradesh",
"9161123", "Biharsharif\,\ Bihar",
"9166446", "Rairakhol\,\ Odisha",
"9171445", "Atner\,\ Madhya\ Pradesh",
"9168683", "Nandapur\,\ Odisha",
"912992", "Jaisalmer\,\ Rajasthan",
"9174522", "Chhabra\,\ Rajasthan",
"9174358", "Gangdhar\,\ Rajasthan",
"9162222", "Sheohar\,\ Bihar",
"912428", "Pathardi\,\ Maharashtra",
"91413", "Pondicherry\,\ Tamil\ Nadu",
"9174677", "Bamanwas\,\ Rajasthan",
"911951", "Badgam\,\ Jammu\ And\ Kashmir",
"9176409", "Shahpur\,\ Madhya\ Pradesh",
"9174300", "Khanpur\,\ Rajasthan",
"9167627", "Dhenkanal\,\ Odisha",
"9161353", "Bikram\,\ Bihar",
"9176241", "Sihora\,\ Madhya\ Pradesh",
"9168195", "Surada\,\ Odisha",
"9174357", "Gangdhar\,\ Rajasthan",
"9174678", "Bamanwas\,\ Rajasthan",
"9174149", "Jaora\,\ Madhya\ Pradesh",
"916212", "Muzaffarpur\,\ Bihar",
"918733", "Asifabad\,\ Andhra\ Pradesh",
"9164756", "S\.Bakhtiarpur\,\ Bihar",
"9167572", "Daspalla\,\ Odisha",
"9166246", "Rajgangpur\,\ Odisha",
"9171574", "Arvi\,\ Maharashtra",
"9168654", "Kashipur\,\ Odisha",
"9165344", "Jhumaritalaiya\,\ Bihar",
"9162422", "Benipur\,\ Bihar",
"9174943", "Kolaras\,\ Madhya\ Pradesh",
"9174128", "Ratlam\,\ Madhya\ Pradesh",
"9181755", "Holenarasipur\,\ Karnataka",
"913214", "Jagatballavpur\,\ West\ Bengal",
"9164335", "Jamtara\,\ Bihar",
"9162504", "Dhaka\,\ Bihar",
"9174204", "Jawad\,\ Madhya\ Pradesh",
"917563", "Nasrullaganj\,\ Madhya\ Pradesh",
"918834", "Rajahmundri\,\ Andhra\ Pradesh",
"918565", "Rajampeta\,\ Andhra\ Pradesh",
"9166736", "Jayapatna\,\ Odisha",
"9171735", "Rajura\,\ Maharashtra",
"916417", "Bhagalpur\,\ Bihar",
"918182", "Shimoga\,\ Karnataka",
"915745", "Jalesar\,\ Uttar\ Pradesh",
"913511", "Bubulchandi\,\ West\ Bengal",
"9163276", "Rafiganj\,\ Bihar",
"9176337", "Waraseoni\,\ Madhya\ Pradesh",
"912758", "Halvad\,\ Gujarat",
"9165593", "Simaria\,\ Bihar",
"9163317", "Imamganj\,\ Bihar",
"9167603", "Talcher\,\ Odisha",
"9171356", "Chamorshi\,\ Maharashtra",
"912432", "Aurangabad\,\ Maharashtra",
"9174510", "Atru\,\ Rajasthan",
"911509", "Suratgarh\,\ Rajasthan",
"9174564", "Kishanganj\/Bhanwargarh\,\ Rajasthan",
"9165387", "Torpa\,\ Bihar",
"9162264", "Sitamarhi\,\ Bihar",
"915834", "Bisauli\,\ Uttar\ Pradesh",
"913251", "Adra\,\ West\ Bengal",
"917527", "Mehgaon\,\ Madhya\ Pradesh",
"91172", "Chandigarh\,\ Punjab",
"918745", "Yellandu\,\ Andhra\ Pradesh",
"911871", "Batala\,\ Punjab",
"9167883", "Soro\,\ Odisha",
"915182", "Khaga\,\ Uttar\ Pradesh",
"9174958", "Badarwas\,\ Madhya\ Pradesh",
"9171813", "Lakhandur\,\ Maharashtra",
"9174238", "Neemuch\,\ Madhya\ Pradesh",
"9163267", "Sherghati\,\ Bihar",
"912589", "Chalisgaon\,\ Maharashtra",
"912642", "Bharuch\,\ Gujarat",
"912846", "Sihor\,\ Gujarat",
"9174519", "Atru\,\ Rajasthan",
"912932", "Pali\,\ Rajasthan",
"9174696", "Hindaun\,\ Rajasthan",
"911799", "Rajgarh\,\ Himachal\ Pradesh",
"912382", "Latur\,\ Maharashtra",
"9165403", "Govindpur\,\ Bihar",
"912970", "Sanchore\/Hadecha\,\ Rajasthan",
"917844", "Pakhanjur\,\ Madhya\ Pradesh",
"914637", "Valliyoor\,\ Tamil\ Nadu",
"918707", "Warangal\,\ Andhra\ Pradesh",
"917655", "Birsinghpur\,\ Madhya\ Pradesh",
"9161816", "Piro\,\ Bihar",
"912829", "Maliya\ Miyana\,\ Gujarat",
"911990", "Ramnagar\,\ Jammu\ And\ Kashmir",
"9174140", "Jaora\,\ Madhya\ Pradesh",
"9176815", "Jatara\,\ Madhya\ Pradesh",
"9171697", "Batkakhapa\,\ Madhya\ Pradesh",
"9163497", "Jhajha\,\ Bihar",
"9167555", "Khurda\,\ Odisha",
"912779", "Bayad\,\ Gujarat",
"9176400", "Shahpur\,\ Madhya\ Pradesh",
"9174309", "Khanpur\,\ Rajasthan",
"9165427", "Bokaro\,\ Bihar",
"9176457", "Karanjia\,\ Madhya\ Pradesh",
"915733", "Pahasu\,\ Uttar\ Pradesh",
"9166435", "Barkot\,\ Odisha",
"912891", "Jamkalyanpur\,\ Gujarat",
"917743", "Chuikhadan\,\ Madhya\ Pradesh",
"9171436", "Bhainsdehi\,\ Madhya\ Pradesh",
"918455", "Sangareddy\,\ Andhra\ Pradesh",
"9176258", "Umariapan\,\ Madhya\ Pradesh",
"914146", "Villupuram\,\ Tamil\ Nadu",
"911852", "Taran\,\ Punjab",
"917815", "Kathghora\,\ Madhya\ Pradesh",
"9165816", "Bhandaria\,\ Bihar",
"911667", "Fatehabad\,\ Haryana",
"9167526", "Puri\,\ Odisha",
"916516", "Ranchi\,\ Bihar",
"917740", "Bodla\,\ Madhya\ Pradesh",
"9166405", "Bagdihi\,\ Odisha",
"9165615", "Garhwa\,\ Bihar",
"914294", "Perundurai\,\ Tamil\ Nadu",
"912924", "Phalodi\/Baroo\,\ Rajasthan",
"9164386", "Madhupur\,\ Bihar",
"9167273", "Kendrapara\,\ Odisha",
"9176430", "Bijadandi\,\ Madhya\ Pradesh",
"9174339", "Pachpahar\/Bhawanimandi\,\ Rajasthan",
"918941", "Palakonda\/Rajam\,\ Andhra\ Pradesh",
"914546", "Theni\,\ Tamil\ Nadu",
"9162476", "Singhwara\,\ Bihar",
"9165462", "Hazaribagh\,\ Bihar",
"915822", "Baheri\,\ Uttar\ Pradesh",
"9163222", "Wazirganj\,\ Bihar",
"912973", "Jalore\,\ Rajasthan",
"911364", "Ukhimath\/Guptkashi\,\ Uttarakhand",
"917127", "Nagpur\,\ Maharashtra",
"9174383", "Keshoraipatan\/Patan\,\ Rajasthan",
"9162752", "Rosera\,\ Bihar",
"9165433", "Barhi\,\ Bihar",
"9174124", "Ratlam\,\ Madhya\ Pradesh",
"914322", "Pudukkottai\,\ Tamil\ Nadu",
"91470", "Attingal\,\ Kerala",
"915165", "Konch\,\ Uttar\ Pradesh",
"913869", "Mon\,\ Nagaland",
"9165292", "Itki\,\ Bihar",
"917778", "Semaria\,\ Madhya\ Pradesh",
"9171786", "Sinderwahi\,\ Maharashtra",
"9166785", "Nowparatan\,\ Odisha",
"9174208", "Jawad\,\ Madhya\ Pradesh",
"912365", "Malwan\,\ Maharashtra",
"9168216", "Bhanjanagar\,\ Odisha",
"912189", "Mohol\,\ Maharashtra",
"915496", "Ballia\/Raniganj\,\ Uttar\ Pradesh",
"9174674", "Bamanwas\,\ Rajasthan",
"9165912", "Chandil\,\ Bihar",
"9176359", "Lanji\,\ Madhya\ Pradesh",
"918813", "Eluru\ Kovvur\/Nidadavolu\,\ Andhra\ Pradesh",
"918389", "Siddapur\,\ Karnataka",
"9167965", "Karanjia\,\ Odisha",
"918582", "B\.Kothakota\,\ Andhra\ Pradesh",
"912694", "Kheda\,\ Gujarat",
"918751", "Boath\/Echoda\,\ Andhra\ Pradesh",
"9165224", "Muri\,\ Bihar",
"918649", "Piduguralla\,\ Andhra\ Pradesh",
"913786", "Khonsa\,\ Arunachal\ Pradesh",
"9176254", "Umariapan\,\ Madhya\ Pradesh",
"9162775", "Phulparas\,\ Bihar",
"912473", "Kallam\,\ Maharashtra",
"9167633", "Athmallik\,\ Odisha",
"9176483", "Mawai\,\ Madhya\ Pradesh",
"9174597", "Ramganj\ Mandi\,\ Rajasthan",
"9176307", "Katangi\,\ Madhya\ Pradesh",
"9161593", "Masrakh\,\ Bihar",
"9171325", "Gadchiroli\,\ Maharashtra",
"9176350", "Lanji\,\ Madhya\ Pradesh",
"918496", "Uravakonda\,\ Andhra\ Pradesh",
"9162297", "Bidupur\,\ Bihar",
"911377", "Bhatwari\/Gangotri\,\ Uttarakhand",
"9171705", "Chumur\,\ Maharashtra",
"9164515", "Barsoi\,\ Bihar",
"9166706", "Bhawanipatna\,\ Odisha",
"917449", "Ladpura\/Kota\,\ Rajasthan",
"912424", "Akole\,\ Maharashtra",
"917560", "Ashta\,\ Madhya\ Pradesh",
"911268", "Ferojpur\,\ Haryana",
"91793", "Ahmedabad\ Local\,\ Gujarat",
"9162467", "Jainagar\,\ Bihar",
"9174954", "Badarwas\,\ Madhya\ Pradesh",
"9174234", "Neemuch\,\ Madhya\ Pradesh",
"917759", "Korba\,\ Madhya\ Pradesh",
"9162534", "Narkatiaganj\,\ Bihar",
"9167415", "Bhubaneshwar\,\ Odisha",
"912675", "Santrampur\,\ Gujarat",
"9176323", "Balaghat\,\ Madhya\ Pradesh",
"9165353", "Chainpur\,\ Bihar",
"9168643", "Mathili\,\ Odisha",
"9176517", "Jaisinghnagar\,\ Madhya\ Pradesh",
"9174568", "Kishanganj\/Bhanwargarh\,\ Rajasthan",
"911425", "Phulera\/Sambhar\,\ Rajasthan",
"911493", "Tijara\,\ Rajasthan",
"9167662", "Keonjhar\,\ Odisha",
"918730", "Khanapur\,\ Andhra\ Pradesh",
"9165947", "Baharagora\,\ Bihar",
"9163464", "Lakhisarai\,\ Bihar",
"9171664", "Chaurai\,\ Madhya\ Pradesh",
"918441", "Sedam\,\ Karnataka",
"9171485", "Prabha\ Pattan\,\ Madhya\ Pradesh",
"9176439", "Bijadandi\,\ Madhya\ Pradesh",
"9174330", "Pachpahar\/Bhawanimandi\,\ Rajasthan",
"9181726", "Hassan\,\ Karnataka",
"918772", "Tirupathi\,\ Andhra\ Pradesh",
"9166486", "Patnagarh\,\ Odisha",
"918626", "Kavali\,\ Andhra\ Pradesh",
"9174924", "Shivpuri\,\ Madhya\ Pradesh",
"912876", "Veraval\,\ Gujarat",
"9168196", "Surada\,\ Odisha",
"9174878", "Begamganj\,\ Madhya\ Pradesh",
"9165323", "Giridih\,\ Bihar",
"9176353", "Lanji\,\ Madhya\ Pradesh",
"912672", "Godhra\,\ Gujarat",
"9189462", "Pathapatnam\/Hiramandalam\,\ Andhra\ Pradesh",
"9171063", "Bhiwapur\,\ Maharashtra",
"9166245", "Rajgangpur\,\ Odisha",
"912630", "Bansada\,\ Gujarat",
"9167827", "Balasore\,\ Odisha",
"917724", "Basana\,\ Madhya\ Pradesh",
"9164755", "S\.Bakhtiarpur\,\ Bihar",
"9165517", "Barkagaon\,\ Bihar",
"9166574", "Kantabhanji\,\ Odisha",
"911422", "Viratnagar\/Shahpura\,\ Rajasthan",
"917583", "Banda\,\ Madhya\ Pradesh",
"9174362", "Hindoli\,\ Rajasthan",
"911998", "Ramban\,\ Jammu\ And\ Kashmir",
"91451", "Dindigul\,\ Tamil\ Nadu",
"91184", "Karnal\,\ Haryana",
"918775", "Tirupathi\,\ Andhra\ Pradesh",
"9181756", "Holenarasipur\,\ Karnataka",
"9164336", "Jamtara\,\ Bihar",
"918916", "Visakhapatnam\,\ Andhra\ Pradesh",
"9176480", "Mawai\,\ Madhya\ Pradesh",
"9174389", "Keshoraipatan\/Patan\,\ Rajasthan",
"917773", "Odgi\,\ Madhya\ Pradesh",
"9171736", "Rajura\,\ Maharashtra",
"9162794", "Barauni\,\ Bihar",
"917823", "Dongargarh\,\ Madhya\ Pradesh",
"913242", "Bankura\,\ West\ Bengal",
"9166735", "Jayapatna\,\ Odisha",
"918504", "Atmakur\,\ Andhra\ Pradesh",
"9165934", "Manoharpur\,\ Bihar",
"9165254", "Simdega\,\ Bihar",
"9163275", "Rafiganj\,\ Bihar",
"912978", "Ahore\,\ Rajasthan",
"918585", "Pakala\,\ Andhra\ Pradesh",
"913484", "Kandi\,\ West\ Bengal",
"9165483", "Ichak\,\ Bihar",
"9174333", "Pachpahar\/Bhawanimandi\,\ Rajasthan",
"9171355", "Chamorshi\,\ Maharashtra",
"9171032", "Butibori\,\ Maharashtra",
"9165307", "Bundu\,\ Bihar",
"912749", "Danta\,\ Gujarat",
"91265", "Vadodara\,\ Gujarat",
"918818", "Tadepalligudem\,\ Andhra\ Pradesh",
"9176320", "Balaghat\,\ Madhya\ Pradesh",
"911692", "Tohana\,\ Haryana",
"9162547", "Bettiah\,\ Bihar",
"9174247", "Malhargarh\,\ Madhya\ Pradesh",
"918117", "Kanakapura\,\ Karnataka",
"911896", "Churah\/Tissa\,\ Himachal\ Pradesh",
"9163252", "Pakribarwan\,\ Bihar",
"9176348", "Lamta\,\ Madhya\ Pradesh",
"914554", "Cumbum\,\ Tamil\ Nadu",
"912478", "Bhoom\,\ Maharashtra",
"9167683", "Parajang\,\ Odisha",
"915162", "Orai\,\ Uttar\ Pradesh",
"9165542", "Rajdhanwar\,\ Bihar",
"9162722", "Darbhanga\,\ Bihar",
"9176433", "Bijadandi\,\ Madhya\ Pradesh",
"9176292", "Pushprajgarh\,\ Madhya\ Pradesh",
"918266", "Narsimharajapur\,\ Karnataka",
"9166813", "Jujumura\,\ Odisha",
"912362", "Kudal\,\ Maharashtra",
"911628", "Samrala\,\ Punjab",
"9174695", "Hindaun\,\ Rajasthan",
"9171372", "Desaiganj\,\ Maharashtra",
"9164617", "Raniganj\,\ Bihar",
"9163413", "Seikhpura\,\ Bihar",
"9171613", "Parasia\,\ Madhya\ Pradesh",
"912569", "Navapur\,\ Maharashtra",
"9176329", "Balaghat\,\ Madhya\ Pradesh",
"9167556", "Khurda\,\ Odisha",
"9176816", "Jatara\,\ Madhya\ Pradesh",
"917812", "Damoh\,\ Madhya\ Pradesh",
"912959", "Jhadol\,\ Rajasthan",
"9161815", "Piro\,\ Bihar",
"9164772", "Triveniganj\,\ Bihar",
"911263", "Gohana\,\ Haryana",
"913637", "Cherrapunjee\,\ Meghalaya",
"9162584", "Areraj\,\ Bihar",
"9171897", "Amagaon\,\ Maharashtra",
"9162512", "Bagaha\,\ Bihar",
"9171435", "Bhainsdehi\,\ Madhya\ Pradesh",
"918416", "Vikrabad\,\ Andhra\ Pradesh",
"9176489", "Mawai\,\ Madhya\ Pradesh",
"9174380", "Keshoraipatan\/Patan\,\ Rajasthan",
"9166436", "Barkot\,\ Odisha",
"9174212", "Manasa\,\ Madhya\ Pradesh",
"911498", "Anupgarh\,\ Rajasthan",
"917867", "Bokaband\,\ Madhya\ Pradesh",
"911922", "Kathua\,\ Jammu\ And\ Kashmir",
"915825", "Nawabganj\,\ Uttar\ Pradesh",
"9176462", "Nainpur\,\ Madhya\ Pradesh",
"918738", "Sirpurkagaznagar\,\ Andhra\ Pradesh",
"917856", "Dantewada\,\ Madhya\ Pradesh",
"9176249", "Sihora\,\ Madhya\ Pradesh",
"9165815", "Bhandaria\,\ Bihar",
"9167525", "Puri\,\ Odisha",
"917479", "Bundi\,\ Rajasthan",
"9165616", "Garhwa\,\ Bihar",
"9166406", "Bagdihi\,\ Odisha",
"9176427", "Mandla\,\ Madhya\ Pradesh",
"9165457", "Mandu\,\ Bihar",
"9164385", "Madhupur\,\ Bihar",
"9168692", "Papadhandi\,\ Odisha",
"914869", "Peermedu\,\ Kerala",
"918452", "Medak\,\ Andhra\ Pradesh",
"91370", "Kohima\,\ Nagaland",
"912443", "Manjalegaon\,\ Maharashtra",
"9162475", "Singhwara\,\ Bihar",
"918471", "Mashal\,\ Karnataka",
"9176387", "Damoh\,\ Madhya\ Pradesh",
"912753", "Limbdi\,\ Gujarat",
"9161542", "Siwan\,\ Bihar",
"9166786", "Nowparatan\,\ Odisha",
"918742", "Khammam\,\ Andhra\ Pradesh",
"9174949", "Kolaras\,\ Madhya\ Pradesh",
"9171785", "Sinderwahi\,\ Maharashtra",
"912645", "Jhagadia\,\ Gujarat",
"9161147", "Jahanabad\,\ Bihar",
"9174874", "Begamganj\,\ Madhya\ Pradesh",
"9174143", "Jaora\,\ Madhya\ Pradesh",
"9174928", "Shivpuri\,\ Madhya\ Pradesh",
"918257", "Sullia\,\ Karnataka",
"917671", "Jaitwara\,\ Madhya\ Pradesh",
"912935", "Marwar\ Junction\,\ Rajasthan",
"9168215", "Bhanjanagar\,\ Odisha",
"9162767", "Madhubani\,\ Bihar",
"9176403", "Shahpur\,\ Madhya\ Pradesh",
"912169", "Shirwal\,\ Maharashtra",
"912385", "Udgir\,\ Maharashtra",
"9167977", "Jashipur\,\ Odisha",
"9167966", "Karanjia\,\ Odisha",
"918562", "Kadapa\,\ Andhra\ Pradesh",
"9174940", "Kolaras\,\ Madhya\ Pradesh",
"9168473", "G\.Udayagiri\,\ Odisha",
"9162776", "Phulparas\,\ Bihar",
"911434", "Deoli\,\ Rajasthan",
"918185", "Hosanagara\,\ Karnataka",
"918369", "Hubli\,\ Karnataka",
"9171002", "Kuhi\,\ Maharashtra",
"9165337", "Basia\,\ Bihar",
"914576", "Mudukulathur\,\ Tamil\ Nadu",
"915742", "Etah\,\ Uttar\ Pradesh",
"9174303", "Khanpur\,\ Rajasthan",
"91281", "Rajkot\,\ Gujarat",
"9171326", "Gadchiroli\,\ Maharashtra",
"917732", "Panna\,\ Madhya\ Pradesh",
"9166705", "Bhawanipatna\,\ Odisha",
"917820", "Khairagarh\,\ Madhya\ Pradesh",
"912435", "Kannad\,\ Maharashtra",
"918517", "Atmakur\,\ Andhra\ Pradesh",
"9171706", "Chumur\,\ Maharashtra",
"917770", "Kathdol\,\ Madhya\ Pradesh",
"9165243", "Gumla\,\ Bihar",
"9164516", "Barsoi\,\ Bihar",
"917361", "Susner\,\ Madhya\ Pradesh",
"9167416", "Bhubaneshwar\,\ Odisha",
"9174327", "Jhalawar\,\ Rajasthan",
"9161323", "Barh\,\ Bihar",
"915738", "Khurja\,\ Uttar\ Pradesh",
"9167657", "Palla\ Hara\,\ Odisha",
"916215", "Muzaffarpur\,\ Bihar",
"917580", "Bina\,\ Madhya\ Pradesh",
"9161517", "Sidhawalia\,\ Bihar",
"9176240", "Sihora\,\ Madhya\ Pradesh",
"9174707", "Bundi\,\ Rajasthan",
"9168174", "R\.Udayigiri\,\ Odisha",
"9174513", "Atru\,\ Rajasthan",
"9168624", "Gudari\,\ Odisha",
"9162452", "Gogri\,\ Bihar",
"915452", "Jaunpur\,\ Uttar\ Pradesh",
"9176344", "Lamta\,\ Madhya\ Pradesh",
"912633", "Dharampur\,\ Gujarat",
"9161112", "Hilsa\,\ Bihar",
"9166485", "Patnagarh\,\ Odisha",
"918952", "Chepurupalli\/Garividi\,\ Andhra\ Pradesh",
"9181725", "Hassan\,\ Karnataka",
"914111", "Sriperumbudur\,\ Tamil\ Nadu",
"9171864", "Sakoli\,\ Maharashtra",
"9167862", "Chandbali\,\ Odisha",
"917748", "Dallirajhara\,\ Madhya\ Pradesh",
"9171486", "Prabha\ Pattan\,\ Madhya\ Pradesh",
"9176355", "Lanji\,\ Madhya\ Pradesh",
"9165325", "Giridih\,\ Bihar",
"91215", "Navi\ Mumbai\/Turbhe\,\ Maharashtra",
"918558", "Tadipatri\,\ Andhra\ Pradesh",
"9161356", "Bikram\,\ Bihar",
"9164753", "S\.Bakhtiarpur\,\ Bihar",
"912765", "Visnagar\,\ Gujarat",
"9171757", "Bhadrawati\,\ Maharashtra",
"918617", "Nellore\,\ Andhra\ Pradesh",
"9171065", "Bhiwapur\,\ Maharashtra",
"9166243", "Rajgangpur\,\ Odisha",
"91535", "Raibareli\,\ Uttar\ Pradesh",
"918662", "Vijayawada\,\ Andhra\ Pradesh",
"9174946", "Kolaras\,\ Madhya\ Pradesh",
"9166762", "M\.Rampur\,\ Odisha",
"9167222", "Pardip\,\ Odisha",
"911764", "Samana\,\ Punjab",
"9166733", "Jayapatna\,\ Odisha",
"917267", "Malkapur\,\ Maharashtra",
"9165664", "Japla\,\ Bihar",
"913019", "Pokhran\/Phalsoond\,\ Rajasthan",
"9174335", "Pachpahar\/Bhawanimandi\,\ Rajasthan",
"9165485", "Ichak\,\ Bihar",
"9174842", "Silwani\,\ Madhya\ Pradesh",
"91485", "Muvattupuzha\,\ Kerala",
"918314", "Belgaum\,\ Karnataka",
"9163273", "Rafiganj\,\ Bihar",
"9164204", "Amarpur\,\ Bihar",
"9167606", "Talcher\,\ Odisha",
"913790", "Tali\,\ Arunachal\ Pradesh",
"9165596", "Simaria\,\ Bihar",
"9168584", "Nowrangapur\,\ Odisha",
"9181737", "Sakleshpur\,\ Karnataka",
"9164357", "Pakur\,\ Bihar",
"9171353", "Chamorshi\,\ Maharashtra",
"917680", "Niwari\,\ Madhya\ Pradesh",
"9161574", "Mairwa\,\ Bihar",
"912130", "Velhe\,\ Maharashtra",
"9168117", "Chhatrapur\,\ Odisha",
"9176435", "Bijadandi\,\ Madhya\ Pradesh",
"918225", "Cowdahalli\,\ Karnataka",
"9173298", "Khakner\,\ Madhya\ Pradesh",
"91124", "Gurgaon\,\ Haryana",
"9167685", "Parajang\,\ Odisha",
"916743", "Bhubaneshwar\,\ Odisha",
"918372", "Gadag\,\ Karnataka",
"9167537", "Nayagarh\,\ Odisha",
"9175228", "Datia\,\ Madhya\ Pradesh",
"914366", "Tiruvarur\,\ Tamil\ Nadu",
"9167886", "Soro\,\ Odisha",
"918330", "Saundatti\,\ Karnataka",
"9171462", "Ghorandogri\,\ Madhya\ Pradesh",
"918579", "Palmaneru\,\ Andhra\ Pradesh",
"917274", "Khategaon\,\ Madhya\ Pradesh",
"918468", "Kamareddy\,\ Andhra\ Pradesh",
"912797", "Dhari\,\ Gujarat",
"917781", "Narainpur\,\ Madhya\ Pradesh",
"9171816", "Lakhandur\,\ Maharashtra",
"9174693", "Hindaun\,\ Rajasthan",
"9166815", "Jujumura\,\ Odisha",
"913838", "Aizwal\/Serchip\,\ Mizoram",
"9165406", "Govindpur\,\ Bihar",
"911587", "Degana\,\ Rajasthan",
"9171615", "Parasia\,\ Madhya\ Pradesh",
"9163415", "Seikhpura\,\ Bihar",
"9171134", "Saoner\,\ Maharashtra",
"91369", "Mokokchung\,\ Nagaland",
"9166457", "Jharsuguda\,\ Odisha",
"912114", "Lonavala\,\ Maharashtra",
"9174817", "Gairatganj\,\ Madhya\ Pradesh",
"9161813", "Piro\,\ Bihar",
"9168547", "Jeypore\,\ Odisha",
"917571", "Khirkiya\,\ Madhya\ Pradesh",
"9176372", "Birsa\,\ Madhya\ Pradesh",
"918218", "Mysore\,\ Karnataka",
"9167914", "Bangiriposi\,\ Odisha",
"918351", "Hungund\,\ Karnataka",
"9171984", "Tirora\,\ Maharashtra",
"917917", "Ahmedabad\ Local\,\ Gujarat",
"9168142", "Digapahandi\,\ Odisha",
"91342", "Burdwan\,\ West\ Bengal",
"9171433", "Bhainsdehi\,\ Madhya\ Pradesh",
"9175387", "Ambah\,\ Madhya\ Pradesh",
"915662", "Chhata\/Kosikalan\,\ Uttar\ Pradesh",
"918789", "Karimnagar\,\ Andhra\ Pradesh",
"9167294", "Pattamundai\,\ Odisha",
"917295", "Badnawar\,\ Madhya\ Pradesh",
"917223", "Achalpur\,\ Maharashtra",
"913842", "Silchar\,\ Assam",
"9167523", "Puri\,\ Odisha",
"9165813", "Bhandaria\,\ Bihar",
"912145", "Mahad\,\ Maharashtra",
"917220", "Chhikaldara\,\ Maharashtra",
"911528", "Lunkaransar\,\ Rajasthan",
"912906", "Salumber\,\ Rajasthan",
"9164674", "Banmankhi\,\ Bihar",
"912669", "Chhota\ Udaipur\,\ Gujarat",
"9167317", "Anandapur\,\ Odisha",
"9175912", "Sironj\,\ Madhya\ Pradesh",
"9173222", "Depalpur\,\ Madhya\ Pradesh",
"9171387", "Dhanora\,\ Maharashtra",
"9166542", "Sonapur\,\ Odisha",
"9167276", "Kendrapara\,\ Odisha",
"9177012", "Pingeshwar\,\ Madhya\ Pradesh",
"916127", "Patna\,\ Bihar",
"911336", "Deoband\,\ Uttar\ Pradesh",
"9164383", "Madhupur\,\ Bihar",
"912358", "Dapoli\,\ Maharashtra",
"9175292", "Laher\,\ Madhya\ Pradesh",
"9162473", "Singhwara\,\ Bihar",
"912808", "Sumrasar\,\ Gujarat",
"9181759", "Holenarasipur\,\ Karnataka",
"9165436", "Barhi\,\ Bihar",
"9174386", "Keshoraipatan\/Patan\,\ Rajasthan",
"9171783", "Sinderwahi\,\ Maharashtra",
"9168452", "Phiringia\,\ Odisha",
"9164787", "Saharsa\,\ Bihar",
"9168213", "Bhanjanagar\,\ Odisha",
"9176810", "Jatara\,\ Madhya\ Pradesh",
"918333", "Hukkeri\/Sankeshwar\,\ Karnataka",
"9165697", "Garu\,\ Bihar",
"9174145", "Jaora\,\ Madhya\ Pradesh",
"917516", "Gwalior\,\ Madhya\ Pradesh",
"912461", "Mukhed\,\ Maharashtra",
"9171427", "Bhimpur\,\ Madhya\ Pradesh",
"9176405", "Shahpur\,\ Madhya\ Pradesh",
"912133", "Manchar\,\ Maharashtra",
"9168475", "G\.Udayagiri\,\ Odisha",
"9171344", "Bhamregadh\,\ Maharashtra",
"917683", "Tikamgarh\,\ Madhya\ Pradesh",
"9175947", "Ganjbasoda\,\ Madhya\ Pradesh",
"911255", "Siwani\,\ Haryana",
"914734", "Adoor\,\ Kerala",
"91461", "Thoothukudi\,\ Tamil\ Nadu",
"9181707", "Alur\,\ Karnataka",
"9176486", "Mawai\,\ Madhya\ Pradesh",
"9167636", "Athmallik\,\ Odisha",
"9181750", "Holenarasipur\,\ Karnataka",
"913793", "Mechuka\,\ Arunachal\ Pradesh",
"9164234", "Maheshpur\ Raj\,\ Bihar",
"9161596", "Masrakh\,\ Bihar",
"918483", "Humnabad\,\ Karnataka",
"9174305", "Khanpur\,\ Rajasthan",
"915333", "Karchhana\/Shankergarh\,\ Uttar\ Pradesh",
"9176819", "Jatara\,\ Madhya\ Pradesh",
"912961", "Ghatol\,\ Rajasthan",
"9165245", "Gumla\,\ Bihar",
"9177047", "Deobhog\,\ Madhya\ Pradesh",
"9167497", "Bhubaneshwar\,\ Odisha",
"917256", "Murtizapur\,\ Maharashtra",
"9166703", "Bhawanipatna\,\ Odisha",
"9166517", "Birmaharajpur\,\ Odisha",
"9165574", "Bagodar\,\ Bihar",
"912551", "Sinnar\,\ Maharashtra",
"9161325", "Barh\,\ Bihar",
"9164597", "Thakurganj\,\ Bihar",
"9168646", "Mathili\,\ Odisha",
"918158", "Sidlaghatta\,\ Karnataka",
"9165356", "Chainpur\,\ Bihar",
"9176326", "Balaghat\,\ Madhya\ Pradesh",
"911592", "Jhunjhunu\,\ Rajasthan",
"9174515", "Atru\,\ Rajasthan",
"9167267", "Jajapur\ Road\,\ Odisha",
"9166727", "Dharamgarh\,\ Odisha",
"918857", "Ramachandrapuram\,\ Andhra\ Pradesh",
"91132", "Saharanpur\,\ Uttar\ Pradesh",
"911702", "Nahan\,\ Himachal\ Pradesh",
"9173294", "Khakner\,\ Madhya\ Pradesh",
"911486", "Mandal\,\ Rajasthan",
"9175224", "Datia\,\ Madhya\ Pradesh",
"9166254", "Lahunipara\,\ Odisha",
"918685", "Bhongir\,\ Andhra\ Pradesh",
"9166483", "Patnagarh\,\ Odisha",
"9181723", "Hassan\,\ Karnataka",
"9168193", "Surada\,\ Odisha",
"9161355", "Bikram\,\ Bihar",
"9177034", "Manpur\,\ Madhya\ Pradesh",
"9176356", "Lanji\,\ Madhya\ Pradesh",
"9165326", "Giridih\,\ Bihar",
"9171066", "Bhiwapur\,\ Maharashtra",
"9166757", "T\.Rampur\,\ Odisha",
"911523", "Bikaner\/Poogal\,\ Rajasthan",
"911595", "Jhunjhunu\/Bissau\,\ Rajasthan",
"9164247", "Banka\,\ Bihar",
"9174945", "Kolaras\,\ Madhya\ Pradesh",
"918682", "Nalgonda\,\ Andhra\ Pradesh",
"91385", "Imphal\,\ Manipur",
"9171762", "Warora\,\ Maharashtra",
"912594", "Trimbak\,\ Maharashtra",
"918210", "Mysore\,\ Karnataka",
"918549", "Kalwakurthy\,\ Andhra\ Pradesh",
"9175934", "Kurwai\,\ Madhya\ Pradesh",
"9166224", "Sundargarh\,\ Odisha",
"9171337", "Aheri\,\ Maharashtra",
"912353", "Rajapur\,\ Maharashtra",
"9181753", "Holenarasipur\,\ Karnataka",
"9164333", "Jamtara\,\ Bihar",
"913830", "Champai\/Chiapui\,\ Mizoram",
"9171733", "Rajura\,\ Maharashtra",
"9174642", "Karauli\,\ Rajasthan",
"9164737", "Supaul\,\ Bihar",
"911252", "Loharu\,\ Haryana",
"911574", "Neem\ Ka\ Thana\,\ Rajasthan",
"9164362", "Sahibganj\,\ Bihar",
"9168494", "Daringbadi\,\ Odisha",
"913872", "Chandel\,\ Manipur",
"912803", "Khavda\,\ Gujarat",
"9181720", "Hassan\,\ Karnataka",
"9165864", "Chainpur\,\ Bihar",
"913676", "Howraghat\,\ Assam",
"915960", "Shahabad\,\ Uttar\ Pradesh",
"9174336", "Pachpahar\/Bhawanimandi\,\ Rajasthan",
"9165486", "Ichak\,\ Bihar",
"917660", "Sirmour\,\ Madhya\ Pradesh",
"917541", "Isagarh\,\ Madhya\ Pradesh",
"9167605", "Talcher\,\ Odisha",
"9165595", "Simaria\,\ Bihar",
"918338", "Chikkodi\,\ Karnataka",
"911883", "Dasua\,\ Punjab",
"9176574", "Jaitpur\,\ Madhya\ Pradesh",
"912837", "Bhachav\,\ Gujarat",
"915460", "Phulpur\,\ Uttar\ Pradesh",
"9168504", "Kalimela\,\ Odisha",
"9176436", "Bijadandi\,\ Madhya\ Pradesh",
"9164212", "Naugachia\,\ Bihar",
"913798", "Mariyang\,\ Arunachal\ Pradesh",
"9167686", "Parajang\,\ Odisha",
"9181729", "Hassan\,\ Karnataka",
"912138", "Shirur\,\ Maharashtra",
"9167885", "Soro\,\ Odisha",
"9168422", "Phulbani\,\ Odisha",
"917688", "Gourihar\,\ Madhya\ Pradesh",
"9166462", "Bargarh\,\ Odisha",
"918531", "Deodurga\,\ Karnataka",
"914936", "Kalpetta\,\ Kerala",
"9177008", "Nagri\,\ Madhya\ Pradesh",
"9166816", "Jujumura\,\ Odisha",
"911567", "Ratangarh\,\ Rajasthan",
"9171815", "Lakhandur\,\ Maharashtra",
"9175908", "Lateri\,\ Madhya\ Pradesh",
"916616", "Rourkela\,\ Odisha",
"9164284", "Nala\,\ Bihar",
"917761", "Tapkara\,\ Madhya\ Pradesh",
"9171616", "Parasia\,\ Madhya\ Pradesh",
"9163416", "Seikhpura\,\ Bihar",
"9181748", "Arsikere\,\ Karnataka",
"918488", "Sindagi\,\ Karnataka",
"91206", "Pune\,\ Maharashtra",
"9161897", "Bhabhua\,\ Bihar",
"9165405", "Govindpur\,\ Bihar",
"9171457", "Chicholi\,\ Madhya\ Pradesh",
"912142", "Pali\,\ Maharashtra",
"9176813", "Jatara\,\ Madhya\ Pradesh",
"9167553", "Khurda\,\ Odisha",
"917370", "Khilchipur\,\ Madhya\ Pradesh",
"917539", "Gohad\,\ Madhya\ Pradesh",
"913713", "Mangaldoi\,\ Assam",
"9174617", "Mahuwa\,\ Rajasthan",
"911957", "Bandipur\,\ Jammu\ And\ Kashmir",
"918153", "Bangarpet\,\ Karnataka",
"91469", "Tiruvalla\,\ Kerala",
"9173932", "Jobat\,\ Madhya\ Pradesh",
"918550", "Yellanuru\,\ Andhra\ Pradesh",
"9166433", "Barkot\,\ Odisha",
"915342", "Pratapgarh\,\ Uttar\ Pradesh",
"918234", "Nagamangala\,\ Karnataka",
"9171147", "Ramtek\,\ Maharashtra",
"9174690", "Hindaun\,\ Rajasthan",
"918394", "Hospet\,\ Karnataka",
"9166403", "Bagdihi\,\ Odisha",
"9165613", "Garhwa\,\ Bihar",
"9176578", "Jaitpur\,\ Madhya\ Pradesh",
"9167275", "Kendrapara\,\ Odisha",
"918150", "Bagepalli\,\ Karnataka",
"913845", "Ukhrul\ Central\,\ Manipur",
"917292", "Dhar\,\ Madhya\ Pradesh",
"913654", "Nongstoin\,\ Meghalaya",
"918222", "Hunsur\,\ Karnataka",
"9165435", "Barhi\,\ Bihar",
"9174385", "Keshoraipatan\/Patan\,\ Rajasthan",
"918375", "Haveri\,\ Karnataka",
"9175938", "Kurwai\,\ Madhya\ Pradesh",
"9166783", "Nowparatan\,\ Odisha",
"918131", "Gubbi\,\ Karnataka",
"9177038", "Manpur\,\ Madhya\ Pradesh",
"9174146", "Jaora\,\ Madhya\ Pradesh",
"913807", "Miao\,\ Arunachal\ Pradesh",
"918963", "Parvathipuram\,\ Andhra\ Pradesh",
"9176406", "Shahpur\,\ Madhya\ Pradesh",
"9168467", "Baliguda\,\ Odisha",
"9166427", "Kuchinda\,\ Odisha",
"915463", "Lalganj\,\ Uttar\ Pradesh",
"912481", "Ner\,\ Maharashtra",
"9168534", "Sunabeda\,\ Odisha",
"9165897", "Jhinkpani\,\ Bihar",
"912326", "Gaganbavada\,\ Maharashtra",
"9167587", "Nimapara\,\ Odisha",
"9167963", "Karanjia\,\ Odisha",
"9168476", "G\.Udayagiri\,\ Odisha",
"9176485", "Mawai\,\ Madhya\ Pradesh",
"9167635", "Athmallik\,\ Odisha",
"9162773", "Phulparas\,\ Bihar",
"917663", "Mauganj\,\ Madhya\ Pradesh",
"9161864", "Aurangabad\,\ Bihar",
"9174306", "Khanpur\,\ Rajasthan",
"915963", "Bageshwar\,\ Uttar\ Pradesh",
"912981", "Sheo\/Harsani\,\ Rajasthan",
"9171323", "Gadchiroli\,\ Maharashtra",
"9161595", "Masrakh\,\ Bihar",
"9171184", "Kalmeshwar\,\ Maharashtra",
"914894", "Agathy\,\ Lakshadweep",
"9164327", "Deoghar\,\ Bihar",
"91233", "Sangli\,\ Maharashtra",
"918463", "Armoor\,\ Andhra\ Pradesh",
"9164513", "Barsoi\,\ Bihar",
"9165246", "Gumla\,\ Bihar",
"9171703", "Chumur\,\ Maharashtra",
"9171517", "Samudrapur\,\ Maharashtra",
"912350", "Madangad\,\ Maharashtra",
"9165355", "Chainpur\,\ Bihar",
"9168645", "Mathili\,\ Odisha",
"9176325", "Balaghat\,\ Madhya\ Pradesh",
"9167413", "Bhubaneshwar\,\ Odisha",
"9163374", "Arwal\,\ Bihar",
"9175904", "Lateri\,\ Madhya\ Pradesh",
"9161326", "Barh\,\ Bihar",
"918213", "Mysore\,\ Karnataka",
"9171727", "Chandrapur\,\ Maharashtra",
"9181744", "Arsikere\,\ Karnataka",
"912762", "Mehsana\,\ Gujarat",
"9174516", "Atru\,\ Rajasthan",
"9174699", "Hindaun\,\ Rajasthan",
"918665", "Vijayawada\,\ Andhra\ Pradesh",
"917228", "Morshi\,\ Maharashtra",
"911520", "Bikaner\/Chhatargarh\,\ Rajasthan",
"91361", "Guwahati\,\ Assam",
"9167932", "Betanati\,\ Odisha",
"9167252", "Dhanmandal\,\ Odisha",
"912194", "Roha\,\ Maharashtra",
"9171483", "Prabha\ Pattan\,\ Madhya\ Pradesh",
"911466", "Kekri\,\ Rajasthan",
"9177004", "Nagri\,\ Madhya\ Pradesh",
"9174532", "Baran\,\ Rajasthan",
"912925", "Phalodi\,\ Rajasthan",
"914295", "Sathiyamangalam\,\ Tamil\ Nadu",
"912993", "Jaisalmer\/Devikot\,\ Rajasthan",
"9167296", "Pattamundai\,\ Odisha",
"9176488", "Mawai\,\ Madhya\ Pradesh",
"9162232", "Motipur\,\ Bihar",
"9171986", "Tirora\,\ Maharashtra",
"916637", "Sambalpur\,\ Odisha",
"911924", "Akhnoor\,\ Jammu\ And\ Kashmir",
"918840", "Kakinada\,\ Andhra\ Pradesh",
"9176287", "Karpa\,\ Madhya\ Pradesh",
"91376", "Jorhat\,\ Assam",
"9167916", "Bangiriposi\,\ Odisha",
"9174137", "Sailana\,\ Madhya\ Pradesh",
"9174870", "Begamganj\,\ Madhya\ Pradesh",
"918715", "Mulug\,\ Andhra\ Pradesh",
"912667", "Savli\,\ Gujarat",
"9165677", "Barwadih\,\ Bihar",
"9165404", "Govindpur\,\ Bihar",
"9164285", "Nala\,\ Bihar",
"9171136", "Saoner\,\ Maharashtra",
"9167812", "Basta\,\ Odisha",
"915164", "Kalpi\,\ Uttar\ Pradesh",
"9171814", "Lakhandur\,\ Maharashtra",
"91478", "Cherthala\,\ Kerala",
"9162742", "Samastipur\,\ Bihar",
"914116", "Tiruvallur\,\ Tamil\ Nadu",
"914552", "Usilampatti\,\ Tamil\ Nadu",
"9176328", "Balaghat\,\ Madhya\ Pradesh",
"9176349", "Lamta\,\ Madhya\ Pradesh",
"9167884", "Soro\,\ Odisha",
"917366", "Khachrod\,\ Madhya\ Pradesh",
"918728", "Peddapalli\,\ Andhra\ Pradesh",
"9174563", "Kishanganj\/Bhanwargarh\,\ Rajasthan",
"918177", "Belur\,\ Karnataka",
"9161567", "Gopalganj\,\ Bihar",
"9140", "Hyderabad\ Local\,\ Andhra\ Pradesh",
"9168505", "Kalimela\,\ Odisha",
"9162263", "Sitamarhi\,\ Bihar",
"912364", "Deogad\,\ Maharashtra",
"913482", "Berhampur\,\ West\ Bengal",
"9176575", "Jaitpur\,\ Madhya\ Pradesh",
"918502", "Alampur\,\ Andhra\ Pradesh",
"9161576", "Mairwa\,\ Bihar",
"912623", "Mandvi\,\ Gujarat",
"9167604", "Talcher\,\ Odisha",
"913244", "Bishnupur\,\ West\ Bengal",
"9171602", "Jamai\,\ Madhya\ Pradesh",
"9165594", "Simaria\,\ Bihar",
"9168586", "Nowrangapur\,\ Odisha",
"911473", "Barisadri\,\ Rajasthan",
"9174227", "Mandsaur\,\ Madhya\ Pradesh",
"9165865", "Chainpur\,\ Bihar",
"917851", "Bhopalpatnam\,\ Madhya\ Pradesh",
"9168495", "Daringbadi\,\ Odisha",
"9162527", "Motihari\,\ Bihar",
"9164206", "Amarpur\,\ Bihar",
"9176340", "Lamta\,\ Madhya\ Pradesh",
"9165666", "Japla\,\ Bihar",
"9162717", "Benipatti\,\ Bihar",
"9162503", "Dhaka\,\ Bihar",
"917722", "Dhamtari\,\ Madhya\ Pradesh",
"9167847", "Bhadrak\,\ Odisha",
"9174203", "Jawad\,\ Madhya\ Pradesh",
"9166225", "Sundargarh\,\ Odisha",
"9175935", "Kurwai\,\ Madhya\ Pradesh",
"9168653", "Kashipur\,\ Odisha",
"9165343", "Jhumaritalaiya\,\ Bihar",
"912674", "Lunavada\,\ Gujarat",
"9174944", "Kolaras\,\ Madhya\ Pradesh",
"9174388", "Keshoraipatan\/Patan\,\ Rajasthan",
"912425", "Sangamner\,\ Maharashtra",
"9174879", "Begamganj\,\ Madhya\ Pradesh",
"9171573", "Arvi\,\ Maharashtra",
"918476", "Wadi\,\ Karnataka",
"9164577", "Korha\,\ Bihar",
"911675", "Malerkotla\,\ Punjab",
"9165237", "Ghaghra\,\ Bihar",
"91354", "Darjeeling\,\ West\ Bengal",
"911424", "Phulera\/Renwal\,\ Rajasthan",
"9161354", "Bikram\,\ Bihar",
"9177035", "Manpur\,\ Madhya\ Pradesh",
"9164622", "Dhamdaha\,\ Bihar",
"9177005", "Nagri\,\ Madhya\ Pradesh",
"9175226", "Datia\,\ Madhya\ Pradesh",
"913663", "Goalpara\,\ Assam",
"9166256", "Lahunipara\,\ Odisha",
"911237", "Sardhana\,\ Uttar\ Pradesh",
"9174347", "Pirawa\/Raipur\,\ Rajasthan",
"9173296", "Khakner\,\ Madhya\ Pradesh",
"915843", "Jalalabad\,\ Uttar\ Pradesh",
"9163463", "Lakhisarai\,\ Bihar",
"9171663", "Chaurai\,\ Madhya\ Pradesh",
"9164667", "Kishanganj\,\ Bihar",
"917833", "Udaipur\,\ Madhya\ Pradesh",
"9181745", "Arsikere\,\ Karnataka",
"913215", "Bongoan\,\ West\ Bengal",
"918619", "Nellore\,\ Andhra\ Pradesh",
"9174233", "Neemuch\,\ Madhya\ Pradesh",
"9175905", "Lateri\,\ Madhya\ Pradesh",
"9174953", "Badarwas\,\ Madhya\ Pradesh",
"918261", "Tarikere\,\ Karnataka",
"9168644", "Mathili\,\ Odisha",
"9165354", "Chainpur\,\ Bihar",
"9176324", "Balaghat\,\ Madhya\ Pradesh",
"915454", "Machlishahar\,\ Uttar\ Pradesh",
"9162533", "Narkatiaganj\,\ Bihar",
"9163375", "Arwal\,\ Bihar",
"9174262", "Sitamau\,\ Madhya\ Pradesh",
"914256", "Bhavani\,\ Tamil\ Nadu",
"915744", "Kasganj\,\ Uttar\ Pradesh",
"911432", "Tonk\,\ Rajasthan",
"918411", "Tanduru\,\ Andhra\ Pradesh",
"9165576", "Bagodar\,\ Bihar",
"9162562", "Ramnagar\,\ Bihar",
"9176412", "Niwas\,\ Madhya\ Pradesh",
"9161594", "Masrakh\,\ Bihar",
"9171185", "Kalmeshwar\,\ Maharashtra",
"9164236", "Maheshpur\ Raj\,\ Bihar",
"913465", "Nalhati\,\ West\ Bengal",
"9172887", "Bhikangaon\,\ Madhya\ Pradesh",
"9174920", "Shivpuri\,\ Madhya\ Pradesh",
"91591", "Moradabad\,\ Uttar\ Pradesh",
"916313", "Gaya\,\ Bihar",
"918835", "Rajahmundri\,\ Andhra\ Pradesh",
"918564", "Proddatur\,\ Andhra\ Pradesh",
"911470", "Dungla\,\ Rajasthan",
"9176253", "Umariapan\,\ Madhya\ Pradesh",
"917269", "Sindkhedaraja\,\ Maharashtra",
"9165223", "Muri\,\ Bihar",
"914343", "Krishnagiri\,\ Tamil\ Nadu",
"9161865", "Aurangabad\,\ Bihar",
"9176484", "Mawai\,\ Madhya\ Pradesh",
"91761", "Jabalpur\,\ Madhya\ Pradesh",
"9167634", "Athmallik\,\ Odisha",
"917734", "Shahnagar\,\ Madhya\ Pradesh",
"9171346", "Bhamregadh\,\ Maharashtra",
"913228", "Tamluk\,\ West\ Bengal",
"913017", "Pokhran\/Madasar\,\ Rajasthan",
"9166832", "Padmapur\,\ Odisha",
"9174673", "Bamanwas\,\ Rajasthan",
"9168535", "Sunabeda\,\ Odisha",
"9174929", "Shivpuri\,\ Madhya\ Pradesh",
"911970", "Dehra\ Gopipur\,\ Himachal\ Pradesh",
"9174312", "Aklera\,\ Rajasthan",
"911382", "Lansdowne\/Kotdwara\,\ Uttarakhand",
"918744", "Kothagudem\,\ Andhra\ Pradesh",
"918206", "Udupi\,\ Karnataka",
"915564", "Padrauna\,\ Uttar\ Pradesh",
"9168687", "Nandapur\,\ Odisha",
"911932", "Anantnag\,\ Jammu\ And\ Kashmir",
"9161522", "Chapra\,\ Bihar",
"911589", "Parbatsar\,\ Rajasthan",
"912871", "Keshod\,\ Gujarat",
"9165567", "Tisri\,\ Bihar",
"918577", "Putturu\,\ Andhra\ Pradesh",
"9161127", "Biharsharif\,\ Bihar",
"9174123", "Ratlam\,\ Madhya\ Pradesh",
"9165434", "Barhi\,\ Bihar",
"9174948", "Kolaras\,\ Madhya\ Pradesh",
"9174384", "Keshoraipatan\/Patan\,\ Rajasthan",
"9176447", "Dindori\,\ Madhya\ Pradesh",
"911638", "Fazilka\,\ Punjab",
"918787", "Karimnagar\,\ Andhra\ Pradesh",
"918843", "Kakinada\,\ Andhra\ Pradesh",
"9167274", "Kendrapara\,\ Odisha",
"9164676", "Banmankhi\,\ Bihar",
"9176248", "Sihora\,\ Madhya\ Pradesh",
"918454", "Gajwel\,\ Andhra\ Pradesh",
"914171", "Gudiyatham\,\ Tamil\ Nadu",
"915261", "Tarabganj\/Colonelganj\,\ Uttar\ Pradesh",
"9174502", "Sangod\,\ Rajasthan",
"914985", "Payyanur\,\ Kerala",
"912990", "Bhinmal\/Jasawantpura\,\ Rajasthan",
"9165447", "Gomia\,\ Bihar",
"918491", "Kanaganapalle\,\ Andhra\ Pradesh",
"911607", "Kharar\,\ Punjab",
"9167295", "Pattamundai\,\ Odisha",
"913668", "Bijni\,\ Assam",
"9176259", "Umariapan\,\ Madhya\ Pradesh",
"9171985", "Tirora\,\ Maharashtra",
"9174120", "Ratlam\,\ Madhya\ Pradesh",
"9174670", "Bamanwas\,\ Rajasthan",
"9167915", "Bangiriposi\,\ Odisha",
"914332", "Manaparai\,\ Tamil\ Nadu",
"9163322", "Nabinagar\,\ Bihar",
"9162583", "Areraj\,\ Bihar",
"917691", "Chhapara\,\ Madhya\ Pradesh",
"9174308", "Khanpur\,\ Rajasthan",
"914982", "Taliparamba\,\ Kerala",
"913552", "Kalimpong\,\ West\ Bengal",
"9165392", "Bolwa\,\ Bihar",
"912347", "Vita\,\ Maharashtra",
"9171614", "Parasia\,\ Madhya\ Pradesh",
"9171135", "Saoner\,\ Maharashtra",
"9163414", "Seikhpura\,\ Bihar",
"91476", "Karunagapally\,\ Kerala",
"9164286", "Nala\,\ Bihar",
"913809", "Sagalee\,\ Arunachal\ Pradesh",
"9167612", "Chhendipada\,\ Odisha",
"9174959", "Badarwas\,\ Madhya\ Pradesh",
"915870", "Bhira\,\ Uttar\ Pradesh",
"9174239", "Neemuch\,\ Madhya\ Pradesh",
"9174518", "Atru\,\ Rajasthan",
"915832", "Badaun\,\ Uttar\ Pradesh",
"9161552", "Ekma\,\ Bihar",
"918621", "Rapur\/Podalakur\,\ Andhra\ Pradesh",
"9166814", "Jujumura\,\ Odisha",
"9165877", "Chakardharpur\,\ Bihar",
"915946", "Haldwani\,\ Uttar\ Pradesh",
"913223", "Nayagarh\/Kultikri\,\ West\ Bengal",
"912384", "Nilanga\,\ Maharashtra",
"9176567", "Kannodi\,\ Madhya\ Pradesh",
"912934", "Desuri\/Rani\,\ Rajasthan",
"9168506", "Kalimela\,\ Odisha",
"914348", "Palakkodu\,\ Tamil\ Nadu",
"9176434", "Bijadandi\,\ Madhya\ Pradesh",
"9163482", "Mallehpur\,\ Bihar",
"9171682", "Harrai\,\ Madhya\ Pradesh",
"9161157", "Danapur\,\ Bihar",
"9167684", "Parajang\,\ Odisha",
"912644", "Jambusar\,\ Gujarat",
"918720", "Mahadevapur\,\ Andhra\ Pradesh",
"9171802", "Salekasa\,\ Maharashtra",
"9161575", "Mairwa\,\ Bihar",
"9168637", "Bisam\ Cuttack\,\ Odisha",
"9176576", "Jaitpur\,\ Madhya\ Pradesh",
"915446", "Dudhi\/Pipri\,\ Uttar\ Pradesh",
"918184", "Sorab\,\ Karnataka",
"911435", "Tonk\/Piploo\,\ Rajasthan",
"9168585", "Nowrangapur\,\ Odisha",
"91181", "Jallandhar\,\ Punjab",
"9174950", "Badarwas\,\ Madhya\ Pradesh",
"9174230", "Neemuch\,\ Madhya\ Pradesh",
"91562", "Agra\,\ Uttar\ Pradesh",
"918636", "Guntur\,\ Andhra\ Pradesh",
"9165412", "Chatra\,\ Bihar",
"913462", "Suri\,\ West\ Bengal",
"918832", "Rajahmundri\,\ Andhra\ Pradesh",
"9174907", "Pohari\,\ Madhya\ Pradesh",
"9168496", "Daringbadi\,\ Odisha",
"9165253", "Simdega\,\ Bihar",
"9164205", "Amarpur\,\ Bihar",
"914287", "Rasipuram\,\ Tamil\ Nadu",
"9165933", "Manoharpur\,\ Bihar",
"91792", "Ahmedabad\ Local\,\ Gujarat",
"9165866", "Chainpur\,\ Bihar",
"9174334", "Pachpahar\/Bhawanimandi\,\ Rajasthan",
"9165484", "Ichak\,\ Bihar",
"9165665", "Japla\,\ Bihar",
"9162793", "Barauni\,\ Bihar",
"9176250", "Umariapan\,\ Madhya\ Pradesh",
"9175936", "Kurwai\,\ Madhya\ Pradesh",
"9166226", "Sundargarh\,\ Odisha",
"915491", "Rasara\,\ Uttar\ Pradesh",
"918848", "Kakinada\,\ Andhra\ Pradesh",
"9174129", "Ratlam\,\ Madhya\ Pradesh",
"916214", "Muzaffarpur\,\ Bihar",
"9167647", "Anugul\,\ Odisha",
"9165962", "Noamundi\,\ Bihar",
"911633", "Muktasar\,\ Punjab",
"9176408", "Shahpur\,\ Madhya\ Pradesh",
"9171064", "Bhiwapur\,\ Maharashtra",
"913212", "Champadanga\,\ West\ Bengal",
"9166573", "Kantabhanji\,\ Odisha",
"9177036", "Manpur\,\ Madhya\ Pradesh",
"9174923", "Shivpuri\,\ Madhya\ Pradesh",
"9174148", "Jaora\,\ Madhya\ Pradesh",
"9174679", "Bamanwas\,\ Rajasthan",
"9176354", "Lanji\,\ Madhya\ Pradesh",
"917790", "Babaichichli\,\ Madhya\ Pradesh",
"9162442", "Khagaria\,\ Bihar",
"9165324", "Giridih\,\ Bihar",
"916576", "Jamshedpur\,\ Bihar",
"917793", "Kareli\,\ Madhya\ Pradesh",
"917725", "Saraipali\,\ Madhya\ Pradesh",
"912841", "Vallabhipur\,\ Gujarat",
"9174569", "Kishanganj\/Bhanwargarh\,\ Rajasthan",
"9175225", "Datia\,\ Madhya\ Pradesh",
"9177006", "Nagri\,\ Madhya\ Pradesh",
"9166255", "Lahunipara\,\ Odisha",
"9171863", "Sakoli\,\ Maharashtra",
"912998", "Jaisalmer\/Khuiyals\,\ Rajasthan",
"9174582", "Pipalda\/Sumerganj\ Mandi\,\ Rajasthan",
"9176343", "Lamta\,\ Madhya\ Pradesh",
"9168623", "Gudari\,\ Odisha",
"912422", "Shri\ Rampur\,\ Maharashtra",
"9173295", "Khakner\,\ Madhya\ Pradesh",
"9176438", "Bijadandi\,\ Madhya\ Pradesh",
"9162282", "Pupri\,\ Bihar",
"9181746", "Arsikere\,\ Karnataka",
"918774", "Tirupathi\,\ Andhra\ Pradesh",
"9174514", "Atru\,\ Rajasthan",
"9168173", "R\.Udayigiri\,\ Odisha",
"9163376", "Arwal\,\ Bihar",
"911672", "Sangrur\,\ Punjab",
"9175906", "Lateri\,\ Madhya\ Pradesh",
"9161324", "Barh\,\ Bihar",
"912896", "Bhanvad\,\ Gujarat",
"9165575", "Bagodar\,\ Bihar",
"913485", "Dhuliyan\,\ West\ Bengal",
"918584", "Piler\,\ Andhra\ Pradesh",
"912692", "Anand\,\ Gujarat",
"9165244", "Gumla\,\ Bihar",
"918505", "Kodangal\,\ Andhra\ Pradesh",
"9174304", "Khanpur\,\ Rajasthan",
"914997", "Kanhangad\,\ Kerala",
"9164235", "Maheshpur\ Raj\,\ Bihar",
"9171186", "Kalmeshwar\,\ Maharashtra",
"911651", "Phulmandi\,\ Punjab",
"911749", "Assandh\,\ Haryana",
"9174257", "Garoth\,\ Madhya\ Pradesh",
"9174937", "Karera\,\ Madhya\ Pradesh",
"9162557", "Raxaul\,\ Bihar",
"911978", "Bilaspur\,\ Himachal\ Pradesh",
"9174200", "Jawad\,\ Madhya\ Pradesh",
"9161866", "Aurangabad\,\ Bihar",
"917289", "Zhirnia\,\ Madhya\ Pradesh",
"9168607", "Boriguma\,\ Odisha",
"9168474", "G\.Udayagiri\,\ Odisha",
"918723", "Sircilla\,\ Andhra\ Pradesh",
"9171832", "Tumsar\,\ Maharashtra",
"9171345", "Bhamregadh\,\ Maharashtra",
"9176404", "Shahpur\,\ Madhya\ Pradesh",
"9168536", "Sunabeda\,\ Odisha",
"911569", "Sujangarh\/Lalgarh\,\ Rajasthan",
"9161877", "Mohania\,\ Bihar",
"9174144", "Jaora\,\ Madhya\ Pradesh",
"9174873", "Begamganj\,\ Madhya\ Pradesh",
"914324", "Karur\,\ Tamil\ Nadu",
"9176522", "Shahdol\,\ Madhya\ Pradesh",
"9176358", "Lanji\,\ Madhya\ Pradesh",
"913220", "Contai\,\ West\ Bengal",
"9163242", "Nawada\,\ Bihar",
"912628", "Nizar\,\ Gujarat",
"912839", "Lakhpat\,\ Gujarat",
"9144", "Chennai\,\ Tamil\ Nadu",
"911478", "Pratapgarh\,\ Rajasthan",
"915723", "Atrauli\,\ Uttar\ Pradesh",
"915873", "Nighasan\/Tikunia\,\ Uttar\ Pradesh",
"9174209", "Jawad\,\ Madhya\ Pradesh",
"9171097", "Kamptee\,\ Maharashtra",
"912922", "Osian\,\ Rajasthan",
"914292", "Valapady\,\ Tamil\ Nadu",
"9163367", "Rajauli\,\ Bihar",
"9174338", "Pachpahar\/Bhawanimandi\,\ Rajasthan",
"914373", "Pattukottai\,\ Tamil\ Nadu",
"9174560", "Kishanganj\/Bhanwargarh\,\ Rajasthan",
"915547", "Khalilabad\,\ Uttar\ Pradesh",
"9165287", "Khunti\,\ Bihar",
"915824", "Aonla\/Ramnagar\,\ Uttar\ Pradesh",
"917537", "Jora\,\ Madhya\ Pradesh",
"915281", "Mahoba\,\ Uttar\ Pradesh",
"9164675", "Banmankhi\,\ Bihar",
"911731", "Barara\,\ Haryana",
"9167293", "Pattamundai\,\ Odisha",
"914188", "Chengam\,\ Tamil\ Nadu",
"912986", "Barmer\/Dhorimanna\,\ Rajasthan",
"9161882", "Rohtas\,\ Bihar",
"9171567", "Talegaokarangal\,\ Maharashtra",
"9171983", "Tirora\,\ Maharashtra",
"912144", "Murud\,\ Maharashtra",
"918199", "Hosadurga\,\ Karnataka",
"9171434", "Bhainsdehi\,\ Madhya\ Pradesh",
"9162585", "Areraj\,\ Bihar",
"91121", "Meerut\,\ Uttar\ Pradesh",
"918232", "Mandya\,\ Karnataka",
"911906", "Spiti\/Kaza\,\ Himachal\ Pradesh",
"9167913", "Bangiriposi\,\ Odisha",
"911669", "Adampur\ Mandi\,\ Haryana",
"916713", "Cuttack\,\ Odisha",
"9161814", "Piro\,\ Bihar",
"9166552", "Titlagarh\,\ Odisha",
"912528", "Dahanu\,\ Maharashtra",
"9171162", "Umrer\,\ Maharashtra",
"9175909", "Lateri\,\ Madhya\ Pradesh",
"9168442", "Kantamal\,\ Odisha",
"9171133", "Saoner\,\ Maharashtra",
"912187", "Sangola\,\ Maharashtra",
"911461", "Bansur\,\ Rajasthan",
"9181749", "Arsikere\,\ Karnataka",
"9174694", "Hindaun\,\ Rajasthan",
"9164532", "Araria\,\ Bihar",
"913867", "Zuenheboto\,\ Nagaland",
"9181728", "Hassan\,\ Karnataka",
"9174566", "Kishanganj\/Bhanwargarh\,\ Rajasthan",
"915647", "Bari\,\ Rajasthan",
"9162266", "Sitamarhi\,\ Bihar",
"918248", "Mangalore\,\ Karnataka",
"9165272", "Kolebira\,\ Bihar",
"9177009", "Nagri\,\ Madhya\ Pradesh",
"917238", "Darwaha\,\ Maharashtra",
"9181740", "Arsikere\,\ Karnataka",
"9162277", "Mahua\,\ Bihar",
"911379", "Pratapnagar\,\ Uttarakhand",
"9174577", "Mangrol\,\ Rajasthan",
"913874", "Churchandpur\,\ Manipur",
"9161573", "Mairwa\,\ Bihar",
"917603", "Tendukheda\,\ Madhya\ Pradesh",
"914735", "Ranni\,\ Kerala",
"911254", "Bawanikhera\,\ Haryana",
"917447", "Ladpura\/Kota\,\ Rajasthan",
"9175957", "Nateran\,\ Madhya\ Pradesh",
"911572", "Sikar\,\ Rajasthan",
"9171354", "Chamorshi\,\ Maharashtra",
"9174622", "Sawaimadhopur\,\ Rajasthan",
"9167352", "Telkoi\,\ Odisha",
"9175900", "Lateri\,\ Madhya\ Pradesh",
"9168583", "Nowrangapur\,\ Odisha",
"9177057", "Kurud\,\ Madhya\ Pradesh",
"9164203", "Amarpur\,\ Bihar",
"918387", "Honnavar\,\ Karnataka",
"9165935", "Manoharpur\,\ Bihar",
"9165255", "Simdega\,\ Bihar",
"9163274", "Rafiganj\,\ Bihar",
"9177000", "Nagri\,\ Madhya\ Pradesh",
"9162795", "Barauni\,\ Bihar",
"915248", "Barabanki\,\ Uttar\ Pradesh",
"918937", "Chintapalle\,\ Andhra\ Pradesh",
"9166734", "Jayapatna\,\ Odisha",
"913583", "Mathabhanga\,\ West\ Bengal",
"9165663", "Japla\,\ Bihar",
"918647", "Narsaraopet\,\ Andhra\ Pradesh",
"918403", "Yerragondapalem\,\ Andhra\ Pradesh",
"914563", "Rajapalayam\,\ Tamil\ Nadu",
"9162506", "Dhaka\,\ Bihar",
"9164227", "Godda\,\ Bihar",
"9165632", "Bhawanathpur\,\ Bihar",
"9174206", "Jawad\,\ Madhya\ Pradesh",
"912321", "Radhanagar\,\ Maharashtra",
"9165346", "Jhumaritalaiya\,\ Bihar",
"9168656", "Kashipur\,\ Odisha",
"913823", "Belonia\,\ Tripura",
"9168417", "Boudh\,\ Odisha",
"9164754", "S\.Bakhtiarpur\,\ Bihar",
"9166575", "Kantabhanji\,\ Odisha",
"918684", "Suryapet\,\ Andhra\ Pradesh",
"912592", "Kalwan\,\ Maharashtra",
"9166244", "Rajgangpur\,\ Odisha",
"9171576", "Arvi\,\ Maharashtra",
"917757", "Shakti\,\ Madhya\ Pradesh",
"918136", "Pavagada\,\ Karnataka",
"915270", "Bikapur\,\ Uttar\ Pradesh",
"91512", "Kanpur\,\ Uttar\ Pradesh",
"911782", "Rampur\ Bushahar\,\ Himachal\ Pradesh",
"9174925", "Shivpuri\,\ Madhya\ Pradesh",
"9171865", "Sakoli\,\ Maharashtra",
"9166253", "Lahunipara\,\ Odisha",
"9175223", "Datia\,\ Madhya\ Pradesh",
"9171747", "Mul\,\ Maharashtra",
"915273", "Tandai\/Tanda\,\ Uttar\ Pradesh",
"9166484", "Patnagarh\,\ Odisha",
"912764", "Kalol\,\ Gujarat",
"9181724", "Hassan\,\ Karnataka",
"9173293", "Khakner\,\ Madhya\ Pradesh",
"9168625", "Gudari\,\ Odisha",
"9176345", "Lamta\,\ Madhya\ Pradesh",
"918328", "Goa",
"9171666", "Chaurai\,\ Madhya\ Pradesh",
"917766", "Dharamjaigarh\,\ Madhya\ Pradesh",
"9163466", "Lakhisarai\,\ Bihar",
"9164262", "Rajmahal\,\ Bihar",
"9168175", "R\.Udayigiri\,\ Odisha",
"911765", "Nabha\,\ Punjab",
"912192", "Khopoli\,\ Maharashtra",
"9176570", "Jaitpur\,\ Madhya\ Pradesh",
"914931", "Nilambur\,\ Kerala",
"9165602", "Patan\,\ Bihar",
"9174956", "Badarwas\,\ Madhya\ Pradesh",
"918536", "Kustagi\,\ Karnataka",
"9166412", "Deodgarh\,\ Odisha",
"9174236", "Neemuch\,\ Madhya\ Pradesh",
"9162536", "Narkatiaganj\,\ Bihar",
"915521", "Bansgaon\/Barhal\ Ganj\,\ Uttar\ Pradesh",
"9174698", "Hindaun\,\ Rajasthan",
"918315", "Belgaum\,\ Karnataka",
"9174852", "Udaipura\,\ Madhya\ Pradesh",
"9165573", "Bagodar\,\ Bihar",
"9166704", "Bhawanipatna\,\ Odisha",
"9177030", "Manpur\,\ Madhya\ Pradesh",
"9164233", "Maheshpur\ Raj\,\ Bihar",
"915881", "Bisalpur\,\ Uttar\ Pradesh",
"9175930", "Kurwai\,\ Madhya\ Pradesh",
"9165226", "Muri\,\ Bihar",
"9176256", "Umariapan\,\ Madhya\ Pradesh",
"9171343", "Bhamregadh\,\ Maharashtra",
"9164347", "Dumka\,\ Bihar",
"914892", "Minicoy\,\ Lakshadweep",
"9174667", "Bonli\,\ Rajasthan",
"911533", "Kolayat\/Goddo\,\ Rajasthan",
"9177039", "Manpur\,\ Madhya\ Pradesh",
"9174676", "Bamanwas\,\ Rajasthan",
"912587", "Amalner\,\ Maharashtra",
"911276", "Bahadurgarh\,\ Haryana",
"915315", "Dalmau\/Lalganj\,\ Uttar\ Pradesh",
"916807", "Berhampur\,\ Odisha",
"9168214", "Bhanjanagar\,\ Odisha",
"914639", "Tiruchendur\,\ Tamil\ Nadu",
"913652", "Jowai\,\ Meghalaya",
"9174875", "Begamganj\,\ Madhya\ Pradesh",
"918224", "Kollegal\,\ Karnataka",
"9171712", "Gond\ Pipri\,\ Maharashtra",
"912115", "Saswad\,\ Maharashtra",
"9166447", "Rairakhol\,\ Odisha",
"914828", "Kanjirapally\,\ Kerala",
"9171784", "Sinderwahi\,\ Maharashtra",
"911507", "Raisinghnagar\,\ Rajasthan",
"9175939", "Kurwai\,\ Madhya\ Pradesh",
"9174126", "Ratlam\,\ Madhya\ Pradesh",
"91224", "Mumbai",
"918392", "Bellary\,\ Karnataka",
"9162474", "Singhwara\,\ Bihar",
"9165882", "Jagarnathpur\,\ Bihar",
"917546", "Chachaura\,\ Madhya\ Pradesh",
"9168557", "Laxmipur\,\ Odisha",
"918599", "Ulvapadu\,\ Andhra\ Pradesh",
"9164384", "Madhupur\,\ Bihar",
"9171127", "Katol\,\ Maharashtra",
"9164312", "Jharmundi\,\ Bihar",
"9163477", "Chakai\,\ Bihar",
"9171677", "Amarwada\,\ Madhya\ Pradesh",
"9164673", "Banmankhi\,\ Bihar",
"9167402", "Bhubaneshwar\,\ Odisha",
"917294", "Dharampuri\,\ Madhya\ Pradesh",
"918709", "Warangal\,\ Andhra\ Pradesh",
"912827", "Kotdasanghani\,\ Gujarat",
"9171522", "Wardha\,\ Maharashtra",
"913671", "Diphu\,\ Assam",
"9165814", "Bhandaria\,\ Bihar",
"9168152", "Parlakhemundi\,\ Odisha",
"9167524", "Puri\,\ Odisha",
"914926", "Shoranur\,\ Kerala",
"9176579", "Jaitpur\,\ Madhya\ Pradesh",
"9168672", "Jharigan\,\ Odisha",
"918323", "Goa",
"918395", "Sandur\,\ Karnataka",
"913453", "Katwa\,\ West\ Bengal",
"917251", "Risod\,\ Maharashtra",
"918677", "Kaikaluru\,\ Andhra\ Pradesh",
"915278", "Faizabad\,\ Uttar\ Pradesh",
"9171157", "Mouda\,\ Maharashtra",
"9166434", "Barkot\,\ Odisha",
"912966", "Sagwara\,\ Rajasthan",
"9168527", "Koraput\,\ Odisha",
"913844", "Hailakandi\,\ Assam",
"9162586", "Areraj\,\ Bihar",
"9176814", "Jatara\,\ Madhya\ Pradesh",
"9167554", "Khurda\,\ Odisha",
"9171552", "Seloo\,\ Maharashtra",
"915664", "Mant\/Vrindavan\,\ Uttar\ Pradesh",
"917477", "Bundi\,\ Rajasthan",
"918259", "Shankarnarayana\,\ Karnataka",
"911481", "Raipur\,\ Rajasthan",
"9164283", "Nala\,\ Bihar",
"912167", "Wai\,\ Maharashtra",
"915240", "Fatehpur\,\ Uttar\ Pradesh",
"913655", "Khliehriat\,\ Meghalaya",
"9173299", "Khakner\,\ Madhya\ Pradesh",
"912112", "Baramati\,\ Maharashtra",
"917230", "Ghatanji\,\ Maharashtra",
"912556", "Chanwad\,\ Maharashtra",
"9175229", "Datia\,\ Madhya\ Pradesh",
"9168503", "Kalimela\,\ Odisha",
"9162265", "Sitamarhi\,\ Bihar",
"917325", "Burhanpur\,\ Madhya\ Pradesh",
"917272", "Dewas\,\ Madhya\ Pradesh",
"9167217", "Narsinghpur\,\ Odisha",
"9174565", "Kishanganj\/Bhanwargarh\,\ Rajasthan",
"918312", "Belgaum\,\ Karnataka",
"9177062", "Gariaband\,\ Madhya\ Pradesh",
"911331", "Nakur\/Gangoh\,\ Uttar\ Pradesh",
"9176573", "Jaitpur\,\ Madhya\ Pradesh",
"9174822", "Raisen\,\ Madhya\ Pradesh",
"918519", "Allagadda\,\ Andhra\ Pradesh",
"918240", "Mangalore\,\ Karnataka",
"911981", "Nyoma\,\ Jammu\ And\ Kashmir",
"9165936", "Manoharpur\,\ Bihar",
"9165256", "Simdega\,\ Bihar",
"913563", "Birpara\,\ West\ Bengal",
"9175220", "Datia\,\ Madhya\ Pradesh",
"9168493", "Daringbadi\,\ Odisha",
"9165863", "Chainpur\,\ Bihar",
"9175962", "Gyraspur\,\ Madhya\ Pradesh",
"914895", "Kalpeni\,\ Lakshadweep",
"9173290", "Khakner\,\ Madhya\ Pradesh",
"9171734", "Rajura\,\ Maharashtra",
"9162796", "Barauni\,\ Bihar",
"918367", "Hubli\,\ Karnataka",
"912901", "Siwana\,\ Rajasthan",
"9174205", "Jawad\,\ Madhya\ Pradesh",
"9166223", "Sundargarh\,\ Odisha",
"9175933", "Kurwai\,\ Madhya\ Pradesh",
"912466", "Kandhar\,\ Maharashtra",
"9181754", "Holenarasipur\,\ Karnataka",
"9164334", "Jamtara\,\ Bihar",
"9162505", "Dhaka\,\ Bihar",
"9172872", "Gogaon\,\ Madhya\ Pradesh",
"912520", "Jawahar\,\ Maharashtra",
"9165832", "Kharsawa\,\ Bihar",
"915677", "Karhal\,\ Uttar\ Pradesh",
"9165345", "Jhumaritalaiya\,\ Bihar",
"9168655", "Kashipur\,\ Odisha",
"9161802", "Adhaura\,\ Bihar",
"9171575", "Arvi\,\ Maharashtra",
"9167242", "Jagatsinghpur\,\ Odisha",
"911762", "Rajpura\,\ Punjab",
"9166576", "Kantabhanji\,\ Odisha",
"9174926", "Shivpuri\,\ Madhya\ Pradesh",
"9177033", "Manpur\,\ Madhya\ Pradesh",
"9168194", "Surada\,\ Odisha",
"918664", "Vijayawada\,\ Andhra\ Pradesh",
"9164257", "Katoria\,\ Bihar",
"911594", "Udaipurwati\,\ Rajasthan",
"9167482", "Bhubaneshwar\,\ Odisha",
"917786", "Kondagaon\,\ Madhya\ Pradesh",
"9171866", "Sakoli\,\ Maharashtra",
"9171484", "Prabha\ Pattan\,\ Madhya\ Pradesh",
"9177003", "Nagri\,\ Madhya\ Pradesh",
"9168626", "Gudari\,\ Odisha",
"9176346", "Lamta\,\ Madhya\ Pradesh",
"914183", "Vandavasi\,\ Tamil\ Nadu",
"9171665", "Chaurai\,\ Madhya\ Pradesh",
"9163465", "Lakhisarai\,\ Bihar",
"91227", "Mumbai",
"9161832", "Buxar\,\ Bihar",
"9181743", "Arsikere\,\ Karnataka",
"9168176", "R\.Udayigiri\,\ Odisha",
"912595", "Dhadgaon\,\ Maharashtra",
"9162535", "Narkatiaganj\,\ Bihar",
"9167414", "Bhubaneshwar\,\ Odisha",
"9163373", "Arwal\,\ Bihar",
"912457", "Jintdor\,\ Maharashtra",
"9171412", "Betul\,\ Madhya\ Pradesh",
"911704", "Paonta\,\ Himachal\ Pradesh",
"9174955", "Badarwas\,\ Madhya\ Pradesh",
"911785", "Pooh\,\ Himachal\ Pradesh",
"9174235", "Neemuch\,\ Madhya\ Pradesh",
"9175903", "Lateri\,\ Madhya\ Pradesh",
"9171704", "Chumur\,\ Maharashtra",
"918356", "Muddebihal\,\ Karnataka",
"9164514", "Barsoi\,\ Bihar",
"915861", "Misrikh\/Aurangabad\,\ Uttar\ Pradesh",
"912747", "Thara\,\ Gujarat",
"9175927", "Vidisha\,\ Madhya\ Pradesh",
"911575", "Srimadhopur\,\ Rajasthan",
"9176818", "Jatara\,\ Madhya\ Pradesh",
"918119", "Doddaballapur\,\ Karnataka",
"91364", "Shillong\,\ Meghalaya",
"913759", "Bihupuria\,\ Assam",
"9167322", "Hindol\,\ Odisha",
"9171183", "Kalmeshwar\,\ Maharashtra",
"9174652", "Sapotra\,\ Rajasthan",
"9171324", "Gadchiroli\,\ Maharashtra",
"9162774", "Phulparas\,\ Bihar",
"917576", "Piparia\,\ Madhya\ Pradesh",
"9161863", "Aurangabad\,\ Bihar",
"9173217", "Sanwer\,\ Madhya\ Pradesh",
"918243", "Mangalore\,\ Karnataka",
"91129", "Faridabad\,\ Haryana",
"9165225", "Muri\,\ Bihar",
"911803", "Panipat\,\ Haryana",
"9174867", "Bareli\,\ Madhya\ Pradesh",
"9176255", "Umariapan\,\ Madhya\ Pradesh",
"9167964", "Karanjia\,\ Odisha",
"9171962", "Arjuni\ Morgaon\,\ Maharashtra",
"9127172", "Sanand\,\ Gujarat",
"917608", "Bijawar\,\ Madhya\ Pradesh",
"91343", "Durgapur\,\ West\ Bengal",
"9168533", "Sunabeda\,\ Odisha",
"917390", "Thandla\,\ Madhya\ Pradesh",
"9174675", "Bamanwas\,\ Rajasthan",
"917233", "Pusad\,\ Maharashtra",
"9174876", "Begamganj\,\ Madhya\ Pradesh",
"9171392", "Kurkheda\,\ Maharashtra",
"912567", "Taloda\,\ Maharashtra",
"9166712", "Rajkhariar\,\ Odisha",
"9171447", "Atner\,\ Madhya\ Pradesh",
"9166784", "Nowparatan\,\ Odisha",
"9181758", "Holenarasipur\,\ Karnataka",
"918408", "Donakonda\,\ Andhra\ Pradesh",
"9174125", "Ratlam\,\ Madhya\ Pradesh",
"9176272", "Manpur\,\ Madhya\ Pradesh",
"913778", "Pakkekesang\,\ Arunachal\ Pradesh",
"9168167", "Mohana\,\ Odisha",
"9165682", "Balumath\,\ Bihar",
"9166404", "Bagdihi\,\ Odisha",
"9165614", "Garhwa\,\ Bihar",
"9164792", "Udakishanganj\,\ Bihar",
"912957", "Vallabhnagar\,\ Rajasthan",
"9174972", "Khaniadhana\,\ Madhya\ Pradesh",
"913639", "Baghmara\,\ Meghalaya",
"918320", "Goa",
"9166522", "Balangir\,\ Odisha",
"9171877", "Goregaon\,\ Maharashtra",
"9168562", "Rayagada\,\ Odisha",
"9173242", "Mhow\,\ Madhya\ Pradesh",
"914652", "Nagercoil\,\ Tamil\ Nadu",
"918557", "Penukonda\,\ Andhra\ Pradesh",
"9176538", "Bandhavgarh\,\ Madhya\ Pradesh",
"911696", "Kalanwali\,\ Haryana",
"911892", "Kangra\/Dharamsala\,\ Himachal\ Pradesh",
"915923", "Sambhal\,\ Uttar\ Pradesh",
"9165845", "Bishrampur\,\ Bihar",
"9171007", "Kuhi\,\ Maharashtra",
"9165332", "Basia\,\ Bihar",
"91285", "Junagarh\,\ Gujarat",
"9165646", "Nagarutari\,\ Bihar",
"918618", "Nellore\,\ Andhra\ Pradesh",
"9176360", "Baihar\,\ Madhya\ Pradesh",
"918495", "Rayadurg\,\ Andhra\ Pradesh",
"9187594", "Outsarangapalle\,\ Andhra\ Pradesh",
"915262", "Gonda\,\ Uttar\ Pradesh",
"913785", "Bameng\,\ Arunachal\ Pradesh",
"9176264", "Vijayraghogarh\,\ Madhya\ Pradesh",
"914172", "Ranipet\,\ Tamil\ Nadu",
"9172868", "Khetia\,\ Madhya\ Pradesh",
"917623", "Kundam\,\ Madhya\ Pradesh",
"917695", "Gopalganj\,\ Madhya\ Pradesh",
"9167235", "Athgarh\,\ Odisha",
"9167955", "Udala\,\ Odisha",
"914151", "Kallakurichi\,\ Tamil\ Nadu",
"917268", "Mekhar\,\ Maharashtra",
"911560", "Sujangarh\/Bidasar\,\ Rajasthan",
"918474", "Chittapur\,\ Karnataka",
"9174702", "Bundi\,\ Rajasthan",
"9166854", "Sohela\,\ Odisha",
"918693", "Thungaturthy\,\ Andhra\ Pradesh",
"9176494", "Kakaiya\,\ Madhya\ Pradesh",
"91164", "Bhatinda\,\ Punjab",
"918912", "Visakhapatnam\,\ Andhra\ Pradesh",
"911931", "Kulgam\,\ Jammu\ And\ Kashmir",
"918625", "Venkatgiri\,\ Andhra\ Pradesh",
"9161512", "Sidhawalia\,\ Bihar",
"913229", "Dantan\,\ West\ Bengal",
"911381", "Joshimath\/Badrinath\,\ Uttarakhand",
"9174558", "Digod\/Sultanpur\,\ Rajasthan",
"9163283", "Daudnagar\,\ Bihar",
"911426", "Jamwa\ Ramgarh\/Achrol\,\ Rajasthan",
"9165475", "Chavparan\,\ Bihar",
"915412", "Chandauli\/Mugalsarai\,\ Uttar\ Pradesh",
"9167652", "Palla\ Hara\,\ Odisha",
"9174919", "Narwar\,\ Madhya\ Pradesh",
"9174322", "Jhalawar\,\ Rajasthan",
"9171654", "Saunsar\,\ Madhya\ Pradesh",
"9163454", "Jamui\,\ Bihar",
"912830", "Rahpar\,\ Gujarat",
"9161117", "Hilsa\,\ Bihar",
"9171023", "Parseoni\,\ Maharashtra",
"9168574", "Gunupur\,\ Odisha",
"917674", "Maihar\,\ Madhya\ Pradesh",
"9167867", "Chandbali\,\ Odisha",
"9161584", "Sonepur\,\ Bihar",
"9162457", "Gogri\,\ Bihar",
"9174964", "Pichhore\,\ Madhya\ Pradesh",
"912872", "Vanthali\,\ Gujarat",
"913803", "Roing\,\ Arunachal\ Pradesh",
"91230", "Khadakwasala\,\ Maharashtra",
"912676", "Halol\,\ Gujarat",
"9177078", "Bagbahera\,\ Madhya\ Pradesh",
"9165363", "Palkot\,\ Bihar",
"914545", "Palani\,\ Tamil\ Nadu",
"9167675", "Barbil\,\ Odisha",
"9176422", "Mandla\,\ Madhya\ Pradesh",
"9165452", "Mandu\,\ Bihar",
"9162733", "Jhajharpur\,\ Bihar",
"9174910", "Narwar\,\ Madhya\ Pradesh",
"911431", "Lalsot\,\ Rajasthan",
"918412", "Pargi\,\ Andhra\ Pradesh",
"9168436", "Puruna\ Katak\,\ Odisha",
"9176504", "Beohari\,\ Madhya\ Pradesh",
"913837", "Kolasib\,\ Mizoram",
"918467", "Bodhan\,\ Andhra\ Pradesh",
"9168697", "Papadhandi\,\ Odisha",
"917816", "Pali\,\ Madhya\ Pradesh",
"915967", "Dharchula\,\ Uttar\ Pradesh",
"9164546", "Purnea\,\ Bihar",
"917280", "Barwaha\,\ Madhya\ Pradesh",
"911588", "Parbatsar\/Makrana\,\ Rajasthan",
"916515", "Ranchi\,\ Bihar",
"917364", "Shajapur\,\ Madhya\ Pradesh",
"9176369", "Baihar\,\ Madhya\ Pradesh",
"912366", "Vengurla\,\ Maharashtra",
"9162243", "Hajipur\,\ Bihar",
"9173205", "Pandhana\,\ Madhya\ Pradesh",
"918217", "Mysore\,\ Karnataka",
"915495", "Saidpur\,\ Uttar\ Pradesh",
"9176382", "Damoh\,\ Madhya\ Pradesh",
"9175216", "Seondha\,\ Madhya\ Pradesh",
"9161547", "Siwan\,\ Bihar",
"9174543", "Chhipaborad\,\ Rajasthan",
"911828", "Sultanpur\ Lodhi\,\ Punjab",
"9173926", "Jhabua\,\ Madhya\ Pradesh",
"9167972", "Jashipur\,\ Odisha",
"911639", "Faridakot\,\ Punjab",
"9171974", "Mohadi\,\ Maharashtra",
"918262", "Chikmagalur\,\ Karnataka",
"9161142", "Jahanabad\,\ Bihar",
"912713", "Dhandhuka\,\ Gujarat",
"914114", "Chengalpattu\,\ Tamil\ Nadu",
"9162762", "Madhubani\,\ Bihar",
"9176297", "Pushprajgarh\,\ Madhya\ Pradesh",
"911527", "Lunkaransar\/Rajasarb\,\ Rajasthan",
"9174968", "Pichhore\,\ Madhya\ Pradesh",
"9163257", "Pakribarwan\,\ Bihar",
"9166215", "Hemgiri\,\ Odisha",
"9177074", "Bagbahera\,\ Madhya\ Pradesh",
"912845", "Savarkundla\,\ Gujarat",
"9162727", "Darbhanga\,\ Bihar",
"91202", "Pune\,\ Maharashtra",
"917721", "Neora\,\ Madhya\ Pradesh",
"9165547", "Rajdhanwar\,\ Bihar",
"912357", "Malgund\,\ Maharashtra",
"9164373", "Mahagama\,\ Bihar",
"9167286", "Jajapur\ Town\,\ Odisha",
"918746", "Bhooragamphad\/Manuguru\,\ Andhra\ Pradesh",
"9164612", "Raniganj\,\ Bihar",
"9171377", "Desaiganj\,\ Maharashtra",
"9176498", "Kakaiya\,\ Madhya\ Pradesh",
"9173235", "Punasa\,\ Madhya\ Pradesh",
"9182899", "Athani\,\ Karnataka",
"9173955", "Sondhwa\,\ Madhya\ Pradesh",
"9171996", "Deori\,\ Maharashtra",
"9174554", "Digod\/Sultanpur\,\ Rajasthan",
"915566", "Salempur\,\ Uttar\ Pradesh",
"918204", "Udupi\,\ Karnataka",
"9174376", "Nainwa\,\ Rajasthan",
"917283", "Maheshwar\,\ Madhya\ Pradesh",
"9176268", "Vijayraghogarh\,\ Madhya\ Pradesh",
"914145", "Gingee\,\ Tamil\ Nadu",
"911655", "Raman\,\ Punjab",
"918729", "Manthani\,\ Andhra\ Pradesh",
"9184534", "Medak\,\ Andhra\ Pradesh",
"9171892", "Amagaon\,\ Maharashtra",
"918501", "Kollapur\,\ Andhra\ Pradesh",
"9172864", "Khetia\,\ Madhya\ Pradesh",
"9164777", "Triveniganj\,\ Bihar",
"913481", "Islampur\,\ West\ Bengal",
"9171773", "Brahmapuri\,\ Maharashtra",
"91421", "Tirupur\,\ Tamil\ Nadu",
"918456", "Narayankhed\,\ Andhra\ Pradesh",
"9176534", "Bandhavgarh\,\ Madhya\ Pradesh",
"911887", "Nangal\,\ Punjab",
"911743", "Cheeka\,\ Haryana",
"9168406", "Tumudibandha\,\ Odisha",
"9176467", "Nainpur\,\ Madhya\ Pradesh",
"9164295", "Kahalgaon\,\ Bihar",
"9162517", "Bagaha\,\ Bihar",
"9167565", "Balugaon\,\ Odisha",
"9174217", "Manasa\,\ Madhya\ Pradesh",
"915690", "Kaimganj\,\ Uttar\ Pradesh",
"917852", "Toynar\,\ Madhya\ Pradesh",
"9181765", "Cannarayapatna\,\ Karnataka",
"914551", "Vedasandur\,\ Tamil\ Nadu",
"9167822", "Balasore\,\ Odisha",
"913800", "Jairampur\,\ Arunachal\ Pradesh",
"9165512", "Barkagaon\,\ Bihar",
"9171824", "Gondia\,\ Maharashtra",
"9168485", "Kotagarh\,\ Odisha",
"9176476", "Ghughari\,\ Madhya\ Pradesh",
"9168664", "Umerkote\,\ Odisha",
"9189467", "Pathapatnam\/Hiramandalam\,\ Andhra\ Pradesh",
"912833", "Khambhalia\,\ Gujarat",
"9166843", "Paikamal\,\ Odisha",
"9164766", "Madhepura\,\ Bihar",
"9165584", "Dumri\(Isribazar\)\,\ Bihar",
"9171643", "Pandhurna\,\ Madhya\ Pradesh",
"9163443", "Monghyr\,\ Bihar",
"911563", "Sardarshahar\/Jaitsisar\,\ Rajasthan",
"9174367", "Hindoli\,\ Rajasthan",
"9168596", "Motu\,\ Odisha",
"918157", "Srinivasapur\,\ Karnataka",
"912734", "Chanasma\,\ Gujarat",
"9161845", "Sasaram\,\ Bihar",
"91261", "Surat\,\ Gujarat",
"9171366", "Etapalli\,\ Maharashtra",
"9162542", "Bettiah\,\ Bihar",
"911735", "Chaaharauli\,\ Haryana",
"914254", "Mettupalayam\,\ Tamil\ Nadu",
"9174242", "Malhargarh\,\ Madhya\ Pradesh",
"9171037", "Butibori\,\ Maharashtra",
"9165302", "Bundu\,\ Bihar",
"918566", "Koduru\,\ Andhra\ Pradesh",
"9167926", "Baripada\,\ Odisha",
"9166473", "Naktideul\,\ Odisha",
"9182890", "Athani\,\ Karnataka",
"91496", "Vatakara\,\ Kerala",
"9176508", "Beohari\,\ Madhya\ Pradesh",
"912436", "Vijapur\,\ Maharashtra",
"9165846", "Bishrampur\,\ Bihar",
"915853", "Shahabad\,\ Uttar\ Pradesh",
"9165645", "Nagarutari\,\ Bihar",
"912921", "Phalodi\/Bap\,\ Rajasthan",
"9162433", "Begusarai\,\ Bihar",
"918186", "Kargal\,\ Karnataka",
"915444", "Robertsganj\,\ Uttar\ Pradesh",
"918711", "Wardhannapet\/Ghanapur\,\ Andhra\ Pradesh",
"911732", "Jagadhari\,\ Haryana",
"914575", "Sivaganga\,\ Tamil\ Nadu",
"915282", "Hamirpur\,\ Uttar\ Pradesh",
"918944", "Bobbili\,\ Andhra\ Pradesh",
"9167236", "Athgarh\,\ Odisha",
"916123", "Patna\,\ Bihar",
"9167956", "Udala\,\ Odisha",
"9174592", "Ramganj\ Mandi\,\ Rajasthan",
"9176302", "Katangi\,\ Madhya\ Pradesh",
"912999", "Jaisalmer\/Nehdai\,\ Rajasthan",
"9162292", "Bidupur\,\ Bihar",
"918634", "Guntur\,\ Andhra\ Pradesh",
"9171854", "Pauni\,\ Maharashtra",
"9171044", "Hingua\,\ Maharashtra",
"9176512", "Jaisinghnagar\,\ Madhya\ Pradesh",
"911580", "Deedwana\,\ Rajasthan",
"9162462", "Jainagar\,\ Bihar",
"9165476", "Chavparan\,\ Bihar",
"9182893", "Athani\,\ Karnataka",
"916216", "Muzaffarpur\,\ Bihar",
"9165942", "Baharagora\,\ Bihar",
"911748", "Gharaunda\,\ Haryana",
"918337", "Murugod\,\ Karnataka",
"9167667", "Keonjhar\,\ Odisha",
"9167676", "Barbil\,\ Odisha",
"913797", "Pangin\,\ Arunachal\ Pradesh",
"911652", "Mansa\,\ Punjab",
"914142", "Cuddalore\,\ Tamil\ Nadu",
"912838", "Mundra\,\ Gujarat",
"912691", "Kapad\ Wanj\,\ Gujarat",
"911479", "Pratapgarh\/Arnod\,\ Rajasthan",
"917687", "Laundi\,\ Madhya\ Pradesh",
"9161504", "Hathua\,\ Bihar",
"9168435", "Puruna\ Katak\,\ Odisha",
"912137", "Nahavara\,\ Maharashtra",
"9165534", "Ramgarh\,\ Bihar",
"917260", "Lonar\,\ Maharashtra",
"911568", "Sujangarh\,\ Rajasthan",
"9165467", "Hazaribagh\,\ Bihar",
"9164545", "Purnea\,\ Bihar",
"917855", "Chingmut\,\ Madhya\ Pradesh",
"918487", "Shirahatti\,\ Karnataka",
"912629", "M\.M\.Mangrol\,\ Gujarat",
"9164274", "Kathikund\,\ Bihar",
"912421", "Jamkhed\,\ Maharashtra",
"9165297", "Itki\,\ Bihar",
"9168613", "Malkangiri\,\ Odisha",
"912646", "Ankleshwar\,\ Gujarat",
"9175215", "Seondha\,\ Madhya\ Pradesh",
"9163227", "Wazirganj\,\ Bihar",
"917410", "Alot\,\ Madhya\ Pradesh",
"911958", "Karnah\,\ Jammu\ And\ Kashmir",
"9173206", "Pandhana\,\ Madhya\ Pradesh",
"912936", "Pali\/Rohat\,\ Rajasthan",
"912842", "Talaja\,\ Gujarat",
"9162757", "Rosera\,\ Bihar",
"9173925", "Jhabua\,\ Madhya\ Pradesh",
"91571", "Aligarh\,\ Uttar\ Pradesh",
"9165917", "Chandil\,\ Bihar",
"918444", "Hunsagi\,\ Karnataka",
"9174524", "Chhabra\,\ Rajasthan",
"918610", "Nellore\,\ Andhra\ Pradesh",
"918282", "Bhadravati\,\ Karnataka",
"915944", "Kichha\/Rudrapur\,\ Uttar\ Pradesh",
"9162224", "Sheohar\,\ Bihar",
"918613", "Nellore\,\ Andhra\ Pradesh",
"9162593", "Pakridayal\,\ Bihar",
"9166216", "Hemgiri\,\ Odisha",
"9165382", "Torpa\,\ Bihar",
"9173236", "Punasa\,\ Madhya\ Pradesh",
"9165314", "Mandar\,\ Bihar",
"9173956", "Sondhwa\,\ Madhya\ Pradesh",
"918265", "Koppa\,\ Karnataka",
"9167285", "Jajapur\ Town\,\ Odisha",
"9174913", "Narwar\,\ Madhya\ Pradesh",
"913211", "Arambag\,\ West\ Bengal",
"9163262", "Sherghati\,\ Bihar",
"913669", "Abhayapuri\,\ Assam",
"914326", "Musiri\,\ Tamil\ Nadu",
"9171995", "Deori\,\ Maharashtra",
"914542", "Kodaikanal\,\ Tamil\ Nadu",
"9163233", "Dumraon\,\ Bihar",
"9174375", "Nainwa\,\ Rajasthan",
"9165422", "Bokaro\,\ Bihar",
"913461", "Rampur\ Hat\,\ West\ Bengal",
"9176452", "Karanjia\,\ Madhya\ Pradesh",
"918415", "Hyderabad\ East\/Ghatkeswar\,\ Andhra\ Pradesh",
"917263", "Khamgaon\,\ Maharashtra",
"9167694", "Kamakhyanagar\,\ Odisha",
"9166773", "Narlaroad\,\ Odisha",
"9171692", "Batkakhapa\,\ Madhya\ Pradesh",
"9163492", "Jhajha\,\ Bihar",
"9165504", "Hunterganj\,\ Bihar",
"9168405", "Tumudibandha\,\ Odisha",
"913808", "Changlang\,\ Arunachal\ Pradesh",
"9161534", "Maharajganj\,\ Bihar",
"9164296", "Kahalgaon\,\ Bihar",
"9167566", "Balugaon\,\ Odisha",
"916512", "Ranchi\,\ Bihar",
"9174540", "Chhipaborad\,\ Rajasthan",
"9168486", "Kotagarh\,\ Odisha",
"915831", "Dataganj\,\ Uttar\ Pradesh",
"918776", "Tirupathi\,\ Andhra\ Pradesh",
"9181766", "Cannarayapatna\,\ Karnataka",
"9165494", "Bermo\,\ Bihar",
"918622", "Kovvur\,\ Andhra\ Pradesh",
"913254", "Jhalda\,\ West\ Bengal",
"918915", "Visakhapatnam\,\ Andhra\ Pradesh",
"9166824", "Attabira\,\ Odisha",
"9167577", "Daspalla\,\ Odisha",
"916747", "Bhubaneshwar\,\ Odisha",
"9174528", "Chhabra\,\ Rajasthan",
"911874", "Gurdaspur\,\ Punjab",
"9171624", "Chhindwara\,\ Madhya\ Pradesh",
"9163424", "H\.Kharagpur\,\ Bihar",
"9162783", "Dalsinghsarai\,\ Bihar",
"9174352", "Gangdhar\,\ Rajasthan",
"9167622", "Dhenkanal\,\ Odisha",
"9176475", "Ghughari\,\ Madhya\ Pradesh",
"9171843", "Bhandara\,\ Maharashtra",
"9171053", "Narkhed\,\ Maharashtra",
"9174549", "Chhipaborad\,\ Rajasthan",
"911583", "Jayal\,\ Rajasthan",
"9164765", "Madhepura\,\ Bihar",
"916574", "Jamshedpur\,\ Bihar",
"9162427", "Benipur\,\ Bihar",
"912875", "Una\/Diu\,\ Gujarat",
"9168595", "Motu\,\ Odisha",
"917841", "Sarona\,\ Madhya\ Pradesh",
"9176363", "Baihar\,\ Madhya\ Pradesh",
"912793", "Damnagar\,\ Gujarat",
"9161846", "Sasaram\,\ Bihar",
"9176332", "Waraseoni\,\ Madhya\ Pradesh",
"911823", "Nawanshahar\,\ Punjab",
"915613", "Achhnera\,\ Uttar\ Pradesh",
"911895", "Bharmour\,\ Himachal\ Pradesh",
"9171365", "Etapalli\,\ Maharashtra",
"918492", "Kambadur\,\ Andhra\ Pradesh",
"915265", "Utraula\,\ Uttar\ Pradesh",
"9165264", "Lohardaga\,\ Bihar",
"913782", "Kalaktung\/Bomdila\,\ Arunachal\ Pradesh",
"912718", "Bareja\,\ Gujarat",
"917227", "Chandurbazar\,\ Maharashtra",
"918586", "Vayalpad\,\ Andhra\ Pradesh",
"914175", "Tiruvannamalai\,\ Tamil\ Nadu",
"912894", "Kalawad\,\ Gujarat",
"918849", "Kakinada\,\ Andhra\ Pradesh",
"915850", "Hardoi\/Baghavli\,\ Uttar\ Pradesh",
"9163312", "Imamganj\,\ Bihar",
"917692", "Seoni\,\ Madhya\ Pradesh",
"917913", "Ahmedabad\ Local\,\ Gujarat",
"9171473", "Multai\,\ Madhya\ Pradesh",
"9167925", "Baripada\,\ Odisha",
"914331", "Jayamkondan\,\ Tamil\ Nadu",
"917255", "Barshi\ Takli\,\ Maharashtra",
"911683", "Julana\,\ Haryana",
"918391", "Kudligi\,\ Karnataka",
"9171584", "Deoli\,\ Maharashtra",
"9167582", "Nimapara\,\ Odisha",
"9165643", "Nagarutari\,\ Bihar",
"911343", "Nagina\,\ Uttar\ Pradesh",
"9174688", "Khandar\,\ Rajasthan",
"913876", "Jiribam\,\ Manipur",
"9166494", "Jamankira\,\ Odisha",
"918522", "Peapalle\,\ Andhra\ Pradesh",
"9171512", "Samudrapur\,\ Maharashtra",
"912447", "Gevrai\,\ Maharashtra",
"9181760", "Cannarayapatna\,\ Karnataka",
"9165824", "Chaibasa\,\ Bihar",
"913672", "Nagaon\,\ Assam",
"9162435", "Begusarai\,\ Bihar",
"9164322", "Deoghar\,\ Bihar",
"918329", "Goa",
"913651", "Tura\,\ Meghalaya",
"9166264", "Banaigarh\,\ Odisha",
"9171722", "Chandrapur\,\ Maharashtra",
"9168224", "Aska\,\ Odisha",
"912757", "Dasada\,\ Gujarat",
"9163286", "Daudnagar\,\ Bihar",
"9173239", "Punasa\,\ Madhya\ Pradesh",
"9182895", "Athani\,\ Karnataka",
"9173959", "Sondhwa\,\ Madhya\ Pradesh",
"911485", "Jahazpur\,\ Rajasthan",
"918134", "Tiptur\,\ Karnataka",
"9167937", "Betanati\,\ Odisha",
"9167257", "Dhanmandal\,\ Odisha",
"9171026", "Parseoni\,\ Maharashtra",
"918253", "Hebri\,\ Karnataka",
"9165366", "Palkot\,\ Bihar",
"912484", "Partur\,\ Maharashtra",
"9173230", "Punasa\,\ Madhya\ Pradesh",
"9173950", "Sondhwa\,\ Madhya\ Pradesh",
"917528", "Bijaypur\,\ Madhya\ Pradesh",
"911985", "Kargil\,\ Jammu\ And\ Kashmir",
"915882", "Pilibhit\,\ Uttar\ Pradesh",
"9171794", "Nagbhir\,\ Maharashtra",
"914829", "Vaikom\,\ Kerala",
"911904", "Nirmand\,\ Himachal\ Pradesh",
"9162736", "Jhajharpur\,\ Bihar",
"9171142", "Ramtek\,\ Maharashtra",
"9168433", "Puruna\ Katak\,\ Odisha",
"918110", "Anekal\,\ Karnataka",
"912905", "Sarada\/Chawand\,\ Rajasthan",
"918513", "Nandikotkur\,\ Andhra\ Pradesh",
"912984", "Barmer\/Sindari\,\ Rajasthan",
"914891", "Amini\,\ Lakshadweep",
"914638", "Vilathikulam\,\ Tamil\ Nadu",
"9164543", "Purnea\,\ Bihar",
"915253", "Nanpara\,\ Uttar\ Pradesh",
"9168615", "Malkangiri\,\ Odisha",
"918708", "Warangal\,\ Andhra\ Pradesh",
"9162246", "Hajipur\,\ Bihar",
"916612", "Rourkela\,\ Odisha",
"9174546", "Chhipaborad\,\ Rajasthan",
"917515", "Gwalior\,\ Madhya\ Pradesh",
"9175213", "Seondha\,\ Madhya\ Pradesh",
"9182204", "Gundlupet\,\ Karnataka",
"91373", "Dibrugarh\,\ Assam",
"915522", "Pharenda\/Compierganj\,\ Uttar\ Pradesh",
"9168462", "Baliguda\,\ Odisha",
"9173923", "Jhabua\,\ Madhya\ Pradesh",
"9174808", "Goharganj\,\ Madhya\ Pradesh",
"9165892", "Jhinkpani\,\ Bihar",
"9166422", "Kuchinda\,\ Odisha",
"912191", "Poladpur\,\ Maharashtra",
"912637", "Navsari\,\ Gujarat",
"9181769", "Cannarayapatna\,\ Karnataka",
"918598", "Kandukuru\,\ Andhra\ Pradesh",
"9168427", "Phulbani\,\ Odisha",
"9166534", "Dunguripali\,\ Odisha",
"91724", "Akola\,\ Maharashtra",
"9162595", "Pakridayal\,\ Bihar",
"912322", "Shirol\/Jalsingpur\,\ Maharashtra",
"911668", "Dabwali\,\ Haryana",
"9166467", "Bargarh\,\ Odisha",
"912529", "Mokhada\,\ Maharashtra",
"9164217", "Naugachia\,\ Bihar",
"911781", "Rohru\,\ Himachal\ Pradesh",
"911552", "Hanumangarh\,\ Rajasthan",
"9174915", "Narwar\,\ Madhya\ Pradesh",
"9167283", "Jajapur\ Town\,\ Odisha",
"9164376", "Mahagama\,\ Bihar",
"911274", "Rewari\,\ Haryana",
"914365", "Nagapattinam\,\ Tamil\ Nadu",
"9171452", "Chicholi\,\ Madhya\ Pradesh",
"9161892", "Bhabhua\,\ Bihar",
"9171993", "Deori\,\ Maharashtra",
"912591", "Manmad\,\ Maharashtra",
"918226", "Chamrajnagar\,\ Karnataka",
"918198", "Molkalmuru\,\ Karnataka",
"9168104", "Khalikote\,\ Odisha",
"9174612", "Mahuwa\,\ Rajasthan",
"915250", "Bahraich\/Bhinga\,\ Uttar\ Pradesh",
"9174373", "Nainwa\,\ Rajasthan",
"917296", "Sardarpur\,\ Madhya\ Pradesh",
"9163235", "Dumraon\,\ Bihar",
"9165974", "Saraikela\/Adstyapur\,\ Bihar",
"911571", "Fatehpur\,\ Rajasthan",
"911962", "Rajouri\,\ Jammu\ And\ Kashmir",
"915865", "Misrikh\,\ Uttar\ Pradesh",
"9166775", "Narlaroad\,\ Odisha",
"9164554", "Forbesganj\,\ Bihar",
"914924", "Mannarkad\,\ Kerala",
"918510", "Koilkuntla\,\ Andhra\ Pradesh",
"917777", "Pratappur\,\ Madhya\ Pradesh",
"9171776", "Brahmapuri\,\ Maharashtra",
"918249", "Mangalore\,\ Karnataka",
"918113", "Channapatna\,\ Karnataka",
"917544", "Raghogarh\,\ Madhya\ Pradesh",
"913753", "Dhemaji\,\ Assam",
"9168403", "Tumudibandha\,\ Odisha",
"9173937", "Jobat\,\ Madhya\ Pradesh",
"9174684", "Khandar\,\ Rajasthan",
"9173200", "Pandhana\,\ Madhya\ Pradesh",
"9166752", "T\.Rampur\,\ Odisha",
"9174804", "Goharganj\,\ Madhya\ Pradesh",
"91381", "Agartala\,\ Tripura",
"9164242", "Banka\,\ Bihar",
"911462", "Beawar\,\ Rajasthan",
"9176473", "Ghughari\,\ Madhya\ Pradesh",
"9162785", "Dalsinghsarai\,\ Bihar",
"918534", "Yelburga\,\ Karnataka",
"918865", "Yelavaram\,\ Andhra\ Pradesh",
"9164763", "Madhepura\,\ Bihar",
"911378", "Devprayag\,\ Uttarakhand",
"912766", "Patan\,\ Gujarat",
"917239", "Wani\,\ Maharashtra",
"9166846", "Paikamal\,\ Odisha",
"9171767", "Warora\,\ Maharashtra",
"9173209", "Pandhana\,\ Madhya\ Pradesh",
"915113", "Bhognipur\/Pakhrayan\,\ Uttar\ Pradesh",
"9171055", "Narkhed\,\ Maharashtra",
"9167334", "Ghatgaon\,\ Odisha",
"9171845", "Bhandara\,\ Maharashtra",
"9171332", "Aheri\,\ Maharashtra",
"9163446", "Monghyr\,\ Bihar",
"917764", "Kunkuri\,\ Madhya\ Pradesh",
"9171646", "Pandhurna\,\ Madhya\ Pradesh",
"9176365", "Baihar\,\ Madhya\ Pradesh",
"9168593", "Motu\,\ Odisha",
"911267", "Nuh\,\ Haryana",
"9164732", "Supaul\,\ Bihar",
"9174647", "Karauli\,\ Rajasthan",
"9164367", "Sahibganj\,\ Bihar",
"9171363", "Etapalli\,\ Maharashtra",
"9181528", "Kolar\,\ Karnatak",
"917863", "Chingamut\,\ Madhya\ Pradesh",
"9161824", "Arrah\,\ Bihar",
"918231", "Malavalli\,\ Karnataka",
"915198", "Karvi\,\ Uttar\ Pradesh",
"9166476", "Naktideul\,\ Odisha",
"9167923", "Baripada\,\ Odisha",
"9171475", "Multai\,\ Madhya\ Pradesh",
"9165654", "Latehar\,\ Bihar",
"9181702", "Alur\,\ Karnataka",
"9165843", "Bishrampur\,\ Bihar",
"91790", "Ahmedabad\ Local\,\ Gujarat",
"911663", "Hansi\,\ Haryana",
"9175942", "Ganjbasoda\,\ Madhya\ Pradesh",
"918700", "Warangal\,\ Andhra\ Pradesh",
"911997", "Bedarwah\,\ Jammu\ And\ Kashmir",
"9162436", "Begusarai\,\ Bihar",
"914651", "Kuzhithurai\,\ Tamil\ Nadu",
"918193", "Hiriyur\,\ Karnataka",
"9171494", "Tamia\,\ Madhya\ Pradesh",
"9166512", "Birmaharajpur\,\ Odisha",
"9167492", "Bhubaneshwar\,\ Odisha",
"9177042", "Deobhog\,\ Madhya\ Pradesh",
"9161854", "Bikramganj\,\ Bihar",
"9174379", "Nainwa\,\ Rajasthan",
"9176470", "Ghughari\,\ Madhya\ Pradesh",
"9167953", "Udala\,\ Odisha",
"9167233", "Athgarh\,\ Odisha",
"9165624", "Daltonganj\,\ Bihar",
"9166722", "Dharamgarh\,\ Odisha",
"9167262", "Jajapur\ Road\,\ Odisha",
"911465", "Thanaghazi\,\ Rajasthan",
"9164592", "Thakurganj\,\ Bihar",
"918666", "Vijayawada\,\ Andhra\ Pradesh",
"917123", "Nagpur\,\ Maharashtra",
"9165473", "Chavparan\,\ Bihar",
"912977", "Jalore\/Sayla\,\ Rajasthan",
"9163285", "Daudnagar\,\ Bihar",
"918862", "Razole\,\ Andhra\ Pradesh",
"914630", "Srivaikundam\,\ Tamil\ Nadu",
"9182896", "Athani\,\ Karnataka",
"9174634", "Gangapur\,\ Rajasthan",
"9171025", "Parseoni\,\ Maharashtra",
"9165365", "Palkot\,\ Bihar",
"918118", "Nelamangala\,\ Karnataka",
"91251", "Kalyan\,\ Maharashtra",
"913758", "Dhakuakhana\,\ Assam",
"9167312", "Anandapur\,\ Odisha",
"9166794", "Komana\,\ Odisha",
"9162735", "Jhajharpur\,\ Bihar",
"9167673", "Barbil\,\ Odisha",
"9171314", "Sironcha\,\ Maharashtra",
"912477", "Paranda\,\ Maharashtra",
"9175917", "Sironj\,\ Madhya\ Pradesh",
"9164524", "Katihar\,\ Bihar",
"911965", "Poonch\,\ Jammu\ And\ Kashmir",
"915862", "Sitapur\,\ Uttar\ Pradesh",
"9175297", "Laher\,\ Madhya\ Pradesh",
"91225", "Mumbai",
"917609", "Buxwaha\,\ Madhya\ Pradesh",
"9173227", "Depalpur\,\ Madhya\ Pradesh",
"912964", "Dungarpur\,\ Rajasthan",
"911373", "Purola\,\ Uttarakhand",
"9177017", "Pingeshwar\,\ Madhya\ Pradesh",
"9171382", "Dhanora\,\ Maharashtra",
"9166547", "Sonapur\,\ Odisha",
"912554", "Malegaon\,\ Maharashtra",
"91389", "Aizawal\,\ Mizoram",
"9164782", "Saharsa\,\ Bihar",
"9168457", "Phiringia\,\ Odisha",
"9173944", "Alirajpur\,\ Madhya\ Pradesh",
"9168616", "Malkangiri\,\ Odisha",
"912325", "Kagal\/Murgud\,\ Maharashtra",
"9174545", "Chhipaborad\,\ Rajasthan",
"9162574", "Barachakia\,\ Bihar",
"913638", "Nongpoh\,\ Meghalaya",
"9174274", "Bhanpura\,\ Madhya\ Pradesh",
"9162245", "Hajipur\,\ Bihar",
"9173203", "Pandhana\,\ Madhya\ Pradesh",
"914362", "Thanjavur\,\ Tamil\ Nadu",
"9175268", "Ghatigaon\,\ Madhya\ Pradesh",
"911555", "Nohar\,\ Rajasthan",
"9174370", "Nainwa\,\ Rajasthan",
"9176479", "Ghughari\,\ Madhya\ Pradesh",
"913779", "Roing\/Mariso\,\ Arunachal\ Pradesh",
"9171422", "Bhimpur\,\ Madhya\ Pradesh",
"9174608", "Sahabad\,\ Rajasthan",
"917868", "Kanker\,\ Madhya\ Pradesh",
"9164714", "Birpur\,\ Bihar",
"918376", "Hirekerur\,\ Karnataka",
"911497", "Kishangarh\,\ Rajasthan",
"9165692", "Garu\,\ Bihar",
"9171534", "Hinganghat\,\ Maharashtra",
"9167532", "Nayagarh\,\ Odisha",
"918737", "Chinnor\,\ Andhra\ Pradesh",
"911348", "Lansdowne\/Syunsi\,\ Uttarakhand",
"9162596", "Pakridayal\,\ Bihar",
"9171467", "Ghorandogri\,\ Madhya\ Pradesh",
"9174638", "Gangapur\,\ Rajasthan",
"9166213", "Hemgiri\,\ Odisha",
"917512", "Gwalior\,\ Madhya\ Pradesh",
"916615", "Rourkela\,\ Odisha",
"915190", "Baberu\,\ Uttar\ Pradesh",
"9173953", "Sondhwa\,\ Madhya\ Pradesh",
"9173233", "Punasa\,\ Madhya\ Pradesh",
"915525", "Bansgaon\,\ Uttar\ Pradesh",
"9174916", "Narwar\,\ Madhya\ Pradesh",
"9166452", "Jharsuguda\,\ Odisha",
"9164375", "Mahagama\,\ Bihar",
"914935", "Mananthavady\,\ Kerala",
"9163236", "Dumraon\,\ Bihar",
"9176377", "Birsa\,\ Madhya\ Pradesh",
"911982", "Leh\,\ Jammu\ And\ Kashmir",
"9173920", "Jhabua\,\ Madhya\ Pradesh",
"911539", "Tibbi\,\ Rajasthan",
"911370", "Devprayag\/Jakholi\,\ Uttarakhand",
"916413", "Bhagalpur\,\ Bihar",
"9171775", "Brahmapuri\,\ Maharashtra",
"9168542", "Jeypore\,\ Odisha",
"9174812", "Gairatganj\,\ Madhya\ Pradesh",
"9166776", "Narlaroad\,\ Odisha",
"911332", "Roorkee\,\ Uttarakhand",
"9164293", "Kahalgaon\,\ Bihar",
"918258", "Karkala\,\ Karnataka",
"912902", "Barmer\/Kanot\,\ Rajasthan",
"9167563", "Balugaon\,\ Odisha",
"9175382", "Ambah\,\ Madhya\ Pradesh",
"9175210", "Seondha\,\ Madhya\ Pradesh",
"9168147", "Digapahandi\,\ Odisha",
"9168483", "Kotagarh\,\ Odisha",
"9171752", "Bhadrawati\,\ Maharashtra",
"9175264", "Ghatigaon\,\ Madhya\ Pradesh",
"9181763", "Cannarayapatna\,\ Karnataka",
"9173929", "Jhabua\,\ Madhya\ Pradesh",
"917523", "Bhander\,\ Madhya\ Pradesh",
"915311", "Salon\,\ Uttar\ Pradesh",
"9174604", "Sahabad\,\ Rajasthan",
"911482", "Bhilwara\,\ Rajasthan",
"9162786", "Dalsinghsarai\,\ Bihar",
"917271", "Bagli\,\ Madhya\ Pradesh",
"914633", "Tenkasi\,\ Tamil\ Nadu",
"9171056", "Narkhed\,\ Maharashtra",
"917784", "Parasgaon\,\ Madhya\ Pradesh",
"9167227", "Pardip\,\ Odisha",
"9171846", "Bhandara\,\ Maharashtra",
"9166767", "M\.Rampur\,\ Odisha",
"911596", "Chirawa\,\ Rajasthan",
"9175219", "Seondha\,\ Madhya\ Pradesh",
"9166845", "Paikamal\,\ Odisha",
"9173948", "Alirajpur\,\ Madhya\ Pradesh",
"918518", "Kurnool\,\ Andhra\ Pradesh",
"9163445", "Monghyr\,\ Bihar",
"9171645", "Pandhurna\,\ Madhya\ Pradesh",
"913473", "Ranaghat\,\ West\ Bengal",
"9176366", "Baihar\,\ Madhya\ Pradesh",
"912111", "Indapur\,\ Maharashtra",
"9174278", "Bhanpura\,\ Madhya\ Pradesh",
"9174847", "Silwani\,\ Madhya\ Pradesh",
"9161843", "Sasaram\,\ Bihar",
"917574", "Hoshangabad\,\ Madhya\ Pradesh",
"917252", "Washim\,\ Maharashtra",
"9168184", "Buguda\,\ Odisha",
"918190", "Tallak\,\ Karnataka",
"9133", "Kolkata\,\ West\ Bengal",
"9167944", "Rairangpur\,\ Odisha",
"918703", "Warangal\,\ Andhra\ Pradesh",
"918354", "Bagalkot\,\ Karnataka",
"9168112", "Chhatrapur\,\ Odisha",
"913675", "Bokajan\,\ Assam",
"9165854", "Ghatsila\,\ Bihar",
"91154", "Sriganganagar\,\ Rajasthan",
"918593", "Medarmetla\,\ Andhra\ Pradesh",
"91481", "Kottayam\,\ Kerala",
"918525", "Gudur\/Kodumur\,\ Andhra\ Pradesh",
"9171476", "Multai\,\ Madhya\ Pradesh",
"917747", "Mohla\,\ Madhya\ Pradesh",
"9166475", "Naktideul\,\ Odisha",
"9164352", "Pakur\,\ Bihar",
"9181732", "Sakleshpur\,\ Karnataka",
"9164715", "Birpur\,\ Bihar",
"9176527", "Shahdol\,\ Madhya\ Pradesh",
"9161872", "Mohania\,\ Bihar",
"912844", "Mahuva\,\ Gujarat",
"9163247", "Nawada\,\ Bihar",
"917846", "Garpa\,\ Madhya\ Pradesh",
"9171973", "Mohadi\,\ Maharashtra",
"9174275", "Bhanpura\,\ Madhya\ Pradesh",
"918284", "Haliyal\,\ Karnataka",
"915942", "Nainital\,\ Uttar\ Pradesh",
"918205", "Udupi\,\ Karnataka",
"915836", "Gunnaur\,\ Uttar\ Pradesh",
"9162244", "Hajipur\,\ Bihar",
"9174544", "Chhipaborad\,\ Rajasthan",
"918821", "Jangareddygudem\,\ Andhra\ Pradesh",
"9162575", "Barachakia\,\ Bihar",
"9182206", "Gundlupet\,\ Karnataka",
"912453", "Gangakhed\,\ Maharashtra",
"9173945", "Alirajpur\,\ Madhya\ Pradesh",
"912527", "Shahapur\,\ Maharashtra",
"918442", "Jewargi\,\ Karnataka",
"912188", "Mangalwedha\,\ Maharashtra",
"918581", "Punganur\,\ Andhra\ Pradesh",
"918752", "Bhainsa\,\ Andhra\ Pradesh",
"9171092", "Kamptee\,\ Maharashtra",
"917203", "Babhulgaon\,\ Maharashtra",
"914144", "Chidambaram\,\ Tamil\ Nadu",
"918360", "Hubli\,\ Karnataka",
"9163362", "Rajauli\,\ Bihar",
"9176503", "Beohari\,\ Madhya\ Pradesh",
"9164525", "Katihar\,\ Bihar",
"911807", "Panipat\,\ Haryana",
"917779", "Ramchandrapur\,\ Madhya\ Pradesh",
"9171796", "Nagbhir\,\ Maharashtra",
"9165282", "Khunti\,\ Bihar",
"918247", "Mangalore\,\ Karnataka",
"915648", "Bayana\,\ Rajasthan",
"9166795", "Komana\,\ Odisha",
"9162734", "Jhajharpur\,\ Bihar",
"9171315", "Sironcha\,\ Maharashtra",
"9161583", "Sonepur\,\ Bihar",
"9174963", "Pichhore\,\ Madhya\ Pradesh",
"912563", "Shirpur\,\ Maharashtra",
"9174587", "Pipalda\/Sumerganj\ Mandi\,\ Rajasthan",
"9165364", "Palkot\,\ Bihar",
"9162287", "Pupri\,\ Bihar",
"917237", "Marigaon\,\ Maharashtra",
"913174", "Diamond\ Harbour\,\ West\ Bengal",
"9168573", "Gunupur\,\ Odisha",
"913880", "Sadarhills\/Kangpokai\,\ Manipur",
"9174635", "Gangapur\,\ Rajasthan",
"9171024", "Parseoni\,\ Maharashtra",
"917448", "Ladpura\/Kota\,\ Rajasthan",
"913216", "Habra\,\ West\ Bengal",
"9163284", "Daudnagar\,\ Bihar",
"918388", "Ankola\,\ Karnataka",
"9171653", "Saunsar\,\ Madhya\ Pradesh",
"9163453", "Jamui\,\ Bihar",
"918648", "Repalle\,\ Andhra\ Pradesh",
"9166266", "Banaigarh\,\ Odisha",
"9174411", "Ladpura\/Kota\,\ Rajasthan",
"918938", "Sileru\,\ Andhra\ Pradesh",
"9176493", "Kakaiya\,\ Madhya\ Pradesh",
"912160", "Sakarwadi\,\ Maharashtra",
"9168226", "Aska\,\ Odisha",
"9166853", "Sohela\,\ Odisha",
"9165625", "Daltonganj\,\ Bihar",
"9171495", "Tamia\,\ Madhya\ Pradesh",
"9176263", "Vijayraghogarh\,\ Madhya\ Pradesh",
"9161855", "Bikramganj\,\ Bihar",
"912735", "Deodar\,\ Gujarat",
"9166496", "Jamankira\,\ Odisha",
"9165826", "Chaibasa\,\ Bihar",
"917758", "Dabhara\,\ Madhya\ Pradesh",
"9171586", "Deoli\,\ Maharashtra",
"918632", "Guntur\,\ Andhra\ Pradesh",
"915821", "Pitamberpur\,\ Uttar\ Pradesh",
"9171837", "Tumsar\,\ Maharashtra",
"91161", "Ludhiana\,\ Punjab",
"918942", "Srikakulam\,\ Andhra\ Pradesh",
"9187593", "Outsarangapalle\,\ Andhra\ Pradesh",
"915284", "Maudaha\,\ Uttar\ Pradesh",
"918836", "Rajahmundri\,\ Andhra\ Pradesh",
"9168602", "Boriguma\,\ Odisha",
"9174252", "Garoth\,\ Madhya\ Pradesh",
"912953", "Nathdwara\,\ Rajasthan",
"9174932", "Karera\,\ Madhya\ Pradesh",
"911734", "Naraingarh\,\ Haryana",
"914255", "Palladam\,\ Tamil\ Nadu",
"915442", "Mirzapur\,\ Uttar\ Pradesh",
"9162552", "Raxaul\,\ Bihar",
"9166474", "Naktideul\,\ Odisha",
"9165417", "Chatra\,\ Bihar",
"918494", "Kadiri\,\ Andhra\ Pradesh",
"918673", "Tirivuru\,\ Andhra\ Pradesh",
"913595", "Gauzing\/Nayabazar\,\ West\ Bengal",
"912950", "Dhariawad\,\ Rajasthan",
"913523", "Raiganj\,\ West\ Bengal",
"9174902", "Pohari\,\ Madhya\ Pradesh",
"9165656", "Latehar\,\ Bihar",
"918327", "Goa",
"9168632", "Bisam\ Cuttack\,\ Odisha",
"9165855", "Ghatsila\,\ Bihar",
"9171807", "Salekasa\,\ Maharashtra",
"9161826", "Arrah\,\ Bihar",
"911851", "Patti\,\ Punjab",
"9167945", "Rairangpur\,\ Odisha",
"917473", "Bundi\,\ Rajasthan",
"9168185", "Buguda\,\ Odisha",
"917694", "Keolari\,\ Madhya\ Pradesh",
"912892", "Okha\,\ Gujarat",
"913784", "Nefra\,\ Arunachal\ Pradesh",
"912696", "Borsad\,\ Gujarat",
"911676", "Sunam\,\ Punjab",
"9171644", "Pandhurna\,\ Madhya\ Pradesh",
"91130", "Sonipat\,\ Haryana",
"9163444", "Monghyr\,\ Bihar",
"9165967", "Noamundi\,\ Bihar",
"9167642", "Anugul\,\ Odisha",
"912163", "Koregaon\,\ Maharashtra",
"915181", "Bindki\,\ Uttar\ Pradesh",
"9165583", "Dumri\(Isribazar\)\,\ Bihar",
"9174548", "Chhipaborad\,\ Rajasthan",
"911872", "Quadian\,\ Punjab",
"918624", "Gudur\,\ Andhra\ Pradesh",
"913252", "Purulia\,\ West\ Bengal",
"9166844", "Paikamal\,\ Odisha",
"918475", "Chincholi\,\ Karnataka",
"9167336", "Ghatgaon\,\ Odisha",
"9168663", "Umerkote\,\ Odisha",
"912381", "Ahmedpur\,\ Maharashtra",
"9162447", "Khagaria\,\ Bihar",
"912426", "Rahuri\,\ Maharashtra",
"9174605", "Sahabad\,\ Rajasthan",
"9174529", "Chhabra\,\ Rajasthan",
"9174806", "Goharganj\,\ Madhya\ Pradesh",
"912931", "Jodhpur\/Jhanwar\,\ Rajasthan",
"917675", "Amarpatan\,\ Madhya\ Pradesh",
"916572", "Jamshedpur\,\ Bihar",
"912759", "Lakhtar\,\ Gujarat",
"9171823", "Gondia\,\ Maharashtra",
"9175265", "Ghatigaon\,\ Madhya\ Pradesh",
"912641", "Amod\,\ Gujarat",
"912560", "Kusumba\,\ Maharashtra",
"913512", "Malda\,\ West\ Bengal",
"912588", "Erandul\,\ Maharashtra",
"918716", "Jangaon\,\ Andhra\ Pradesh",
"9174686", "Khandar\,\ Rajasthan",
"918181", "Thirthahalli\,\ Karnataka",
"9176533", "Bandhavgarh\,\ Madhya\ Pradesh",
"9165442", "Gomia\,\ Bihar",
"914544", "Natham\,\ Tamil\ Nadu",
"916514", "Ranchi\,\ Bihar",
"918363", "Hubli\,\ Karnataka",
"9164556", "Forbesganj\,\ Bihar",
"9172863", "Khetia\,\ Madhya\ Pradesh",
"9174520", "Chhabra\,\ Rajasthan",
"911508", "Suratgarh\/Goluwala\,\ Rajasthan",
"9171774", "Brahmapuri\,\ Maharashtra",
"912431", "Paithan\,\ Maharashtra",
"9165397", "Bolwa\,\ Bihar",
"912740", "Vav\,\ Gujarat",
"912926", "Osian\/Mathania\,\ Rajasthan",
"914296", "Avanashi\,\ Tamil\ Nadu",
"9165976", "Saraikela\/Adstyapur\,\ Bihar",
"9163327", "Nabinagar\,\ Bihar",
"9184533", "Medak\,\ Andhra\ Pradesh",
"9165872", "Chakardharpur\,\ Bihar",
"9174553", "Digod\/Sultanpur\,\ Rajasthan",
"915673", "Bhogaon\,\ Uttar\ Pradesh",
"9161557", "Ekma\,\ Bihar",
"915494", "Bansdeeh\,\ Uttar\ Pradesh",
"9168106", "Khalikote\,\ Odisha",
"9167617", "Chhendipada\,\ Odisha",
"9164374", "Mahagama\,\ Bihar",
"917365", "Mahidpurcity\,\ Madhya\ Pradesh",
"9176562", "Kannodi\,\ Madhya\ Pradesh",
"912828", "Wankaner\,\ Gujarat",
"914115", "Madurantakam\,\ Tamil\ Nadu",
"912778", "Idar\,\ Gujarat",
"9161152", "Danapur\,\ Bihar",
"9163487", "Mallehpur\,\ Bihar",
"9177073", "Bagbahera\,\ Madhya\ Pradesh",
"9171687", "Harrai\,\ Madhya\ Pradesh",
"9166536", "Dunguripali\,\ Odisha",
"9171535", "Hinganghat\,\ Maharashtra",
"91424", "Erode\,\ Tamil\ Nadu",
"9172860", "Khetia\,\ Madhya\ Pradesh",
"9161527", "Chapra\,\ Bihar",
"9168682", "Nandapur\,\ Odisha",
"9174523", "Chhabra\,\ Rajasthan",
"9162223", "Sheohar\,\ Bihar",
"9164716", "Birpur\,\ Bihar",
"917750", "Marwahi\,\ Madhya\ Pradesh",
"914868", "Nedumkandam\,\ Kerala",
"9174317", "Aklera\,\ Rajasthan",
"917362", "Agar\,\ Madhya\ Pradesh",
"918678", "Nandigama\,\ Andhra\ Pradesh",
"9174711", "Bundi\,\ Rajasthan",
"914112", "Kancheepuram\,\ Tamil\ Nadu",
"918739", "Jannaram\/Luxittipet\,\ Andhra\ Pradesh",
"9162576", "Barachakia\,\ Bihar",
"9165562", "Tisri\,\ Bihar",
"9182205", "Gundlupet\,\ Karnataka",
"9176368", "Baihar\,\ Madhya\ Pradesh",
"9174276", "Bhanpura\,\ Madhya\ Pradesh",
"9161122", "Biharsharif\,\ Bihar",
"9176530", "Bandhavgarh\,\ Madhya\ Pradesh",
"917478", "Bundi\,\ Rajasthan",
"9173946", "Alirajpur\,\ Madhya\ Pradesh",
"9168614", "Malkangiri\,\ Odisha",
"915451", "Mariyahu\,\ Uttar\ Pradesh",
"918380", "Navalgund\,\ Karnataka",
"9164273", "Kathikund\,\ Bihar",
"918414", "Ibrahimpatnam\,\ Andhra\ Pradesh",
"9177070", "Bagbahera\,\ Madhya\ Pradesh",
"9176442", "Dindori\,\ Madhya\ Pradesh",
"912168", "Mahabaleswar\,\ Maharashtra",
"9165533", "Ramgarh\,\ Bihar",
"918640", "Krosuru\,\ Andhra\ Pradesh",
"918561", "Rayachoti\,\ Andhra\ Pradesh",
"911537", "Nohar\/Rawatsar\,\ Rajasthan",
"9174550", "Digod\/Sultanpur\,\ Rajasthan",
"9164526", "Katihar\,\ Bihar",
"9174507", "Sangod\,\ Rajasthan",
"9161503", "Hathua\,\ Bihar",
"91203", "Pune\,\ Maharashtra",
"9166796", "Komana\,\ Odisha",
"917440", "Ladpura\/Kota\,\ Rajasthan",
"917731", "Gunnore\,\ Madhya\ Pradesh",
"9171316", "Sironcha\,\ Maharashtra",
"915368", "Amethi\,\ Uttar\ Pradesh",
"9171795", "Nagbhir\,\ Maharashtra",
"915414", "Bhadohi\,\ Uttar\ Pradesh",
"9174342", "Pirawa\/Raipur\,\ Rajasthan",
"913860", "Wokha\,\ Nagaland",
"9164662", "Kishanganj\,\ Bihar",
"911875", "Dinanagar\,\ Punjab",
"918659", "Mylavaram\,\ Andhra\ Pradesh",
"916803", "Berhampur\,\ Odisha",
"918741", "Sudhimalla\/Tekulapalli\,\ Andhra\ Pradesh",
"918914", "Visakhapatnam\,\ Andhra\ Pradesh",
"915640", "Kaman\,\ Rajasthan",
"915561", "Salempur\/Barhaj\,\ Uttar\ Pradesh",
"912583", "Edalabad\,\ Maharashtra",
"9177079", "Bagbahera\,\ Madhya\ Pradesh",
"9174636", "Gangapur\,\ Rajasthan",
"918472", "Gulbarga\,\ Karnataka",
"912874", "Manavadar\,\ Gujarat",
"9182894", "Athani\,\ Karnataka",
"916575", "Jamshedpur\,\ Bihar",
"918368", "Hubli\,\ Karnataka",
"917726", "Bhatapara\,\ Madhya\ Pradesh",
"917672", "Satna\,\ Madhya\ Pradesh",
"911503", "Sadulshahar\,\ Rajasthan",
"9168225", "Aska\,\ Odisha",
"9174559", "Digod\/Sultanpur\,\ Rajasthan",
"9171043", "Hingua\,\ Maharashtra",
"9166265", "Banaigarh\,\ Odisha",
"9171853", "Pauni\,\ Maharashtra",
"9174918", "Narwar\,\ Madhya\ Pradesh",
"9172882", "Bhikangaon\,\ Madhya\ Pradesh",
"9176417", "Niwas\,\ Madhya\ Pradesh",
"9165626", "Daltonganj\,\ Bihar",
"913592", "Gangtok\,\ West\ Bengal",
"911894", "Palampur\,\ Himachal\ Pradesh",
"9166495", "Jamankira\,\ Odisha",
"9174267", "Sitamau\,\ Madhya\ Pradesh",
"9172869", "Khetia\,\ Madhya\ Pradesh",
"9165825", "Chaibasa\,\ Bihar",
"9162434", "Begusarai\,\ Bihar",
"9171496", "Tamia\,\ Madhya\ Pradesh",
"917749", "Balod\,\ Madhya\ Pradesh",
"9162567", "Ramnagar\,\ Bihar",
"9161856", "Bikramganj\,\ Bihar",
"9176539", "Bandhavgarh\,\ Madhya\ Pradesh",
"9166837", "Padmapur\,\ Odisha",
"9171585", "Deoli\,\ Maharashtra",
"91595", "Rampur\,\ Uttar\ Pradesh",
"91490", "Tellicherry\,\ Kerala",
"918451", "Zahirabad\,\ Andhra\ Pradesh",
"912895", "Lalpur\,\ Gujarat",
"912823", "Jetpur\,\ Gujarat",
"914174", "Vaniyambadi\,\ Tamil\ Nadu",
"912773", "Malpur\,\ Gujarat",
"915264", "Balarampur\/Tulsipur\,\ Uttar\ Pradesh",
"918506", "Narayanpet\,\ Andhra\ Pradesh",
"9171607", "Jamai\,\ Madhya\ Pradesh",
"9171474", "Multai\,\ Madhya\ Pradesh",
"912770", "Prantij\,\ Gujarat",
"9165655", "Latehar\,\ Bihar",
"912820", "Paddhari\,\ Gujarat",
"911999", "Mahore\,\ Jammu\ And\ Kashmir",
"913192", "Andaman\ \&\ Nicobar\,\ Andaman\ Islands",
"9161825", "Arrah\,\ Bihar",
"9165263", "Lohardaga\,\ Bihar",
"9176490", "Kakaiya\,\ Madhya\ Pradesh",
"9176509", "Beohari\,\ Madhya\ Pradesh",
"9165856", "Ghatsila\,\ Bihar",
"917811", "Pasan\,\ Madhya\ Pradesh",
"9174960", "Pichhore\,\ Madhya\ Pradesh",
"9168186", "Buguda\,\ Odisha",
"918635", "Guntur\,\ Andhra\ Pradesh",
"911921", "Basholi\,\ Jammu\ And\ Kashmir",
"9167946", "Rairangpur\,\ Odisha",
"918945", "Tekkali\/Palasa\,\ Andhra\ Pradesh",
"916717", "Cuttack\,\ Odisha",
"914574", "Manamadurai\,\ Tamil\ Nadu",
"914252", "Udumalpet\,\ Tamil\ Nadu",
"9174222", "Mandsaur\,\ Madhya\ Pradesh",
"9162522", "Motihari\,\ Bihar",
"915445", "Robertsganj\/Obra\,\ Uttar\ Pradesh",
"911436", "Uniayara\,\ Rajasthan",
"912748", "Dhanera\,\ Gujarat",
"918819", "Tanuku\,\ Andhra\ Pradesh",
"9176364", "Baihar\,\ Madhya\ Pradesh",
"91427", "Salem\,\ Tamil\ Nadu",
"9167842", "Bhadrak\,\ Odisha",
"912183", "Madha\,\ Maharashtra",
"9171054", "Narkhed\,\ Maharashtra",
"9167335", "Ghatgaon\,\ Odisha",
"9162712", "Benipatti\,\ Bihar",
"9171844", "Bhandara\,\ Maharashtra",
"9165232", "Ghaghra\,\ Bihar",
"9174606", "Sahabad\,\ Rajasthan",
"915643", "Nadbai\,\ Rajasthan",
"9164627", "Dhamdaha\,\ Bihar",
"912580", "Jamner\,\ Maharashtra",
"9163423", "H\.Kharagpur\,\ Bihar",
"9171623", "Chhindwara\,\ Madhya\ Pradesh",
"9162784", "Dalsinghsarai\,\ Bihar",
"912979", "Sanchore\,\ Rajasthan",
"9176260", "Vijayraghogarh\,\ Madhya\ Pradesh",
"9175266", "Ghatigaon\,\ Madhya\ Pradesh",
"9164572", "Korha\,\ Bihar",
"9166823", "Attabira\,\ Odisha",
"913863", "Kiphire\,\ Nagaland",
"9174805", "Goharganj\,\ Madhya\ Pradesh",
"9165493", "Bermo\,\ Bihar",
"9174685", "Khandar\,\ Rajasthan",
"917443", "Ladpura\/Kota\,\ Rajasthan",
"9161533", "Maharajganj\,\ Bihar",
"91816", "Tumkur\,\ Karnataka",
"912568", "Sakri\,\ Maharashtra",
"913241", "Gangajalghati\,\ West\ Bengal",
"9174537", "Baran\,\ Rajasthan",
"9162237", "Motipur\,\ Bihar",
"918643", "Bapatla\,\ Andhra\ Pradesh",
"918407", "Darsi\,\ Andhra\ Pradesh",
"9176269", "Vijayraghogarh\,\ Madhya\ Pradesh",
"917854", "Ilamidi\,\ Madhya\ Pradesh",
"9165503", "Hunterganj\,\ Bihar",
"9166774", "Narlaroad\,\ Odisha",
"918933", "Bheemunipatnam\,\ Andhra\ Pradesh",
"9164555", "Forbesganj\,\ Bihar",
"9167693", "Kamakhyanagar\,\ Odisha",
"9163234", "Dumraon\,\ Bihar",
"9176282", "Karpa\,\ Madhya\ Pradesh",
"9165975", "Saraikela\/Adstyapur\,\ Bihar",
"918383", "Joida\,\ Karnataka",
"9174132", "Sailana\,\ Madhya\ Pradesh",
"9162747", "Samastipur\,\ Bihar",
"9168105", "Khalikote\,\ Odisha",
"913777", "Yangkiyang\,\ Arunachal\ Pradesh",
"9167817", "Basta\,\ Odisha",
"9182898", "Athani\,\ Karnataka",
"9176499", "Kakaiya\,\ Madhya\ Pradesh",
"9176500", "Beohari\,\ Madhya\ Pradesh",
"9165313", "Mandar\,\ Bihar",
"911499", "Sangaria\,\ Rajasthan",
"9165672", "Barwadih\,\ Bihar",
"914567", "Ramanathpuram\,\ Tamil\ Nadu",
"9174914", "Narwar\,\ Madhya\ Pradesh",
"911936", "Pahalgam\,\ Jammu\ And\ Kashmir",
"9161562", "Gopalganj\,\ Bihar",
"918202", "Udupi\,\ Karnataka",
"912958", "Kotra\,\ Rajasthan",
"915945", "Haldwani\/Chorgalian\,\ Uttar\ Pradesh",
"917753", "Kota\,\ Madhya\ Pradesh",
"9171536", "Hinganghat\,\ Maharashtra",
"9174969", "Pichhore\,\ Madhya\ Pradesh",
"9166535", "Dunguripali\,\ Odisha",
"911421", "Kotputli\,\ Rajasthan",
"9162594", "Pakridayal\,\ Bihar",
"911386", "Lansdowne\,\ Uttarakhand",
"9176478", "Ghughari\,\ Madhya\ Pradesh",
"918543", "Wanaparthy\,\ Andhra\ Pradesh",
"9175269", "Ghatigaon\,\ Madhya\ Pradesh",
"9162225", "Sheohar\,\ Bihar",
"912359", "Guhagar\,\ Maharashtra",
"911591", "Merta\/Gotan\,\ Rajasthan",
"9174525", "Chhabra\,\ Rajasthan",
"9166717", "Rajkhariar\,\ Odisha",
"9171397", "Kurkheda\,\ Maharashtra",
"9173924", "Jhabua\,\ Madhya\ Pradesh",
"91278", "Bhavnagar\,\ Gujarat",
"9174609", "Sahabad\,\ Rajasthan",
"912552", "Nandgaon\,\ Maharashtra",
"9171976", "Mohadi\,\ Maharashtra",
"911529", "Lunkaransar\/Kanholi\,\ Rajasthan",
"9175214", "Seondha\,\ Madhya\ Pradesh",
"9176277", "Manpur\,\ Madhya\ Pradesh",
"9182203", "Gundlupet\,\ Karnataka",
"912668", "Waghodia\,\ Gujarat",
"9171442", "Atner\,\ Madhya\ Pradesh",
"914364", "Mayiladuthurai\,\ Tamil\ Nadu",
"9181521", "Kolar\,\ Karnatak",
"911275", "Palwal\,\ Haryana",
"9168162", "Mohana\,\ Odisha",
"9164275", "Kathikund\,\ Bihar",
"9164544", "Purnea\,\ Bihar",
"915864", "Sidhauli\/Mahmodabad\,\ Uttar\ Pradesh",
"9165687", "Balumath\,\ Bihar",
"9165535", "Ramgarh\,\ Bihar",
"9171872", "Goregaon\,\ Maharashtra",
"918727", "Huzurabad\,\ Andhra\ Pradesh",
"9161505", "Hathua\,\ Bihar",
"9168434", "Puruna\ Katak\,\ Odisha",
"9166527", "Balangir\,\ Odisha",
"9173247", "Mhow\,\ Madhya\ Pradesh",
"9168567", "Rayagada\,\ Odisha",
"9176506", "Beohari\,\ Madhya\ Pradesh",
"912962", "Banswara\,\ Rajasthan",
"9164797", "Udakishanganj\,\ Bihar",
"9171793", "Nagbhir\,\ Maharashtra",
"9174977", "Khaniadhana\,\ Madhya\ Pradesh",
"91257", "Jalgaon\,\ Maharashtra",
"917545", "Arone\,\ Madhya\ Pradesh",
"9174966", "Pichhore\,\ Madhya\ Pradesh",
"918535", "Sindhanur\,\ Karnataka",
"918864", "Rampachodavaram\,\ Andhra\ Pradesh",
"9161586", "Sonepur\,\ Bihar",
"9161837", "Buxar\,\ Bihar",
"9164252", "Katoria\,\ Bihar",
"9168576", "Gunupur\,\ Odisha",
"912378", "Medha\,\ Maharashtra",
"9167487", "Bhubaneshwar\,\ Odisha",
"9171417", "Betul\,\ Madhya\ Pradesh",
"917765", "Pathalgaon\,\ Madhya\ Pradesh",
"9171656", "Saunsar\,\ Madhya\ Pradesh",
"9163456", "Jamui\,\ Bihar",
"9171855", "Pauni\,\ Maharashtra",
"9171045", "Hingua\,\ Maharashtra",
"912462", "Nanded\,\ Maharashtra",
"9166263", "Banaigarh\,\ Odisha",
"915178", "Mauranipur\,\ Uttar\ Pradesh",
"9168223", "Aska\,\ Odisha",
"9166856", "Sohela\,\ Odisha",
"9176496", "Kakaiya\,\ Madhya\ Pradesh",
"914268", "Velur\,\ Tamil\ Nadu",
"9174600", "Sahabad\,\ Rajasthan",
"9175922", "Vidisha\,\ Madhya\ Pradesh",
"9174657", "Sapotra\,\ Rajasthan",
"915543", "Naugarh\/Barhani\,\ Uttar\ Pradesh",
"9167327", "Hindol\,\ Odisha",
"9175260", "Ghatigaon\,\ Madhya\ Pradesh",
"9174378", "Nainwa\,\ Rajasthan",
"9176266", "Vijayraghogarh\,\ Madhya\ Pradesh",
"9165823", "Chaibasa\,\ Bihar",
"9166493", "Jamankira\,\ Odisha",
"9165644", "Nagarutari\,\ Bihar",
"9171967", "Arjuni\ Morgaon\,\ Maharashtra",
"9171583", "Deoli\,\ Maharashtra",
"911398", "Kairana\/Shamli\,\ Uttar\ Pradesh",
"918159", "Mulbagal\,\ Karnataka",
"9187596", "Outsarangapalle\,\ Andhra\ Pradesh",
"9127177", "Sanand\,\ Gujarat",
"918316", "Belgaum\,\ Karnataka",
"9174862", "Bareli\,\ Madhya\ Pradesh",
"917533", "Karhal\,\ Madhya\ Pradesh",
"9173212", "Sanwer\,\ Madhya\ Pradesh",
"91796", "Ahmedabad\ Local\,\ Gujarat",
"9167924", "Baripada\,\ Odisha",
"917530", "Sheopurkalan\,\ Madhya\ Pradesh",
"9165653", "Latehar\,\ Bihar",
"915143", "Hasanganj\,\ Uttar\ Pradesh",
"917572", "Itarsi\,\ Madhya\ Pradesh",
"911603", "Kharar\,\ Punjab",
"917254", "Malgaon\,\ Maharashtra",
"9177067", "Gariaband\,\ Madhya\ Pradesh",
"9165265", "Lohardaga\,\ Bihar",
"9174827", "Raisen\,\ Madhya\ Pradesh",
"9161823", "Arrah\,\ Bihar",
"912343", "Atpadi\,\ Maharashtra",
"913841", "Vdarbondh\,\ Assam",
"9175967", "Gyraspur\,\ Madhya\ Pradesh",
"9171364", "Etapalli\,\ Maharashtra",
"918559", "Dharmavaram\,\ Andhra\ Pradesh",
"915661", "Sadabad\,\ Uttar\ Pradesh",
"918352", "Bijapur\,\ Karnataka",
"9174630", "Gangapur\,\ Rajasthan",
"9165586", "Dumri\(Isribazar\)\,\ Bihar",
"918135", "Sira\,\ Karnataka",
"911484", "Shahapura\,\ Rajasthan",
"9165837", "Kharsawa\,\ Bihar",
"9173949", "Alirajpur\,\ Madhya\ Pradesh",
"9175218", "Seondha\,\ Madhya\ Pradesh",
"9168594", "Motu\,\ Odisha",
"9164764", "Madhepura\,\ Bihar",
"918371", "Mundargi\,\ Karnataka",
"9174279", "Bhanpura\,\ Madhya\ Pradesh",
"9172877", "Gogaon\,\ Madhya\ Pradesh",
"9167333", "Ghatgaon\,\ Odisha",
"9171625", "Chhindwara\,\ Madhya\ Pradesh",
"9163425", "H\.Kharagpur\,\ Bihar",
"9176474", "Ghughari\,\ Madhya\ Pradesh",
"912485", "Bhokardan\,\ Maharashtra",
"9168666", "Umerkote\,\ Odisha",
"9161807", "Adhaura\,\ Bihar",
"9165495", "Bermo\,\ Bihar",
"9166825", "Attabira\,\ Odisha",
"9173928", "Jhabua\,\ Madhya\ Pradesh",
"9174803", "Goharganj\,\ Madhya\ Pradesh",
"913018", "Jaisalmer\/Sadhna\,\ Rajasthan",
"91755", "Bhopal\,\ Madhya\ Pradesh",
"913227", "Amlagora\,\ West\ Bengal",
"917782", "Jagdalpur\,\ Madhya\ Pradesh",
"9171826", "Gondia\,\ Maharashtra",
"9167247", "Jagatsinghpur\,\ Odisha",
"911334", "Roorkee\/Haridwar\,\ Uttarakhand",
"913839", "Jalukie\,\ Nagaland",
"9168522", "Koraput\,\ Odisha",
"9174683", "Khandar\,\ Rajasthan",
"9174270", "Bhanpura\,\ Madhya\ Pradesh",
"9171152", "Mouda\,\ Maharashtra",
"9176536", "Bandhavgarh\,\ Madhya\ Pradesh",
"9168404", "Tumudibandha\,\ Odisha",
"9168677", "Jharigan\,\ Odisha",
"911905", "Mandi\,\ Himachal\ Pradesh",
"9173940", "Alirajpur\,\ Madhya\ Pradesh",
"9161535", "Maharajganj\,\ Bihar",
"9171557", "Seloo\,\ Maharashtra",
"9167695", "Kamakhyanagar\,\ Odisha",
"9172866", "Khetia\,\ Madhya\ Pradesh",
"9164553", "Forbesganj\,\ Bihar",
"91721", "Amravati\,\ Maharashtra",
"9165505", "Hunterganj\,\ Bihar",
"9174374", "Nainwa\,\ Rajasthan",
"918578", "Srikalahasthi\,\ Andhra\ Pradesh",
"9184536", "Medak\,\ Andhra\ Pradesh",
"91217", "Sholapur\,\ Maharashtra",
"912985", "Barmer\/Ramsar\,\ Rajasthan",
"9165973", "Saraikela\/Adstyapur\,\ Bihar",
"914283", "Sankagiri\,\ Tamil\ Nadu",
"912904", "Deogarh\,\ Rajasthan",
"911637", "Malaut\,\ Punjab",
"9171994", "Deori\,\ Maharashtra",
"917514", "Gwalior\,\ Madhya\ Pradesh",
"9174556", "Digod\/Sultanpur\,\ Rajasthan",
"9168103", "Khalikote\,\ Odisha",
"9167284", "Jajapur\ Town\,\ Odisha",
"918788", "Karimnagar\,\ Andhra\ Pradesh",
"9165315", "Mandar\,\ Bihar",
"91487", "Thrissur\,\ Kerala",
"9167212", "Narsinghpur\,\ Odisha",
"9177076", "Bagbahera\,\ Madhya\ Pradesh",
"9174639", "Gangapur\,\ Rajasthan",
"9166533", "Dunguripali\,\ Odisha",
"918219", "Mysore\,\ Karnataka",
"918540", "Nagarkurnool\,\ Andhra\ Pradesh",
"9174526", "Chhabra\,\ Rajasthan",
"916614", "Rourkela\,\ Odisha",
"9174809", "Goharganj\,\ Madhya\ Pradesh",
"9171717", "Gond\ Pipri\,\ Maharashtra",
"9162226", "Sheohar\,\ Bihar",
"9164713", "Birpur\,\ Bihar",
"912761", "Kheralu\,\ Gujarat",
"911233", "Mawana\,\ Uttar\ Pradesh",
"9171975", "Mohadi\,\ Maharashtra",
"9181768", "Cannarayapatna\,\ Karnataka",
"913667", "Bilasipara\,\ Assam",
"9162573", "Barachakia\,\ Bihar",
"9173204", "Pandhana\,\ Madhya\ Pradesh",
"9174680", "Khandar\,\ Rajasthan",
"9174273", "Bhanpura\,\ Madhya\ Pradesh",
"9166442", "Rairakhol\,\ Odisha",
"915524", "Pharenda\/Anand\ Nagar\,\ Uttar\ Pradesh",
"9173943", "Alirajpur\,\ Madhya\ Pradesh",
"916317", "Gaya\,\ Bihar",
"9171122", "Katol\,\ Maharashtra",
"9168552", "Laxmipur\,\ Odisha",
"9164276", "Kathikund\,\ Bihar",
"9165536", "Ramgarh\,\ Bihar",
"91522", "Lucknow\,\ Uttar\ Pradesh",
"915170", "Chirgaon\/Moth\,\ Uttar\ Pradesh",
"9165887", "Jagarnathpur\,\ Bihar",
"911902", "Kullu\,\ Himachal\ Pradesh",
"918236", "Pandavpura\,\ Karnataka",
"9176505", "Beohari\,\ Madhya\ Pradesh",
"9168157", "Parlakhemundi\,\ Odisha",
"9164523", "Katihar\,\ Bihar",
"9171527", "Wardha\,\ Maharashtra",
"913013", "Jaisalmer\/Dhanaua\,\ Rajasthan",
"9161506", "Hathua\,\ Bihar",
"9171313", "Sironcha\,\ Maharashtra",
"9167674", "Barbil\,\ Odisha",
"9167407", "Bhubaneshwar\,\ Odisha",
"9171672", "Amarwada\,\ Madhya\ Pradesh",
"9163472", "Chakai\,\ Bihar",
"9166793", "Komana\,\ Odisha",
"9164317", "Jharmundi\,\ Bihar",
"914347", "Denkanikota\,\ Tamil\ Nadu",
"912982", "Barmer\,\ Rajasthan",
"918132", "Kunigal\,\ Karnataka",
"9161585", "Sonepur\,\ Bihar",
"9174965", "Pichhore\,\ Madhya\ Pradesh",
"911786", "Kalpa\,\ Himachal\ Pradesh",
"918221", "Nanjangud\,\ Karnataka",
"912596", "Pachora\,\ Maharashtra",
"9174633", "Gangapur\,\ Rajasthan",
"9171742", "Mul\,\ Maharashtra",
"9168575", "Gunupur\,\ Odisha",
"9166417", "Deodgarh\,\ Odisha",
"9165474", "Chavparan\,\ Bihar",
"9165607", "Patan\,\ Bihar",
"912482", "Jalna\,\ Maharashtra",
"9171655", "Saunsar\,\ Madhya\ Pradesh",
"9163455", "Jamui\,\ Bihar",
"914288", "Tiruchengode\,\ Tamil\ Nadu",
"918573", "Bangarupalem\,\ Andhra\ Pradesh",
"913623", "Barama\,\ Assam",
"9164267", "Rajmahal\,\ Bihar",
"9173238", "Punasa\,\ Madhya\ Pradesh",
"9173958", "Sondhwa\,\ Madhya\ Pradesh",
"9166855", "Sohela\,\ Odisha",
"9176495", "Kakaiya\,\ Madhya\ Pradesh",
"9171856", "Pauni\,\ Maharashtra",
"917785", "Makodi\,\ Madhya\ Pradesh",
"9171046", "Hingua\,\ Maharashtra",
"9167234", "Athgarh\,\ Odisha",
"9167954", "Udala\,\ Odisha",
"918783", "Karimnagar\,\ Andhra\ Pradesh",
"918847", "Kakinada\,\ Andhra\ Pradesh",
"9165623", "Daltonganj\,\ Bihar",
"917229", "Warlydwarud\,\ Maharashtra",
"917575", "Sohagpur\,\ Madhya\ Pradesh",
"9174800", "Goharganj\,\ Madhya\ Pradesh",
"9161853", "Bikramganj\,\ Bihar",
"9174857", "Udaipura\,\ Madhya\ Pradesh",
"9171493", "Tamia\,\ Madhya\ Pradesh",
"9176265", "Vijayraghogarh\,\ Madhya\ Pradesh",
"911576", "Dantaramgarh\/Shyamji\,\ Rajasthan",
"9164342", "Dumka\,\ Bihar",
"917291", "Manawar\,\ Madhya\ Pradesh",
"9187595", "Outsarangapalle\,\ Andhra\ Pradesh",
"917803", "Majholi\,\ Madhya\ Pradesh",
"9174662", "Bonli\,\ Rajasthan",
"918524", "Srisailam\,\ Andhra\ Pradesh",
"913674", "Hojai\,\ Assam",
"9165844", "Bishrampur\,\ Bihar",
"9174689", "Khandar\,\ Rajasthan",
"918355", "Bableshwar\,\ Karnataka",
"9175952", "Nateran\,\ Madhya\ Pradesh",
"914896", "Kavaratti\,\ Lakshadweep",
"9167357", "Telkoi\,\ Odisha",
"91733", "Khandwa\,\ Madhya\ Pradesh",
"9174627", "Sawaimadhopur\,\ Rajasthan",
"91798", "Ahmedabad\ Local\,\ Gujarat",
"9165266", "Lohardaga\,\ Bihar",
"918548", "Shadnagar\,\ Andhra\ Pradesh",
"9162272", "Mahua\,\ Bihar",
"912141", "Alibagh\,\ Maharashtra",
"9165853", "Ghatsila\,\ Bihar",
"9174572", "Mangrol\,\ Rajasthan",
"912997", "Jaisalmer\/Mohargarh\,\ Rajasthan",
"912663", "Dabhoi\,\ Gujarat",
"915681", "Bidhuna\,\ Uttar\ Pradesh",
"9168183", "Buguda\,\ Odisha",
"9167943", "Rairangpur\,\ Odisha",
"9161844", "Sasaram\,\ Bihar",
"9177052", "Kurud\,\ Madhya\ Pradesh",
"915341", "Kunda\,\ Uttar\ Pradesh",
"918780", "Karimnagar\,\ Andhra\ Pradesh",
"9181529", "Kolar\,\ Karnatak",
"916633", "Sambalpur\,\ Odisha",
"918532", "Raichur\,\ Karnataka",
"91151", "Bikaner\,\ Rajasthan",
"91484", "Ernakulam\,\ Kerala",
"9165585", "Dumri\(Isribazar\)\,\ Bihar",
"9173208", "Pandhana\,\ Madhya\ Pradesh",
"9168412", "Boudh\,\ Odisha",
"918339", "Ainapur\,\ Karnataka",
"9164222", "Godda\,\ Bihar",
"918570", "Kuppam\,\ Andhra\ Pradesh",
"914998", "Uppala\,\ Kerala",
"911464", "Rajgarh\,\ Rajasthan",
"9165637", "Bhawanathpur\,\ Bihar",
"9174603", "Sahabad\,\ Rajasthan",
"917762", "Raigarh\,\ Madhya\ Pradesh",
"9163426", "H\.Kharagpur\,\ Bihar",
"9171626", "Chhindwara\,\ Madhya\ Pradesh",
"9168665", "Umerkote\,\ Odisha",
"9175263", "Ghatigaon\,\ Madhya\ Pradesh",
"912465", "Billoli\,\ Maharashtra",
"9171825", "Gondia\,\ Maharashtra",
"9168484", "Kotagarh\,\ Odisha",
"9165496", "Bermo\,\ Bihar",
"9181764", "Cannarayapatna\,\ Karnataka",
"9166826", "Attabira\,\ Odisha",
"9167564", "Balugaon\,\ Odisha",
"914922", "Alathur\,\ Kerala",
"9171562", "Talegaokarangal\,\ Maharashtra",
"912373", "Mahaswad\,\ Maharashtra",
"911964", "Kalakot\,\ Jammu\ And\ Kashmir",
"91372", "Lungleh\,\ Mizoram",
"913871", "Mao\/Korang\,\ Manipur",
"911251", "Jhajjar\,\ Haryana",
"9164294", "Kahalgaon\,\ Bihar",
"9161536", "Maharajganj\,\ Bihar",
"913010", "Jaisalmer\/Shahgarh\,\ Rajasthan",
"9176535", "Bandhavgarh\,\ Madhya\ Pradesh",
"9161887", "Rohtas\,\ Bihar",
"9166557", "Titlagarh\,\ Odisha",
"9167696", "Kamakhyanagar\,\ Odisha",
"9171167", "Umrer\,\ Maharashtra",
"913799", "Tuting\,\ Arunachal\ Pradesh",
"9172865", "Khetia\,\ Madhya\ Pradesh",
"912965", "Kushalgarh\,\ Rajasthan",
"9165506", "Hunterganj\,\ Bihar",
"9184535", "Medak\,\ Andhra\ Pradesh",
"912139", "Pirangut\,\ Maharashtra",
"917542", "Guna\,\ Madhya\ Pradesh",
"917689", "Badamalhera\,\ Madhya\ Pradesh",
"911477", "Nimbahera\,\ Rajasthan",
"918396", "Siruguppa\,\ Karnataka",
"917326", "Baldi\,\ Madhya\ Pradesh",
"9174555", "Digod\/Sultanpur\,\ Rajasthan",
"912324", "Hatkangale\/Ichalkaranji\,\ Maharashtra",
"9173234", "Punasa\,\ Madhya\ Pradesh",
"9165316", "Mandar\,\ Bihar",
"9173954", "Sondhwa\,\ Madhya\ Pradesh",
"9168447", "Kantamal\,\ Odisha",
"915548", "Khalilabad\/Mehdawal\,\ Uttar\ Pradesh",
"912555", "Satana\,\ Maharashtra",
"9177075", "Bagbahera\,\ Madhya\ Pradesh",
"918681", "Chandoor\,\ Andhra\ Pradesh",
"9166214", "Hemgiri\,\ Odisha",
"9165277", "Kolebira\,\ Bihar",
"9181520", "Kolar\,\ Karnatak",
"913656", "Mawkyrwat\,\ Meghalaya",
"9164537", "Araria\,\ Bihar",
"9171533", "Hinganghat\,\ Maharashtra",};

    sub new {
      my $class = shift;
      my $number = shift;
      $number =~ s/(^\+91|\D)//g;
      my $self = bless({ number => $number, formatters => $formatters, validators => $validators, areanames => \%areanames}, $class);
      return $self if ($self->is_valid());
      $number =~ s/^(?:0)//;
      $self = bless({ number => $number, formatters => $formatters, validators => $validators, areanames => \%areanames}, $class);
      return $self->is_valid() ? $self : undef;
    }
1;